% Auto-generated chapter 23 for bukhari
% Hadiths in this chapter: 148

\hadithdefcmd{bukhari}{1237}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا وَاصِلٌ الأَحْدَبُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَانِي آتٍ مِنْ رَبِّي فَأَخْبَرَنِي ـ أَوْ قَالَ بَشَّرَنِي ـ أَنَّهُ مَنْ مَاتَ مِنْ أُمَّتِي لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏"‏‏.‏ قُلْتُ وَإِنْ زَنَى وَإِنْ سَرَقَ قَالَ ‏"‏ وَإِنْ زَنَى وَإِنْ سَرَقَ ‏"‏‏.‏\hadithno{1237}\hadithtrans{Narrated Abu Dhar:Allah's Messenger (ﷺ) said, "Someone came to me from my Lord and gave me the news (or good tidings) that if any of my followers dies worshipping none (in any way) along with Allah, he will enter Paradise." I asked, "Even if he committed illegal sexual intercourse (adultery) and theft?" He replied, "Even if he committed illegal sexual intercourse (adultery) and theft}}
\hadithdefcmd{bukhari}{1238}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا شَقِيقٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ مَاتَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ النَّارَ ‏"‏‏.‏ وَقُلْتُ أَنَا مَنْ مَاتَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ‏.‏\hadithno{1238}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "Anyone who dies worshipping others along with Allah will definitely enter the Fire." I said, "Anyone who dies worshipping none along with Allah will definitely enter Paradise}}
\hadithdefcmd{bukhari}{1239}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَشْعَثِ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم بِسَبْعٍ، وَنَهَانَا عَنْ سَبْعٍ أَمَرَنَا بِاتِّبَاعِ الْجَنَائِزِ، وَعِيَادَةِ الْمَرِيضِ، وَإِجَابَةِ الدَّاعِي، وَنَصْرِ الْمَظْلُومِ، وَإِبْرَارِ الْقَسَمِ، وَرَدِّ السَّلاَمِ، وَتَشْمِيتِ الْعَاطِسِ‏.‏ وَنَهَانَا عَنْ آنِيَةِ الْفِضَّةِ، وَخَاتَمِ الذَّهَبِ، وَالْحَرِيرِ، وَالدِّيبَاجِ، وَالْقَسِّيِّ، وَالإِسْتَبْرَقِ‏.‏\hadithno{1239}\hadithtrans{Narrated Al-Bara' bin `Azib:Allah's Messenger (ﷺ) ordered us to do seven things and forbade us to do other seven. He ordered us: to follow the funeral procession. to visit the sick, to accept invitations, to help the oppressed, to fulfill the oaths, to return the greeting and to reply to the sneezer: (saying, "May Allah be merciful on you," provided the sneezer says, "All the praises are for Allah,"). He forbade us to use silver utensils and dishes and to wear golden rings, silk (clothes), Dibaj (pure silk cloth), Qassi and Istabraq (two kinds of silk cloths)}}
\hadithdefcmd{bukhari}{1240}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، عَنِ الأَوْزَاعِيِّ، قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ حَقُّ الْمُسْلِمِ عَلَى الْمُسْلِمِ خَمْسٌ رَدُّ السَّلاَمِ، وَعِيَادَةُ الْمَرِيضِ، وَاتِّبَاعُ الْجَنَائِزِ، وَإِجَابَةُ الدَّعْوَةِ، وَتَشْمِيتُ الْعَاطِسِ ‏"‏‏.‏ تَابَعَهُ عَبْدُ الرَّزَّاقِ قَالَ أَخْبَرَنَا مَعْمَرٌ‏.‏ وَرَوَاهُ سَلاَمَةُ عَنْ عُقَيْلٍ‏.‏\hadithno{1240}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "The rights of a Muslim on the Muslims are five: to respond to the salaam, visiting the sick, to follow the funeral processions, to accept an invitation, and to reply to those who sneeze. (see Hadith)}}
\hadithdefcmd{bukhari}{1242}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنِي مَعْمَرٌ، وَيُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ قَالَتْ أَقْبَلَ أَبُو بَكْرٍ ـ رضى الله عنه ـ عَلَى فَرَسِهِ مِنْ مَسْكَنِهِ بِالسُّنْحِ حَتَّى نَزَلَ، فَدَخَلَ الْمَسْجِدَ، فَلَمْ يُكَلِّمِ النَّاسَ، حَتَّى نَزَلَ فَدَخَلَ عَلَى عَائِشَةَ ـ رضى الله عنها ـ فَتَيَمَّمَ النَّبِيَّ صلى الله عليه وسلم وَهُوَ مُسَجًّى بِبُرْدِ حِبَرَةٍ، فَكَشَفَ عَنْ وَجْهِهِ، ثُمَّ أَكَبَّ عَلَيْهِ فَقَبَّلَهُ ثُمَّ بَكَى فَقَالَ بِأَبِي أَنْتَ يَا نَبِيَّ اللَّهِ، لاَ يَجْمَعُ اللَّهُ عَلَيْكَ مَوْتَتَيْنِ، أَمَّا الْمَوْتَةُ الَّتِي كُتِبَتْ عَلَيْكَ فَقَدْ مُتَّهَا‏.‏ قَالَ أَبُو سَلَمَةَ فَأَخْبَرَنِي ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ خَرَجَ وَعُمَرُ ـ رضى الله عنه ـ يُكَلِّمُ النَّاسَ‏.‏ فَقَالَ اجْلِسْ‏.‏ فَأَبَى‏.‏ فَقَالَ اجْلِسْ‏.‏ فَأَبَى، فَتَشَهَّدَ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَمَالَ إِلَيْهِ النَّاسُ، وَتَرَكُوا عُمَرَ فَقَالَ أَمَّا بَعْدُ، فَمَنْ كَانَ مِنْكُمْ يَعْبُدُ مُحَمَّدًا صلى الله عليه وسلم فَإِنَّ مُحَمَّدًا صلى الله عليه وسلم قَدْ مَاتَ، وَمَنْ كَانَ يَعْبُدُ اللَّهَ فَإِنَّ اللَّهَ حَىٌّ لاَ يَمُوتُ، قَالَ اللَّهُ تَعَالَى ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ‏\}‏ إِلَى ‏\{‏الشَّاكِرِينَ‏\}‏ وَاللَّهِ لَكَأَنَّ النَّاسَ لَمْ يَكُونُوا يَعْلَمُونَ أَنَّ اللَّهَ أَنْزَلَ الآيَةَ حَتَّى تَلاَهَا أَبُو بَكْرٍ ـ رضى الله عنه ـ فَتَلَقَّاهَا مِنْهُ النَّاسُ، فَمَا يُسْمَعُ بَشَرٌ إِلاَّ يَتْلُوهَا‏.‏\hadithno{1242}\hadithtrans{Narrated `Aisha:Abu Bakr came riding his horse from his dwelling place in As-Sunh. He got down from it, entered the Mosque and did not speak with anybody till he came to me and went directly to the Prophet, who was covered with a marked blanket. Abu Bakr uncovered his face. He knelt down and kissed him and then started weeping and said, "My father and my mother be sacrificed for you, O Allah's Prophet! Allah will not combine two deaths on you. You have died the death which was written for you." Narrated Abu Salama from Ibn `Abbas : Abu Bakr came out and `Umar , was addressing the people, and Abu Bakr told him to sit down but `Umar refused. Abu Bakr again told him to sit down but `Umar again refused. Then Abu Bakr recited the Tashah-hud (i.e. none has the right to be worshipped but Allah and Muhammad is Allah's Messenger (ﷺ)) and the people attended to Abu Bakr and left `Umar. Abu Bakr said, "Amma ba'du, whoever amongst you worshipped Muhammad, then Muhammad is dead, but whoever worshipped Allah, Allah is alive and will never die. Allah said: 'Muhammad is no more than an Apostle and indeed (many) Apostles have passed away before him ..(up to the) grateful.' " (3.144) (The narrator added, "By Allah, it was as if the people never knew that Allah had revealed this verse before till Abu Bakr recited it and then whoever heard it, started reciting it)}}
\hadithdefcmd{bukhari}{1243}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، أَنَّ أُمَّ الْعَلاَءِ ـ امْرَأَةً مِنَ الأَنْصَارِ ـ بَايَعَتِ النَّبِيَّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّهُ اقْتُسِمَ الْمُهَاجِرُونَ قُرْعَةً فَطَارَ لَنَا عُثْمَانُ بْنُ مَظْعُونٍ، فَأَنْزَلْنَاهُ فِي أَبْيَاتِنَا، فَوَجِعَ وَجَعَهُ الَّذِي تُوُفِّيَ فِيهِ، فَلَمَّا تُوُفِّيَ وَغُسِّلَ وَكُفِّنَ فِي أَثْوَابِهِ، دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ رَحْمَةُ اللَّهِ عَلَيْكَ أَبَا السَّائِبِ، فَشَهَادَتِي عَلَيْكَ لَقَدْ أَكْرَمَكَ اللَّهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَمَا يُدْرِيكِ أَنَّ اللَّهَ قَدْ أَكْرَمَهُ ‏"‏‏.‏ فَقُلْتُ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ فَمَنْ يُكْرِمُهُ اللَّهُ فَقَالَ ‏"‏ أَمَّا هُوَ فَقَدْ جَاءَهُ الْيَقِينُ، وَاللَّهِ إِنِّي لأَرْجُو لَهُ الْخَيْرَ، وَاللَّهِ مَا أَدْرِي ـ وَأَنَا رَسُولُ اللَّهِ ـ مَا يُفْعَلُ بِي ‏"‏‏.‏ قَالَتْ فَوَاللَّهِ لاَ أُزَكِّي أَحَدًا بَعْدَهُ أَبَدًا‏.‏ حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا اللَّيْثُ، مِثْلَهُ‏.‏ وَقَالَ نَافِعُ بْنُ يَزِيدَ عَنْ عُقَيْلٍ، مَا يُفْعَلُ بِهِ وَتَابَعَهُ شُعَيْبٌ وَعَمْرُو بْنُ دِينَارٍ وَمَعْمَرٌ‏.‏\hadithno{1243}\hadithtrans{Narrated Kharija bin Zaid bin Thabit:Um Al-`Ala', an Ansari woman who gave the pledge of allegiance to the Prophet (ﷺ) said to me, "The emigrants were distributed amongst us by drawing lots and we got in our share `Uthman bin Maz'un. We made him stay with us in our house. Then he suffered from a disease which proved fatal when he died and was given a bath and was shrouded in his clothes, Allah's Messenger (ﷺ) came I said, 'May Allah be merciful to you, O Abu As-Sa'ib! I testify that Allah has honored you'. The Prophet (ﷺ) said, 'How do you know that Allah has honored him?' I replied, 'O Allah's Messenger (ﷺ)! Let my father be sacrificed for you! On whom else shall Allah bestow His honor?' The Prophet (ﷺ) said, 'No doubt, death came to him. By Allah, I too wish him good, but by Allah, I do not know what Allah will do with me though I am Allah's Messenger (ﷺ). ' By Allah, I never attested the piety of anyone after that." Al-Laith also narrated as above}}
\hadithdefcmd{bukhari}{1244}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ لَمَّا قُتِلَ أَبِي جَعَلْتُ أَكْشِفُ الثَّوْبَ عَنْ وَجْهِهِ أَبْكِي، وَيَنْهَوْنِي عَنْهُ وَالنَّبِيُّ صلى الله عليه وسلم لاَ يَنْهَانِي، فَجَعَلَتْ عَمَّتِي فَاطِمَةُ تَبْكِي، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَبْكِينَ أَوْ لاَ تَبْكِينَ، مَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا حَتَّى رَفَعْتُمُوهُ ‏"‏‏.‏ تَابَعَهُ ابْنُ جُرَيْجٍ أَخْبَرَنِي ابْنُ الْمُنْكَدِرِ سَمِعَ جَابِرًا ـ رضى الله عنه ـ‏.‏\hadithno{1244}\hadithtrans{Narrated Jabir bin `Abdullah:When my father was martyred, I lifted the sheet from his face and wept and the people forbade me to do so but the Prophet (ﷺ) did not forbid me. Then my aunt Fatima began weeping and the Prophet (ﷺ) said, "It is all the same whether you weep or not. The angels were shading him continuously with their wings till you shifted him (from the field)}}
\hadithdefcmd{bukhari}{1245}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى النَّجَاشِيَّ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ، خَرَجَ إِلَى الْمُصَلَّى، فَصَفَّ بِهِمْ وَكَبَّرَ أَرْبَعًا‏.‏\hadithno{1245}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) informed (the people) about the death of An-Najashi on the very day he died. He went towards the Musalla (praying place) and the people stood behind him in rows. He said four Takbirs (i.e. offered the Funeral prayer)}}
\hadithdefcmd{bukhari}{1246}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَخَذَ الرَّايَةَ زَيْدٌ فَأُصِيبَ، ثُمَّ أَخَذَهَا جَعْفَرٌ فَأُصِيبَ، ثُمَّ أَخَذَهَا عَبْدُ اللَّهِ بْنُ رَوَاحَةَ فَأُصِيبَ ـ وَإِنَّ عَيْنَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَتَذْرِفَانِ ـ ثُمَّ أَخَذَهَا خَالِدُ بْنُ الْوَلِيدِ مِنْ غَيْرِ إِمْرَةٍ فَفُتِحَ لَهُ ‏"‏\hadithno{1246}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Zaid took over the flag and was martyred. Then it was taken by Jafar who was martyred as well. Then `Abdullah bin Rawaha took the flag but he too was martyred and at that time the eyes of Allah's Messenger (ﷺ) were full of tears. Then Khalid bin Al-Walid took the flag without being nominated as a chief (before hand) and was blessed with victory}}
\hadithdefcmd{bukhari}{1247}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ مَاتَ إِنْسَانٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُهُ فَمَاتَ بِاللَّيْلِ فَدَفَنُوهُ لَيْلاً، فَلَمَّا أَصْبَحَ أَخْبَرُوهُ فَقَالَ ‏ "‏ مَا مَنَعَكُمْ أَنْ تُعْلِمُونِي ‏"‏‏.‏ قَالُوا كَانَ اللَّيْلُ فَكَرِهْنَا ـ وَكَانَتْ ظُلْمَةٌ ـ أَنْ نَشُقَّ عَلَيْكَ‏.‏ فَأَتَى قَبْرَهُ فَصَلَّى عَلَيْهِ‏.‏\hadithno{1247}\hadithtrans{Narrated Ibn `Abbas.:A person died and Allah's Messenger (ﷺ) used to visit him. He died at night and (the people) buried him at night. In the morning they informed the Prophet (about his death). He said, "What prevented you from informing me?" They replied, "It was night and it was a dark night and so we disliked to trouble you." The Prophet (ﷺ) went to his grave and offered the (funeral) prayer}}
\hadithdefcmd{bukhari}{1248}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا مِنَ النَّاسِ مِنْ مُسْلِمٍ يُتَوَفَّى لَهُ ثَلاَثٌ لَمْ يَبْلُغُوا الْحِنْثَ، إِلاَّ أَدْخَلَهُ اللَّهُ الْجَنَّةَ بِفَضْلِ رَحْمَتِهِ إِيَّاهُمْ ‏"‏‏.‏\hadithno{1248}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "A Muslim whose three children die before the age of puberty will be granted Paradise by Allah due to his mercy for them}}
\hadithdefcmd{bukhari}{1250}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَصْبَهَانِيِّ، عَنْ ذَكْوَانَ، عَنْ أَبِي سَعِيدٍ، رضى الله عنه أَنَّ النِّسَاءَ، قُلْنَ لِلنَّبِيِّ صلى الله عليه وسلم اجْعَلْ لَنَا يَوْمًا‏.‏ فَوَعَظَهُنَّ، وَقَالَ ‏"‏ أَيُّمَا امْرَأَةٍ مَاتَ لَهَا ثَلاَثَةٌ مِنَ الْوَلَدِ كَانُوا حِجَابًا مِنَ النَّارِ ‏"‏‏.‏ قَالَتِ امْرَأَةٌ وَاثْنَانِ‏.‏ قَالَ ‏"‏ وَاثْنَانِ ‏"‏‏.‏ وَقَالَ شَرِيكٌ عَنِ ابْنِ الأَصْبَهَانِيِّ، حَدَّثَنِي أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ، وَأَبِي، هُرَيْرَةَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ أَبُو هُرَيْرَةَ ‏"‏ لَمْ يَبْلُغُوا الْحِنْثَ ‏"‏‏.‏\hadithno{1250}\hadithtrans{Narrated Abu Sa`id:The women requested the Prophet, "Please fix a day for us." So the Prophet (ﷺ) preached to them and said, "A woman whose three children died would be screened from the Hell Fire by them," Hearing that, a woman asked, "If two died?" The Prophet (ﷺ) replied, "Even two (would screen her from the (Hell) Fire. " And Abu Huraira added, "Those children should be below the age of puberty}}
\hadithdefcmd{bukhari}{1251}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَمُوتُ لِمُسْلِمٍ ثَلاَثَةٌ مِنَ الْوَلَدِ، فَيَلِجَ النَّارَ إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ ‏\{‏وَإِنْ مِنْكُمْ إِلاَّ وَارِدُهَا‏\}‏‏.‏\hadithno{1251}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "No Muslim whose three children died will go to the Fire except for Allah's oath (i.e. everyone has to pass over the bridge above the lake of fire)}}
\hadithdefcmd{bukhari}{1252}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِامْرَأَةٍ عِنْدَ قَبْرٍ وَهِيَ تَبْكِي فَقَالَ ‏ "‏ اتَّقِي اللَّهَ وَاصْبِرِي ‏"‏‏.‏\hadithno{1252}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) passed by a woman who was sitting and weeping beside a grave and said to her, "Fear Allah and be patient}}
\hadithdefcmd{bukhari}{1253}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ الأَنْصَارِيَّةِ ـ رضى الله عنها ـ قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَتِ ابْنَتُهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مَنْ ذَلِكَ إِنْ رَأَيْتُنَّ ذَلِكَ بِمَاءٍ وَسِدْرٍ، وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ، فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَعْطَانَا حِقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏‏.‏ تَعْنِي إِزَارَهُ‏.‏\hadithno{1253}\hadithtrans{Narrated Um 'Atiyya al-Ansariya:Allah's Messenger (ﷺ) came to us when his daughter died and said, "Wash her thrice or five times or more, if you see it necessary, with water and Sidr and then apply camphor or some camphor at the end; and when you finish, notify me." So when we finished it, we informed him and he gave us his waist-sheet and told us to shroud the dead body in it}}
\hadithdefcmd{bukhari}{1254}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَغْسِلُ ابْنَتَهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ بِمَاءٍ وَسِدْرٍ، وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا، فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ، فَأَلْقَى إِلَيْنَا حِقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏‏.‏ فَقَالَ أَيُّوبُ وَحَدَّثَتْنِي حَفْصَةُ بِمِثْلِ حَدِيثِ مُحَمَّدٍ وَكَانَ فِي حَدِيثِ حَفْصَةَ ‏"‏ اغْسِلْنَهَا وِتْرًا ‏"‏‏.‏ وَكَانَ فِيهِ ‏:‏ ‏"‏ ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا ‏"‏‏.‏ وَكَانَ فِيهِ أَنَّهُ قَالَ ‏"‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏‏.‏ وَكَانَ فِيهِ أَنَّ أُمَّ عَطِيَّةَ قَالَتْ وَمَشَطْنَاهَا ثَلاَثَةَ قُرُونٍ‏.‏\hadithno{1254}\hadithtrans{Narrated Um 'Atiyya:Allah's Messenger (ﷺ) came to us and we were giving a bath to his (dead) daughter and said, "Wash her three, five or more times with water and Sidr and sprinkle camphor on her at the end; and when you finish, notify me." So when we finished, we informed him and he gave us his waist-sheet and told us to shroud her in it. Aiyub said that Hafsa narrated to him a narration similar to that of Muhammad in which it was said that the bath was to be given for an odd number of times, and the numbers 3, 5 or 7 were mentioned. It was also said that they were to start with the right side and with the parts which were washed in ablution, and that Um 'Atiyya also mentioned, "We combed her hair and divided them in three braids}}
\hadithdefcmd{bukhari}{1255}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا خَالِدٌ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي غَسْلِ ابْنَتِهِ ‏ "‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏‏.‏\hadithno{1255}\hadithtrans{Narrated Um 'Atiyya:Allah's Messenger (ﷺ) , concerning his (dead) daughter's bath, said, "Start with the right side, and the parts which are washed in ablution}}
\hadithdefcmd{bukhari}{1256}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا غَسَّلْنَا بِنْتَ النَّبِيِّ صلى الله عليه وسلم قَالَ لَنَا وَنَحْنُ نَغْسِلُهَا ‏ "‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ ‏"‏‏.‏\hadithno{1256}\hadithtrans{Narrated Um 'Atiyya:When we washed the deceased daughter of the Prophet, he said to us, while we were washing her, "Start the bath from the right side and from the parts which are washed in ablution}}
\hadithdefcmd{bukhari}{1257}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ حَمَّادٍ، أَخْبَرَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ تُوُفِّيَتْ بِنْتُ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَنَا ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ، فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَنَزَعَ مِنْ حِقْوِهِ إِزَارَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏‏.‏\hadithno{1257}\hadithtrans{Narrated Um 'Atiyya:The daughter of the Prophet (ﷺ) expired, and he said to us, "Wash her three or five times, or more if you see it necessary, and when you finish, notify me." So, (when we finished) we informed him and he unfastened his waist-sheet and told us to shroud her in it}}
\hadithdefcmd{bukhari}{1259}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ تُوُفِّيَتْ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم فَخَرَجَ، فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ بِمَاءٍ وَسِدْرٍ، وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ، فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏‏.‏ قَالَتْ فَلَمَّا فَرَغْنَا آذَنَّاهُ، فَأَلْقَى إِلَيْنَا حِقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏‏.‏ وَعَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنهما ـ بِنَحْوِهِ وَقَالَتْ إِنَّهُ قَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ ‏"‏‏.‏ قَالَتْ حَفْصَةُ قَالَتْ أُمُّ عَطِيَّةَ ـ رضى الله عنها ـ وَجَعَلْنَا رَأْسَهَا ثَلاَثَةَ قُرُونٍ‏.‏\hadithno{1259}\hadithtrans{Narrated Muhammad:Um 'Atiyya said, "One of the daughters of the Prophet (ﷺ) died and he came out and said, 'Wash her three or five times or more, if you think it necessary, with water and Sidr, and last of all put camphor (or some camphor) and when you finish, inform me.' " Um Atiyya added, "When we finished we informed him and he gave us his waist-sheet and said, 'Shroud her in it.' " And Um 'Atiyya (in another narration) added, "The Prophet (ﷺ) said, 'Wash her three, five or seven times or more, if you think it necessary.' " Hafsa said that Um 'Atiyya had also said, "We entwined her hair into three braids}}
\hadithdefcmd{bukhari}{1260}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَيُّوبُ وَسَمِعْتُ حَفْصَةَ بِنْتَ سِيرِينَ، قَالَتْ حَدَّثَتْنَا أُمُّ عَطِيَّةَ ـ رضى الله عنها ـ أَنَّهُنَّ جَعَلْنَ رَأْسَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَلاَثَةَ قُرُونٍ نَقَضْنَهُ ثُمَّ غَسَلْنَهُ ثُمَّ جَعَلْنَهُ ثَلاَثَةَ قُرُونٍ‏.‏\hadithno{1260}\hadithtrans{Narrated Hafsa bint Seereen:Um 'Atiyya said that they had entwined the hair of the daughter of Allah's Messenger (ﷺ) in three braids. They first undid her hair, washed and then entwined it in three braids}}
\hadithdefcmd{bukhari}{1261}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَنَّ أَيُّوبَ، أَخْبَرَهُ قَالَ سَمِعْتُ ابْنَ سِيرِينَ، يَقُولُ جَاءَتْ أُمُّ عَطِيَّةَ ـ رضى الله عنها ـ امْرَأَةٌ مِنَ الأَنْصَارِ مِنَ اللاَّتِي بَايَعْنَ، قَدِمَتِ الْبِصْرَةَ، تُبَادِرُ ابْنًا لَهَا فَلَمْ تُدْرِكْهُ ـ فَحَدَّثَتْنَا قَالَتْ دَخَلَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ نَغْسِلُ ابْنَتَهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ ذَلِكَ بِمَاءٍ وَسِدْرٍ، وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا، فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏‏.‏ قَالَتْ فَلَمَّا فَرَغْنَا أَلْقَى إِلَيْنَا حَقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏‏.‏ وَلَمْ يَزِدْ عَلَى ذَلِكَ، وَلاَ أَدْرِي أَىُّ بَنَاتِهِ‏.‏ وَزَعَمَ أَنَّ الإِشْعَارَ الْفُفْنَهَا فِيهِ، وَكَذَلِكَ كَانَ ابْنُ سِيرِينَ يَأْمُرُ بِالْمَرْأَةِ أَنْ تُشْعَرَ وَلاَ تُؤْزَرَ‏.‏\hadithno{1261}\hadithtrans{Narrated Ibn Seereen:Um 'Atiyya (an Ansari woman who gave the pledge of allegiance to the Prophet (ﷺ) ) came to Basra to visit her son, but she could not find him. She narrated to us, "The Prophet (ﷺ) came to us while we were giving bath to his (dead) daughter, he said: 'Wash her three times, five times or more, if you think it necessary, with water and Sidr, and last of all put camphor, and when you finish, notify me.' " Um 'Atiyya added, "After finishing, we informed him and he gave us his waist sheet and told us to shroud her in it and did not say more than that}}
\hadithdefcmd{bukhari}{1262}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أُمِّ الْهُذَيْلِ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ ضَفَرْنَا شَعَرَ بِنْتِ النَّبِيِّ صلى الله عليه وسلم‏.‏ تَعْنِي ثَلاَثَةَ قُرُونٍ‏.‏ وَقَالَ وَكِيعٌ قَالَ سُفْيَانُ نَاصِيَتَهَا وَقَرْنَيْهَا‏.‏\hadithno{1262}\hadithtrans{Narrated Um 'Atiyya:We entwined the hair of the dead daughter of the Prophet (ﷺ) into three braids. Waki said that Sufyan said, "One braid was entwined in front and the other two were entwined on the sides of the head}}
\hadithdefcmd{bukhari}{1263}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامِ بْنِ حَسَّانَ، قَالَ حَدَّثَتْنَا حَفْصَةُ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ تُوُفِّيَتْ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم فَأَتَانَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اغْسِلْنَهَا بِالسِّدْرِ وِتْرًا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ ذَلِكَ، وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ، فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ، فَأَلْقَى إِلَيْنَا حِقْوَهُ، فَضَفَرْنَا شَعَرَهَا ثَلاَثَةَ قُرُونٍ وَأَلْقَيْنَاهَا خَلْفَهَا‏.‏\hadithno{1263}\hadithtrans{Narrated Um 'Atiyya:One of the daughters of the Prophet (ﷺ) expired and he came to us and said, "Wash her with Sidr (water) for odd number of times, i.e. three, five or more, if you think it necessary, and in the last, put camphor or (some camphor on her), and when you finish, notify me." So when we finished we informed him. He gave his waist-sheet to us (to shroud her). We entwined the hair (of the deceased girl) in three braids and made them fall at her back}}
\hadithdefcmd{bukhari}{1264}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ يَمَانِيَةٍ بِيضٍ سَحُولِيَّةٍ مِنْ كُرْسُفٍ، لَيْسَ فِيهِنَّ قَمِيصٌ وَلاَ عِمَامَةٌ‏.‏\hadithno{1264}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) was shrouded in three Yemenite white Suhuliya (pieces of cloth) of cotton, and in them there was neither a shirt nor a turban}}
\hadithdefcmd{bukhari}{1265}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهم ـ قَالَ بَيْنَمَا رَجُلٌ وَاقِفٌ بِعَرَفَةَ إِذْ وَقَعَ عَنْ رَاحِلَتِهِ فَوَقَصَتْهُ ـ أَوْ قَالَ فَأَوْقَصَتْهُ ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ، وَكَفِّنُوهُ فِي ثَوْبَيْنِ، وَلاَ تُحَنِّطُوهُ وَلاَ تُخَمِّرُوا رَأْسَهُ، فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏‏.‏\hadithno{1265}\hadithtrans{Narrated Ibn `Abbas:While a man was riding (his Mount) in `Arafat, he fell down from it (his Mount) and broke his neck (and died). The Prophet (ﷺ) said, "Wash him with water and Sidr and shroud him in two pieces of cloth, and neither perfume him, nor cover his head, for he will be resurrected on the Day of Resurrection saying, 'Labbaik,' (i.e. like a pilgrim)}}
\hadithdefcmd{bukhari}{1266}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بَيْنَمَا رَجُلٌ وَاقِفٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَرَفَةَ إِذْ وَقَعَ مِنْ رَاحِلَتِهِ فَأَقْصَعَتْهُ ـ أَوْ قَالَ فَأَقْعَصَتْهُ ـ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ، وَكَفِّنُوهُ فِي ثَوْبَيْنِ، وَلاَ تُحَنِّطُوهُ وَلاَ تُخَمِّرُوا رَأْسَهُ، فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏‏.‏\hadithno{1266}\hadithtrans{Narrated Ibn `Abbas:While a man was at `Arafat (for Hajj) with Allah's Messenger (ﷺ), he fell down from his Mount and broke his neck (and died). So Allah's Messenger (ﷺ) said, "Wash him with water and Sidr and shroud him in two pieces of cloth and neither perfume him nor cover his head, for Allah will resurrect him on the Day of Resurrection and he will be saying 'Labbaik}}
\hadithdefcmd{bukhari}{1267}{حَدَّثَنَا أَبُو النُّعْمَانِ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهم ـ أَنَّ رَجُلاً، وَقَصَهُ بَعِيرُهُ، وَنَحْنُ مَعَ النَّبِيِّ صلى الله عليه وسلم وَهْوَ مُحْرِمٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ، وَكَفِّنُوهُ فِي ثَوْبَيْنِ، وَلاَ تُمِسُّوهُ طِيبًا، وَلاَ تُخَمِّرُوا رَأْسَهُ، فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ مُلَبِّدًا ‏"‏‏.‏\hadithno{1267}\hadithtrans{Narrated Ibn `Abbas:A man was killed by his camel while we were with the Prophet (ﷺ) and he was a Muhrim. So the Prophet (ﷺ) said, "Wash him with water and Sidr and shroud him in two pieces of cloth and neither perfume him nor cover his head, for Allah will resurrect him on the Day of Resurrection and he will be saying 'Labbaik}}
\hadithdefcmd{bukhari}{1268}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، وَأَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهم ـ قَالَ كَانَ رَجُلٌ وَاقِفٌ مَعَ النَّبِيِّ صلى الله عليه وسلم بِعَرَفَةَ فَوَقَعَ عَنْ رَاحِلَتِهِ ـ قَالَ أَيُّوبُ فَوَقَصَتْهُ، وَقَالَ عَمْرٌو فَأَقْصَعَتْهُ ـ فَمَاتَ فَقَالَ ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ، وَكَفِّنُوهُ فِي ثَوْبَيْنِ، وَلاَ تُحَنِّطُوهُ وَلاَ تُخَمِّرُوا رَأْسَهُ، فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ ـ قَالَ أَيُّوبُ يُلَبِّي، وَقَالَ عَمْرٌو ـ مُلَبِّيًا ‏"‏‏.‏\hadithno{1268}\hadithtrans{Narrated Ibn `Abbas:A man fell from his Mount and died while he was with the Prophet (ﷺ) at `Arafat. The Prophet (ﷺ) said, "Wash him with water and Sidr and shroud him in two pieces of cloth and neither perfume him nor cover his head, for he will be resurrected on the Day of Resurrection saying, 'Labbaik}}
\hadithdefcmd{bukhari}{1269}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عَبْدَ، اللَّهِ بْنَ أُبَىٍّ لَمَّا تُوُفِّيَ جَاءَ ابْنُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَعْطِنِي قَمِيصَكَ أُكَفِّنْهُ فِيهِ، وَصَلِّ عَلَيْهِ وَاسْتَغْفِرْ لَهُ، فَأَعْطَاهُ النَّبِيُّ صلى الله عليه وسلم قَمِيصَهُ فَقَالَ ‏"‏ آذِنِّي أُصَلِّي عَلَيْهِ ‏"‏‏.‏ فَآذَنَهُ، فَلَمَّا أَرَادَ أَنْ يُصَلِّيَ عَلَيْهِ جَذَبَهُ عُمَرُ ـ رضى الله عنه ـ فَقَالَ أَلَيْسَ اللَّهُ نَهَاكَ أَنْ تُصَلِّيَ عَلَى الْمُنَافِقِينَ فَقَالَ ‏"‏ أَنَا بَيْنَ خِيرَتَيْنِ قَالَ ‏\{‏اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ إِنْ تَسْتَغْفِرْ لَهُمْ سَبْعِينَ مَرَّةً فَلَنْ يَغْفِرَ اللَّهُ لَهُمْ‏\}‏ ‏"‏‏.‏ فَصَلَّى عَلَيْهِ فَنَزَلَتْ ‏\{‏وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا‏\}‏\hadithno{1269}\hadithtrans{Narrated Ibn `Umar:When `Abdullah bin Ubai (the chief of hypocrites) died, his son came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! Please give me your shirt to shroud him in it, offer his funeral prayer and ask for Allah's forgiveness for him." So Allah's Messenger (ﷺ) gave his shirt to him and said, "Inform me (When the funeral is ready) so that I may offer the funeral prayer." So, he informed him and when the Prophet intended to offer the funeral prayer, `Umar took hold of his hand and said, "Has Allah not forbidden you to offer the funeral prayer for the hypocrites? The Prophet (ﷺ) said, "I have been given the choice for Allah says: '(It does not avail) Whether you (O Muhammad) ask forgiveness for them (hypocrites), or do not ask for forgiveness for them. Even though you ask for their forgiveness seventy times, Allah will not forgive them. (9.80)" So the Prophet (ﷺ) offered the funeral prayer and on that the revelation came: "And never (O Muhammad) pray (funeral prayer) for any of them (i.e. hypocrites) that dies}}
\hadithdefcmd{bukhari}{1270}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، سَمِعَ جَابِرًا ـ رضى الله عنه ـ قَالَ أَتَى النَّبِيُّ صلى الله عليه وسلم عَبْدَ اللَّهِ بْنَ أُبَىٍّ بَعْدَ مَا دُفِنَ فَأَخْرَجَهُ، فَنَفَثَ فِيهِ مِنْ رِيقِهِ وَأَلْبَسَهُ قَمِيصَهُ‏.‏\hadithno{1270}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) came to (the grave of) `Abdullah bin Ubai after his body was buried. The body was brought out and then the Prophet (ﷺ) put his saliva over the body and clothed it in his shirt}}
\hadithdefcmd{bukhari}{1271}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كُفِّنَ النَّبِيُّ صلى الله عليه وسلم فِي ثَلاَثَةِ أَثْوَابِ سَحُولَ كُرْسُفٍ، لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ‏.‏\hadithno{1271}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) was shrouded in three pieces of cloth which were made of Suhul (a type of cotton), and neither a shirt nor a turban were used}}
\hadithdefcmd{bukhari}{1272}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ، لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ‏.‏\hadithno{1272}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) was shrouded in three pieces of cloth and neither a shirt nor a turban were used}}
\hadithdefcmd{bukhari}{1273}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سَحُولِيَّةٍ، لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ‏.‏\hadithno{1273}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) was shrouded in three pieces of cloth which were made of white Suhul and neither a shirt nor a turban were used}}
\hadithdefcmd{bukhari}{1274}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَكِّيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ سَعْدٍ، عَنْ أَبِيهِ، قَالَ أُتِيَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ ـ رضى الله عنه ـ يَوْمًا بِطَعَامِهِ فَقَالَ قُتِلَ مُصْعَبُ بْنُ عُمَيْرٍ ـ وَكَانَ خَيْرًا مِنِّي ـ فَلَمْ يُوجَدْ لَهُ مَا يُكَفَّنُ فِيهِ إِلاَّ بُرْدَةٌ، وَقُتِلَ حَمْزَةُ أَوْ رَجُلٌ آخَرُ خَيْرٌ مِنِّي فَلَمْ يُوجَدْ لَهُ مَا يُكَفَّنُ فِيهِ إِلاَّ بُرْدَةٌ، لَقَدْ خَشِيتُ أَنْ يَكُونَ قَدْ عُجِّلَتْ لَنَا طَيِّبَاتُنَا فِي حَيَاتِنَا الدُّنْيَا، ثُمَّ جَعَلَ يَبْكِي‏.‏\hadithno{1274}\hadithtrans{Narrated Sa`d from his father:Once the meal of `Abdur-Rahman bin `Auf was brought in front of him, and he said, "Mus`ab bin `Umair was martyred and he was better than I, and he had nothing except his Burd (a black square narrow dress) to be shrouded in. Hamza or another person was martyred and he was also better than I and he had nothing to be shrouded in except his Burd. No doubt, I fear that the rewards of my deeds might have been given early in this world." Then he started weeping}}
\hadithdefcmd{bukhari}{1275}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِيهِ، إِبْرَاهِيمَ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ ـ رضى الله عنه ـ أُتِيَ بِطَعَامٍ وَكَانَ صَائِمًا فَقَالَ قُتِلَ مُصْعَبُ بْنُ عُمَيْرٍ وَهُوَ خَيْرٌ مِنِّي، كُفِّنَ فِي بُرْدَةٍ، إِنْ غُطِّيَ رَأْسُهُ بَدَتْ رِجْلاَهُ، وَإِنْ غُطِّيَ رِجْلاَهُ بَدَا رَأْسُهُ ـ وَأُرَاهُ قَالَ ـ وَقُتِلَ حَمْزَةُ وَهُوَ خَيْرٌ مِنِّي، ثُمَّ بُسِطَ لَنَا مِنَ الدُّنْيَا مَا بُسِطَ ـ أَوْ قَالَ أُعْطِينَا مِنَ الدُّنْيَا مَا أُعْطِينَا ـ وَقَدْ خَشِينَا أَنْ تَكُونَ حَسَنَاتُنَا عُجِّلَتْ لَنَا، ثُمَّ جَعَلَ يَبْكِي حَتَّى تَرَكَ الطَّعَامَ‏.‏\hadithno{1275}\hadithtrans{Narrated Ibrahim:Once a meal was brought to `Abdur-Rahman bin `Auf and he was fasting. He said, "Mus`ab bin `Umair was martyred and he was better than I and was shrouded in his Burd and when his head was covered with it, his legs became bare, and when his legs were covered his head got uncovered. Hamza was martyred and was better than I. Now the worldly wealth have been bestowed upon us (or said a similar thing). No doubt, I fear that the rewards of my deeds might have been given earlier in this world." Then he started weeping and left his food}}
\hadithdefcmd{bukhari}{1276}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا شَقِيقٌ، حَدَّثَنَا خَبَّابٌ ـ رضى الله عنه ـ قَالَ هَاجَرْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم نَلْتَمِسُ وَجْهَ اللَّهِ، فَوَقَعَ أَجْرُنَا عَلَى اللَّهِ، فَمِنَّا مَنْ مَاتَ لَمْ يَأْكُلْ مِنْ أَجْرِهِ شَيْئًا مِنْهُمْ مُصْعَبُ بْنُ عُمَيْرٍ، وَمِنَّا مَنْ أَيْنَعَتْ لَهُ ثَمَرَتُهُ فَهُوَ يَهْدِبُهَا‏.‏ قُتِلَ يَوْمَ أُحُدٍ، فَلَمْ نَجِدْ مَا نُكَفِّنُهُ إِلاَّ بُرْدَةً إِذَا غَطَّيْنَا بِهَا رَأْسَهُ خَرَجَتْ رِجْلاَهُ، وَإِذَا غَطَّيْنَا رِجْلَيْهِ خَرَجَ رَأْسُهُ، فَأَمَرَنَا النَّبِيُّ صلى الله عليه وسلم أَنْ نُغَطِّيَ رَأْسَهُ، وَأَنْ نَجْعَلَ عَلَى رِجْلَيْهِ مِنَ الإِذْخِرِ‏.‏\hadithno{1276}\hadithtrans{Narrated Khabbab:We emigrated with the Prophet (ﷺ) in Allah's cause, and so our reward was then surely incumbent on Allah. Some of us died and they did not take anything from their rewards in this world, and amongst them was Mus`ab bin `Umair; and the others were those who got their rewards. Mus`ab bin `Umair was martyred on the day of the Battle of Uhud and we could get nothing except his Burd to shroud him in. And when we covered his head his feet became bare and vice versa. So the Prophet (ﷺ) ordered us to cover his head only and to put idhkhir (a kind of shrub) over his feet}}
\hadithdefcmd{bukhari}{1277}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ ـ رضى الله عنه ـ أَنَّ امْرَأَةً، جَاءَتِ النَّبِيَّ صلى الله عليه وسلم بِبُرْدَةٍ مَنْسُوجَةٍ فِيهَا حَاشِيَتُهَا ـ أَتَدْرُونَ مَا الْبُرْدَةُ قَالُوا الشَّمْلَةُ‏.‏ قَالَ نَعَمْ‏.‏ قَالَتْ نَسَجْتُهَا بِيَدِي، فَجِئْتُ لأَكْسُوَكَهَا‏.‏ فَأَخَذَهَا النَّبِيُّ صلى الله عليه وسلم مُحْتَاجًا إِلَيْهَا، فَخَرَجَ إِلَيْنَا وَإِنَّهَا إِزَارُهُ، فَحَسَّنَهَا فُلاَنٌ فَقَالَ اكْسُنِيهَا، مَا أَحْسَنَهَا‏.‏ قَالَ الْقَوْمُ مَا أَحْسَنْتَ، لَبِسَهَا النَّبِيُّ صلى الله عليه وسلم مُحْتَاجًا إِلَيْهَا، ثُمَّ سَأَلْتَهُ وَعَلِمْتَ أَنَّهُ لاَ يَرُدُّ‏.‏ قَالَ إِنِّي وَاللَّهِ مَا سَأَلْتُهُ لأَلْبَسَهَا إِنَّمَا سَأَلْتُهُ لِتَكُونَ كَفَنِي‏.‏ قَالَ سَهْلٌ فَكَانَتْ كَفَنَهُ‏.‏\hadithno{1277}\hadithtrans{Narrated Sahl:A woman brought a woven Burda (sheet) having edging (border) to the Prophet, Then Sahl asked them whether they knew what is Burda, they said that Burda is a cloak and Sahl confirmed their reply. Then the woman said, "I have woven it with my own hands and I have brought it so that you may wear it." The Prophet (ﷺ) accepted it, and at that time he was in need of it. So he came out wearing it as his waist-sheet. A man praised it and said, "Will you give it to me? How nice it is!" The other people said, "You have not done the right thing as the Prophet (ﷺ) is in need of it and you have asked for it when you know that he never turns down anybody's request." The man replied, "By Allah, I have not asked for it to wear it but to make it my shroud." Later it was his shroud}}
\hadithdefcmd{bukhari}{1278}{حَدَّثَنَا قَبِيصَةُ بْنُ عُقْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أُمِّ الْهُذَيْلِ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ نُهِينَا عَنِ اتِّبَاعِ الْجَنَائِزِ، وَلَمْ يُعْزَمْ عَلَيْنَا‏.‏\hadithno{1278}\hadithtrans{Narrated Um 'Atiyya:We were forbidden to accompany funeral processions but not strictly}}
\hadithdefcmd{bukhari}{1279}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سَلَمَةُ بْنُ عَلْقَمَةَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ تُوُفِّيَ ابْنٌ لأُمِّ عَطِيَّةَ ـ رضى الله عنها ـ فَلَمَّا كَانَ الْيَوْمُ الثَّالِثُ دَعَتْ بِصُفْرَةٍ، فَتَمَسَّحَتْ بِهِ وَقَالَتْ نُهِينَا أَنْ نُحِدَّ أَكْثَرَ مِنْ ثَلاَثٍ إِلاَّ بِزَوْجٍ‏.‏\hadithno{1279}\hadithtrans{Narrated Muhammad bin Seereen:One of the sons of Um 'Atiyya died, and when it was the third day she asked for a yellow perfume and put it over her body, and said, "We were forbidden to mourn for more than three days except for our husbands}}
\hadithdefcmd{bukhari}{1280}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَيُّوبُ بْنُ مُوسَى، قَالَ أَخْبَرَنِي حُمَيْدُ بْنُ نَافِعٍ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، قَالَتْ لَمَّا جَاءَ نَعْىُ أَبِي سُفْيَانَ مِنَ الشَّأْمِ دَعَتْ أُمُّ حَبِيبَةَ ـ رضى الله عنها ـ بِصُفْرَةٍ فِي الْيَوْمِ الثَّالِثِ، فَمَسَحَتْ عَارِضَيْهَا وَذِرَاعَيْهَا وَقَالَتْ إِنِّي كُنْتُ عَنْ هَذَا لَغَنِيَّةً، لَوْلاَ أَنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ، فَإِنَّهَا تُحِدُّ عَلَيْهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{1280}\hadithtrans{Narrated Zainab bint Abi Salama:When the news of the death of Abu Sufyan reached from Sham, Um Habiba on the third day, asked for a yellow perfume and scented her cheeks and forearms and said, "No doubt, I would not have been in need of this, had I not heard the Prophet (ﷺ) saying: "It is not legal for a woman who believes in Allah and the Last Day to mourn for more than three days for any dead person except her husband, for whom she should mourn for four months and ten days}}
\hadithdefcmd{bukhari}{1282}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَخْبَرَتْهُ قَالَتْ، دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا، فَدَعَتْ بِطِيبٍ فَمَسَّتْ ثُمَّ قَالَتْ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ، غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَقُولُ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{1282}\hadithtrans{Narrated Zainab bint Abi Salama:I went to Um Habiba, the wife of Prophet, who said, "I heard the Prophets saying, 'It is not legal for a woman who believes in Allah and the Last Day to mourn for any dead person for more than three days except for her husband, (for whom she should mourn) for four months and ten days'." Later I went to Zainab bint Jahsh when her brother died; she asked for some scent, and after using it she said, "I am not in need of scent but I heard Allah's Messenger (ﷺ) saying, 'It is not legal for a woman who believes in Allah and the Last Day to mourn for more than three days for any dead person except her husband, (for whom she should mourn) for four months and ten days}}
\hadithdefcmd{bukhari}{1283}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِامْرَأَةٍ تَبْكِي عِنْدَ قَبْرٍ فَقَالَ ‏"‏ اتَّقِي اللَّهَ وَاصْبِرِي ‏"‏‏.‏ قَالَتْ إِلَيْكَ عَنِّي، فَإِنَّكَ لَمْ تُصَبْ بِمُصِيبَتِي، وَلَمْ تَعْرِفْهُ‏.‏ فَقِيلَ لَهَا إِنَّهُ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَأَتَتْ باب النَّبِيِّ صلى الله عليه وسلم فَلَمْ تَجِدْ عِنْدَهُ بَوَّابِينَ فَقَالَتْ لَمْ أَعْرِفْكَ‏.‏ فَقَالَ ‏"‏ إِنَّمَا الصَّبْرُ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏‏.‏\hadithno{1283}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) passed by a woman who was weeping beside a grave. He told her to fear Allah and be patient. She said to him, "Go away, for you have not been afflicted with a calamity like mine." And she did not recognize him. Then she was informed that he was the Prophet (ﷺ) . so she went to the house of the Prophet (ﷺ) and there she did not find any guard. Then she said to him, "I did not recognize you." He said, "Verily, the patience is at the first stroke of a calamity}}
\hadithdefcmd{bukhari}{1284}{حَدَّثَنَا عَبْدَانُ، وَمُحَمَّدٌ، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عَاصِمُ بْنُ سُلَيْمَانَ، عَنْ أَبِي عُثْمَانَ، قَالَ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ ـ رضى الله عنهما ـ قَالَ أَرْسَلَتِ ابْنَةُ النَّبِيِّ صلى الله عليه وسلم إِلَيْهِ إِنَّ ابْنًا لِي قُبِضَ فَائْتِنَا‏.‏ فَأَرْسَلَ يُقْرِئُ السَّلاَمَ وَيَقُولُ ‏"‏ إِنَّ لِلَّهِ مَا أَخَذَ وَلَهُ مَا أَعْطَى وَكُلٌّ عِنْدَهُ بِأَجَلٍ مُسَمًّى، فَلْتَصْبِرْ وَلْتَحْتَسِبْ ‏"‏‏.‏ فَأَرْسَلَتْ إِلَيْهِ تُقْسِمُ عَلَيْهِ لَيَأْتِيَنَّهَا، فَقَامَ وَمَعَهُ سَعْدُ بْنُ عُبَادَةَ وَمُعَاذُ بْنُ جَبَلٍ وَأُبَىُّ بْنُ كَعْبٍ وَزَيْدُ بْنُ ثَابِتٍ وَرِجَالٌ، فَرُفِعَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الصَّبِيُّ وَنَفْسُهُ تَتَقَعْقَعُ ـ قَالَ حَسِبْتُهُ أَنَّهُ قَالَ ـ كَأَنَّهَا شَنٌّ‏.‏ فَفَاضَتْ عَيْنَاهُ‏.‏ فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ مَا هَذَا فَقَالَ ‏"‏ هَذِهِ رَحْمَةٌ جَعَلَهَا اللَّهُ فِي قُلُوبِ عِبَادِهِ، وَإِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏‏.‏\hadithno{1284}\hadithtrans{Narrated Usama bin Zaid:The daughter of the Prophet (ﷺ) sent (a messenger) to the Prophet (ﷺ) requesting him to come as her child was dying (or was gasping), but the Prophet (ﷺ) returned the messenger and told him to convey his greeting to her and say: "Whatever Allah takes is for Him and whatever He gives, is for Him, and everything with Him has a limited fixed term (in this world) and so she should be patient and hope for Allah's reward." She again sent for him, swearing that he should come. The Prophet (ﷺ) got up, and so did Sa`d bin 'Ubada, Mu`adh bin Jabal, Ubai bin Ka`b, Zaid bin Thabit and some other men. The child was brought to Allah's Messenger (ﷺ) while his breath was disturbed in his chest (the sub-narrator thinks that Usama added: ) as if it was a leather water-skin. On that the eyes of the Prophet (ﷺ) started shedding tears. Sa`d said, "O Allah's Messenger (ﷺ)! What is this?" He replied, "It is mercy which Allah has lodged in the hearts of His slaves, and Allah is merciful only to those of His slaves who are merciful (to others)}}
\hadithdefcmd{bukhari}{1285}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ شَهِدْنَا بِنْتًا لِرَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ عَلَى الْقَبْرِ ـ قَالَ فَرَأَيْتُ عَيْنَيْهِ تَدْمَعَانِ قَالَ ـ فَقَالَ ‏"‏ هَلْ مِنْكُمْ رَجُلٌ لَمْ يُقَارِفِ اللَّيْلَةَ ‏"‏‏.‏ فَقَالَ أَبُو طَلْحَةَ أَنَا‏.‏ قَالَ ‏"‏ فَانْزِلْ ‏"‏‏.‏ قَالَ فَنَزَلَ فِي قَبْرِهَا‏.‏\hadithno{1285}\hadithtrans{Narrated Anas bin Malik:We were (in the funeral procession) of one of the daughters of the Prophet (ﷺ) and he was sitting by the side of the grave. I saw his eyes shedding tears. He said, "Is there anyone among you who did not have sexual relations with his wife last night?" Abu Talha replied in the affirmative. And so the Prophet told him to get down in the grave. And so he got down in her grave}}
\hadithdefcmd{bukhari}{1288}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ تُوُفِّيَتِ ابْنَةٌ لِعُثْمَانَ ـ رضى الله عنه ـ بِمَكَّةَ وَجِئْنَا لِنَشْهَدَهَا، وَحَضَرَهَا ابْنُ عُمَرَ وَابْنُ عَبَّاسٍ ـ رضى الله عنهم ـ وَإِنِّي لَجَالِسٌ بَيْنَهُمَا ـ أَوْ قَالَ جَلَسْتُ إِلَى أَحَدِهِمَا‏.‏ ثُمَّ جَاءَ الآخَرُ، فَجَلَسَ إِلَى جَنْبِي فَقَالَ عَبْدُ اللَّهِ بْنُ عَمَرَ ـ رضى الله عنهما ـ لِعَمْرِو بْنِ عُثْمَانَ أَلاَ تَنْهَى عَنِ الْبُكَاءِ، فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ فَقَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَدْ كَانَ عُمَرُ ـ رضى الله عنه ـ يَقُولُ بَعْضَ ذَلِكَ، ثُمَّ حَدَّثَ قَالَ صَدَرْتُ مَعَ عُمَرَ ـ رضى الله عنه ـ مِنْ مَكَّةَ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ، إِذَا هُوَ بِرَكْبٍ تَحْتَ ظِلِّ سَمُرَةٍ فَقَالَ اذْهَبْ، فَانْظُرْ مَنْ هَؤُلاَءِ الرَّكْبُ قَالَ فَنَظَرْتُ فَإِذَا صُهَيْبٌ، فَأَخْبَرْتُهُ فَقَالَ ادْعُهُ لِي‏.‏ فَرَجَعْتُ إِلَى صُهَيْبٍ فَقُلْتُ ارْتَحِلْ فَالْحَقْ أَمِيرَ الْمُؤْمِنِينَ‏.‏ فَلَمَّا أُصِيبَ عُمَرُ دَخَلَ صُهَيْبٌ يَبْكِي يَقُولُ وَاأَخَاهُ، وَاصَاحِبَاهُ‏.‏ فَقَالَ عُمَرُ ـ رضى الله عنه ـ يَا صُهَيْبُ أَتَبْكِي عَلَىَّ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ يُعَذَّبُ بِبَعْضِ بُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما فَلَمَّا مَاتَ عُمَرُ ـ رضى الله عنه ـ ذَكَرْتُ ذَلِكَ لِعَائِشَةَ ـ رضى الله عنها ـ فَقَالَتْ رَحِمَ اللَّهُ عُمَرَ، وَاللَّهِ مَا حَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّ اللَّهَ لَيُعَذِّبُ الْمُؤْمِنَ بِبُكَاءِ أَهْلِهِ عَلَيْهِ‏.‏ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ لَيَزِيدُ الْكَافِرَ عَذَابًا بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ وَقَالَتْ حَسْبُكُمُ الْقُرْآنُ ‏\{‏وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى‏\}‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ عِنْدَ ذَلِكَ وَاللَّهُ هُوَ أَضْحَكَ وَأَبْكَى‏.‏ قَالَ ابْنُ أَبِي مُلَيْكَةَ وَاللَّهِ مَا قَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ شَيْئًا‏.‏\hadithno{1288}\hadithtrans{Narrated `Abdullah bin 'Ubaidullah bin Abi Mulaika:One of the daughters of `Uthman died at Mecca. We went to attend her funeral procession. Ibn `Umar and Ibn `Abbas were also present. I sat in between them (or said, I sat beside one of them. Then a man came and sat beside me.) `Abdullah bin `Umar said to `Amr bin `Uthman, "Will you not prohibit crying as Allah's Messenger (ﷺ) has said, 'The dead person is tortured by the crying of his relatives.?" Ibn `Abbas said, "`Umar used to say so." Then he added narrating, "I accompanied `Umar on a journey from Mecca till we reached Al-Baida. There he saw some travelers in the shade of a Samura (A kind of forest tree). He said (to me), "Go and see who those travelers are." So I went and saw that one of them was Suhaib. I told this to `Umar who then asked me to call him. So I went back to Suhaib and said to him, "Depart and follow the chief of the faithful believers." Later, when `Umar was stabbed, Suhaib came in weeping and saying, "O my brother, O my friend!" (on this `Umar said to him, "O Suhaib! Are you weeping for me while the Prophet (ﷺ) said, "The dead person is punished by some of the weeping of his relatives?" Ibn `Abbas added, "When `Umar died I told all this to Aisha and she said, 'May Allah be merciful to `Umar. By Allah, Allah's Messenger (ﷺ) did not say that a believer is punished by the weeping of his relatives. But he said, Allah increases the punishment of a non-believer because of the weeping of his relatives." Aisha further added, "The Qur'an is sufficient for you (to clear up this point) as Allah has stated: 'No burdened soul will bear another's burden.' " (35.18). Ibn `Abbas then said, "Only Allah makes one laugh or cry." Ibn `Umar did not say anything after that}}
\hadithdefcmd{bukhari}{1289}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، سَمِعَتْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ إِنَّمَا مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى يَهُودِيَّةٍ يَبْكِي عَلَيْهَا أَهْلُهَا فَقَالَ ‏ "‏ إِنَّهُمْ لَيَبْكُونَ عَلَيْهَا، وَإِنَّهَا لَتُعَذَّبُ فِي قَبْرِهَا ‏"‏‏.‏\hadithno{1289}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Once Allah's Messenger (ﷺ) passed by (the grave of) a Jewess whose relatives were weeping over her. He said, "They are weeping over her and she is being tortured in her grave}}
\hadithdefcmd{bukhari}{1290}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ خَلِيلٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، حَدَّثَنَا أَبُو إِسْحَاقَ ـ وَهْوَ الشَّيْبَانِيُّ ـ عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ لَمَّا أُصِيبَ عُمَرُ ـ رضى الله عنه ـ جَعَلَ صُهَيْبٌ يَقُولُ وَاأَخَاهُ‏.‏ فَقَالَ عُمَرُ أَمَا عَلِمْتَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ الْحَىِّ ‏"‏‏.‏\hadithno{1290}\hadithtrans{Narrated Abu Burda:That his father said, "When `Umar was stabbed, Suhaib started crying: O my brother! `Umar said, 'Don't you know that the Prophet (ﷺ) said: The deceased is tortured for the weeping of the living'?}}
\hadithdefcmd{bukhari}{1291}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدٍ، عَنْ عَلِيِّ بْنِ رَبِيعَةَ، عَنِ الْمُغِيرَةِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ كَذِبًا عَلَىَّ لَيْسَ كَكَذِبٍ عَلَى أَحَدٍ، مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏‏.‏ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ نِيحَ عَلَيْهِ يُعَذَّبُ بِمَا نِيحَ عَلَيْهِ ‏"‏‏.‏\hadithno{1291}\hadithtrans{Narrated Al-Mughira:I heard the Prophet (ﷺ) saying, "Ascribing false things to me is not like ascribing false things to anyone else. Whosoever tells a lie against me intentionally then surely let him occupy his seat in Hell-Fire." I heard the Prophet (ﷺ) saying, "The deceased who is wailed over is tortured for that wailing}}
\hadithdefcmd{bukhari}{1292}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عُمَرَ، عَنْ أَبِيهِ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْمَيِّتُ يُعَذَّبُ فِي قَبْرِهِ بِمَا نِيحَ عَلَيْهِ ‏"‏‏.‏ تَابَعَهُ عَبْدُ الأَعْلَى حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ حَدَّثَنَا سَعِيدٌ حَدَّثَنَا قَتَادَةُ‏.‏ وَقَالَ آدَمُ عَنْ شُعْبَةَ ‏"‏ الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ الْحَىِّ عَلَيْهِ ‏"‏‏.‏\hadithno{1292}\hadithtrans{Narrated Ibn 'Umar from his father: The Prophet (ﷺ) said, "The deceased is tortured in his grave for the wailing done over him." Narrated Shu'ba: The deceased is tortured for the wailing of the living ones over him}}
\hadithdefcmd{bukhari}{1293}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ جِيءَ بِأَبِي يَوْمَ أُحُدٍ، قَدْ مُثِّلَ بِهِ حَتَّى وُضِعَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ سُجِّيَ ثَوْبًا فَذَهَبْتُ أُرِيدُ أَنْ أَكْشِفَ عَنْهُ فَنَهَانِي قَوْمِي، ثُمَّ ذَهَبْتُ أَكْشِفُ عَنْهُ فَنَهَانِي قَوْمِي، فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُفِعَ فَسَمِعَ صَوْتَ صَائِحَةٍ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏‏.‏ فَقَالُوا ابْنَةُ عَمْرٍو أَوْ أُخْتُ عَمْرٍو‏.‏ قَالَ ‏"‏ فَلِمَ تَبْكِي أَوْ لاَ تَبْكِي فَمَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا حَتَّى رُفِعَ ‏"‏‏.‏\hadithno{1293}\hadithtrans{Narrated Jabir bin `Abdullah:On the day of the Battle of Uhud, my father was brought and he had been mutilated (in battle) and was placed in front of Allah's Messenger (ﷺ) and a sheet was over him. I went intending to uncover my father but my people forbade me; again I wanted to uncover him but my people forbade me. Allah's Messenger (ﷺ) gave his order and he was shifted away. At that time he heard the voice of a crying woman and asked, "Who is this?" They said, "It is the daughter or the sister of `Amr." He said, "Why does she weep? (or let her stop weeping), for the angels had been shading him with their wings till he (i.e. the body of the martyr) was shifted away}}
\hadithdefcmd{bukhari}{1294}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا زُبَيْدٌ الْيَامِيُّ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ لَطَمَ الْخُدُودَ، وَشَقَّ الْجُيُوبَ، وَدَعَا بِدَعْوَى الْجَاهِلِيَّةِ ‏"‏‏.‏\hadithno{1294}\hadithtrans{Narrated `Abdullah:the Prophet (ﷺ) said, "He who slaps his cheeks, tears his clothes and follows the ways and traditions of the Days of Ignorance is not one of us}}
\hadithdefcmd{bukhari}{1295}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي عَامَ حَجَّةِ الْوَدَاعِ مِنْ وَجَعٍ اشْتَدَّ بِي فَقُلْتُ إِنِّي قَدْ بَلَغَ بِي مِنَ الْوَجَعِ وَأَنَا ذُو مَالٍ، وَلاَ يَرِثُنِي إِلاَّ ابْنَةٌ، أَفَأَتَصَدَّقُ بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏‏.‏ فَقُلْتُ بِالشَّطْرِ فَقَالَ ‏"‏ لاَ ‏"‏ ثُمَّ قَالَ ‏"‏ الثُّلُثُ وَالثُّلْثُ كَبِيرٌ ـ أَوْ كَثِيرٌ ـ إِنَّكَ أَنْ تَذَرَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَذَرَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ، وَإِنَّكَ لَنْ تُنْفِقَ نَفَقَةً تَبْتَغِي بِهَا وَجْهَ اللَّهِ إِلاَّ أُجِرْتَ بِهَا، حَتَّى مَا تَجْعَلُ فِي فِي امْرَأَتِكَ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ، أُخَلَّفُ بَعْدَ أَصْحَابِي قَالَ ‏"‏ إِنَّكَ لَنْ تُخَلَّفَ فَتَعْمَلَ عَمَلاً صَالِحًا إِلاَّ ازْدَدْتَ بِهِ دَرَجَةً وَرِفْعَةً، ثُمَّ لَعَلَّكَ أَنْ تُخَلَّفَ حَتَّى يَنْتَفِعَ بِكَ أَقْوَامٌ وَيُضَرَّ بِكَ آخَرُونَ، اللَّهُمَّ أَمْضِ لأَصْحَابِي هِجْرَتَهُمْ، وَلاَ تَرُدَّهُمْ عَلَى أَعْقَابِهِمْ، لَكِنِ الْبَائِسُ سَعْدُ ابْنُ خَوْلَةَ، يَرْثِي لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ مَاتَ بِمَكَّةَ ‏"‏‏.‏\hadithno{1295}\hadithtrans{Narrated 'Amir bin Sa`d bin Abi Waqqas:That his father said, "In the year of the last Hajj of the Prophet (ﷺ) I became seriously ill and the Prophet (ﷺ) used to visit me inquiring about my health. I told him, 'I am reduced to this state because of illness and I am wealthy and have no inheritors except a daughter, (In this narration the name of 'Amir bin Sa`d is mentioned and in fact it is a mistake; the narrator is `Aisha bint Sa`d bin Abi Waqqas). Should I give two-thirds of my property in charity?' He said, 'No.' I asked, 'Half?' He said, 'No.' then he added, 'One-third, and even one-third is much. You'd better leave your inheritors wealthy rather than leaving them poor, begging others. You will get a reward for whatever you spend for Allah's sake, even for what you put in your wife's mouth.' I said, 'O Allah's Messenger (ﷺ)! Will I be left alone after my companions have gone?' He said, 'If you are left behind, whatever good deeds you will do will upgrade you and raise you high. And perhaps you will have a long life so that some people will be benefited by you while others will be harmed by you. O Allah! Complete the emigration of my companions and do not turn them renegades.' But Allah's Messenger (ﷺ) felt sorry for poor Sa`d bin Khaula as he died in Mecca." (but Sa`d bin Abi Waqqas lived long after the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{1296}{وَقَالَ الْحَكَمُ بْنُ مُوسَى حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جَابِرٍ، أَنَّ الْقَاسِمَ بْنَ مُخَيْمِرَةَ، حَدَّثَهُ قَالَ حَدَّثَنِي أَبُو بُرْدَةَ بْنُ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ وَجِعَ أَبُو مُوسَى وَجَعًا فَغُشِيَ عَلَيْهِ، وَرَأْسُهُ فِي حَجْرِ امْرَأَةٍ مِنْ أَهْلِهِ، فَلَمْ يَسْتَطِعْ أَنْ يَرُدَّ عَلَيْهَا شَيْئًا، فَلَمَّا أَفَاقَ قَالَ أَنَا بَرِيءٌ مِمَّنْ بَرِئَ مِنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم، إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَرِئَ مِنَ الصَّالِقَةِ وَالْحَالِقَةِ وَالشَّاقَّةِ‏.‏\hadithno{1296}\hadithtrans{Narrated Abu Burda bin Abi Musa:Abu Musa got seriously ill, fainted and could not reply to his wife while he was lying with his head in her lap. When he came to his senses, he said, "I am innocent of those, of whom Allah's Messenger (ﷺ) was innocent. Allah's Messenger (ﷺ) is innocent of a woman who cries aloud (or slaps her face) who shaves her head and who tear off her clothes (on the falling of a calamity)}}
\hadithdefcmd{bukhari}{1297}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَّا مَنْ ضَرَبَ الْخُدُودَ، وَشَقَّ الْجُيُوبَ، وَدَعَا بِدَعْوَى الْجَاهِلِيَّةِ ‏"‏‏.‏\hadithno{1297}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "He who slaps the cheeks, tears the clothes and follows the tradition of the Days of Ignorance is not from us}}
\hadithdefcmd{bukhari}{1298}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ ضَرَبَ الْخُدُودَ، وَشَقَّ الْجُيُوبَ، وَدَعَا بِدَعْوَى الْجَاهِلِيَّةِ ‏"‏‏.‏\hadithno{1298}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "He who slaps the cheeks, tears the clothes and follows the traditions of the Days of Ignorance is not from us}}
\hadithdefcmd{bukhari}{1299}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى، قَالَ أَخْبَرَتْنِي عَمْرَةُ، قَالَتْ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا جَاءَ النَّبِيَّ صلى الله عليه وسلم قَتْلُ ابْنِ حَارِثَةَ وَجَعْفَرٍ وَابْنِ رَوَاحَةَ جَلَسَ يُعْرَفُ فِيهِ الْحُزْنُ، وَأَنَا أَنْظُرُ مِنْ صَائِرِ الْبَابِ ـ شَقِّ الْبَابِ ـ فَأَتَاهُ رَجُلٌ، فَقَالَ إِنَّ نِسَاءَ جَعْفَرٍ، وَذَكَرَ بُكَاءَهُنَّ، فَأَمَرَهُ أَنْ يَنْهَاهُنَّ، فَذَهَبَ ثُمَّ أَتَاهُ الثَّانِيَةَ، لَمْ يُطِعْنَهُ فَقَالَ انْهَهُنَّ‏.‏ فَأَتَاهُ الثَّالِثَةَ قَالَ وَاللَّهِ غَلَبْنَنَا يَا رَسُولَ اللَّهِ فَزَعَمَتْ أَنَّهُ قَالَ ‏ "‏ فَاحْثُ فِي أَفْوَاهِهِنَّ التُّرَابَ ‏"‏‏.‏ فَقُلْتُ أَرْغَمَ اللَّهُ أَنْفَكَ، لَمْ تَفْعَلْ مَا أَمَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ تَتْرُكْ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنَ الْعَنَاءِ‏.‏\hadithno{1299}\hadithtrans{Narrated `Aisha:When the Prophet (ﷺ) got the news of the death of Ibn Haritha, Ja`far and Ibn Rawaha he sat down and looked sad and I was looking at him through the chink of the door. A man came and told him about the crying of the women of Ja`far. The Prophet (ﷺ) ordered him to forbid them. The man went and came back saying that he had told them but they did not listen to him. The Prophet (ﷺ) said, "Forbid them." So again he went and came back for the third time and said, "O Allah's Messenger (ﷺ)! By Allah, they did not listen to us at all." (`Aisha added): Allah's Messenger (ﷺ) ordered him to go and put dust in their mouths. I said, (to that man) "May Allah stick your nose in the dust (i.e. humiliate you)! You could neither (persuade the women to) fulfill the order of Allah's Messenger (ﷺ) nor did you relieve Allah's Messenger (ﷺ) from fatigue}}
\hadithdefcmd{bukhari}{1300}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا حِينَ قُتِلَ الْقُرَّاءُ، فَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم حَزِنَ حُزْنًا قَطُّ أَشَدَّ مِنْهُ‏.‏\hadithno{1300}\hadithtrans{Narrated Anas:When the reciters of Qur'an were martyred, Allah's Messenger (ﷺ) recited Qunut for one month and I never saw him (i.e. Allah's Messenger (ﷺ)) so sad as he was on that day}}
\hadithdefcmd{bukhari}{1301}{حَدَّثَنَا بِشْرُ بْنُ الْحَكَمِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، أَخْبَرَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ اشْتَكَى ابْنٌ لأَبِي طَلْحَةَ ـ قَالَ ـ فَمَاتَ وَأَبُو طَلْحَةَ خَارِجٌ، فَلَمَّا رَأَتِ امْرَأَتُهُ أَنَّهُ قَدْ مَاتَ هَيَّأَتْ شَيْئًا وَنَحَّتْهُ فِي جَانِبِ الْبَيْتِ، فَلَمَّا جَاءَ أَبُو طَلْحَةَ قَالَ كَيْفَ الْغُلاَمُ قَالَتْ قَدْ هَدَأَتْ نَفْسُهُ، وَأَرْجُو أَنْ يَكُونَ قَدِ اسْتَرَاحَ‏.‏ وَظَنَّ أَبُو طَلْحَةَ أَنَّهَا صَادِقَةٌ، قَالَ فَبَاتَ، فَلَمَّا أَصْبَحَ اغْتَسَلَ، فَلَمَّا أَرَادَ أَنْ يَخْرُجَ، أَعْلَمَتْهُ أَنَّهُ قَدْ مَاتَ، فَصَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ أَخْبَرَ النَّبِيَّ صلى الله عليه وسلم بِمَا كَانَ مِنْهُمَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَلَّ اللَّهَ أَنْ يُبَارِكَ لَكُمَا فِي لَيْلَتِكُمَا ‏"‏‏.‏ قَالَ سُفْيَانُ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ فَرَأَيْتُ لَهُمَا تِسْعَةَ أَوْلاَدٍ كُلُّهُمْ قَدْ قَرَأَ الْقُرْآنَ‏.‏\hadithno{1301}\hadithtrans{Narrated Anas bin Malik:One of the sons of Abu Talha became sick and died and Abu Talha at that time was not at home. When his wife saw that he was dead, she prepared him (washed and shrouded him) and placed him somewhere in the house. When Abu Talha came, he asked, "How is the boy?" She said, "The child is quiet and I hope he is in peace." Abu Talha thought that she had spoken the truth. Abu Talha passed the night and in the morning took a bath and when he intended to go out, she told him that his son had died, Abu Talha offered the (morning) prayer with the Prophet (ﷺ) and informed the Prophet (ﷺ) of what happened to them. Allah's Messenger (ﷺ) said, "May Allah bless you concerning your night. (That is, may Allah bless you with good offspring)." Sufyan said, "One of the Ansar said, 'They (i.e. Abu Talha and his wife) had nine sons and all of them became reciters of the Qur'an (by heart)}}
\hadithdefcmd{bukhari}{1302}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّبْرُ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏‏.‏\hadithno{1302}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "The real patience is at the first stroke of a calamity}}
\hadithdefcmd{bukhari}{1303}{حَدَّثَنَا الْحَسَنُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا قُرَيْشٌ ـ هُوَ ابْنُ حَيَّانَ ـ عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ دَخَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى أَبِي سَيْفٍ الْقَيْنِ ـ وَكَانَ ظِئْرًا لإِبْرَاهِيمَ ـ عَلَيْهِ السَّلاَمُ ـ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِبْرَاهِيمَ فَقَبَّلَهُ وَشَمَّهُ، ثُمَّ دَخَلْنَا عَلَيْهِ بَعْدَ ذَلِكَ، وَإِبْرَاهِيمُ يَجُودُ بِنَفْسِهِ، فَجَعَلَتْ عَيْنَا رَسُولِ اللَّهِ صلى الله عليه وسلم تَذْرِفَانِ‏.‏ فَقَالَ لَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ ـ رضى الله عنه ـ وَأَنْتَ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ يَا ابْنَ عَوْفٍ إِنَّهَا رَحْمَةٌ ‏"‏‏.‏ ثُمَّ أَتْبَعَهَا بِأُخْرَى فَقَالَ صلى الله عليه وسلم ‏"‏ إِنَّ الْعَيْنَ تَدْمَعُ، وَالْقَلْبَ يَحْزَنُ، وَلاَ نَقُولُ إِلاَّ مَا يَرْضَى رَبُّنَا، وَإِنَّا بِفِرَاقِكَ يَا إِبْرَاهِيمُ لَمَحْزُونُونَ ‏"‏‏.‏ رَوَاهُ مُوسَى عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ عَنْ ثَابِتٍ عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1303}\hadithtrans{Narrated Anas bin Malik:We went with Allah's Messenger (ﷺ) to the blacksmith Abu Saif, and he was the husband of the wet-nurse of Ibrahim (the son of the Prophet). Allah's Messenger (ﷺ) took Ibrahim and kissed him and smelled him and later we entered Abu Saif's house and at that time Ibrahim was in his last breaths, and the eyes of Allah's Messenger (ﷺ) started shedding tears. `Abdur Rahman bin `Auf said, "O Allah's Apostle, even you are weeping!" He said, "O Ibn `Auf, this is mercy." Then he wept more and said, "The eyes are shedding tears and the heart is grieved, and we will not say except what pleases our Lord, O Ibrahim ! Indeed we are grieved by your separation}}
\hadithdefcmd{bukhari}{1304}{حَدَّثَنَا أَصْبَغُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، عَنْ سَعِيدِ بْنِ الْحَارِثِ الأَنْصَارِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ اشْتَكَى سَعْدُ بْنُ عُبَادَةَ شَكْوَى لَهُ فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ مَعَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَسَعْدِ بْنِ أَبِي وَقَّاصٍ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنهم ـ فَلَمَّا دَخَلَ عَلَيْهِ فَوَجَدَهُ فِي غَاشِيَةِ أَهْلِهِ فَقَالَ ‏"‏ قَدْ قَضَى ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ فَبَكَى النَّبِيُّ صلى الله عليه وسلم فَلَمَّا رَأَى الْقَوْمُ بُكَاءَ النَّبِيِّ صلى الله عليه وسلم بَكَوْا فَقَالَ ‏"‏ أَلاَ تَسْمَعُونَ إِنَّ اللَّهَ لاَ يُعَذِّبُ بِدَمْعِ الْعَيْنِ، وَلاَ بِحُزْنِ الْقَلْبِ، وَلَكِنْ يُعَذِّبُ بِهَذَا ـ وَأَشَارَ إِلَى لِسَانِهِ ـ أَوْ يَرْحَمُ وَإِنَّ الْمَيِّتَ يُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ وَكَانَ عُمَرُ ـ رضى الله عنه ـ يَضْرِبُ فِيهِ بِالْعَصَا، وَيَرْمِي بِالْحِجَارَةِ وَيَحْثِي بِالتُّرَابِ‏.‏\hadithno{1304}\hadithtrans{Narrated `Abdullah bin `Umar:Sa`d bin 'Ubada became sick and the Prophet (ﷺ) along with `Abdur Rahman bin `Auf, Sa`d bin Abi Waqqas and `Abdullah bin Mas`ud visited him to inquire about his health. When he came to him, he found him surrounded by his household and he asked, "Has he died?" They said, "No, O Allah's Apostle." The Prophet (ﷺ) wept and when the people saw the weeping of Allah's Messenger (ﷺ) they all wept. He said, "Will you listen? Allah does not punish for shedding tears, nor for the grief of the heart but he punishes or bestows His Mercy because of this." He pointed to his tongue and added, "The deceased is punished for the wailing of his relatives over him." `Umar used to beat with a stick and throw stones and put dust over the faces (of those who used to wail over the dead)}}
\hadithdefcmd{bukhari}{1305}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَتْنِي عَمْرَةُ، قَالَتْ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ لَمَّا جَاءَ قَتْلُ زَيْدِ بْنِ حَارِثَةَ وَجَعْفَرٍ وَعَبْدِ اللَّهِ بْنِ رَوَاحَةَ، جَلَسَ النَّبِيُّ صلى الله عليه وسلم يُعْرَفُ فِيهِ الْحُزْنُ، وَأَنَا أَطَّلِعُ مِنْ شَقِّ الْبَابِ، فَأَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ نِسَاءَ جَعْفَرٍ وَذَكَرَ بُكَاءَهُنَّ فَأَمَرَهُ بِأَنْ يَنْهَاهُنَّ، فَذَهَبَ الرَّجُلُ ثُمَّ أَتَى فَقَالَ قَدْ نَهَيْتُهُنَّ، وَذَكَرَ أَنَّهُنَّ لَمْ يُطِعْنَهُ، فَأَمَرَهُ الثَّانِيَةَ أَنْ يَنْهَاهُنَّ، فَذَهَبَ، ثُمَّ أَتَى، فَقَالَ وَاللَّهِ لَقَدْ غَلَبْنَنِي أَوْ غَلَبْنَنَا الشَّكُّ مِنْ مُحَمَّدِ بْنِ حَوْشَبٍ ـ فَزَعَمَتْ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ فَاحْثُ فِي أَفْوَاهِهِنَّ التُّرَابَ ‏"‏‏.‏ فَقُلْتُ أَرْغَمَ اللَّهُ أَنْفَكَ، فَوَاللَّهِ مَا أَنْتَ بِفَاعِلٍ وَمَا تَرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنَ الْعَنَاءِ‏.‏\hadithno{1305}\hadithtrans{Narrated Aisha:When the news of the martyrdom of Zaid bin Haritha, Ja`far and `Abdullah bin Rawaha came, the Prophet sat down looking sad, and I was looking through the chink of the door. A man came and said, "O Allah's Messenger (ﷺ)! The women of Ja`far," and then he mentioned their crying . The Prophet (ﷺ) ordered him to stop them from crying. The man went and came back and said, "I tried to stop them but they disobeyed." The Prophet (ﷺ) ordered him for the second time to forbid them. He went again and came back and said, "They did not listen to me, (or "us": the sub-narrator Muhammad bin Haushab is in doubt as to which is right). " (`Aisha added: The Prophet (ﷺ) said, "Put dust in their mouths." I said (to that man), "May Allah stick your nose in the dust (i.e. humiliate you)." By Allah, you could not (stop the women from crying) to fulfill the order, besides you did not relieve Allah's Apostle from fatigue}}
\hadithdefcmd{bukhari}{1306}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنها ـ قَالَتْ أَخَذَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم عِنْدَ الْبَيْعَةِ أَنْ لاَ نَنُوحَ، فَمَا وَفَتْ مِنَّا امْرَأَةٌ غَيْرَ خَمْسِ نِسْوَةٍ أُمِّ سُلَيْمٍ وَأُمِّ الْعَلاَءِ وَابْنَةِ أَبِي سَبْرَةَ امْرَأَةِ مُعَاذٍ وَامْرَأَتَيْنِ أَوِ ابْنَةِ أَبِي سَبْرَةَ وَامْرَأَةِ مُعَاذٍ وَامْرَأَةٍ أُخْرَى‏.‏\hadithno{1306}\hadithtrans{Narrated Um 'Atiyya:At the time of giving the pledge of allegiance to the Prophet (ﷺ) one of the conditions was that we would not wail, but it was not fulfilled except by five women and they are Um Sulaim, Um Al-`Ala', the daughter of Abi Sabra (the wife of Mu`adh), and two other women; or the daughter of Abi Sabra and the wife of Mu`adh and another woman}}
\hadithdefcmd{bukhari}{1307}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا حَتَّى تُخَلِّفَكُمْ ‏"‏‏.‏ قَالَ سُفْيَانُ قَالَ الزُّهْرِيُّ أَخْبَرَنِي سَالِمٌ عَنْ أَبِيهِ قَالَ أَخْبَرَنَا عَامِرُ بْنُ رَبِيعَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ زَادَ الْحُمَيْدِيُّ ‏"‏ حَتَّى تُخَلِّفَكُمْ أَوْ تُوضَعَ ‏"‏‏.‏\hadithno{1307}\hadithtrans{Narrated 'Amir bin Rabi`a:The Prophet (ﷺ) said, "Whenever you see a funeral procession, stand up till the procession goes ahead of you." Al-Humaidi added, "Till the coffin leaves you behind or is put down}}
\hadithdefcmd{bukhari}{1308}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنْ عَامِرِ بْنِ رَبِيعَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَى أَحَدُكُمْ جَنَازَةً فَإِنْ لَمْ يَكُنْ مَاشِيًا مَعَهَا فَلْيَقُمْ حَتَّى يُخَلِّفَهَا، أَوْ تُخَلِّفَهُ أَوْ تُوضَعَ مِنْ قَبْلِ أَنْ تُخَلِّفَهُ ‏"‏‏.‏\hadithno{1308}\hadithtrans{Narrated 'Amir bin Rabi`a:The Prophet (ﷺ) said, "If any one of you sees a funeral procession and he is not going along with it, then he should stand and remain standing till he gets behind it, or it leaves him behind, or the coffin is put down before it goes ahead of him}}
\hadithdefcmd{bukhari}{1309}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، قَالَ كُنَّا فِي جَنَازَةٍ فَأَخَذَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ بِيَدِ مَرْوَانَ فَجَلَسَا قَبْلَ أَنْ تُوضَعَ، فَجَاءَ أَبُو سَعِيدٍ ـ رضى الله عنه ـ فَأَخَذَ بِيَدِ مَرْوَانَ فَقَالَ قُمْ فَوَاللَّهِ لَقَدْ عَلِمَ هَذَا أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَانَا عَنْ ذَلِكَ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ صَدَقَ‏.‏\hadithno{1309}\hadithtrans{Narrated Sa`id Al-Maqburi:That his father said, "While we were accompanying a funeral procession, Abu Huraira got hold of the hand of Marwan and they sat down before the coffin was put down. Then Abu Sa`id came and took hold of Marwan's hand and said, "Get up. By Allah, no doubt this (i.e. Abu Huraira) knows that the Prophet forbade us to do that." Abu Huraira said, "He (Abu Sa`id) has spoken the truth}}
\hadithdefcmd{bukhari}{1310}{حَدَّثَنَا مُسْلِمٌ ـ يَعْنِي ابْنَ إِبْرَاهِيمَ ـ حَدَّثَنَا هِشَامٌ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا، فَمَنْ تَبِعَهَا فَلاَ يَقْعُدْ حَتَّى تُوضَعَ ‏"‏‏.‏\hadithno{1310}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "When you see a funeral procession, you should stand up, and whoever accompanies it should not sit till the coffin is put down}}
\hadithdefcmd{bukhari}{1311}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ مَرَّ بِنَا جَنَازَةٌ فَقَامَ لَهَا النَّبِيُّ صلى الله عليه وسلم وَقُمْنَا بِهِ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ، إِنَّهَا جَنَازَةُ يَهُودِيٍّ‏.‏ قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا ‏"‏‏.‏\hadithno{1311}\hadithtrans{Narrated Jabir bin `Abdullah:A funeral procession passed in front of us and the Prophet (ﷺ) stood up and we too stood up. We said, 'O Allah's Messenger (ﷺ)! This is the funeral procession of a Jew." He said, "Whenever you see a funeral procession, you should stand up}}
\hadithdefcmd{bukhari}{1313}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، قَالَ كَانَ سَهْلُ بْنُ حُنَيْفٍ وَقَيْسُ بْنُ سَعْدٍ قَاعِدَيْنِ بِالْقَادِسِيَّةِ، فَمَرُّوا عَلَيْهِمَا بِجَنَازَةٍ فَقَامَا‏.‏ فَقِيلَ لَهُمَا إِنَّهَا مِنْ أَهْلِ الأَرْضِ، أَىْ مِنْ أَهْلِ الذِّمَّةِ فَقَالاَ إِنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّتْ بِهِ جَنَازَةٌ فَقَامَ فَقِيلَ لَهُ إِنَّهَا جَنَازَةُ يَهُودِيٍّ‏.‏ فَقَالَ ‏ "‏ أَلَيْسَتْ نَفْسًا ‏"‏‏.‏ وَقَالَ أَبُو حَمْزَةَ عَنِ الأَعْمَشِ، عَنْ عَمْرٍو، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ كُنْتُ مَعَ قَيْسٍ وَسَهْلٍ ـ رضى الله عنهما ـ فَقَالاَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ زَكَرِيَّاءُ عَنِ الشَّعْبِيِّ عَنِ ابْنِ أَبِي لَيْلَى كَانَ أَبُو مَسْعُودٍ وَقَيْسٌ يَقُومَانِ لِلْجِنَازَةِ‏.‏\hadithno{1313}\hadithtrans{Narrated `Abdur Rahman bin Abi Laila:Sahl bin Hunaif and Qais bin Sa`d were sitting in the city of Al-Qadisiya. A funeral procession passed in front of them and they stood up. They were told that funeral procession was of one of the inhabitants of the land i.e. of a non-believer, under the protection of Muslims. They said, "A funeral procession passed in front of the Prophet (ﷺ) and he stood up. When he was told that it was the coffin of a Jew, he said, "Is it not a living being (soul)?}}
\hadithdefcmd{bukhari}{1314}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وُضِعَتِ الْجِنَازَةُ وَاحْتَمَلَهَا الرِّجَالُ عَلَى أَعْنَاقِهِمْ، فَإِنْ كَانَتْ صَالِحَةً قَالَتْ قَدِّمُونِي‏.‏ وَإِنْ كَانَتْ غَيْرَ صَالِحَةٍ قَالَتْ يَا وَيْلَهَا أَيْنَ يَذْهَبُونَ بِهَا يَسْمَعُ صَوْتَهَا كُلُّ شَىْءٍ إِلاَّ الإِنْسَانَ، وَلَوْ سَمِعَهُ صَعِقَ ‏"‏‏.‏\hadithno{1314}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, When the funeral is ready and the men carry it on their shoulders, if the deceased was righteous it will say, 'Present me (hurriedly),' and if he was not righteous, it will say, 'Woe to it (me)! Where are they taking it (me)?' Its voice is heard by everything except man and if he heard it he would fall unconscious}}
\hadithdefcmd{bukhari}{1315}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنَ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْرِعُوا بِالْجِنَازَةِ، فَإِنْ تَكُ صَالِحَةً فَخَيْرٌ تُقَدِّمُونَهَا ‏\{‏إِلَيْهِ‏\}‏، وَإِنْ يَكُ سِوَى ذَلِكَ فَشَرٌّ تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏"‏‏.‏\hadithno{1315}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Hurry up with the dead body for if it was righteous, you are forwarding it to welfare; and if it was otherwise, then you are putting off an evil thing down your necks}}
\hadithdefcmd{bukhari}{1316}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا سَعِيدٌ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا وُضِعَتِ الْجِنَازَةُ فَاحْتَمَلَهَا الرِّجَالُ عَلَى أَعْنَاقِهِمْ، فَإِنْ كَانَتْ صَالِحَةً قَالَتْ قَدِّمُونِي‏.‏ وَإِنْ كَانَتْ غَيْرَ صَالِحَةٍ قَالَتْ لأَهْلِهَا يَا وَيْلَهَا أَيْنَ يَذْهَبُونَ بِهَا يَسْمَعُ صَوْتَهَا كُلُّ شَىْءٍ إِلاَّ الإِنْسَانَ، وَلَوْ سَمِعَ الإِنْسَانُ لَصَعِقَ ‏"‏‏.‏\hadithno{1316}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "When a funeral is ready and the men carry the deceased on their necks (shoulders), if it was pious then it will say, 'Present me quickly', and if it was not pious, then it will say, 'Woe to it (me), where are they taking it (me)?' And its voice is heard by everything except mankind and if he heard it he would fall unconscious}}
\hadithdefcmd{bukhari}{1317}{حَدَّثَنَا مُسَدَّدٌ، عَنْ أَبِي عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى عَلَى النَّجَاشِيِّ، فَكُنْتُ فِي الصَّفِّ الثَّانِي أَوِ الثَّالِثِ‏.‏\hadithno{1317}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) offered the funeral prayer for An-Najashi and I was in the second or third row}}
\hadithdefcmd{bukhari}{1318}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَعَى النَّبِيُّ صلى الله عليه وسلم إِلَى أَصْحَابِهِ النَّجَاشِيَّ، ثُمَّ تَقَدَّمَ فَصَفُّوا خَلْفَهُ فَكَبَّرَ أَرْبَعًا‏.‏\hadithno{1318}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) informed his companions about the death of An-Najashi and then he went ahead (to lead the prayer) and the people lined up behind him in rows and he said four Takbir}}
\hadithdefcmd{bukhari}{1319}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الشَّيْبَانِيُّ، عَنِ الشَّعْبِيِّ، قَالَ أَخْبَرَنِي مَنْ، شَهِدَ النَّبِيَّ صلى الله عليه وسلم أَنَّهُ أَتَى عَلَى قَبْرٍ مَنْبُوذٍ فَصَفَّهُمْ وَكَبَّرَ أَرْبَعًا‏.‏ قُلْتُ مَنْ حَدَّثَكَ قَالَ ابْنُ عَبَّاسٍ رضى الله عنهما‏.‏\hadithno{1319}\hadithtrans{Narrated Ash-Shaibani:Ash-Shu`bi said, "I was informed by a man who had seen the Prophet (ﷺ) going to a grave that was separate from the other graves and he aligned the people in rows and said four Takbir." I said, "O Abu `Amr! who narrated (that) to you"? He said, "Ibn `Abbas}}
\hadithdefcmd{bukhari}{1320}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي عَطَاءٌ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ قَدْ تُوُفِّيَ الْيَوْمَ رَجُلٌ صَالِحٌ مِنَ الْحَبَشِ فَهَلُمَّ فَصَلُّوا عَلَيْهِ ‏"‏‏.‏ قَالَ فَصَفَفْنَا فَصَلَّى النَّبِيُّ صلى الله عليه وسلم عَلَيْهِ وَنَحْنُ صُفُوفٌ‏.‏ قَالَ أَبُو الزُّبَيْرِ عَنْ جَابِرٍ كُنْتُ فِي الصَّفِّ الثَّانِي‏.‏\hadithno{1320}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "Today a pious man from Ethiopia (i.e. An Najashi) has expired, come on to offer the funeral prayer." (Jabir said): We lined up in rows and after that the Prophet (ﷺ) led the prayer and we were in rows. Jabir added, I was in the second row}}
\hadithdefcmd{bukhari}{1321}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الشَّيْبَانِيُّ، عَنْ عَامِرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِقَبْرٍ قَدْ دُفِنَ لَيْلاً فَقَالَ ‏"‏ مَتَى دُفِنَ هَذَا ‏"‏‏.‏ قَالُوا الْبَارِحَةَ‏.‏ قَالَ ‏"‏ أَفَلاَ آذَنْتُمُونِي ‏"‏‏.‏ قَالُوا دَفَنَّاهُ فِي ظُلْمَةِ اللَّيْلِ فَكَرِهْنَا أَنْ نُوقِظَكَ‏.‏ فَقَامَ فَصَفَفْنَا خَلْفَهُ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَأَنَا فِيهِمْ فَصَلَّى عَلَيْهِ‏.‏\hadithno{1321}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) passed by a grave of a deceased who had been buried at night. He said, "When was this (deceased) buried?" The people said, "Yesterday." He said, "Why did you not inform me?" They said, "We buried him when it was dark and so we disliked to wake you up." He stood up and we lined up behind him. (Ibn `Abbas said): I was one of them, and the Prophet (ﷺ) offered the funeral prayer}}
\hadithdefcmd{bukhari}{1322}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، قَالَ أَخْبَرَنِي مَنْ، مَرَّ مَعَ نَبِيِّكُمْ صلى الله عليه وسلم عَلَى قَبْرٍ مَنْبُوذٍ فَأَمَّنَا فَصَفَفْنَا خَلْفَهُ‏.‏ فَقُلْنَا يَا أَبَا عَمْرٍو مَنْ حَدَّثَكَ قَالَ ابْنُ عَبَّاسٍ رضى الله عنهما‏.‏\hadithno{1322}\hadithtrans{Narrated Ash-Shaibani:Ash-Shu`bi said, "Somebody who passed along with your Prophet (ﷺ) by a grave that was separate from the other graves informed me (saying), "The Prophet (ﷺ) led us (in the prayer) and we aligned behind him." We said, "O Abu `Amr! Who told you this narration?" He replied, "Ibn `Abbas}}
\hadithdefcmd{bukhari}{1324}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ سَمِعْتُ نَافِعًا، يَقُولُ حُدِّثَ ابْنُ عُمَرَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنهم ـ يَقُولُ مَنْ تَبِعَ جَنَازَةً فَلَهُ قِيرَاطٌ‏.‏ فَقَالَ أَكْثَرَ أَبُو هُرَيْرَةَ عَلَيْنَا‏.‏ فَصَدَّقَتْ ـ يَعْنِي عَائِشَةَ ـ أَبَا هُرَيْرَةَ وَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُهُ‏.‏ فَقَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ لَقَدْ فَرَّطْنَا فِي قَرَارِيطَ كَثِيرَةٍ‏.‏ ‏\{‏فَرَّطْتُ‏\}‏ ضَيَّعْتُ مِنْ أَمْرِ اللَّهِ‏.‏\hadithno{1324}\hadithtrans{Narrated Nafi`:Ibn `Umar was told that Abu Huraira said, "Whoever accompanies the funeral procession will have a reward equal to one Qirat." Ibn `Umar said, "Abu Huraira talks of a too enormous reward." Aisha attested Abu Huraira's narration and said, "I heard Allah's Messenger (ﷺ) saying like that." Ibn `Umar said, "We have lost numerous Qirats}}
\hadithdefcmd{bukhari}{1325}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ قَرَأْتُ عَلَى ابْنِ أَبِي ذِئْبٍ عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، أَنَّهُ سَأَلَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ شَبِيبِ بْنِ سَعِيدٍ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا يُونُسُ، قَالَ ابْنُ شِهَابٍ وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ الأَعْرَجُ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ شَهِدَ الْجَنَازَةَ حَتَّى يُصَلِّيَ عَلَيْهَا فَلَهُ قِيرَاطٌ، وَمَنْ شَهِدَ حَتَّى تُدْفَنَ كَانَ لَهُ قِيرَاطَانِ ‏"‏‏.‏ قِيلَ وَمَا الْقِيرَاطَانِ قَالَ ‏"‏ مِثْلُ الْجَبَلَيْنِ الْعَظِيمَيْنِ ‏"‏‏.‏\hadithno{1325}\hadithtrans{Narrated Abu Huraira:that Allah's Messenger (ﷺ) said, "Whoever attends the funeral procession till he offers the funeral prayer for it, will get a reward equal to one Qirat, and whoever accompanies it till burial, will get a reward equal to two Qirats." It was asked, "What are two Qirats?" He replied, "Like two huge mountains}}
\hadithdefcmd{bukhari}{1326}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زَائِدَةُ، حَدَّثَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، عَنْ عَامِرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْرًا، فَقَالُوا هَذَا دُفِنَ، أَوْ دُفِنَتِ الْبَارِحَةَ‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ فَصَفَّنَا خَلْفَهُ ثُمَّ صَلَّى عَلَيْهَا‏.‏\hadithno{1326}\hadithtrans{Narrated 'Amir:Ibn `Abbas (who was at that time a boy) said, "Allah's Messenger (ﷺ) came to a grave and the people said, 'He or she was buried yesterday.' " Ibn `Abbas added, "We aligned behind the Prophet (ﷺ) and he led the funeral prayer of the deceased}}
\hadithdefcmd{bukhari}{1328}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ أَنَّهُمَا حَدَّثَاهُ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَعَى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم النَّجَاشِيَّ صَاحِبَ الْحَبَشَةِ، يَوْمَ الَّذِي مَاتَ فِيهِ فَقَالَ ‏ "‏ اسْتَغْفِرُوا لأَخِيكُمْ ‏"‏‏.‏ وَعَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم صَفَّ بِهِمْ بِالْمُصَلَّى فَكَبَّرَ عَلَيْهِ أَرْبَعًا‏.‏\hadithno{1328}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) informed about the news of the death of An-Najash (King of Ethiopia) on the day he expired. He said, "Ask Allah's forgiveness for your brother. " Narrated Abu Huraira: The Prophet (ﷺ) made them align in rows at the Musalla and said four Takbir}}
\hadithdefcmd{bukhari}{1329}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ الْيَهُودَ، جَاءُوا إِلَى النَّبِيِّ صلى الله عليه وسلم بِرَجُلٍ مِنْهُمْ وَامْرَأَةٍ زَنَيَا، فَأَمَرَ بِهِمَا فَرُجِمَا قَرِيبًا مِنْ مَوْضِعِ الْجَنَائِزِ عِنْدَ الْمَسْجِدِ‏.‏\hadithno{1329}\hadithtrans{Narrated `Abdullah bin `Umar:The Jew brought to the Prophet (ﷺ) a man and a woman from amongst them who had committed (adultery) illegal sexual intercourse. He ordered both of them to be stoned (to death), near the place of offering the funeral prayers beside the mosque}}
\hadithdefcmd{bukhari}{1330}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ هِلاَلٍ ـ هُوَ الْوَزَّانُ ـ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ وَالنَّصَارَى، اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسْجِدًا ‏"‏‏.‏ قَالَتْ وَلَوْلاَ ذَلِكَ لأَبْرَزُوا قَبْرَهُ غَيْرَ أَنِّي أَخْشَى أَنْ يُتَّخَذَ مَسْجِدًا‏.‏\hadithno{1330}\hadithtrans{Narrated `Urwa:Aisha said, "The Prophet (ﷺ) in his fatal illness said, 'Allah cursed the Jews and the Christians because they took the graves of their Prophets as places for praying."' Aisha added, "Had it not been for that, the grave of the Prophet (ﷺ) would have been made prominent but I am afraid it might be taken (as a) place for praying}}
\hadithdefcmd{bukhari}{1331}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حُسَيْنٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ سَمُرَةَ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ وَرَاءَ النَّبِيِّ صلى الله عليه وسلم عَلَى امْرَأَةٍ مَاتَتْ فِي نِفَاسِهَا، فَقَامَ عَلَيْهَا وَسَطَهَا‏.‏\hadithno{1331}\hadithtrans{Narrated Samura bin Jundab:I offered the funeral prayer behind the Prophet (ﷺ) for a woman who had died during childbirth and he stood up by the middle of the coffin}}
\hadithdefcmd{bukhari}{1332}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا حُسَيْنٌ، عَنِ ابْنِ بُرَيْدَةَ، حَدَّثَنَا سَمُرَةُ بْنُ جُنْدُبٍ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ وَرَاءَ النَّبِيِّ صلى الله عليه وسلم عَلَى امْرَأَةٍ مَاتَتْ فِي نِفَاسِهَا فَقَامَ عَلَيْهَا وَسَطَهَا‏.‏\hadithno{1332}\hadithtrans{Narrated Samura bin Jundab:I offered the funeral prayer behind the Prophet (ﷺ) for a woman who had died during childbirth and he stood up by the middle of the coffin}}
\hadithdefcmd{bukhari}{1333}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى النَّجَاشِيَّ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ، وَخَرَجَ بِهِمْ إِلَى الْمُصَلَّى فَصَفَّ بِهِمْ، وَكَبَّرَ عَلَيْهِ أَرْبَعَ تَكْبِيرَاتٍ‏.‏\hadithno{1333}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) informed about the news of the death of An-Najash on the day he died. He went out with us to the Musalla and we aligned in rows and he said four Takbirs for An-Najashi's funeral prayer}}
\hadithdefcmd{bukhari}{1334}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، عَنْ جَابِرٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى أَصْحَمَةَ النَّجَاشِيِّ فَكَبَّرَ أَرْبَعًا‏.‏ وَقَالَ يَزِيدُ بْنُ هَارُونَ وَعَبْدُ الصَّمَدِ عَنْ سَلِيمٍ أَصْحَمَةَ‏.‏ وَتَابَعَهُ عَبْدُ الصَّمَدِ‏.‏\hadithno{1334}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) offered the funeral prayer of As-Hama An-Najash and said four Takbir}}
\hadithdefcmd{bukhari}{1335}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، عَنْ طَلْحَةَ، قَالَ صَلَّيْتُ خَلْفَ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، قَالَ صَلَّيْتُ خَلْفَ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَلَى جَنَازَةٍ فَقَرَأَ بِفَاتِحَةِ الْكِتَابِ قَالَ لِيَعْلَمُوا أَنَّهَا سُنَّةٌ‏.‏\hadithno{1335}\hadithtrans{Narrated Talha bin `Abdullah bin `Auf:I offered the funeral prayer behind Ibn `Abbas and he recited Al-Fatiha and said, "You should know that it (i.e. recitation of Al-Fatiha) is the tradition of the Prophet Muhammad (ﷺ)}}
\hadithdefcmd{bukhari}{1336}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي سُلَيْمَانُ الشَّيْبَانِيُّ، قَالَ سَمِعْتُ الشَّعْبِيَّ، قَالَ أَخْبَرَنِي مَنْ، مَرَّ مَعَ النَّبِيِّ صلى الله عليه وسلم عَلَى قَبْرٍ مَنْبُوذٍ فَأَمَّهُمْ وَصَلَّوْا خَلْفَهُ‏.‏ قُلْتُ مَنْ حَدَّثَكَ هَذَا يَا أَبَا عَمْرٍو قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ‏.‏\hadithno{1336}\hadithtrans{Narrated Sulaiman Ash-Shaibani:I heard Ash-Shu`bi saying, "I was told by a man who had passed with the Prophet (ﷺ) by a grave that was separate from the other graves that he (the Prophet (ﷺ) ) led them in the prayer and they prayed behind him." I said, "O Abu `Amr! Who narrated that to you?" He replied, "Ibn `Abbas}}
\hadithdefcmd{bukhari}{1337}{حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ أَسْوَدَ ـ رَجُلاً أَوِ امْرَأَةً ـ كَانَ يَقُمُّ الْمَسْجِدَ فَمَاتَ، وَلَمْ يَعْلَمِ النَّبِيُّ صلى الله عليه وسلم بِمَوْتِهِ فَذَكَرَهُ ذَاتَ يَوْمٍ فَقَالَ ‏"‏ مَا فَعَلَ ذَلِكَ الإِنْسَانُ ‏"‏‏.‏ قَالُوا مَاتَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ أَفَلاَ آذَنْتُمُونِي ‏"‏‏.‏ فَقَالُوا إِنَّهُ كَانَ كَذَا وَكَذَا قِصَّتَهُ‏.‏ قَالَ فَحَقَرُوا شَأْنَهُ‏.‏ قَالَ ‏"‏ فَدُلُّونِي عَلَى قَبْرِهِ ‏"‏‏.‏ فَأَتَى قَبْرَهُ فَصَلَّى عَلَيْهِ‏.‏\hadithno{1337}\hadithtrans{Narrated Abu Huraira:A black person, a male or a female used to clean the Mosque and then died. The Prophet (ﷺ) did not know about it . One day the Prophet (ﷺ) remembered him and said, "What happened to that person?" The people replied, "O Allah's Messenger (ﷺ)! He died." He said, "Why did you not inform me?" They said, "His story was so and so (i.e. regarded him as insignificant)." He said, "Show me his grave." He then went to his grave and offered the funeral prayer}}
\hadithdefcmd{bukhari}{1338}{حَدَّثَنَا عَيَّاشٌ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، قَالَ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا ابْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَبْدُ إِذَا وُضِعَ فِي قَبْرِهِ، وَتُوُلِّيَ وَذَهَبَ أَصْحَابُهُ حَتَّى إِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ، أَتَاهُ مَلَكَانِ فَأَقْعَدَاهُ فَيَقُولاَنِ لَهُ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ مُحَمَّدٍ صلى الله عليه وسلم فَيَقُولُ أَشْهَدُ أَنَّهُ عَبْدُ اللَّهِ وَرَسُولُهُ‏.‏ فَيُقَالُ انْظُرْ إِلَى مَقْعَدِكَ مِنَ النَّارِ، أَبْدَلَكَ اللَّهُ بِهِ مَقْعَدًا مِنَ الْجَنَّةِ ـ قَالَ النَّبِيُّ صلى الله عليه وسلم فَيَرَاهُمَا جَمِيعًا ـ وَأَمَّا الْكَافِرُ ـ أَوِ الْمُنَافِقُ ـ فَيَقُولُ لاَ أَدْرِي، كُنْتُ أَقُولُ مَا يَقُولُ النَّاسُ‏.‏ فَيُقَالُ لاَ دَرَيْتَ وَلاَ تَلَيْتَ‏.‏ ثُمَّ يُضْرَبُ بِمِطْرَقَةٍ مِنْ حَدِيدٍ ضَرْبَةً بَيْنَ أُذُنَيْهِ، فَيَصِيحُ صَيْحَةً يَسْمَعُهَا مَنْ يَلِيهِ إِلاَّ الثَّقَلَيْنِ ‏"‏‏.‏\hadithno{1338}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "When a human being is laid in his grave and his companions return and he even hears their foot steps, two angels come to him and make him sit and ask him: What did you use to say about this man, Muhammad ? He will say: I testify that he is Allah's slave and His Apostle. Then it will be said to him, 'Look at your place in the Hell-Fire. Allah has given you a place in Paradise instead of it.' " The Prophet (ﷺ) added, "The dead person will see both his places. But a non-believer or a hypocrite will say to the angels, 'I do not know, but I used to say what the people used to say! It will be said to him, 'Neither did you know nor did you take the guidance (by reciting the Qur'an).' Then he will be hit with an iron hammer between his two ears, and he will cry and that cry will be heard by whatever approaches him except human beings and jinns}}
\hadithdefcmd{bukhari}{1339}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ ‏"‏ أُرْسِلَ مَلَكُ الْمَوْتِ إِلَى مُوسَى ـ عَلَيْهِمَا السَّلاَمُ ـ فَلَمَّا جَاءَهُ صَكَّهُ فَرَجَعَ إِلَى رَبِّهِ فَقَالَ أَرْسَلْتَنِي إِلَى عَبْدٍ لاَ يُرِيدُ الْمَوْتَ‏.‏ فَرَدَّ اللَّهُ عَلَيْهِ عَيْنَهُ وَقَالَ ارْجِعْ فَقُلْ لَهُ يَضَعُ يَدَهُ عَلَى مَتْنِ ثَوْرٍ، فَلَهُ بِكُلِّ مَا غَطَّتْ بِهِ يَدُهُ بِكُلِّ شَعْرَةٍ سَنَةٌ‏.‏ قَالَ أَىْ رَبِّ، ثُمَّ مَاذَا قَالَ ثُمَّ الْمَوْتُ‏.‏ قَالَ فَالآنَ‏.‏ فَسَأَلَ اللَّهَ أَنْ يُدْنِيَهُ مِنَ الأَرْضِ الْمُقَدَّسَةِ رَمْيَةً بِحَجَرٍ ‏"‏‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلَوْ كُنْتُ ثَمَّ لأَرَيْتُكُمْ قَبْرَهُ إِلَى جَانِبِ الطَّرِيقِ عِنْدَ الْكَثِيبِ الأَحْمَرِ ‏"‏‏.‏\hadithno{1339}\hadithtrans{Narrated Abu Huraira:The angel of death was sent to Moses and when he went to him, Moses slapped him severely, spoiling one of his eyes. The angel went back to his Lord, and said, "You sent me to a slave who does not want to die." Allah restored his eye and said, "Go back and tell him (i.e. Moses) to place his hand over the back of an ox, for he will be allowed to live for a number of years equal to the number of hairs coming under his hand." (So the angel came to him and told him the same). Then Moses asked, "O my Lord! What will be then?" He said, "Death will be then." He said, "(Let it be) now." He asked Allah that He bring him near the Sacred Land at a distance of a stone's throw. Allah's Messenger (ﷺ) said, "Were I there I would show you the grave of Moses by the way near the red sand hill}}
\hadithdefcmd{bukhari}{1340}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم عَلَى رَجُلٍ بَعْدَ مَا دُفِنَ بِلَيْلَةٍ قَامَ هُوَ وَأَصْحَابُهُ، وَكَانَ سَأَلَ عَنْهُ فَقَالَ ‏ "‏ مَنْ هَذَا ‏"‏‏.‏ فَقَالُوا فُلاَنٌ، دُفِنَ الْبَارِحَةَ‏.‏ فَصَلَّوْا عَلَيْهِ‏.‏\hadithno{1340}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) offered the funeral prayer of a man one night after he was buried, he and his companions stood up (for the Prayer). He had asked them about him before standing, saying, "Who is this?" They said, "He is so and so and was buried last night." So all of them offered the funeral prayer}}
\hadithdefcmd{bukhari}{1341}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا اشْتَكَى النَّبِيُّ صلى الله عليه وسلم ذَكَرَتْ بَعْضُ نِسَائِهِ كَنِيسَةً رَأَيْنَهَا بِأَرْضِ الْحَبَشَةِ، يُقَالُ لَهَا مَارِيَةُ، وَكَانَتْ أُمُّ سَلَمَةَ وَأُمُّ حَبِيبَةَ ـ رضى الله عنهما ـ أَتَتَا أَرْضَ الْحَبَشَةِ، فَذَكَرَتَا مِنْ حُسْنِهَا وَتَصَاوِيرَ فِيهَا، فَرَفَعَ رَأْسَهُ فَقَالَ ‏ "‏ أُولَئِكَ إِذَا مَاتَ مِنْهُمُ الرَّجُلُ الصَّالِحُ بَنَوْا عَلَى قَبْرِهِ مَسْجِدًا، ثُمَّ صَوَّرُوا فِيهِ تِلْكَ الصُّورَةَ، أُولَئِكَ شِرَارُ الْخَلْقِ عِنْدَ اللَّهِ ‏"‏‏.‏\hadithno{1341}\hadithtrans{Narrated `Aisha:When the Prophet (ﷺ) became ill, some of his wives talked about a church which they had seen in Ethiopia and it was called Mariya. Um Salma and Um Habiba had been to Ethiopia, and both of them narrated its (the Church's) beauty and the pictures it contained. The Prophet (ﷺ) raised his head and said, "Those are the people who, whenever a pious man dies amongst them, make a place of worship at his grave and then they make those pictures in it. Those are the worst creatures in the Sight of Allah}}
\hadithdefcmd{bukhari}{1342}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ شَهِدْنَا بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ عَلَى الْقَبْرِ، فَرَأَيْتُ عَيْنَيْهِ تَدْمَعَانِ فَقَالَ ‏"‏ هَلْ فِيكُمْ مِنْ أَحَدٍ لَمْ يُقَارِفِ اللَّيْلَةَ ‏"‏‏.‏ فَقَالَ أَبُو طَلْحَةَ أَنَا‏.‏ قَالَ ‏"‏ فَانْزِلْ فِي قَبْرِهَا ‏"‏‏.‏ فَنَزَلَ فِي قَبْرِهَا فَقَبَرَهَا‏.‏ قَالَ ابْنُ الْمُبَارَكِ قَالَ فُلَيْحٌ أُرَاهُ يَعْنِي الذَّنْبَ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ ‏\{‏لِيَقْتَرِفُوا‏\}‏ أَىْ لِيَكْتَسِبُوا‏.‏\hadithno{1342}\hadithtrans{Narrated Anas:We were in the funeral procession of the daughter of Allah's Messenger (ﷺ) and Allah's Messenger (ﷺ) was sitting near the grave and I saw his eyes full of tears. He said, "Is there anyone amongst you who did not have sexual relations with his wife last night?" Abu Talha replied in the affirmative. And so Allah's Apostle told him to get down in her grave and he got down in her grave and buried her}}
\hadithdefcmd{bukhari}{1343}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ فِي ثَوْبٍ وَاحِدٍ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمْ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدِهِمَا قَدَّمَهُ فِي اللَّحْدِ وَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ وَأَمَرَ بِدَفْنِهِمْ فِي دِمَائِهِمْ، وَلَمْ يُغَسَّلُوا وَلَمْ يُصَلَّ عَلَيْهِمْ‏.‏\hadithno{1343}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) collected every two martyrs of Uhud in one piece of cloth, then he would ask, "Which of them had (knew) more of the Qur'an?" When one of them was pointed out for him, he would put that one first in the grave and say, "I will be a witness on these on the Day of Resurrection." He ordered them to be buried with their blood on their bodies and they were neither washed nor was a funeral prayer offered for them}}
\hadithdefcmd{bukhari}{1344}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمًا فَصَلَّى عَلَى أَهْلِ أُحُدٍ صَلاَتَهُ عَلَى الْمَيِّتِ، ثُمَّ انْصَرَفَ إِلَى الْمِنْبَرِ فَقَالَ ‏ "‏ إِنِّي فَرَطٌ لَكُمْ، وَأَنَا شَهِيدٌ عَلَيْكُمْ، وَإِنِّي وَاللَّهِ لأَنْظُرُ إِلَى حَوْضِي الآنَ، وَإِنِّي أُعْطِيتُ مَفَاتِيحَ خَزَائِنِ الأَرْضِ ـ أَوْ مَفَاتِيحَ الأَرْضِ ـ وَإِنِّي وَاللَّهِ مَا أَخَافُ عَلَيْكُمْ أَنْ تُشْرِكُوا بَعْدِي، وَلَكِنْ أَخَافُ عَلَيْكُمْ أَنْ تَنَافَسُوا فِيهَا ‏"‏‏.‏\hadithno{1344}\hadithtrans{Narrated `Uqba bin 'Amir:One day the Prophet (ﷺ) went out and offered the funeral prayers of the martyrs of Uhud and then went up the pulpit and said, "I will pave the way for you as your predecessor and will be a witness on you. By Allah! I see my Fount (Kauthar) just now and I have been given the keys of all the treasures of the earth (or the keys of the earth). By Allah! I am not afraid that you will worship others along with Allah after my death, but I am afraid that you will fight with one another for the worldly things}}
\hadithdefcmd{bukhari}{1345}{حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ‏.‏\hadithno{1345}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) buried every two martyrs in of Uhud in one grave}}
\hadithdefcmd{bukhari}{1346}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبٍ، عَنْ جَابِرٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ادْفِنُوهُمْ فِي دِمَائِهِمْ ‏"‏‏.‏ ـ يَعْنِي يَوْمَ أُحُدٍ ـ وَلَمْ يُغَسِّلْهُمْ‏.‏\hadithno{1346}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said, "Bury them (i.e. martyrs) with their blood." (that was) On the day of the Battle of Uhud. He did not get them washed}}
\hadithdefcmd{bukhari}{1348}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا لَيْثُ بْنُ سَعْدٍ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ فِي ثَوْبٍ وَاحِدٍ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمْ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدِهِمَا قَدَّمَهُ فِي اللَّحْدِ وَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ ‏"‏‏.‏ وَأَمَرَ بِدَفْنِهِمْ بِدِمَائِهِمْ، وَلَمْ يُصَلِّ عَلَيْهِمْ وَلَمْ يُغَسِّلْهُمْ‏.‏ وَأَخْبَرَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ لِقَتْلَى أُحُدٍ ‏"‏ أَىُّ هَؤُلاَءِ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى رَجُلٍ قَدَّمَهُ فِي اللَّحْدِ قَبْلَ صَاحِبِهِ‏.‏ وَقَالَ جَابِرٌ فَكُفِّنَ أَبِي وَعَمِّي فِي نَمِرَةٍ وَاحِدَةٍ‏.‏ وَقَالَ سُلَيْمَانُ بْنُ كَثِيرٍ حَدَّثَنِي الزُّهْرِيُّ، حَدَّثَنَا مَنْ، سَمِعَ جَابِرًا ـ رضى الله عنه‏.‏\hadithno{1348}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) shrouded every two martyrs of Uhud in one piece of cloth and then he would ask, "Which of them knew more Qur'an?" When one of them was pointed out he would put him first in the grave. He said, "I am a witness on these." Then he ordered them to be buried with blood on their bodies. Neither did he offer their funeral prayer nor did he get them washed. (Jabir bin `Abdullah added): Allah's Messenger (ﷺ) used to ask about the martyrs of Uhud as to which of them knew more of the Qur'an." And when one of them was pointed out as having more of it he would put him first in the grave and then his companions. (Jabir added): My father and my uncle were shrouded in one sheet}}
\hadithdefcmd{bukhari}{1349}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ حَرَّمَ اللَّهُ مَكَّةَ، فَلَمْ تَحِلَّ لأَحَدٍ قَبْلِي وَلاَ لأَحَدٍ بَعْدِي، أُحِلَّتْ لِي سَاعَةً مِنْ نَهَارٍ، لاَ يُخْتَلَى خَلاَهَا، وَلاَ يُعْضَدُ شَجَرُهَا، وَلاَ يُنَفَّرُ صَيْدُهَا، وَلاَ تُلْتَقَطُ لُقَطَتُهَا إِلاَّ لِمُعَرِّفٍ ‏"‏‏.‏ فَقَالَ الْعَبَّاسُ ـ رضى الله عنه ـ إِلاَّ الإِذْخِرَ لِصَاغَتِنَا وَقُبُورِنَا‏.‏ فَقَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏ وَقَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لِقُبُورِنَا وَبُيُوتِنَا ‏"‏‏.‏ وَقَالَ أَبَانُ بْنُ صَالِحٍ عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم مِثْلَهُ‏.‏ وَقَالَ مُجَاهِدٌ عَنْ طَاوُسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ لِقَيْنِهِمْ وَبُيُوتِهِمْ‏.‏\hadithno{1349}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Allah has made Mecca a sanctuary (sacred place) and it was a sanctuary before me and will be so after me. It was made legal for me (to fight in it) for a few hours of the day. None is allowed to uproot its thorny shrubs or to cut its trees or to chase its game or to pick up its fallen things except by a person who announces it publicly." On that Al-Abbas said (to the Prophet), "Except Al- Idhkhir for our goldsmiths and for our graves." And so the Prophet (ﷺ) added, "Except Al-Idhkhir. " And Abu Huraira narrated that the Prophet (ﷺ) said, "Except Al-Idhkhir for our graves and houses." And Ibn `Abbas said, "For their goldsmiths and houses}}
\hadithdefcmd{bukhari}{1350}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَبْدَ اللَّهِ بْنَ أُبَىٍّ بَعْدَ مَا أُدْخِلَ حُفْرَتَهُ فَأَمَرَ بِهِ فَأُخْرِجَ، فَوَضَعَهُ عَلَى رُكْبَتَيْهِ، وَنَفَثَ عَلَيْهِ مِنْ رِيقِهِ، وَأَلْبَسَهُ قَمِيصَهُ، فَاللَّهُ أَعْلَمُ، وَكَانَ كَسَا عَبَّاسًا قَمِيصًا‏.‏ قَالَ سُفْيَانُ وَقَالَ أَبُو هَارُونَ وَكَانَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَمِيصَانِ، فَقَالَ لَهُ ابْنُ عَبْدِ اللَّهِ يَا رَسُولَ اللَّهِ، أَلْبِسْ أَبِي قَمِيصَكَ الَّذِي يَلِي جِلْدَكَ‏.‏ قَالَ سُفْيَانُ فَيُرَوْنَ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَلْبَسَ عَبْدَ اللَّهِ قَمِيصَهُ مُكَافَأَةً لِمَا صَنَعَ‏.‏\hadithno{1350}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) came to `Abdullah bin Ubai (a hypocrite) after his death and he had been laid in his pit (grave). He ordered (that he be taken out of the grave) and he was taken out. Then he placed him on his knees and threw some of his saliva on him and clothed him in his (the Prophet's) own shirt. Allah knows better (why he did so). `Abdullah bin Ubai had given his shirt to Al-Abbas to wear. Abu Harun said, "Allah's Messenger (ﷺ) at that time had two shirts and the son of `Abdullah bin Ubai said to him, 'O Allah's Messenger (ﷺ)! Clothe my father in your shirt which has been in contact with your skin.' ' Sufyan added, "Thus people think that the Prophet (ﷺ) clothed `Abdullah bin Ubai in his shirt in lieu of what he (Abdullah) had done (for Al-`Abbas, the Prophet's uncle)}}
\hadithdefcmd{bukhari}{1351}{حَدَّثَنَا مُسَدَّدٌ، أَخْبَرَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ لَمَّا حَضَرَ أُحُدٌ دَعَانِي أَبِي مِنَ اللَّيْلِ فَقَالَ مَا أُرَانِي إِلاَّ مَقْتُولاً فِي أَوَّلِ مَنْ يُقْتَلُ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم، وَإِنِّي لاَ أَتْرُكُ بَعْدِي أَعَزَّ عَلَىَّ مِنْكَ، غَيْرَ نَفْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَإِنَّ عَلَىَّ دَيْنًا فَاقْضِ، وَاسْتَوْصِ بِأَخَوَاتِكَ خَيْرًا‏.‏ فَأَصْبَحْنَا فَكَانَ أَوَّلَ قَتِيلٍ، وَدُفِنَ مَعَهُ آخَرُ فِي قَبْرٍ، ثُمَّ لَمْ تَطِبْ نَفْسِي أَنْ أَتْرُكَهُ مَعَ الآخَرِ فَاسْتَخْرَجْتُهُ بَعْدَ سِتَّةِ أَشْهُرٍ، فَإِذَا هُوَ كَيَوْمِ وَضَعْتُهُ هُنَيَّةً غَيْرَ أُذُنِهِ‏.‏\hadithno{1351}\hadithtrans{Narrated Jabir:When the time of the Battle of Uhud approached, my father called me at night and said, "I think that I will be the first amongst the companions of the Prophet (ﷺ) to be martyred. I do not leave anyone after me dearer to me than you, except Allah's Messenger's (ﷺ) soul and I owe some debt and you should repay it and treat your sisters favorably (nicely and politely)." So in the morning he was the first to be martyred and was buried along with another (martyr). I did not like to leave him with the other (martyr) so I took him out of the grave after six months of his burial and he was in the same condition as he was on the day of burial, except a slight change near his ear}}
\hadithdefcmd{bukhari}{1352}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ شُعْبَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ دُفِنَ مَعَ أَبِي رَجُلٌ فَلَمْ تَطِبْ نَفْسِي حَتَّى أَخْرَجْتُهُ فَجَعَلْتُهُ فِي قَبْرٍ عَلَى حِدَةٍ‏.‏\hadithno{1352}\hadithtrans{Narrated Jabir:A man was buried along with my father and I did not like it till I took him (i.e. my father) out and buried him in a separate grave}}
\hadithdefcmd{bukhari}{1353}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا اللَّيْثُ بْنُ سَعْدٍ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَجْمَعُ بَيْنَ رَجُلَيْنِ مِنْ قَتْلَى أُحُدٍ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمْ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدِهِمَا قَدَّمَهُ فِي اللَّحْدِ فَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ فَأَمَرَ بِدَفْنِهِمْ بِدِمَائِهِمْ وَلَمْ يُغَسِّلْهُمْ‏.‏\hadithno{1353}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) collected every two martyrs of Uhud (in one grave) and then he would ask, "Which of them knew the Qur'an more?" And if one of them was pointed out for him as having more knowledge, he would put him first in the Lahd. The Prophet (ﷺ) said, "I will be a witness on these on the Day of Resurrection." Then he ordered them to be buried with their blood on their bodies and he did not have them washed}}
\hadithdefcmd{bukhari}{1355}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ عُمَرَ انْطَلَقَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي رَهْطٍ قِبَلَ ابْنِ صَيَّادٍ، حَتَّى وَجَدُوهُ يَلْعَبُ مَعَ الصِّبْيَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ، وَقَدْ قَارَبَ ابْنُ صَيَّادٍ الْحُلُمَ فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ ثُمَّ قَالَ لاِبْنِ صَيَّادٍ ‏"‏ تَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏‏.‏ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ‏.‏ فَقَالَ ابْنُ صَيَّادٍ لِلنَّبِيِّ صلى الله عليه وسلم أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَرَفَضَهُ وَقَالَ آمَنْتُ بِاللَّهِ وَبِرُسُلِهِ‏.‏ فَقَالَ لَهُ ‏"‏ مَاذَا تَرَى ‏"‏‏.‏ قَالَ ابْنُ صَيَّادٍ يَأْتِينِي صَادِقٌ وَكَاذِبٌ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏ ثُمَّ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ خَبَأْتُ لَكَ خَبِيئًا ‏"‏‏.‏ فَقَالَ ابْنُ صَيَّادٍ هُوَ الدُّخُّ‏.‏ فَقَالَ ‏"‏ اخْسَأْ، فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏‏.‏ فَقَالَ عُمَرُ ـ رضى الله عنه ـ دَعْنِي يَا رَسُولَ اللَّهِ أَضْرِبْ عُنُقَهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْهُ فَلَنْ تُسَلَّطَ عَلَيْهِ، وَإِنْ لَمْ يَكُنْهُ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏‏.‏ وَقَالَ سَالِمٌ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ انْطَلَقَ بَعْدَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ إِلَى النَّخْلِ الَّتِي فِيهَا ابْنُ صَيَّادٍ وَهُوَ يَخْتِلُ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ ابْنُ صَيَّادٍ فَرَآهُ النَّبِيُّ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ، يَعْنِي فِي قَطِيفَةٍ لَهُ فِيهَا رَمْزَةٌ أَوْ زَمْرَةٌ، فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَتَّقِي بِجُذُوعِ النَّخْلِ فَقَالَتْ لاِبْنِ صَيَّادٍ يَا صَافِ ـ وَهْوَ اسْمُ ابْنِ صَيَّادٍ ـ هَذَا مُحَمَّدٌ صلى الله عليه وسلم‏.‏ فَثَارَ ابْنُ صَيَّادٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏‏.‏ وَقَالَ شُعَيْبٌ فِي حَدِيثِهِ فَرَفَصَهُ رَمْرَمَةٌ، أَوْ زَمْزَمَةٌ‏.‏ وَقَالَ إِسْحَاقُ الْكَلْبِيُّ وَعُقَيْلٌ رَمْرَمَةٌ‏.‏ وَقَالَ مَعْمَرٌ رَمْزَةٌ‏.‏\hadithno{1355}\hadithtrans{Narrated Ibn `Umar:`Umar set out along with the Prophet (ﷺ) with a group of people to Ibn Saiyad till they saw him playing with the boys near the hillocks of Bani Mughala. Ibn Saiyad at that time was nearing his puberty and did not notice (us) until the Prophet (ﷺ) stroked him with his hand and said to him, "Do you testify that I am Allah's Messenger (ﷺ)?" Ibn Saiyad looked at him and said, "I testify that you are the Messenger of illiterates." Then Ibn Saiyad asked the Prophet (ﷺ), "Do you testify that I am Allah's Messenger (ﷺ)?" The Prophet (ﷺ) refuted it and said, "I believe in Allah and His Apostles." Then he said (to Ibn Saiyad), "What do you think?" Ibn Saiyad answered, "True people and liars visit me." The Prophet (ﷺ) said, "You have been confused as to this matter." Then the Prophet (ﷺ) said to him, "I have kept something (in my mind) for you, (can you tell me that?)" Ibn Saiyad said, "It is Al-Dukh (the smoke)." (2) The Prophet (ﷺ) said, "Let you be in ignominy. You cannot cross your limits." On that `Umar, said, "O Allah's Messenger (ﷺ)! Allow me to chop his head off." The Prophet (ﷺ) said, "If he is he (i.e. Dajjal), then you cannot overpower him, and if he is not, then there is no use of murdering him." (Ibn `Umar added): Later on Allah's Messenger (ﷺ) once again went along with Ubai bin Ka`b to the date-palm trees (garden) where Ibn Saiyad was staying. The Prophet (ﷺ) wanted to hear something from Ibn Saiyad before Ibn Saiyad could see him, and the Prophet (ﷺ) saw him lying covered with a sheet and from where his murmurs were heard. Ibn Saiyad's mother saw Allah's Apostle while he was hiding himself behind the trunks of the date-palm trees. She addressed Ibn Saiyad, "O Saf ! (and this was the name of Ibn Saiyad) Here is Muhammad." And with that Ibn Saiyad got up. The Prophet (ﷺ) said, "Had this woman left him (Had she not disturbed him), then Ibn Saiyad would have revealed the reality of his case}}
\hadithdefcmd{bukhari}{1356}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ ـ وَهْوَ ابْنُ زَيْدٍ ـ عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ غُلاَمٌ يَهُودِيٌّ يَخْدُمُ النَّبِيَّ صلى الله عليه وسلم فَمَرِضَ، فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ، فَقَعَدَ عِنْدَ رَأْسِهِ فَقَالَ لَهُ ‏"‏ أَسْلِمْ ‏"‏‏.‏ فَنَظَرَ إِلَى أَبِيهِ وَهْوَ عِنْدَهُ فَقَالَ لَهُ أَطِعْ أَبَا الْقَاسِمِ صلى الله عليه وسلم‏.‏ فَأَسْلَمَ، فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم وَهْوَ يَقُولُ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَنْقَذَهُ مِنَ النَّارِ ‏"‏‏.‏\hadithno{1356}\hadithtrans{Narrated Anas:A young Jewish boy used to serve the Prophet (ﷺ) and he became sick. So the Prophet (ﷺ) went to visit him. He sat near his head and asked him to embrace Islam. The boy looked at his father, who was sitting there; the latter told him to obey Abul-Qasim and the boy embraced Islam. The Prophet (ﷺ) came out saying: "Praises be to Allah Who saved the boy from the Hell-fire}}
\hadithdefcmd{bukhari}{1357}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ عُبَيْدُ اللَّهِ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ كُنْتُ أَنَا وَأُمِّي، مِنَ الْمُسْتَضْعَفِينَ أَنَا مِنَ الْوِلْدَانِ، وَأُمِّي، مِنَ النِّسَاءِ‏.‏\hadithno{1357}\hadithtrans{Narrated Ibn `Abbas:My mother and I were among the weak and oppressed. I from among the children, and my mother from among the women}}
\hadithdefcmd{bukhari}{1358}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، قَالَ ابْنُ شِهَابٍ يُصَلَّى عَلَى كُلِّ مَوْلُودٍ مُتَوَفًّى وَإِنْ كَانَ لِغَيَّةٍ، مِنْ أَجْلِ أَنَّهُ وُلِدَ عَلَى فِطْرَةِ الإِسْلاَمِ، يَدَّعِي أَبَوَاهُ الإِسْلاَمَ أَوْ أَبُوهُ خَاصَّةً، وَإِنْ كَانَتْ أُمُّهُ عَلَى غَيْرِ الإِسْلاَمِ، إِذَا اسْتَهَلَّ صَارِخًا صُلِّيَ عَلَيْهِ، وَلاَ يُصَلَّى عَلَى مَنْ لاَ يَسْتَهِلُّ مِنْ أَجْلِ أَنَّهُ سِقْطٌ، فَإِنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ كَانَ يُحَدِّثُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُولَدُ عَلَى الْفِطْرَةِ، فَأَبَوَاهُ يُهَوِّدَانِهِ أَوْ يُنَصِّرَانِهِ أَوْ يُمَجِّسَانِهِ، كَمَا تُنْتَجُ الْبَهِيمَةُ بَهِيمَةً جَمْعَاءَ هَلْ تُحِسُّونَ فِيهَا مِنْ جَدْعَاءَ ‏"‏‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ ـ رضى الله عنه – ‏\{‏فِطْرَةَ اللَّهِ الَّتِي فَطَرَ النَّاسَ عَلَيْهَا‏\}‏ الآيَةَ‏.‏\hadithno{1358}\hadithtrans{Narrated Ibn Shihab:The funeral prayer should be offered for every child even if he were the son of a prostitute as he was born with a true faith of Islam (i.e. to worship none but Allah Alone). If his parents are Muslims, particularly the father, even if his mother were a non-Muslim, and if he after the delivery cries (even once) before his death (i.e. born alive) then the funeral prayer must be offered. And if the child does not cry after his delivery (i.e. born dead) then his funeral prayer should not be offered, and he will be considered as a miscarriage. Abu Huraira, narrated that the Prophet (ﷺ) said, "Every child is born with a true faith (i.e. to worship none but Allah Alone) but his parents convert him to Judaism or to Christianity or to Magianism, as an animal delivers a perfect baby animal. Do you find it mutilated?" Then Abu Huraira recited the holy verses: 'The pure Allah's Islamic nature (true faith i.e. to worship none but Allah Alone), with which He has created human beings}}
\hadithdefcmd{bukhari}{1359}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُولَدُ عَلَى الْفِطْرَةِ، فَأَبَوَاهُ يُهَوِّدَانِهِ أَوْ يُنَصِّرَانِهِ أَوْ يُمَجِّسَانِهِ، كَمَا تُنْتَجُ الْبَهِيمَةُ بَهِيمَةً جَمْعَاءَ، هَلْ تُحِسُّونَ فِيهَا مِنْ جَدْعَاءَ ‏"‏‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ ـ رضى الله عنه ‏\{‏فِطْرَةَ اللَّهِ الَّتِي فَطَرَ النَّاسَ عَلَيْهَا لاَ تَبْدِيلَ لِخَلْقِ اللَّهِ ذَلِكَ الدِّينُ الْقَيِّمُ‏\}‏\hadithno{1359}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Every child is born with a true faith of Islam (i.e. to worship none but Allah Alone) but his parents convert him to Judaism, Christianity or Magianism, as an animal delivers a perfect baby animal. Do you find it mutilated?" Then Abu Huraira recited the holy verses: "The pure Allah's Islamic nature (true faith of Islam) (i.e. worshipping none but Allah) with which He has created human beings. No change let there be in the religion of Allah (i.e. joining none in worship with Allah). That is the straight religion (Islam) but most of men know, not}}
\hadithdefcmd{bukhari}{1360}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، لَمَّا حَضَرَتْ أَبَا طَالِبٍ الْوَفَاةُ جَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَوَجَدَ عِنْدَهُ أَبَا جَهْلِ بْنَ هِشَامٍ، وَعَبْدَ اللَّهِ بْنَ أَبِي أُمَيَّةَ بْنِ الْمُغِيرَةِ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي طَالِبٍ ‏"‏ يَا عَمِّ، قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ، كَلِمَةً أَشْهَدُ لَكَ بِهَا عِنْدَ اللَّهِ ‏"‏‏.‏ فَقَالَ أَبُو جَهْلٍ وَعَبْدُ اللَّهِ بْنُ أَبِي أُمَيَّةَ يَا أَبَا طَالِبٍ، أَتَرْغَبُ عَنْ مِلَّةِ عَبْدِ الْمُطَّلِبِ فَلَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْرِضُهَا عَلَيْهِ، وَيَعُودَانِ بِتِلْكَ الْمَقَالَةِ، حَتَّى قَالَ أَبُو طَالِبٍ آخِرَ مَا كَلَّمَهُمْ هُوَ عَلَى مِلَّةِ عَبْدِ الْمُطَّلِبِ، وَأَبَى أَنْ يَقُولَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَاللَّهِ لأَسْتَغْفِرَنَّ لَكَ، مَا لَمْ أُنْهَ عَنْكَ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى فِيهِ ‏\{‏مَا كَانَ لِلنَّبِيِّ‏\}‏ الآيَةَ‏.‏\hadithno{1360}\hadithtrans{Narrated Sa`id bin Al-Musaiyab from his father:When the time of the death of Abu Talib approached, Allah's Messenger (ﷺ) went to him and found Abu Jahl bin Hisham and `Abdullah bin Abi Umaiya bin Al-Mughira by his side. Allah's Messenger (ﷺ) said to Abu Talib, "O uncle! Say: None has the right to be worshipped but Allah, a sentence with which I shall be a witness (i.e. argue) for you before Allah. Abu Jahl and `Abdullah bin Abi Umaiya said, "O Abu Talib! Are you going to denounce the religion of `Abdul Muttalib?" Allah's Messenger (ﷺ) kept on inviting Abu Talib to say it (i.e. 'None has the right to be worshipped but Allah') while they (Abu Jahl and `Abdullah) kept on repeating their statement till Abu Talib said as his last statement that he was on the religion of `Abdul Muttalib and refused to say, 'None has the right to be worshipped but Allah.' (Then Allah's Messenger (ﷺ) said, "I will keep on asking Allah's forgiveness for you unless I am forbidden (by Allah) to do so." So Allah revealed (the verse) concerning him (i.e. It is not fitting for the Prophet (ﷺ) and those who believe that they should invoke (Allah) for forgiveness for pagans even though they be of kin, after it has become clear to them that they are companions of the fire}}
\hadithdefcmd{bukhari}{1361}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ مَرَّ بِقَبْرَيْنِ يُعَذَّبَانِ فَقَالَ ‏"‏ إِنَّهُمَا لَيُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا أَحَدُهُمَا فَكَانَ لاَ يَسْتَتِرُ مِنَ الْبَوْلِ، وَأَمَّا الآخَرُ فَكَانَ يَمْشِي بِالنَّمِيمَةِ ‏"‏‏.‏ ثُمَّ أَخَذَ جَرِيدَةً رَطْبَةً فَشَقَّهَا بِنِصْفَيْنِ، ثُمَّ غَرَزَ فِي كُلِّ قَبْرٍ وَاحِدَةً‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ، لِمَ صَنَعْتَ هَذَا فَقَالَ ‏"‏ لَعَلَّهُ أَنْ يُخَفَّفَ عَنْهُمَا مَا لَمْ يَيْبَسَا ‏"‏‏.‏\hadithno{1361}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) once passed by two graves, and those two persons (in the graves) were being tortured. He said, "They are being tortured not for a great thing (to avoid). One of them never saved himself from being soiled with his urine, while the other went about committing slander (to make enmity between friends). He then took a green leaf of a date-palm tree split it into two pieces and fixed one on each grave. The people said, "O Allah's Messenger (ﷺ)! Why have you done so?" He replied, "I hope that their punishment may be lessened till they (the leaf) become dry}}
\hadithdefcmd{bukhari}{1362}{حَدَّثَنَا عُثْمَانُ، قَالَ حَدَّثَنِي جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ كُنَّا فِي جَنَازَةٍ فِي بَقِيعِ الْغَرْقَدِ، فَأَتَانَا النَّبِيُّ صلى الله عليه وسلم فَقَعَدَ وَقَعَدْنَا حَوْلَهُ، وَمَعَهُ مِخْصَرَةٌ فَنَكَّسَ، فَجَعَلَ يَنْكُتُ بِمِخْصَرَتِهِ ثُمَّ قَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ، مَا مِنْ نَفْسٍ مَنْفُوسَةٍ إِلاَّ كُتِبَ مَكَانُهَا مِنَ الْجَنَّةِ وَالنَّارِ، وَإِلاَّ قَدْ كُتِبَ شَقِيَّةً أَوْ سَعِيدَةً ‏"‏‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ، أَفَلاَ نَتَّكِلُ عَلَى كِتَابِنَا وَنَدَعُ الْعَمَلَ، فَمَنْ كَانَ مِنَّا مِنْ أَهْلِ السَّعَادَةِ فَسَيَصِيرُ إِلَى عَمَلِ أَهْلِ السَّعَادَةِ، وَأَمَّا مَنْ كَانَ مِنَّا مِنْ أَهْلِ الشَّقَاوَةِ فَسَيَصِيرُ إِلَى عَمَلِ أَهْلِ الشَّقَاوَةِ قَالَ ‏"‏ أَمَّا أَهْلُ السَّعَادَةِ فَيُيَسَّرُونَ لِعَمَلِ السَّعَادَةِ، وَأَمَّا أَهْلُ الشَّقَاوَةِ فَيُيَسَّرُونَ لِعَمَلِ الشَّقَاوَةِ ‏"‏، ثُمَّ قَرَأَ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى‏\}‏ الآيَةَ‏.‏\hadithno{1362}\hadithtrans{Narrated `Ali:" We were accompanying a funeral procession in Baqi-I-Gharqad. The Prophet (ﷺ) came to us and sat and we sat around him. He had a small stick in his hand then he bent his head and started scraping the ground with it. He then said, "There is none among you, and not a created soul, but has place either in Paradise or in Hell assigned for him and it is also determined for him whether he will be among the blessed or wretched." A man said, "O Allah's Messenger (ﷺ)! Should we not depend on what has been written for us and leave the deeds as whoever amongst us is blessed will do the deeds of a blessed person and whoever amongst us will be wretched, will do the deeds of a wretched person?" The Prophet said, "The good deeds are made easy for the blessed, and bad deeds are made easy for the wretched." Then he recited the Verses:-- "As for him who gives (in charity) and is Allah-fearing And believes in the Best reward from Allah}}
\hadithdefcmd{bukhari}{1364}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ بِمِلَّةٍ غَيْرِ الإِسْلاَمِ كَاذِبًا مُتَعَمِّدًا فَهُوَ كَمَا قَالَ، وَمَنْ قَتَلَ نَفْسَهُ بِحَدِيدَةٍ عُذِّبَ بِهِ فِي نَارِ جَهَنَّمَ ‏"‏‏.‏ وَقَالَ حَجَّاجُ بْنُ مِنْهَالٍ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الْحَسَنِ، حَدَّثَنَا جُنْدَبٌ ـ رضى الله عنه ـ فِي هَذَا الْمَسْجِدِ فَمَا نَسِينَا، وَمَا نَخَافُ أَنْ يَكْذِبَ جُنْدَبٌ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ كَانَ بِرَجُلٍ جِرَاحٌ فَقَتَلَ نَفْسَهُ فَقَالَ اللَّهُ بَدَرَنِي عَبْدِي بِنَفْسِهِ حَرَّمْتُ عَلَيْهِ الْجَنَّةَ ‏"‏‏.‏\hadithno{1364}\hadithtrans{Narrated Thabit bin Ad-Dahhak:The Prophet (ﷺ) said, "Whoever intentionally swears falsely by a religion other than Islam, then he is what he has said, (e.g. if he says, 'If such thing is not true then I am a Jew,' he is really a Jew). And whoever commits suicide with piece of iron will be punished with the same piece of iron in the Hell Fire." Narrated Jundab the Prophet (ﷺ) said, "A man was inflicted with wounds and he committed suicide, and so Allah said: My slave has caused death on himself hurriedly, so I forbid Paradise for him}}
\hadithdefcmd{bukhari}{1365}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الَّذِي يَخْنُقُ نَفْسَهُ يَخْنُقُهَا فِي النَّارِ، وَالَّذِي يَطْعُنُهَا يَطْعُنُهَا فِي النَّارِ ‏"‏‏.‏\hadithno{1365}\hadithtrans{Narrated Abu Huraira-:The Prophet (ﷺ) said, "He who commits suicide by throttling shall keep on throttling himself in the Hell Fire (forever) and he who commits suicide by stabbing himself shall keep on stabbing himself in the Hell-Fire}}
\hadithdefcmd{bukhari}{1366}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنهم ـ أَنَّهُ قَالَ لَمَّا مَاتَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ دُعِيَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ عَلَيْهِ، فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَبْتُ إِلَيْهِ فَقُلْتُ يَا رَسُولَ اللَّهِ، أَتُصَلِّي عَلَى ابْنِ أُبَىٍّ وَقَدْ قَالَ يَوْمَ كَذَا وَكَذَا كَذَا وَكَذَا ـ أُعَدِّدُ عَلَيْهِ قَوْلَهُ ـ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ أَخِّرْ عَنِّي يَا عُمَرُ ‏"‏‏.‏ فَلَمَّا أَكْثَرْتُ عَلَيْهِ قَالَ ‏"‏ إِنِّي خُيِّرْتُ فَاخْتَرْتُ، لَوْ أَعْلَمُ أَنِّي إِنْ زِدْتُ عَلَى السَّبْعِينَ فَغُفِرَ لَهُ لَزِدْتُ عَلَيْهَا ‏"‏‏.‏ قَالَ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ انْصَرَفَ، فَلَمْ يَمْكُثْ إِلاَّ يَسِيرًا حَتَّى نَزَلَتِ الآيَتَانِ مِنْ ‏\{‏بَرَاءَةٌ‏\}‏ ‏\{‏وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا‏\}‏ إِلَى ‏\{‏وَهُمْ فَاسِقُونَ‏\}‏ قَالَ فَعَجِبْتُ بَعْدُ مِنْ جُرْأَتِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ، وَاللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏\hadithno{1366}\hadithtrans{Narrated `Umar bin Al-Khattab:When `Abdullah bin Ubai bin Salul died, Allah's Messenger (ﷺ) was called upon to offer his funeral prayer. When Allah's Messenger (ﷺ) stood up to offer the prayer, I got up quickly and said, "O Allah's Apostle! Are you going to pray for Ibn Ubai and he said so and so on such and such occasions?" And started mentioning all that he had said. Allah's Messenger (ﷺ) smiled and said, "O `Umar! Go away from me." When I talked too much he said, "I have been given the choice and so I have chosen (to offer the prayer). Had I known that he would be forgiven by asking for Allah's forgiveness for more than seventy times, surely I would have done so." (`Umar added): Allah's Messenger (ﷺ) offered his funeral prayer and returned and after a short while the two verses of Surat Bara' were revealed: i.e. "And never (O Muhammad) pray for any of them who dies . . . (to the end of the verse) rebellion (9.84)" -- (`Umar added), "Later I was astonished at my daring before Allah's Messenger (ﷺ) on that day. And Allah and His Apostle know better}}
\hadithdefcmd{bukhari}{1367}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ مَرُّوا بِجَنَازَةٍ فَأَثْنَوْا عَلَيْهَا خَيْرًا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏‏.‏ ثُمَّ مَرُّوا بِأُخْرَى فَأَثْنَوْا عَلَيْهَا شَرًّا فَقَالَ ‏"‏ وَجَبَتْ ‏"‏‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ـ رضى الله عنه ـ مَا وَجَبَتْ قَالَ ‏"‏ هَذَا أَثْنَيْتُمْ عَلَيْهِ خَيْرًا فَوَجَبَتْ لَهُ الْجَنَّةُ، وَهَذَا أَثْنَيْتُمْ عَلَيْهِ شَرًّا فَوَجَبَتْ لَهُ النَّارُ، أَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏‏.‏\hadithno{1367}\hadithtrans{Narrated Anas bin Malik:A funeral procession passed and the people praised the deceased. The Prophet (ﷺ) said, "It has been affirmed to him." Then another funeral procession passed and the people spoke badly of the deceased. The Prophet (ﷺ) said, "It has been affirmed to him". `Umar bin Al-Khattab asked (Allah's Messenger (ﷺ) ), "What has been affirmed?" He replied, "You praised this, so Paradise has been affirmed to him; and you spoke badly of this, so Hell has been affirmed to him. You people are Allah's witnesses on earth}}
\hadithdefcmd{bukhari}{1368}{حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي الْفُرَاتِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ، قَالَ قَدِمْتُ الْمَدِينَةَ وَقَدْ وَقَعَ بِهَا مَرَضٌ، فَجَلَسْتُ إِلَى عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ فَمَرَّتْ بِهِمْ جَنَازَةٌ فَأُثْنِيَ عَلَى صَاحِبِهَا خَيْرًا فَقَالَ عُمَرُ ـ رضى الله عنه ـ وَجَبَتْ‏.‏ ثُمَّ مُرَّ بِأُخْرَى فَأُثْنِيَ عَلَى صَاحِبِهَا خَيْرًا، فَقَالَ عُمَرُ ـ رضى الله عنه ـ وَجَبَتْ‏.‏ ثُمَّ مُرَّ بِالثَّالِثَةِ، فَأُثْنِيَ عَلَى صَاحِبِهَا شَرًّا فَقَالَ وَجَبَتْ‏.‏ فَقَالَ أَبُو الأَسْوَدِ فَقُلْتُ وَمَا وَجَبَتْ يَا أَمِيرَ الْمُؤْمِنِينَ قَالَ قُلْتُ كَمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَيُّمَا مُسْلِمٍ شَهِدَ لَهُ أَرْبَعَةٌ بِخَيْرٍ أَدْخَلَهُ اللَّهُ الْجَنَّةَ ‏"‏‏.‏ فَقُلْنَا وَثَلاَثَةٌ قَالَ ‏"‏ وَثَلاَثَةٌ ‏"‏‏.‏ فَقُلْنَا وَاثْنَانِ قَالَ ‏"‏ وَاثْنَانِ ‏"‏‏.‏ ثُمَّ لَمْ نَسْأَلْهُ عَنِ الْوَاحِدِ‏.‏\hadithno{1368}\hadithtrans{Narrated Abu Al-Aswad:I came to Medina when an epidemic had broken out. While I was sitting with `Umar bin Al-Khattab a funeral procession passed by and the people praised the deceased. `Umar said, "It has been affirmed to him." And another funeral procession passed by and the people praised the deceased. `Umar said, "It has been affirmed to him." A third (funeral procession) passed by and the people spoke badly of the deceased. He said, "It has been affirmed to him." I (Abu Al-Aswad) asked, "O chief of the believers! What has been affirmed?" He replied, "I said the same as the Prophet (ﷺ) had said, that is: if four persons testify the piety of a Muslim, Allah will grant him Paradise." We asked, "If three persons testify his piety?" He (the Prophet) replied, "Even three." Then we asked, "If two?" He replied, "Even two." We did not ask him regarding one witness}}
\hadithdefcmd{bukhari}{1369}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أُقْعِدَ الْمُؤْمِنُ فِي قَبْرِهِ أُتِيَ، ثُمَّ شَهِدَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ، فَذَلِكَ قَوْلُهُ ‏\{‏يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا بِالْقَوْلِ الثَّابِتِ‏\}‏ ‏"‏‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا غُنْدَرٌ حَدَّثَنَا شُعْبَةُ بِهَذَا وَزَادَ ‏\{‏يُثَبِّتُ اللَّهُ الَّذِينَ آمَنُوا‏\}‏ نَزَلَتْ فِي عَذَابِ الْقَبْرِ‏.‏\hadithno{1369}\hadithtrans{Narrated Al-Bara' bin 'Azib : The Prophet (ﷺ) said, "When a faithful believer is made to sit in his grave, then (the angels) come to him and he testifies that none has the right to be worshipped but Allah and Muhammad is Allah's Apostle. And that corresponds to Allah's statement: Allah will keep firm those who believe with the word that stands firm . . . (14.27). Narrated Shu'ba: Same as above and added, "Allah will keep firm those who believe . . . (14.27) was revealed concerning the punishment of the grave}}
\hadithdefcmd{bukhari}{1370}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، حَدَّثَنِي نَافِعٌ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ قَالَ اطَّلَعَ النَّبِيُّ صلى الله عليه وسلم عَلَى أَهْلِ الْقَلِيبِ فَقَالَ ‏"‏ وَجَدْتُمْ مَا وَعَدَ رَبُّكُمْ حَقًّا ‏"‏‏.‏ فَقِيلَ لَهُ تَدْعُو أَمْوَاتًا فَقَالَ ‏"‏ مَا أَنْتُمْ بِأَسْمَعَ مِنْهُمْ وَلَكِنْ لاَ يُجِيبُونَ ‏"‏‏.‏\hadithno{1370}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) looked at the people of the well (the well in which the bodies of the pagans killed in the Battle of Badr were thrown) and said, "Have you found true what your Lord promised you?" Somebody said to him, "You are addressing dead people." He replied, "You do not hear better than they but they cannot reply}}
\hadithdefcmd{bukhari}{1371}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ إِنَّمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهُمْ لَيَعْلَمُونَ الآنَ أَنَّ مَا كُنْتُ أَقُولُ حَقٌّ وَقَدْ قَالَ اللَّهُ تَعَالَى ‏\{‏إِنَّكَ لاَ تُسْمِعُ الْمَوْتَى‏\}‏‏"‏\hadithno{1371}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "They now realize that what I used to tell them was the truth. "And Allah said, 'Verily! You cannot make the dead to hear (i.e. benefit them, and similarly the disbelievers) nor can you make the deaf hear}}
\hadithdefcmd{bukhari}{1372}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، سَمِعْتُ الأَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ يَهُودِيَّةً، دَخَلَتْ عَلَيْهَا، فَذَكَرَتْ عَذَابَ الْقَبْرِ، فَقَالَتْ لَهَا أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ‏.‏ فَسَأَلَتْ عَائِشَةُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ عَذَابِ الْقَبْرِ فَقَالَ ‏"‏ نَعَمْ عَذَابُ الْقَبْرِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ فَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدُ صَلَّى صَلاَةً إِلاَّ تَعَوَّذَ مِنْ عَذَابِ الْقَبْرِ‏.‏ زَادَ غُنْدَرٌ ‏"‏ عَذَابُ الْقَبْرِ حَقٌّ ‏"‏‏.‏\hadithno{1372}\hadithtrans{Narrated Masruq:`Aisha said that a Jewess came to her and mentioned the punishment in the grave, saying to her, "May Allah protect you from the punishment of the grave." `Aisha then asked Allah's Messenger (ﷺ) about the punishment of the grave. He said, "Yes, (there is) punishment in the grave." `Aisha added, "After that I never saw Allah's Messenger (ﷺ) but seeking refuge with Allah from the punishment in the grave in every prayer he prayed}}
\hadithdefcmd{bukhari}{1373}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَمِعَ أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ ـ رضى الله عنهما ـ تَقُولُ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَطِيبًا فَذَكَرَ فِتْنَةَ الْقَبْرِ الَّتِي يَفْتَتِنُ فِيهَا الْمَرْءُ، فَلَمَّا ذَكَرَ ذَلِكَ ضَجَّ الْمُسْلِمُونَ ضَجَّةً‏.‏\hadithno{1373}\hadithtrans{Narrated Asma' bint Abi Bakr:Allah's Messenger (ﷺ) once stood up delivering a sermon and mentioned the trial which people will face in the grave. When he mentioned that, the Muslims started shouting loudly}}
\hadithdefcmd{bukhari}{1374}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ، وَتَوَلَّى عَنْهُ أَصْحَابُهُ، وَإِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ، أَتَاهُ مَلَكَانِ فَيُقْعِدَانِهِ فَيَقُولاَنِ مَا كُنْتَ تَقُولُ فِي الرَّجُلِ لِمُحَمَّدٍ صلى الله عليه وسلم‏.‏ فَأَمَّا الْمُؤْمِنُ فَيَقُولُ أَشْهَدُ أَنَّهُ عَبْدُ اللَّهِ وَرَسُولُهُ‏.‏ فَيُقَالُ لَهُ انْظُرْ إِلَى مَقْعَدِكَ مِنَ النَّارِ، قَدْ أَبْدَلَكَ اللَّهُ بِهِ مَقْعَدًا مِنَ الْجَنَّةِ، فَيَرَاهُمَا جَمِيعًا ‏"‏‏.‏ قَالَ قَتَادَةُ وَذُكِرَ لَنَا أَنَّهُ يُفْسَحُ فِي قَبْرِهِ‏.‏ ثُمَّ رَجَعَ إِلَى حَدِيثِ أَنَسٍ قَالَ ‏"‏ وَأَمَّا الْمُنَافِقُ وَالْكَافِرُ فَيُقَالُ لَهُ مَا كُنْتَ تَقُولُ فِي هَذَا الرَّجُلِ فَيَقُولُ لاَ أَدْرِي، كُنْتُ أَقُولُ مَا يَقُولُ النَّاسُ‏.‏ فَيُقَالُ لاَ دَرَيْتَ وَلاَ تَلَيْتَ‏.‏ وَيُضْرَبُ بِمَطَارِقَ مِنْ حَدِيدٍ ضَرْبَةً، فَيَصِيحُ صَيْحَةً يَسْمَعُهَا مَنْ يَلِيهِ، غَيْرَ الثَّقَلَيْنِ ‏"‏‏.‏\hadithno{1374}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "When (Allah's) slave is put in his grave and his companions return and he even hears their footsteps, two angels come to him and make him sit and ask, 'What did you use to say about this man (i.e. Muhammad)?' The faithful Believer will say, 'I testify that he is Allah's slave and His Apostle.' Then they will say to him, 'Look at your place in the Hell Fire; Allah has given you a place in Paradise instead of it.' So he will see both his places." (Qatada said, "We were informed that his grave would be made spacious." Then Qatada went back to the narration of Anas who said;) Whereas a hypocrite or a non-believer will be asked, "What did you use to say about this man." He will reply, "I do not know; but I used to say what the people used to say." So they will say to him, "Neither did you know nor did you take the guidance (by reciting the Qur'an)." Then he will be hit with iron hammers once, that he will send such a cry as everything near to him will hear, except Jinns and human beings. (See Hadith No)}}
\hadithdefcmd{bukhari}{1375}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي عَوْنُ بْنُ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنْ أَبِي أَيُّوبَ ـ رضى الله عنهم ـ قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم وَقَدْ وَجَبَتِ الشَّمْسُ، فَسَمِعَ صَوْتًا فَقَالَ ‏ "‏ يَهُودُ تُعَذَّبُ فِي قُبُورِهَا ‏"‏‏.‏ وَقَالَ النَّضْرُ أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا عَوْنٌ، سَمِعْتُ أَبِي، سَمِعْتُ الْبَرَاءَ، عَنْ أَبِي أَيُّوبَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1375}\hadithtrans{Narrated Abi Aiyub:Once the Prophet (ﷺ) went out after sunset and heard a dreadful voice, and said, "The Jews are being punished in their graves}}
\hadithdefcmd{bukhari}{1376}{حَدَّثَنَا مُعَلًّى، حَدَّثَنَا وُهَيْبٌ، عَنْ مُوسَى بْنِ عُقْبَةَ، قَالَ حَدَّثَتْنِي ابْنَةُ خَالِدِ بْنِ سَعِيدِ بْنِ الْعَاصِ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ‏.‏\hadithno{1376}\hadithtrans{Narrated Musa bin `Uqba:(From the daughter of Khalid bin Sa`id bin Al-`Asi) who said that she had heard the Prophet (ﷺ) seeking refuge with Allah from the punishment in the grave}}
\hadithdefcmd{bukhari}{1377}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ، وَمِنْ عَذَابِ النَّارِ، وَمِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ، وَمِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ ‏"‏‏.‏\hadithno{1377}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) used to invoke (Allah): "Allahumma ini a`udhu bika min 'adhabi-l-Qabr, wa min 'adhabi-nnar, wa min fitnati-l-mahya wa-lmamat, wa min fitnati-l-masih ad-dajjal. (O Allah! I seek refuge with you from the punishment in the grave and from the punishment in the Hell fire and from the afflictions of life and death, and the afflictions of Al-Masih Ad-Dajjal)}}
\hadithdefcmd{bukhari}{1378}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ مَرَّ النَّبِيُّ صلى الله عليه وسلم عَلَى قَبْرَيْنِ فَقَالَ ‏"‏ إِنَّهُمَا لَيُعَذَّبَانِ، وَمَا يُعَذَّبَانِ مِنْ كَبِيرٍ ـ ثُمَّ قَالَ ـ بَلَى أَمَّا أَحَدُهُمَا فَكَانَ يَسْعَى بِالنَّمِيمَةِ، وَأَمَّا أَحَدُهُمَا فَكَانَ لاَ يَسْتَتِرُ مِنْ بَوْلِهِ ‏"‏‏.‏ قَالَ ثُمَّ أَخَذَ عُودًا رَطْبًا فَكَسَرَهُ بِاثْنَتَيْنِ ثُمَّ غَرَزَ كُلَّ وَاحِدٍ مِنْهُمَا عَلَى قَبْرٍ، ثُمَّ قَالَ ‏"‏ لَعَلَّهُ يُخَفَّفُ عَنْهُمَا مَا لَمْ يَيْبَسَا ‏"‏‏.‏\hadithno{1378}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) once passed by two graves and said, "They (the deceased persons in those graves) are being tortured not for a great thing to avoid." And then added, "Yes, (they are being punished for a big sin), for one of them used to go about with calumnies while the other never saved himself from being soiled with his urine." (Ibn `Abbas added): Then he took a green leaf of a date-palm) and split it into two pieces and fixed one piece on each grave and said, "May their punishment be abated till these (two pieces) get dry}}
\hadithdefcmd{bukhari}{1379}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا مَاتَ عُرِضَ عَلَيْهِ مَقْعَدُهُ بِالْغَدَاةِ وَالْعَشِيِّ، إِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ، وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ، فَيُقَالُ هَذَا مَقْعَدُكَ حَتَّى يَبْعَثَكَ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{1379}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "When anyone of you dies, he is shown his place both in the morning and in the evening. If he is one of the people of Paradise; he is shown his place in it, and if he is from the people of the Hell-Fire; he is shown his place there-in. Then it is said to him, 'This is your place till Allah resurrect you on the Day of Resurrection}}
\hadithdefcmd{bukhari}{1380}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وُضِعَتِ الْجَنَازَةُ فَاحْتَمَلَهَا الرِّجَالُ عَلَى أَعْنَاقِهِمْ، فَإِنْ كَانَتْ صَالِحَةً قَالَتْ قَدِّمُونِي قَدِّمُونِي‏.‏ وَإِنْ كَانَتْ غَيْرَ صَالِحَةٍ قَالَتْ يَا وَيْلَهَا أَيْنَ يَذْهَبُونَ بِهَا‏.‏ يَسْمَعُ صَوْتَهَا كُلُّ شَىْءٍ إِلاَّ الإِنْسَانَ، وَلَوْ سَمِعَهَا الإِنْسَانُ لَصَعِقَ ‏"‏‏.‏\hadithno{1380}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "When the funeral is ready (for its burial) and the people lift it on their shoulders, then if the deceased is a righteous person he says, 'Take me ahead,' and if he is not a righteous one then he says, 'Woe to it (me)! Where are you taking it (me)?' And his voice is audible to everything except human beings; and if they heard it they would fall down unconscious}}
\hadithdefcmd{bukhari}{1381}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنَ النَّاسِ مُسْلِمٌ يَمُوتُ لَهُ ثَلاَثَةٌ مِنَ الْوَلَدِ لَمْ يَبْلُغُوا الْحِنْثَ إِلاَّ أَدْخَلَهُ اللَّهُ الْجَنَّةَ بِفَضْلِ رَحْمَتِهِ إِيَّاهُمْ ‏"‏‏.‏\hadithno{1381}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "Any Muslim whose three children died before the age of puberty will be granted Paradise by Allah because of His mercy to them}}
\hadithdefcmd{bukhari}{1382}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، أَنَّهُ سَمِعَ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ لَمَّا تُوُفِّيَ إِبْرَاهِيمُ ـ عَلَيْهِ السَّلاَمُ ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لَهُ مُرْضِعًا فِي الْجَنَّةِ ‏"‏‏.‏\hadithno{1382}\hadithtrans{Narrated Al-Bara':When Ibrahim (the son of Prophet) expired, Allah's Messenger (ﷺ) said, "There is a wet-nurse for him in Paradise}}
\hadithdefcmd{bukhari}{1383}{حَدَّثَنَا حِبَّانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهم ـ قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَوْلاَدِ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ إِذْ خَلَقَهُمْ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏‏.‏\hadithno{1383}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) was asked about the children of (Mushrikeen) pagans. The Prophet (ﷺ) replied, "Since Allah created them, He knows what sort of deeds they would have done}}
\hadithdefcmd{bukhari}{1384}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَطَاءُ بْنُ يَزِيدَ اللَّيْثِيُّ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ ذَرَارِيِّ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏‏.‏\hadithno{1384}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) was asked about the offspring of pagans (Mushrikeen); so he said, "Allah knows what sort of deeds they would have done}}
\hadithdefcmd{bukhari}{1385}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلُّ مَوْلُودٍ يُولَدُ عَلَى الْفِطْرَةِ، فَأَبَوَاهُ يُهَوِّدَانِهِ أَوْ يُنَصِّرَانِهِ أَوْ يُمَجِّسَانِهِ، كَمَثَلِ الْبَهِيمَةِ تُنْتَجُ الْبَهِيمَةَ، هَلْ تَرَى فِيهَا جَدْعَاءَ ‏"‏‏.‏\hadithno{1385}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Every child is born with a true faith of Islam (i.e. to worship none but Allah Alone) and his parents convert him to Judaism or Christianity or Magianism, as an animal delivers a perfect baby animal. Do you find it mutilated?}}
\hadithdefcmd{bukhari}{1386}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى صَلاَةً أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏"‏ مَنْ رَأَى مِنْكُمُ اللَّيْلَةَ رُؤْيَا ‏"‏‏.‏ قَالَ فَإِنْ رَأَى أَحَدٌ قَصَّهَا، فَيَقُولُ مَا شَاءَ اللَّهُ، فَسَأَلَنَا يَوْمًا، فَقَالَ ‏"‏ هَلْ رَأَى أَحَدٌ مِنْكُمْ رُؤْيَا ‏"‏‏.‏ قُلْنَا لاَ‏.‏ قَالَ ‏"‏ لَكِنِّي رَأَيْتُ اللَّيْلَةَ رَجُلَيْنِ أَتَيَانِي فَأَخَذَا بِيَدِي، فَأَخْرَجَانِي إِلَى الأَرْضِ الْمُقَدَّسَةِ، فَإِذَا رَجُلٌ جَالِسٌ، وَرَجُلٌ قَائِمٌ بِيَدِهِ كَلُّوبٌ مِنْ حَدِيدٍ ـ قَالَ بَعْضُ أَصْحَابِنَا عَنْ مُوسَى إِنَّهُ ـ يُدْخِلُ ذَلِكَ الْكَلُّوبَ فِي شِدْقِهِ، حَتَّى يَبْلُغَ قَفَاهُ، ثُمَّ يَفْعَلُ بِشِدْقِهِ الآخَرِ مِثْلَ ذَلِكَ، وَيَلْتَئِمُ شِدْقُهُ هَذَا، فَيَعُودُ فَيَصْنَعُ مِثْلَهُ‏.‏ قُلْتُ مَا هَذَا قَالاَ انْطَلِقْ‏.‏ فَانْطَلَقْنَا حَتَّى أَتَيْنَا عَلَى رَجُلٍ مُضْطَجِعٍ عَلَى قَفَاهُ، وَرَجُلٌ قَائِمٌ عَلَى رَأْسِهِ بِفِهْرٍ أَوْ صَخْرَةٍ، فَيَشْدَخُ بِهِ رَأْسَهُ، فَإِذَا ضَرَبَهُ تَدَهْدَهَ الْحَجَرُ، فَانْطَلَقَ إِلَيْهِ لِيَأْخُذَهُ، فَلاَ يَرْجِعُ إِلَى هَذَا حَتَّى يَلْتَئِمَ رَأْسُهُ، وَعَادَ رَأْسُهُ كَمَا هُوَ، فَعَادَ إِلَيْهِ فَضَرَبَهُ، قُلْتُ مَنْ هَذَا قَالاَ انْطَلِقْ‏.‏ فَانْطَلَقْنَا إِلَى ثَقْبٍ مِثْلِ التَّنُّورِ، أَعْلاَهُ ضَيِّقٌ وَأَسْفَلُهُ وَاسِعٌ، يَتَوَقَّدُ تَحْتَهُ نَارًا، فَإِذَا اقْتَرَبَ ارْتَفَعُوا حَتَّى كَادَ أَنْ يَخْرُجُوا، فَإِذَا خَمَدَتْ رَجَعُوا فِيهَا، وَفِيهَا رِجَالٌ وَنِسَاءٌ عُرَاةٌ‏.‏ فَقُلْتُ مَنْ هَذَا قَالاَ انْطَلِقْ‏.‏ فَانْطَلَقْنَا حَتَّى أَتَيْنَا عَلَى نَهَرٍ مِنْ دَمٍ، فِيهِ رَجُلٌ قَائِمٌ عَلَى وَسَطِ النَّهَرِ رَجُلٌ بَيْنَ يَدَيْهِ حِجَارَةٌ، فَأَقْبَلَ الرَّجُلُ الَّذِي فِي النَّهَرِ، فَإِذَا أَرَادَ أَنْ يَخْرُجَ رَمَى الرَّجُلُ بِحَجَرٍ فِي فِيهِ، فَرَدَّهُ حَيْثُ كَانَ، فَجَعَلَ كُلَّمَا جَاءَ لِيَخْرُجَ رَمَى فِي فِيهِ بِحَجَرٍ، فَيَرْجِعُ كَمَا كَانَ‏.‏ فَقُلْتُ مَا هَذَا قَالاَ انْطَلِقْ‏.‏ فَانْطَلَقْنَا حَتَّى انْتَهَيْنَا إِلَى رَوْضَةٍ خَضْرَاءَ، فِيهَا شَجَرَةٌ عَظِيمَةٌ، وَفِي أَصْلِهَا شَيْخٌ وَصِبْيَانٌ، وَإِذَا رَجُلٌ قَرِيبٌ مِنَ الشَّجَرَةِ بَيْنَ يَدَيْهِ نَارٌ يُوقِدُهَا، فَصَعِدَا بِي فِي الشَّجَرَةِ، وَأَدْخَلاَنِي دَارًا لَمْ أَرَ قَطُّ أَحْسَنَ مِنْهَا، فِيهَا رِجَالٌ شُيُوخٌ وَشَبَابٌ، وَنِسَاءٌ وَصِبْيَانٌ، ثُمَّ أَخْرَجَانِي مِنْهَا فَصَعِدَا بِي الشَّجَرَةَ فَأَدْخَلاَنِي دَارًا هِيَ أَحْسَنُ وَأَفْضَلُ، فِيهَا شُيُوخٌ وَشَبَابٌ‏.‏ قُلْتُ طَوَّفْتُمَانِي اللَّيْلَةَ، فَأَخْبِرَانِي عَمَّا رَأَيْتُ‏.‏ قَالاَ نَعَمْ، أَمَّا الَّذِي رَأَيْتَهُ يُشَقُّ شِدْقُهُ فَكَذَّابٌ يُحَدِّثُ بِالْكَذْبَةِ، فَتُحْمَلُ عَنْهُ حَتَّى تَبْلُغَ الآفَاقَ، فَيُصْنَعُ بِهِ إِلَى يَوْمِ الْقِيَامَةِ‏.‏ وَالَّذِي رَأَيْتَهُ يُشْدَخُ رَأْسُهُ فَرَجُلٌ عَلَّمَهُ اللَّهُ الْقُرْآنَ، فَنَامَ عَنْهُ بِاللَّيْلِ، وَلَمْ يَعْمَلْ فِيهِ بِالنَّهَارِ، يُفْعَلُ بِهِ إِلَى يَوْمِ الْقِيَامَةِ‏.‏ وَالَّذِي رَأَيْتَهُ فِي الثَّقْبِ فَهُمُ الزُّنَاةُ‏.‏ وَالَّذِي رَأَيْتَهُ فِي النَّهَرِ آكِلُو الرِّبَا‏.‏ وَالشَّيْخُ فِي أَصْلِ الشَّجَرَةِ إِبْرَاهِيمُ ـ عَلَيْهِ السَّلاَمُ ـ وَالصِّبْيَانُ حَوْلَهُ فَأَوْلاَدُ النَّاسِ، وَالَّذِي يُوقِدُ النَّارَ مَالِكٌ خَازِنُ النَّارِ‏.‏ وَالدَّارُ الأُولَى الَّتِي دَخَلْتَ دَارُ عَامَّةِ الْمُؤْمِنِينَ، وَأَمَّا هَذِهِ الدَّارُ فَدَارُ الشُّهَدَاءِ، وَأَنَا جِبْرِيلُ، وَهَذَا مِيكَائِيلُ، فَارْفَعْ رَأْسَكَ، فَرَفَعْتُ رَأْسِي فَإِذَا فَوْقِي مِثْلُ السَّحَابِ‏.‏ قَالاَ ذَاكَ مَنْزِلُكَ‏.‏ قُلْتُ دَعَانِي أَدْخُلْ مَنْزِلِي‏.‏ قَالاَ إِنَّهُ بَقِيَ لَكَ عُمْرٌ لَمْ تَسْتَكْمِلْهُ، فَلَوِ اسْتَكْمَلْتَ أَتَيْتَ مَنْزِلَكَ ‏"‏‏.‏\hadithno{1386}\hadithtrans{Narrated Samura bin Jundab:Whenever the Prophet (ﷺ) finished the (morning) prayer, he would face us and ask, "Who amongst you had a dream last night?" So if anyone had seen a dream he would narrate it. The Prophet (ﷺ) would say: "Ma sha'a-llah" (An Arabic maxim meaning literally, 'What Allah wished,' and it indicates a good omen.) One day, he asked us whether anyone of us had seen a dream. We replied in the negative. The Prophet said, "But I had seen (a dream) last night that two men came to me, caught hold of my hands, and took me to the Sacred Land (Jerusalem). There, I saw a person sitting and another standing with an iron hook in his hand pushing it inside the mouth of the former till it reached the jawbone, and then tore off one side of his cheek, and then did the same with the other side; in the meantime the first side of his cheek became normal again and then he repeated the same operation again. I said, 'What is this?' They told me to proceed on and we went on till we came to a man Lying flat on his back, and another man standing at his head carrying a stone or a piece of rock, and crushing the head of the Lying man, with that stone. Whenever he struck him, the stone rolled away. The man went to pick it up and by the time he returned to him, the crushed head had returned to its normal state and the man came back and struck him again (and so on). I said, 'Who is this?' They told me to proceed on; so we proceeded on and passed by a hole like an oven; with a narrow top and wide bottom, and the fire was kindling underneath that hole. Whenever the fire-flame went up, the people were lifted up to such an extent that they were about to get out of it, and whenever the fire got quieter, the people went down into it, and there were naked men and women in it. I said, 'Who is this?' They told me to proceed on. So we proceeded on till we reached a river of blood and a man was in it, and another man was standing at its bank with stones in front of him, facing the man standing in the river. Whenever the man in the river wanted to come out, the other one threw a stone in his mouth and caused him to retreat to his original position; and so whenever he wanted to come out the other would throw a stone in his mouth, and he would retreat to his original position. I asked, 'What is this?' They told me to proceed on and we did so till we reached a well-flourished green garden having a huge tree and near its root was sitting an old man with some children. (I saw) Another man near the tree with fire in front of him and he was kindling it up. Then they (i.e. my two companions) made me climb up the tree and made me enter a house, better than which I have ever seen. In it were some old men and young men, women and children. Then they took me out of this house and made me climb up the tree and made me enter another house that was better and superior (to the first) containing old and young people. I said to them (i.e. my two companions), 'You have made me ramble all the night. Tell me all about that I have seen.' They said, 'Yes. As for the one whose cheek you saw being torn away, he was a liar and he used to tell lies, and the people would report those lies on his authority till they spread all over the world. So, he will be punished like that till the Day of Resurrection. The one whose head you saw being crushed is the one whom Allah had given the knowledge of Qur'an (i.e. knowing it by heart) but he used to sleep at night (i.e. he did not recite it then) and did not use to act upon it (i.e. upon its orders etc.) by day; and so this punishment will go on till the Day of Resurrection. And those you saw in the hole (like oven) were adulterers (those men and women who commit illegal sexual intercourse). And those you saw in the river of blood were those dealing in Riba (usury). And the old man who was sitting at the base of the tree was Abraham and the little children around him were the offspring of the people. And the one who was kindling the fire was Malik, the gatekeeper of the Hell-fire. And the first house in which you have gone was the house of the common believers, and the second house was of the martyrs. I am Gabriel and this is Michael. Raise your head.' I raised my head and saw a thing like a cloud over me. They said, 'That is your place.' I said, 'Let me enter my place.' They said, 'You still have some life which you have not yet completed, and when you complete (that remaining portion of your life) you will then enter your place}}
\hadithdefcmd{bukhari}{1387}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلْتُ عَلَى أَبِي بَكْرٍ ـ رضى الله عنه ـ فَقَالَ فِي كَمْ كَفَّنْتُمُ النَّبِيَّ صلى الله عليه وسلم قَالَتْ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سَحُولِيَّةٍ، لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ‏.‏ وَقَالَ لَهَا فِي أَىِّ يَوْمٍ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ يَوْمَ الاِثْنَيْنِ‏.‏ قَالَ فَأَىُّ يَوْمٍ هَذَا قَالَتْ يَوْمُ الاِثْنَيْنِ‏.‏ قَالَ أَرْجُو فِيمَا بَيْنِي وَبَيْنَ اللَّيْلِ‏.‏ فَنَظَرَ إِلَى ثَوْبٍ عَلَيْهِ كَانَ يُمَرَّضُ فِيهِ، بِهِ رَدْعٌ مِنْ زَعْفَرَانٍ فَقَالَ اغْسِلُوا ثَوْبِي هَذَا، وَزِيدُوا عَلَيْهِ ثَوْبَيْنِ فَكَفِّنُونِي فِيهَا‏.‏ قُلْتُ إِنَّ هَذَا خَلَقٌ‏.‏ قَالَ إِنَّ الْحَىَّ أَحَقُّ بِالْجَدِيدِ مِنَ الْمَيِّتِ، إِنَّمَا هُوَ لِلْمُهْلَةِ‏.‏ فَلَمْ يُتَوَفَّ حَتَّى أَمْسَى مِنْ لَيْلَةِ الثُّلاَثَاءِ وَدُفِنَ قَبْلَ أَنْ يُصْبِحَ‏.‏\hadithno{1387}\hadithtrans{Narrated Hisham's father:Aisha said, "I went to Abu Bakr (during his fatal illness) and he asked me, 'In how many garments was the Prophet (ﷺ) shrouded?' She replied, 'In three Suhuliya pieces of white cloth of cotton, and there was neither a shirt nor a turban among them.' Abu Bakr further asked her, 'On which day did the Prophet die?' She replied, 'He died on Monday.' He asked, 'What is today?' She replied, 'Today is Monday.' He added, 'I hope I shall die sometime between this morning and tonight.' Then he looked at a garment that he was wearing during his illness and it had some stains of saffron. Then he said, 'Wash this garment of mine and add two more garments and shroud me in them.' I said, 'This is worn out.' He said, 'A living person has more right to wear new clothes than a dead one; the shroud is only for the body's pus.' He did not die till it was the night of Tuesday and was buried before the morning}}
\hadithdefcmd{bukhari}{1388}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ‏.‏ أَنَّ رَجُلاً، قَالَ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أُمِّي افْتُلِتَتْ نَفْسُهَا، وَأَظُنُّهَا لَوْ تَكَلَّمَتْ تَصَدَّقَتْ، فَهَلْ لَهَا أَجْرٌ إِنْ تَصَدَّقْتُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏\hadithno{1388}\hadithtrans{Narrated Aisha:A man said to the Prophet (ﷺ), "My mother died suddenly and I thought that if she had lived she would have given alms. So, if I give alms now on her behalf, will she get the reward?" The Prophet (ﷺ) replied in the affirmative}}
\hadithdefcmd{bukhari}{1389}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي سُلَيْمَانُ، عَنْ هِشَامٍ، وَحَدَّثَنِي مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو مَرْوَانَ، يَحْيَى بْنُ أَبِي زَكَرِيَّاءَ عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيَتَعَذَّرُ فِي مَرَضِهِ ‏ "‏ أَيْنَ أَنَا الْيَوْمَ أَيْنَ أَنَا غَدًا ‏"‏ اسْتِبْطَاءً لِيَوْمِ عَائِشَةَ، فَلَمَّا كَانَ يَوْمِي قَبَضَهُ اللَّهُ بَيْنَ سَحْرِي وَنَحْرِي، وَدُفِنَ فِي بَيْتِي‏.‏\hadithno{1389}\hadithtrans{Narrated `Aisha:During his sickness, Allah's Messenger (ﷺ) was asking repeatedly, "Where am I today? Where will I be tomorrow?" And I was waiting for the day of my turn (impatiently). Then, when my turn came, Allah took his soul away (in my lap) between my chest and arms and he was buried in my house}}
\hadithdefcmd{bukhari}{1390}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ هِلاَلٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ الَّذِي لَمْ يَقُمْ مِنْهُ ‏ "‏ لَعَنَ اللَّهُ الْيَهُودَ وَالنَّصَارَى، اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏‏.‏ لَوْلاَ ذَلِكَ أُبْرِزَ قَبْرُهُ، غَيْرَ أَنَّهُ خَشِيَ أَوْ خُشِيَ أَنَّ يُتَّخَذَ مَسْجِدًا‏.‏ وَعَنْ هِلاَلٍ قَالَ كَنَّانِي عُرْوَةُ بْنُ الزُّبَيْرِ وَلَمْ يُولَدْ لِي‏.‏\hadithno{1390}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) in his fatal illness said, "Allah cursed the Jews and the Christians, for they built the places of worship at the graves of their prophets." And if that had not been the case, then the Prophet's grave would have been made prominent before the people. So (the Prophet (ﷺ) ) was afraid, or the people were afraid that his grave might be taken as a place for worship}}
\hadithdefcmd{bukhari}{1390p2}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ سُفْيَانَ التَّمَّارِ، أَنَّهُ حَدَّثَهُ أَنَّهُ، رَأَى قَبْرَ النَّبِيِّ صلى الله عليه وسلم مُسَنَّمًا‏.‏\hadithno{1390.2}\hadithtrans{Narrated Abu Bakr bin `Aiyash:Sufyan at-Tammar told me that he had seen the grave of the Prophet (ﷺ) elevated and convex}}
\hadithdefcmd{bukhari}{1390p3}{حَدَّثَنَا فَرْوَةُ، حَدَّثَنَا عَلِيٌّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، لَمَّا سَقَطَ عَلَيْهِمُ الْحَائِطُ فِي زَمَانِ الْوَلِيدِ بْنِ عَبْدِ الْمَلِكِ أَخَذُوا فِي بِنَائِهِ، فَبَدَتْ لَهُمْ قَدَمٌ فَفَزِعُوا، وَظَنُّوا أَنَّهَا قَدَمُ النَّبِيِّ صلى الله عليه وسلم فَمَا وَجَدُوا أَحَدًا يَعْلَمُ ذَلِكَ حَتَّى قَالَ لَهُمْ عُرْوَةُ لاَ وَاللَّهِ مَا هِيَ قَدَمُ النَّبِيِّ صلى الله عليه وسلم مَا هِيَ إِلاَّ قَدَمُ عُمَرَ ـ رضى الله عنه ـ‏.‏\hadithno{1390.3}\hadithtrans{Narrated `Urwa:When the wall fell on them (i.e. graves) during the caliphate of Al-Walid bin `Abdul Malik, the people started repairing it, and a foot appeared to them. The people got scared and thought that it was the foot of the Prophet. No one could be found who could tell them about it till I (`Urwa) said to them, "By Allah, this is not the foot of the Prophet (ﷺ) but it is the foot of `Umar}}
\hadithdefcmd{bukhari}{1391}{وَعَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا أَوْصَتْ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ ـ رضى الله عنهما ـ لاَ تَدْفِنِّي مَعَهُمْ وَادْفِنِّي مَعَ صَوَاحِبِي بِالْبَقِيعِ، لاَ أُزَكَّى بِهِ أَبَدًا‏.‏\hadithno{1391}\hadithtrans{Aisha narrated that she made a will to `Abdullah bin Zubair, "Do not bury me with them (the Prophet (ﷺ) and his two companions) but bury me with my companions (wives of the Prophet (ﷺ) ) in Al-Baqi as I would not like to be looked upon as better than I really am (by being buried near the Prophet)}}
\hadithdefcmd{bukhari}{1392}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، حَدَّثَنَا حُصَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ مَيْمُونٍ الأَوْدِيِّ، قَالَ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ قَالَ يَا عَبْدَ اللَّهِ بْنَ عُمَرَ، اذْهَبْ إِلَى أُمِّ الْمُؤْمِنِينَ عَائِشَةَ ـ رضى الله عنها ـ فَقُلْ يَقْرَأُ عُمَرُ بْنُ الْخَطَّابِ عَلَيْكِ السَّلاَمَ، ثُمَّ سَلْهَا أَنْ أُدْفَنَ مَعَ صَاحِبَىَّ‏.‏ قَالَتْ كُنْتُ أُرِيدُهُ لِنَفْسِي، فَلأُوثِرَنَّهُ الْيَوْمَ عَلَى نَفْسِي‏.‏ فَلَمَّا أَقْبَلَ قَالَ لَهُ مَا لَدَيْكَ قَالَ أَذِنَتْ لَكَ يَا أَمِيرَ الْمُؤْمِنِينَ‏.‏ قَالَ مَا كَانَ شَىْءٌ أَهَمَّ إِلَىَّ مِنْ ذَلِكَ الْمَضْجَعِ، فَإِذَا قُبِضْتُ فَاحْمِلُونِي ثُمَّ سَلِّمُوا ثُمَّ قُلْ يَسْتَأْذِنُ عُمَرُ بْنُ الْخَطَّابِ‏.‏ فَإِنْ أَذِنَتْ لِي فَادْفِنُونِي، وَإِلاَّ فَرُدُّونِي إِلَى مَقَابِرِ الْمُسْلِمِينَ، إِنِّي لاَ أَعْلَمُ أَحَدًا أَحَقَّ بِهَذَا الأَمْرِ مِنْ هَؤُلاَءِ النَّفَرِ الَّذِينَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَنْهُمْ رَاضٍ، فَمَنِ اسْتَخْلَفُوا بَعْدِي فَهُوَ الْخَلِيفَةُ، فَاسْمَعُوا لَهُ وَأَطِيعُوا‏.‏ فَسَمَّى عُثْمَانَ وَعَلِيًّا وَطَلْحَةَ وَالزُّبَيْرَ وَعَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ وَسَعْدَ بْنَ أَبِي وَقَّاصٍ، وَوَلَجَ عَلَيْهِ شَابٌّ مِنَ الأَنْصَارِ فَقَالَ أَبْشِرْ يَا أَمِيرَ الْمُؤْمِنِينَ بِبُشْرَى اللَّهِ، كَانَ لَكَ مِنَ الْقَدَمِ فِي الإِسْلاَمِ مَا قَدْ عَلِمْتَ، ثُمَّ اسْتُخْلِفْتَ فَعَدَلْتَ، ثُمَّ الشَّهَادَةُ بَعْدَ هَذَا كُلِّهِ‏.‏ فَقَالَ لَيْتَنِي يَا ابْنَ أَخِي وَذَلِكَ كَفَافًا لاَ عَلَىَّ وَلاَ لِي أُوصِي الْخَلِيفَةَ مِنْ بَعْدِي بِالْمُهَاجِرِينَ الأَوَّلِينَ خَيْرًا، أَنْ يَعْرِفَ لَهُمْ حَقَّهُمْ، وَأَنْ يَحْفَظَ لَهُمْ حُرْمَتَهُمْ، وَأُوصِيهِ بِالأَنْصَارِ خَيْرًا الَّذِينَ تَبَوَّءُوا الدَّارَ وَالإِيمَانَ أَنْ يُقْبَلَ مِنْ مُحْسِنِهِمْ، وَيُعْفَى عَنْ مُسِيئِهِمْ، وَأُوصِيهِ بِذِمَّةِ اللَّهِ وَذِمَّةِ رَسُولِهِ صلى الله عليه وسلم أَنْ يُوفَى لَهُمْ بِعَهْدِهِمْ، وَأَنْ يُقَاتَلَ مِنْ وَرَائِهِمْ، وَأَنْ لاَ يُكَلَّفُوا فَوْقَ طَاقَتِهِمْ‏.‏\hadithno{1392}\hadithtrans{Narrated `Amr bin Maimun Al-Audi:I saw `Umar bin Al-Khattab (when he was stabbed) saying, "O `Abdullah bin `Umar! Go to the mother of the believers Aisha and say, `Umar bin Al-Khattab sends his greetings to you,' and request her to allow me to be buried with my companions." (So, Ibn `Umar conveyed the message to `Aisha.) She said, "I had the idea of having this place for myself but today I prefer him (`Umar) to myself (and allow him to be buried there)." When `Abdullah bin `Umar returned, `Umar asked him, "What (news) do you have?" He replied, "O chief of the believers! She has allowed you (to be buried there)." On that `Umar said, "Nothing was more important to me than to be buried in that (sacred) place. So, when I expire, carry me there and pay my greetings to her (`Aisha ) and say, `Umar bin Al-Khattab asks permission; and if she gives permission, then bury me (there) and if she does not, then take me to the graveyard of the Muslims. I do not think any person has more right for the caliphate than those with whom Allah's Messenger (ﷺ) was always pleased till his death. And whoever is chosen by the people after me will be the caliph, and you people must listen to him and obey him," and then he mentioned the name of `Uthman, `Ali, Talha, Az-Zubair, `Abdur-Rahman bin `Auf and Sa`d bin Abi Waqqas. By this time a young man from Ansar came and said, "O chief of the believers! Be happy with Allah's glad tidings. The grade which you have in Islam is known to you, then you became the caliph and you ruled with justice and then you have been awarded martyrdom after all this." `Umar replied, "O son of my brother! Would that all that privileges will counterbalance (my short comings), so that I neither lose nor gain anything. I recommend my successor to be good to the early emigrants and realize their rights and to protect their honor and sacred things. And I also recommend him to be good to the Ansar who before them, had homes (in Medina) and had adopted the Faith. He should accept the good of the righteous among them and should excuse their wrongdoers. I recommend him to abide by the rules and regulations concerning the Dhimmis (protectees) of Allah and His Apostle, to fulfill their contracts completely and fight for them and not to tax (overburden) them beyond their capabilities}}
\hadithdefcmd{bukhari}{1393}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا الأَمْوَاتَ فَإِنَّهُمْ قَدْ أَفْضَوْا إِلَى مَا قَدَّمُوا ‏"‏‏.‏ وَرَوَاهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الْقُدُّوسِ عَنِ الأَعْمَشِ، وَمُحَمَّدُ بْنُ أَنَسٍ عَنِ الأَعْمَشِ‏.‏ تَابَعَهُ عَلِيُّ بْنُ الْجَعْدِ وَابْنُ عَرْعَرَةَ وَابْنُ أَبِي عَدِيٍّ عَنْ شُعْبَةَ‏.‏\hadithno{1393}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Don't abuse the dead, because they have reached the result of what they forwarded}}
\hadithdefcmd{bukhari}{1394}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي عَمْرُو بْنُ مُرَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ أَبُو لَهَبٍ ـ عَلَيْهِ لَعْنَةُ اللَّهِ ـ لِلنَّبِيِّ صلى الله عليه وسلم تَبًّا لَكَ سَائِرَ الْيَوْمِ‏.‏ فَنَزَلَتْ ‏\{‏تَبَّتْ يَدَا أَبِي لَهَبٍ وَتَبَّ‏\}‏ ‏.‏\hadithno{1394}\hadithtrans{Narrated Ibn `Abbas.:Abu Lahab, may Allah curse him, once said to the Prophet (ﷺ), "Perish you all the day." Then the Divine Inspiration came: "Perish the hands of Abi Lahab! And perish he}}
