% Auto-generated chapter 67 for bukhari
% Hadiths in this chapter: 183

\hadithdefcmd{bukhari}{5063}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا حُمَيْدُ بْنُ أَبِي حُمَيْدٍ الطَّوِيلُ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ جَاءَ ثَلاَثَةُ رَهْطٍ إِلَى بُيُوتِ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم يَسْأَلُونَ عَنْ عِبَادَةِ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا أُخْبِرُوا كَأَنَّهُمْ تَقَالُّوهَا فَقَالُوا وَأَيْنَ نَحْنُ مِنَ النَّبِيِّ صلى الله عليه وسلم قَدْ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ‏.‏ قَالَ أَحَدُهُمْ أَمَّا أَنَا فَإِنِّي أُصَلِّي اللَّيْلَ أَبَدًا‏.‏ وَقَالَ آخَرُ أَنَا أَصُومُ الدَّهْرَ وَلاَ أُفْطِرُ‏.‏ وَقَالَ آخَرُ أَنَا أَعْتَزِلُ النِّسَاءَ فَلاَ أَتَزَوَّجُ أَبَدًا‏.‏ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَنْتُمُ الَّذِينَ قُلْتُمْ كَذَا وَكَذَا أَمَا وَاللَّهِ إِنِّي لأَخْشَاكُمْ لِلَّهِ وَأَتْقَاكُمْ لَهُ، لَكِنِّي أَصُومُ وَأُفْطِرُ، وَأُصَلِّي وَأَرْقُدُ وَأَتَزَوَّجُ النِّسَاءَ، فَمَنْ رَغِبَ عَنْ سُنَّتِي فَلَيْسَ مِنِّي ‏"‏‏.‏\hadithno{5063}\hadithtrans{Narrated Anas bin Malik:A group of three men came to the houses of the wives of the Prophet (ﷺ) asking how the Prophet (ﷺ) worshipped (Allah), and when they were informed about that, they considered their worship insufficient and said, "Where are we from the Prophet (ﷺ) as his past and future sins have been forgiven." Then one of them said, "I will offer the prayer throughout the night forever." The other said, "I will fast throughout the year and will not break my fast." The third said, "I will keep away from the women and will not marry forever." Allah's Messenger (ﷺ) came to them and said, "Are you the same people who said so-and-so? By Allah, I am more submissive to Allah and more afraid of Him than you; yet I fast and break my fast, I do sleep and I also marry women. So he who does not follow my tradition in religion, is not from me (not one of my followers)}}
\hadithdefcmd{bukhari}{5064}{حَدَّثَنَا عَلِيٌّ، سَمِعَ حَسَّانَ بْنَ إِبْرَاهِيمَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ قَوْلِهِ تَعَالَى ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ مَثْنَى وَثُلاَثَ وَرُبَاعَ فَإِنْ خِفْتُمْ أَنْ لاَ تَعْدِلُوا فَوَاحِدَةً أَوْ مَا مَلَكَتْ أَيْمَانُكُمْ ذَلِكَ أَدْنَى أَنْ لاَ تَعُولُوا‏\}‏‏.‏ قَالَتْ يَا ابْنَ أُخْتِي، الْيَتِيمَةُ تَكُونُ فِي حَجْرِ وَلِيِّهَا، فَيَرْغَبُ فِي مَالِهَا وَجَمَالِهَا، يُرِيدُ أَنْ يَتَزَوَّجَهَا بِأَدْنَى مِنْ سُنَّةِ صَدَاقِهَا، فَنُهُوا أَنْ يَنْكِحُوهُنَّ إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ فَيُكْمِلُوا الصَّدَاقَ، وَأُمِرُوا بِنِكَاحِ مَنْ سِوَاهُنَّ مِنَ النِّسَاءِ‏.‏\hadithno{5064}\hadithtrans{Narrated 'Urwa:that he asked `Aisha about the Statement of Allah: 'If you fear that you shall not be able to deal justly with the orphan girls, then marry (other) women of your choice, two or three or four; but if you fear that you shall not be able to deal justly (with them), then only one, or (the captives) that your right hands possess. That will be nearer to prevent you from doing injustice.' (4.3) `Aisha said, "O my nephew! (This Verse has been revealed in connection with) an orphan girl under the guardianship of her guardian who is attracted by her wealth and beauty and intends to marry her with a Mahr less than what other women of her standard deserve. So they (such guardians) have been forbidden to marry them unless they do justice to them and give them their full Mahr, and they are ordered to marry other women instead of them}}
\hadithdefcmd{bukhari}{5065}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنْ عَلْقَمَةَ، قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ فَلَقِيَهُ عُثْمَانُ بِمِنًى فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّ لِي إِلَيْكَ حَاجَةً‏.‏ فَخَلَيَا فَقَالَ عُثْمَانُ هَلْ لَكَ يَا أَبَا عَبْدِ الرَّحْمَنِ فِي أَنْ نُزَوِّجَكَ بِكْرًا، تُذَكِّرُكَ مَا كُنْتَ تَعْهَدُ، فَلَمَّا رَأَى عَبْدُ اللَّهِ أَنْ لَيْسَ لَهُ حَاجَةٌ إِلَى هَذَا أَشَارَ إِلَىَّ فَقَالَ يَا عَلْقَمَةُ، فَانْتَهَيْتُ إِلَيْهِ وَهْوَ يَقُولُ أَمَا لَئِنْ قُلْتَ ذَلِكَ لَقَدْ قَالَ لَنَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ، وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏‏.‏\hadithno{5065}\hadithtrans{Narrated 'Alqama:While I was with `Abdullah, `Uthman met him at Mina and said, "O Abu `Abdur-Rahman ! I have something to say to you." So both of them went aside and `Uthman said, "O Abu `Abdur-Rah. man! Shall we marry you to a virgin who will make you remember your past days?" When `Abdullah felt that he was not in need of that, he beckoned me (to join him) saying, "O 'Alqama!" Then I heard him saying (in reply to `Uthman), "As you have said that, (I tell you that) the Prophet (ﷺ) once said to us, 'O young people! Whoever among you is able to marry, should marry, and whoever is not able to marry, is recommended to fast, as fasting diminishes his sexual power}}
\hadithdefcmd{bukhari}{5066}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي عُمَارَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ دَخَلْتُ مَعَ عَلْقَمَةَ وَالأَسْوَدِ عَلَى عَبْدِ اللَّهِ فَقَالَ عَبْدُ اللَّهِ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم شَبَابًا لاَ نَجِدُ شَيْئًا فَقَالَ لَنَا رَسُولُ اللَّهُ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ الْبَاءَةَ فَلْيَتَزَوَّجْ، فَإِنَّهُ أَغَضُّ لِلْبَصَرِ، وَأَحْصَنُ لِلْفَرْجِ، وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ، فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏‏.‏\hadithno{5066}\hadithtrans{Narrated `Abdullah:We were with the Prophet (ﷺ) while we were young and had no wealth. So Allah's Messenger (ﷺ) said, "O young people! Whoever among you can marry, should marry, because it helps him lower his gaze and guard his modesty (i.e. his private parts from committing illegal sexual intercourse etc.), and whoever is not able to marry, should fast, as fasting diminishes his sexual power}}
\hadithdefcmd{bukhari}{5067}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي عَطَاءٌ، قَالَ حَضَرْنَا مَعَ ابْنِ عَبَّاسٍ جَنَازَةَ مَيْمُونَةَ بِسَرِفَ، فَقَالَ ابْنُ عَبَّاسٍ هَذِهِ زَوْجَةُ النَّبِيِّ صلى الله عليه وسلم فَإِذَا رَفَعْتُمْ نَعْشَهَا فَلاَ تُزَعْزِعُوهَا وَلاَ تُزَلْزِلُوهَا وَارْفُقُوا، فَإِنَّهُ كَانَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم تِسْعٌ، كَانَ يَقْسِمُ لِثَمَانٍ وَلاَ يَقْسِمُ لِوَاحِدَةٍ‏.‏\hadithno{5067}\hadithtrans{Narrated 'Ata:We presented ourselves along with Ibn `Abbas at the funeral procession of Maimuna at a place called Sarif. Ibn `Abbas said, "This is the wife of the Prophet (ﷺ) so when you lift her bier, do not Jerk it or shake it much, but walk smoothly because the Prophet (ﷺ) had nine wives and he used to observe the night turns with eight of them, and for one of them there was no night turn}}
\hadithdefcmd{bukhari}{5068}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ فِي لَيْلَةٍ وَاحِدَةٍ، وَلَهُ تِسْعُ نِسْوَةٍ‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسًا، حَدَّثَهُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5068}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used to go round (have sexual relations with) all his wives in one night, and he had nine wives}}
\hadithdefcmd{bukhari}{5069}{حَدَّثَنَا عَلِيُّ بْنُ الْحَكَمِ الأَنْصَارِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ رَقَبَةَ، عَنْ طَلْحَةَ الْيَامِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قَالَ لِي ابْنُ عَبَّاسٍ هَلْ تَزَوَّجْتَ قُلْتُ لاَ‏.‏ قَالَ فَتَزَوَّجْ فَإِنَّ خَيْرَ هَذِهِ الأُمَّةِ أَكْثَرُهَا نِسَاءً‏.‏\hadithno{5069}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Abbas asked me, "Are you married?" I replied, "No." He said, "Marry, for the best person of this (Muslim) nation (i.e., Muhammad) of all other Muslims, had the largest number of wives}}
\hadithdefcmd{bukhari}{5070}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْعَمَلُ بِالنِّيَّةِ، وَإِنَّمَا لاِمْرِئٍ مَا نَوَى، فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ صلى الله عليه وسلم وَمَنْ كَانَتْ هِجْرَتُهُ إِلَى دُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَنْكِحُهَا، فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏‏.‏\hadithno{5070}\hadithtrans{Narrated `Umar bin Al-Khattab:The Prophet (ﷺ) said, "The rewards (of deeds) are according to the intention, and everybody will get the reward for what he has intended. So whoever emigrated for Allah's and His Apostle's sake, his emigration was for Allah and His Apostle; and whoever emigrated for worldly benefits, or to marry a woman, then his emigration was for the thing for what he emigrated for}}
\hadithdefcmd{bukhari}{5071}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي قَيْسٌ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ كُنَّا نَغْزُو مَعَ النَّبِيِّ صلى الله عليه وسلم وَلَيْسَ لَنَا نِسَاءٌ فَقُلْنَا يَا رَسُولَ اللَّهِ أَلاَ نَسْتَخْصِي فَنَهَانَا عَنْ ذَلِكَ‏.‏\hadithno{5071}\hadithtrans{Narrated Ibn Masud:We used to fight in the holy battles in the company of the Prophet (ﷺ) and we had no wives with us. So we said, "O Allah's Messenger (ﷺ)! Shall we get castrated?" The Prophet (ﷺ) forbade us to do so}}
\hadithdefcmd{bukhari}{5072}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنْ سُفْيَانَ، عَنْ حُمَيْدٍ الطَّوِيلِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، قَالَ قَدِمَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فَآخَى النَّبِيُّ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَ سَعْدِ بْنِ الرَّبِيعِ الأَنْصَارِيِّ وَعِنْدَ الأَنْصَارِيِّ امْرَأَتَانِ، فَعَرَضَ عَلَيْهِ أَنْ يُنَاصِفَهُ أَهْلَهُ وَمَالَهُ فَقَالَ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ دُلُّونِي عَلَى السُّوقِ، فَأَتَى السُّوقَ فَرَبِحَ شَيْئًا مِنْ أَقِطٍ وَشَيْئًا مِنْ سَمْنٍ فَرَآهُ النَّبِيُّ صلى الله عليه وسلم بَعْدَ أَيَّامٍ وَعَلَيْهِ وَضَرٌ مِنْ صُفْرَةٍ فَقَالَ ‏"‏ مَهْيَمْ يَا عَبْدَ الرَّحْمَنِ ‏"‏‏.‏ فَقَالَ تَزَوَّجْتُ أَنْصَارِيَّةً‏.‏ قَالَ ‏"‏ فَمَا سُقْتَ ‏"‏‏.‏ قَالَ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ‏.‏ قَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{5072}\hadithtrans{Narrated Anas bin Malik:`Abdur-Rahman bin `Auf came (from Mecca to Medina) and the Prophet (ﷺ) made a bond of brotherhood between him and Sa`d bin Ar-Rabi` Al-Ansari. Al-Ansari had two wives, so he suggested that `Abdur- Rahman take half, his wives and property. `Abdur-Rahman replied, "May Allah bless you with your wives and property. Kindly show me the market." So `Abdur-Rahman went to the market and gained (in bargains) some dried yoghurt and some butter. After a few days the Prophet (ﷺ) saw `Abdur-Rahman with some yellow stains on his clothes and asked him, "What is that, O `Abdur-Rahman?" He replied, "I had married an Ansari woman." The Prophet (ﷺ) asked, "How much Mahr did you give her?" He replied, "The weight of one (date) stone of gold." The Prophet (ﷺ) said, "Offer a banquet, even with one sheep}}
\hadithdefcmd{bukhari}{5073}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ رَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عُثْمَانَ بْنِ مَظْعُونٍ التَّبَتُّلَ، وَلَوْ أَذِنَ لَهُ لاَخْتَصَيْنَا‏.‏\hadithno{5073}\hadithtrans{Narrated Sa`d bin Abi Waqqas:Allah's Messenger (ﷺ) forbade `Uthman bin Maz'un to abstain from marrying (and other pleasures) and if he had allowed him, we would have gotten ourselves castrated}}
\hadithdefcmd{bukhari}{5074}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُ سَمِعَ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ لَقَدْ رَدَّ ذَلِكَ ـ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ـ عَلَى عُثْمَانَ، وَلَوْ أَجَازَ لَهُ التَّبَتُّلَ لاَخْتَصَيْنَا‏.‏\hadithno{5074}\hadithtrans{Narrated Sa`d bin Abi Waqqas:The Prophet (ﷺ) prevented `Uthman bin Mazun from that (not marrying), and had he allowed him, we would have got ourselves castrated}}
\hadithdefcmd{bukhari}{5075}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ قَالَ عَبْدُ اللَّهِ كُنَّا نَغْزُو مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَيْسَ لَنَا شَىْءٌ فَقُلْنَا أَلاَ نَسْتَخْصِي فَنَهَانَا عَنْ ذَلِكَ ثُمَّ رَخَّصَ لَنَا أَنْ نَنْكِحَ الْمَرْأَةَ بِالثَّوْبِ، ثُمَّ قَرَأَ عَلَيْنَا ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تُحَرِّمُوا طَيِّبَاتِ مَا أَحَلَّ اللَّهُ لَكُمْ وَلاَ تَعْتَدُوا إِنَّ اللَّهَ لاَ يُحِبُّ الْمُعْتَدِينَ‏\}‏‏.‏\hadithno{5075}\hadithtrans{Narrated 'Abdullah: We used to participate in the holy battles led by Allah's Messenger (ﷺ) and we had nothing (no wives) with us. So we said, "Shall we get ourselves castrated?" He forbade us that and then allowed us to marry women with a temporary contract (2) and recited to us: -- 'O you who believe ! Make not unlawful the good things which Allah has made lawful for you, but commit no transgression}}
\hadithdefcmd{bukhari}{5076}{وَقَالَ أَصْبَغُ أَخْبَرَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ شَابٌّ وَأَنَا أَخَافُ عَلَى نَفْسِي الْعَنَتَ وَلاَ أَجِدُ مَا أَتَزَوَّجُ بِهِ النِّسَاءَ، فَسَكَتَ عَنِّي، ثُمَّ قُلْتُ مِثْلَ ذَلِكَ، فَسَكَتَ عَنِّي ثُمَّ قُلْتُ مِثْلَ ذَلِكَ، فَسَكَتَ عَنِّي ثُمَّ قُلْتُ مِثْلَ ذَلِكَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَبَا هُرَيْرَةَ جَفَّ الْقَلَمُ بِمَا أَنْتَ لاَقٍ، فَاخْتَصِ عَلَى ذَلِكَ أَوْ ذَرْ ‏"‏‏.‏\hadithno{5076}\hadithtrans{Narrated Abu Huraira: I said, "O Allah's Messenger (ﷺ)! I am a young man and I am afraid that I may commit illegal sexual intercourse and I cannot afford to marry." He kept silent, and then repeated my question once again, but he kept silent. I said the same (for the third time) and he remained silent. Then repeated my question (for the fourth time), and only then the Prophet said, "O Abu Huraira! The pen has dried after writing what you are going to confront. So (it does not matter whether you) get yourself castrated or not}}
\hadithdefcmd{bukhari}{5077}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ لَوْ نَزَلْتَ وَادِيًا وَفِيهِ شَجَرَةٌ قَدْ أُكِلَ مِنْهَا، وَوَجَدْتَ شَجَرًا لَمْ يُؤْكَلْ مِنْهَا، فِي أَيِّهَا كُنْتَ تُرْتِعُ بَعِيرَكَ قَالَ ‏ "‏ فِي الَّذِي لَمْ يُرْتَعْ مِنْهَا ‏"‏‏.‏ تَعْنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَتَزَوَّجْ بِكْرًا غَيْرَهَا‏.‏\hadithno{5077}\hadithtrans{Narrated `Aisha:I said, "O Allah's Messenger (ﷺ)! Suppose you landed in a valley where there is a tree of which something has been eaten and then you found trees of which nothing has been eaten, of which tree would you let your camel graze?" He said, "(I will let my camel graze) of the one of which nothing has been eaten before." (The sub-narrator added: `Aisha meant that Allah's Messenger (ﷺ) had not married a virgin besides herself}}
\hadithdefcmd{bukhari}{5078}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُرِيتُكِ فِي الْمَنَامِ مَرَّتَيْنِ، إِذَا رَجُلٌ يَحْمِلُكِ فِي سَرَقَةِ حَرِيرٍ فَيَقُولُ هَذِهِ امْرَأَتُكَ، فَأَكْشِفُهَا فَإِذَا هِيَ أَنْتِ، فَأَقُولُ إِنْ يَكُنْ هَذَا مِنْ عِنْدِ اللَّهِ يُمْضِهِ ‏"‏‏.‏\hadithno{5078}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said (to me), "You have been shown to me twice in (my) dreams. A man was carrying you in a silken cloth and said to me, 'This is your wife.' I uncovered it; and behold, it was you. I said to myself, 'If this dream is from Allah, He will cause it to come true}}
\hadithdefcmd{bukhari}{5079}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا سَيَّارٌ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَفَلْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم مِنْ غَزْوَةٍ فَتَعَجَّلْتُ عَلَى بَعِيرٍ لِي قَطُوفٍ، فَلَحِقَنِي رَاكِبٌ مِنْ خَلْفِي، فَنَخَسَ بَعِيرِي بِعَنَزَةٍ كَانَتْ مَعَهُ، فَانْطَلَقَ بَعِيرِي كَأَجْوَدِ مَا أَنْتَ رَاءٍ مِنَ الإِبِلِ، فَإِذَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا يُعْجِلُكَ ‏"‏‏.‏ قُلْتُ كُنْتُ حَدِيثَ عَهْدٍ بِعُرُسٍ‏.‏ قَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ قُلْتُ ثَيِّبٌ‏.‏ قَالَ ‏"‏ فَهَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏‏.‏ قَالَ فَلَمَّا ذَهَبْنَا لِنَدْخُلَ قَالَ ‏"‏ أَمْهِلُوا حَتَّى تَدْخُلُوا لَيْلاً ـ أَىْ عِشَاءً ـ لِكَىْ تَمْتَشِطَ الشَّعِثَةُ وَتَسْتَحِدَّ الْمُغِيبَةُ ‏"‏‏.‏\hadithno{5079}\hadithtrans{Narrated Jabir bin `Abdullah:While we were returning from a Ghazwa (Holy Battle) with the Prophet, I started driving my camel fast, as it was a lazy camel A rider came behind me and pricked my camel with a spear he had with him, and then my camel started running as fast as the best camel you may see. Behold! The rider was the Prophet (ﷺ) himself. He said, 'What makes you in such a hurry?" I replied, I am newly married " He said, "Did you marry a virgin or a matron? I replied, "A matron." He said, "Why didn't you marry a young girl so that you may play with her and she with you?" When we were about to enter (Medina), the Prophet (ﷺ) said, "Wait so that you may enter (Medina) at night so that the lady of unkempt hair may comb her hair and the one whose husband has been absent may shave her pubic region}}
\hadithdefcmd{bukhari}{5080}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَارِبٌ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، رضى الله عنهما يَقُولُ تَزَوَّجْتُ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَزَوَّجْتَ ‏"‏‏.‏ فَقُلْتُ تَزَوَّجْتُ ثَيِّبًا‏.‏ فَقَالَ ‏"‏ مَا لَكَ وَلِلْعَذَارَى وَلِعَابِهَا ‏"‏‏.‏ فَذَكَرْتُ ذَلِكَ لِعَمْرِو بْنِ دِينَارٍ فَقَالَ عَمْرٌو سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏‏.‏\hadithno{5080}\hadithtrans{Narrated Jabir bin `Abdullah:When I got married, Allah's Messenger (ﷺ) said to me, "What type of lady have you married?" I replied, "I have married a matron' He said, "Why, don't you have a liking for the virgins and for fondling them?" Jabir also said: Allah's Messenger (ﷺ) said, "Why didn't you marry a young girl so that you might play with her and she with you?}}
\hadithdefcmd{bukhari}{5081}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ، عَنْ عِرَاكٍ، عَنْ عُرْوَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ عَائِشَةَ إِلَى أَبِي بَكْرٍ فَقَالَ لَهُ أَبُو بَكْرٍ إِنَّمَا أَنَا أَخُوكَ، فَقَالَ ‏ "‏ أَنْتَ أَخِي فِي دِينِ اللَّهِ وَكِتَابِهِ وَهْىَ لِي حَلاَلٌ ‏"‏‏.‏\hadithno{5081}\hadithtrans{Narrated 'Urwa:The Prophet (ﷺ) asked Abu Bakr for `Aisha's hand in marriage. Abu Bakr said "But I am your brother." The Prophet (ﷺ) said, "You are my brother in Allah's religion and His Book, but she (Aisha) is lawful for me to marry}}
\hadithdefcmd{bukhari}{5082}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ نِسَاءٍ رَكِبْنَ الإِبِلَ صَالِحُو نِسَاءِ قُرَيْشٍ، أَحْنَاهُ عَلَى وَلَدٍ فِي صِغَرِهِ وَأَرْعَاهُ عَلَى زَوْجٍ فِي ذَاتِ يَدِهِ ‏"‏‏.‏\hadithno{5082}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The best women are the riders of the camels and the righteous among the women of Quraish. They are the kindest women to their children in their childhood and the more careful women of the property of their husbands}}
\hadithdefcmd{bukhari}{5083}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا صَالِحُ بْنُ صَالِحٍ الْهَمْدَانِيُّ، حَدَّثَنَا الشَّعْبِيُّ، قَالَ حَدَّثَنِي أَبُو بُرْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّمَا رَجُلٍ كَانَتْ عِنْدَهُ وَلِيدَةٌ فَعَلَّمَهَا فَأَحْسَنَ تَعْلِيمَهَا، وَأَدَّبَهَا فَأَحْسَنَ تَأْدِيبَهَا، ثُمَّ أَعْتَقَهَا وَتَزَوَّجَهَا فَلَهُ أَجْرَانِ، وَأَيُّمَا رَجُلٍ مِنْ أَهْلِ الْكِتَابِ آمَنَ بِنَبِيِّهِ وَآمَنَ بِي فَلَهُ أَجْرَانِ، وَأَيُّمَا مَمْلُوكٍ أَدَّى حَقَّ مَوَالِيهِ وَحَقَّ رَبِّهِ فَلَهُ أَجْرَانِ ‏"‏‏.‏ قَالَ الشَّعْبِيُّ خُذْهَا بِغَيْرِ شَىْءٍ قَدْ كَانَ الرَّجُلُ يَرْحَلُ فِيمَا دُونَهُ إِلَى الْمَدِينَةِ‏.‏ وَقَالَ أَبُو بَكْرٍ عَنْ أَبِي حَصِينٍ عَنْ أَبِي بُرْدَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أَعْتَقَهَا ثُمَّ أَصْدَقَهَا ‏"‏‏.‏\hadithno{5083}\hadithtrans{Narrated Abu Burda's father:Allah's Messenger (ﷺ) said, any man who has a slave girl whom he educates properly, teaches good manners, manumits and marries her, will get a double reward And if any man of the people of the Scriptures believes in his own prophet and then believes in me too, he will (also) get a double reward And any slave who fulfills his duty to his master and to his Lord, will (also) get a double reward}}
\hadithdefcmd{bukhari}{5084}{حَدَّثَنَا سَعِيدُ بْنُ تَلِيدٍ، قَالَ أَخْبَرَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا سُلَيْمَانُ عَنْ حَمَّادِ بْنِ زَيْدٍ عَنْ أَيُّوبَ عَنْ مُحَمَّدٍ عَنْ أَبِي هُرَيْرَةَ ‏\{‏قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم‏\}‏ ‏ "‏ لَمْ يَكْذِبْ إِبْرَاهِيمُ إِلاَّ ثَلاَثَ كَذَبَاتٍ بَيْنَمَا إِبْرَاهِيمُ مَرَّ بِجَبَّارٍ وَمَعَهُ سَارَةُ ـ فَذَكَرَ الْحَدِيثَ ـ فَأَعْطَاهَا هَاجَرَ قَالَتْ كَفَّ اللَّهُ يَدَ الْكَافِرِ وَأَخْدَمَنِي آجَرَ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ فَتِلْكَ أُمُّكُمْ يَا بَنِي مَاءِ السَّمَاءِ‏.‏\hadithno{5084}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said: Abraham did not tell lies except three. (One of them was) when Abraham passed by a tyrant and (his wife) Sara was accompanying him (Abu Huraira then mentioned the whole narration and said:) (The tyrant) gave her Hajar. Sara said, "Allah saved me from the hands of the Kafir (i.e. infidel) and gave me Hajar to serve me." (Abu Huraira added:) That (Hajar) is your mother, O Banu Ma'-As-Sama' (i.e., the Arabs)}}
\hadithdefcmd{bukhari}{5085}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أَقَامَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ خَيْبَرَ وَالْمَدِينَةِ ثَلاَثًا يُبْنَى عَلَيْهِ بِصَفِيَّةَ بِنْتِ حُيَىٍّ فَدَعَوْتُ الْمُسْلِمِينَ إِلَى وَلِيمَتِهِ فَمَا كَانَ فِيهَا مِنْ خُبْزٍ وَلاَ لَحْمٍ، أُمِرَ بِالأَنْطَاعِ فَأَلْقَى فِيهَا مِنَ التَّمْرِ وَالأَقِطِ وَالسَّمْنِ فَكَانَتْ وَلِيمَتَهُ، فَقَالَ الْمُسْلِمُونَ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ أَوْ مِمَّا مَلَكَتْ يَمِينُهُ، فَقَالُوا إِنْ حَجَبَهَا فَهْىَ مِنْ أُمَّهَاتِ الْمُؤْمِنِينَ، وَإِنْ لَمْ يَحْجُبْهَا فَهْىَ مِمَّا مَلَكَتْ يَمِينُهُ، فَلَمَّا ارْتَحَلَ وَطَّى لَهَا خَلْفَهُ وَمَدَّ الْحِجَابَ بَيْنَهَا وَبَيْنَ النَّاسِ‏.‏\hadithno{5085}\hadithtrans{Narrated Anas:The Prophet (ﷺ) stayed for three days between Khaibar and Medina, and there he consummated his marriage to Safiyya bint Huyai. I invited the Muslims to the wedding banquet in which neither meat nor bread was offered. He ordered for leather dining-sheets to be spread, and dates, dried yoghurt and butter were laid on it, and that was the Prophet's wedding banquet. The Muslims wondered, "Is she (Saffiyya) considered as his wife or his slave girl?" Then they said, "If he orders her to veil herself, she will be one of the mothers of the Believers; but if he does not order her to veil herself, she will be a slave girl. So when the Prophet (ﷺ) proceeded from there, he spared her a space behind him (on his she-camel) and put a screening veil between her and the people}}
\hadithdefcmd{bukhari}{5086}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، وَشُعَيْبِ بْنِ الْحَبْحَابِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْتَقَ صَفِيَّةَ، وَجَعَلَ عِتْقَهَا صَدَاقَهَا‏.‏\hadithno{5086}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) manumitted Safiyya and regarded her manumission as her Mahr}}
\hadithdefcmd{bukhari}{5087}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ جِئْتُ أَهَبُ لَكَ نَفْسِي قَالَ فَنَظَرَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَعَّدَ النَّظَرَ فِيهَا وَصَوَّبَهُ ثُمَّ طَأْطَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَأْسَهُ فَلَمَّا رَأَتِ الْمَرْأَةُ أَنَّهُ لَمْ يَقْضِ فِيهَا شَيْئًا جَلَسَتْ فَقَامَ رَجُلٌ مِنْ أَصْحَابِهِ فَقَالَ يَا رَسُولَ اللَّهِ إِنْ لَمْ يَكُنْ لَكَ بِهَا حَاجَةٌ فَزَوِّجْنِيهَا‏.‏ فَقَالَ ‏"‏ وَهَلْ عِنْدَكَ مِنْ شَىْءٍ ‏"‏‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ اذْهَبْ إِلَى أَهْلِكَ فَانْظُرْ هَلْ تَجِدُ شَيْئًا ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ مَا وَجَدْتُ شَيْئًا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْظُرْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ وَلاَ خَاتَمًا مِنْ حَدِيدٍ وَلَكِنْ هَذَا إِزَارِي ـ قَالَ سَهْلٌ مَا لَهُ رِدَاءٌ فَلَهَا نِصْفُهُ ـ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَصْنَعُ بِإِزَارِكَ إِنْ لَبِسْتَهُ لَمْ يَكُنْ عَلَيْهَا مِنْهُ شَىْءٌ وَإِنْ لَبِسَتْهُ لَمْ يَكُنْ عَلَيْكَ شَىْءٌ ‏"‏‏.‏ فَجَلَسَ الرَّجُلُ حَتَّى إِذَا طَالَ مَجْلِسُهُ قَامَ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مُوَلِّيًا فَأَمَرَ بِهِ فَدُعِيَ فَلَمَّا جَاءَ قَالَ ‏"‏ مَاذَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏ قَالَ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا عَدَّدَهَا‏.‏ فَقَالَ ‏"‏ تَقْرَؤُهُنَّ عَنْ ظَهْرِ قَلْبِكَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ اذْهَبْ فَقَدْ مَلَّكْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5087}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:A woman came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! I have come to give you myself in marriage (without Mahr)." Allah's Messenger (ﷺ) looked at her. He looked at her carefully and fixed his glance on her and then lowered his head. When the lady saw that he did not say anything, she sat down. A man from his companions got up and said, "O Allah's Messenger (ﷺ)! If you are not in need of her, then marry her to me." The Prophet (ﷺ) said, "Have you got anything to offer?" The man said, "No, by Allah, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said (to him), "Go to your family and see if you have something." The man went and returned, saying, "No, by Allah, I have not found anything." Allah's Apostle said, "(Go again) and look for something, even if it is an iron ring." He went again and returned, saying, "No, by Allah, O Allah's Messenger (ﷺ)! I could not find even an iron ring, but this is my Izar (waist sheet)." He had no rida. He added, "I give half of it to her." Allah's Messenger (ﷺ) said, "What will she do with your Izar? If you wear it, she will be naked, and if she wears it, you will be naked." So that man sat down for a long while and then got up (to depart). When Allah's Messenger (ﷺ) saw him going, he ordered that he be called back. When he came, the Prophet (ﷺ) said, "How much of the Qur'an do you know?" He said, "I know such Sura and such Sura," counting them. The Prophet (ﷺ) said, "Do you know them by heart?" He replied, "Yes." The Prophet (ﷺ) said, "Go, I marry her to you for that much of the Qur'an which you have}}
\hadithdefcmd{bukhari}{5088}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ أَبَا حُذَيْفَةَ بْنَ عُتْبَةَ بْنِ رَبِيعَةَ بْنِ عَبْدِ شَمْسٍ،، وَكَانَ، مِمَّنْ شَهِدَ بَدْرًا مَعَ النَّبِيِّ صلى الله عليه وسلم تَبَنَّى سَالِمًا، وَأَنْكَحَهُ بِنْتَ أَخِيهِ هِنْدَ بِنْتَ الْوَلِيدِ بْنِ عُتْبَةَ بْنِ رَبِيعَةَ وَهْوَ مَوْلًى لاِمْرَأَةٍ مِنَ الأَنْصَارِ، كَمَا تَبَنَّى النَّبِيُّ صلى الله عليه وسلم زَيْدًا، وَكَانَ مَنْ تَبَنَّى رَجُلاً فِي الْجَاهِلِيَّةِ دَعَاهُ النَّاسُ إِلَيْهِ وَوَرِثَ مِنْ مِيرَاثِهِ حَتَّى أَنْزَلَ اللَّهُ ‏\{‏ادْعُوهُمْ لآبَائِهِمْ‏\}‏ إِلَى قَوْلِهِ ‏\{‏وَمَوَالِيكُمْ‏\}‏ فَرُدُّوا إِلَى آبَائِهِمْ، فَمَنْ لَمْ يُعْلَمْ لَهُ أَبٌ كَانَ مَوْلًى وَأَخًا فِي الدِّينِ، فَجَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلِ بْنِ عَمْرٍو الْقُرَشِيِّ ثُمَّ الْعَامِرِيِّ ـ وَهْىَ امْرَأَةُ أَبِي حُذَيْفَةَ ـ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَرَى سَالِمًا وَلَدًا وَقَدْ أَنْزَلَ اللَّهُ فِيهِ مَا قَدْ عَلِمْتَ فَذَكَرَ الْحَدِيثَ‏.‏\hadithno{5088}\hadithtrans{Narrated `Aisha:Abu Hudhaifa bin `Utba bin Rabi`a bin `Abdi Shams who had witnessed the battle of Badr along with the Prophet (ﷺ) adopted Salim as his son, to whom he married his niece, Hind bint Al-Walid bin `Utba bin Rabi`a; and Salim was the freed slave of an Ansar woman, just as the Prophet (ﷺ) had adopted Zaid as his son. It was the custom in the Pre-Islamic Period that if somebody adopted a boy, the people would call him the son of the adoptive father and he would be the latter's heir. But when Allah revealed the Divine Verses: 'Call them by (the names of) their fathers . . . your freed-slaves,' (33.5) the adopted persons were called by their fathers' names. The one whose father was not known, would be regarded as a Maula and your brother in religion. Later on Sahla bint Suhail bin `Amr Al-Quraishi Al-`Amiri-- and she was the wife of Abu- Hudhaifa bin `Utba--came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! We used to consider Salim as our (adopted) son, and now Allah has revealed what you know (regarding adopted sons)." The sub-narrator then mentioned the rest of the narration}}
\hadithdefcmd{bukhari}{5089}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ضُبَاعَةَ بِنْتِ الزُّبَيْرِ فَقَالَ لَهَا ‏"‏ لَعَلَّكِ أَرَدْتِ الْحَجَّ ‏"‏‏.‏ قَالَتْ وَاللَّهِ لاَ أَجِدُنِي إِلاَّ وَجِعَةً‏.‏ فَقَالَ لَهَا ‏"‏ حُجِّي وَاشْتَرِطِي، قُولِي اللَّهُمَّ مَحِلِّي حَيْثُ حَبَسْتَنِي ‏"‏‏.‏ وَكَانَتْ تَحْتَ الْمِقْدَادِ بْنِ الأَسْوَدِ‏.‏\hadithno{5089}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) entered upon Dubaa bint Az-Zubair and said to her, "Do you have a desire to perform the Hajj?" She replied, "By Allah, I feel sick." He said to her, "Intend to perform Hajj and stipulate something by saying, 'O Allah, I will finish my Ihram at any place where You stop me (i.e. I am unable to go further)." She was the wife of Al-Miqdad bin Al-Aswad}}
\hadithdefcmd{bukhari}{5090}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُنْكَحُ الْمَرْأَةُ لأَرْبَعٍ لِمَالِهَا وَلِحَسَبِهَا وَجَمَالِهَا وَلِدِينِهَا، فَاظْفَرْ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏‏.‏\hadithno{5090}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A woman is married for four things, i.e., her wealth, her family status, her beauty and her religion. So you should marry the religious woman (otherwise) you will be a losers}}
\hadithdefcmd{bukhari}{5091}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، قَالَ مَرَّ رَجُلٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا تَقُولُونَ فِي هَذَا ‏"‏‏.‏ قَالُوا حَرِيٌّ إِنْ خَطَبَ أَنْ يُنْكَحَ، وَإِنْ شَفَعَ أَنْ يُشَفَّعَ، وَإِنْ قَالَ أَنْ يُسْتَمَعَ‏.‏ قَالَ ثُمَّ سَكَتَ فَمَرَّ رَجُلٌ مِنَ فُقَرَاءِ الْمُسْلِمِينَ فَقَالَ ‏"‏ مَا تَقُولُونَ فِي هَذَا ‏"‏‏.‏ قَالُوا حَرِيٌّ إِنْ خَطَبَ أَنْ لاَ يُنْكَحَ وَإِنْ شَفَعَ أَنْ لاَ يُشَفَّعَ، وَإِنْ قَالَ أَنْ لاَ يُسْتَمَعَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا خَيْرٌ مِنْ مِلْءِ الأَرْضِ مِثْلَ هَذَا ‏"‏‏.‏\hadithno{5091}\hadithtrans{Narrated Sahl:A man passed by Allah's Messenger (ﷺ) and Allah's Apostle asked (his companions) "What do you say about this (man)?" They replied "If he asks for a lady's hand, he ought to be given her in marriage; and if he intercedes (for someone) his intercessor should be accepted; and if he speaks, he should be listened to." Allah's Messenger (ﷺ) kept silent, and then a man from among the poor Muslims passed by, an Allah's Apostle asked (them) "What do you say about this man?" They replied, "If he asks for a lady's hand in marriage he does not deserve to be married, and he intercedes (for someone), his intercession should not be accepted; And if he speaks, he should not be listened to.' Allah's Messenger (ﷺ) said, "This poor man is better than so many of the first as filling the earth}}
\hadithdefcmd{bukhari}{5092}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّهُ سَأَلَ عَائِشَةَ ـ رضى الله عنها ـ ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى‏\}‏ قَالَتْ يَا ابْنَ أُخْتِي هَذِهِ الْيَتِيمَةُ تَكُونُ فِي حَجْرِ وَلِيِّهَا فَيَرْغَبُ فِي جَمَالِهَا وَمَالِهَا، وَيُرِيدُ أَنْ يَنْتَقِصَ صَدَاقَهَا، فَنُهُوا عَنْ نِكَاحِهِنَّ إِلاَّ أَنْ يُقْسِطُوا فِي إِكْمَالِ الصَّدَاقِ، وَأُمِرُوا بِنِكَاحِ مَنْ سِوَاهُنَّ، قَالَتْ وَاسْتَفْتَى النَّاسُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ، فَأَنْزَلَ اللَّهُ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ‏\}‏ إِلَى ‏\{‏وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏ فَأَنْزَلَ اللَّهُ لَهُمْ أَنَّ الْيَتِيمَةَ إِذَا كَانَتْ ذَاتَ جَمَالٍ وَمَالٍ رَغِبُوا فِي نِكَاحِهَا وَنَسَبِهَا فِي إِكْمَالِ الصَّدَاقِ، وَإِذَا كَانَتْ مَرْغُوبَةً عَنْهَا فِي قِلَّةِ الْمَالِ وَالْجَمَالِ تَرَكُوهَا وَأَخَذُوا غَيْرَهَا مِنَ النِّسَاءِ، قَالَتْ فَكَمَا يَتْرُكُونَهَا حِينَ يَرْغَبُونَ عَنْهَا فَلَيْسَ لَهُمْ أَنْ يَنْكِحُوهَا إِذَا رَغِبُوا فِيهَا إِلاَّ أَنْ يُقْسِطُوا لَهَا وَيُعْطُوهَا حَقَّهَا الأَوْفَى فِي الصَّدَاقِ‏.‏\hadithno{5092}\hadithtrans{Narrated 'Urwa:that he asked `Aisha regarding the Verse: 'If you fear that you shall not be able to deal justly with the orphans (4.3) She said, "O my nephew! This Verse refers to the orphan girl who is under the guardianship of her guardian who likes her beauty and wealth and wishes to (marry her and) curtails her Mahr. Such guardians have been forbidden to marry them unless they do justice by giving them their full Mahr, and they have been ordered to marry other than them. The people asked for the verdict of Allah's Messenger (ﷺ) after that, so Allah revealed: 'They ask your instruction concerning the women . . . whom you desire to marry.' (4.127) So Allah revealed to them that if the orphan girl had beauty and wealth, they desired to marry her and for her family status. They can only marry them if they give them their full Mahr. And if they had no desire to marry them because of their lack of wealth and beauty, they would leave them and marry other women. So, as they used to leave them, when they had no interest, in them, they were forbidden to marry them when they had such interest, unless they treated them justly and gave them their full Mahr Apostle said, 'If at all there is evil omen, it is in the horse, the woman and the house." a lady is to be warded off. And the Statement of Allah: 'Truly, among your wives and your children, there are enemies for you (i.e may stop you from the obedience of Allah)}}
\hadithdefcmd{bukhari}{5093}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ، وَسَالِمٍ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّؤْمُ فِي الْمَرْأَةِ وَالدَّارِ وَالْفَرَسِ ‏"‏‏.‏\hadithno{5093}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Evil omen is in the women, the house and the horse}}
\hadithdefcmd{bukhari}{5094}{حَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا عُمَرُ بْنُ مُحَمَّدٍ الْعَسْقَلاَنِيُّ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ ذَكَرُوا الشُّؤْمَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنْ كَانَ الشُّؤْمُ فِي شَىْءٍ فَفِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏‏.‏\hadithno{5094}\hadithtrans{Narrated Ibn `Umar:Evil omen was mentioned before the Prophet: The Prophet (ﷺ) said, "If there is evil omen in anything, it is in the house, the woman and the horse}}
\hadithdefcmd{bukhari}{5095}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ فَفِي الْفَرَسِ وَالْمَرْأَةِ وَالْمَسْكَنِ ‏"‏‏.‏\hadithno{5095}\hadithtrans{Narrated Sahl bin Sa`d:Allah's Messenger (ﷺ) said, "If at all there is bad omen, it is in the horse, the woman, and the house}}
\hadithdefcmd{bukhari}{5096}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ النَّهْدِيَّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا تَرَكْتُ بَعْدِي فِتْنَةً أَضَرَّ عَلَى الرِّجَالِ مِنَ النِّسَاءِ ‏"‏‏.‏\hadithno{5096}\hadithtrans{Narrated Usama bin Zaid:The Prophet (ﷺ) said, "After me I have not left any trial more severe to men than women}}
\hadithdefcmd{bukhari}{5097}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ فِي بَرِيرَةَ ثَلاَثُ سُنَنٍ عَتَقَتْ فَخُيِّرَتْ، وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ وَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَبُرْمَةٌ عَلَى النَّارِ، فَقُرِّبَ إِلَيْهِ خُبْزٌ وَأُدْمٌ مِنْ أُدْمِ الْبَيْتِ فَقَالَ ‏"‏ لَمْ أَرَ الْبُرْمَةَ ‏"‏‏.‏ فَقِيلَ لَحْمٌ تُصُدِّقَ عَلَى بَرِيرَةَ، وَأَنْتَ لاَ تَأْكُلُ الصَّدَقَةَ قَالَ ‏"‏ هُوَ عَلَيْهَا صَدَقَةٌ، وَلَنَا هَدِيَّةٌ ‏"‏‏.‏\hadithno{5097}\hadithtrans{Narrated `Aisha:Three principles were established because of Barira: (i) When Banra was manumitted she was given the option (to remain with her slave husband or not). (ii) Allah's Messenger (ﷺ) said "The Wala of the slave) is for the one who manumits (the slave). (iii) When Allah's Messenger (ﷺ) entered (the house), he saw a cooking pot on the fire but he was given bread and meat soup from the soup of the home. The Prophet (ﷺ) said, "Didn't I see the cooking pot (on the fire)?" It was said, "That is the meat given in charity to Barira, and you do not eat the (things given in) charity." The Prophet (ﷺ) said, "It is an object of charity for Barira, and it is a present for us}}
\hadithdefcmd{bukhari}{5098}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ، تُقْسِطُوا فِي الْيَتَامَى‏\}‏‏.‏ قَالَتِ الْيَتِيمَةُ تَكُونُ عِنْدَ الرَّجُلِ وَهْوَ وَلِيُّهَا، فَيَتَزَوَّجُهَا عَلَى مَالِهَا، وَيُسِيءُ صُحْبَتَهَا، وَلاَ يَعْدِلُ فِي مَالِهَا، فَلْيَتَزَوَّجْ مَا طَابَ لَهُ مِنَ النِّسَاءِ سِوَاهَا مَثْنَى وَثُلاَثَ وَرُبَاعَ‏.‏\hadithno{5098}\hadithtrans{Narrated Aisha":(regarding) the Verse: 'And if you fear that you shall not be able to deal justly with the orphans...' (4.3) It is about the orphan girl who is in the custody of a man who is her guardian, and he intends to marry her because of her wealth, but he treats her badly and does not manage her property fairly and honestly. Such a man should marry women of his liking other than her, two or three or four. 'Prohibited to you (for marriage) are: ...your foster-mothers (who suckled you).' (4.23) Marriage is prohibited between persons having a foster suckling relationship corresponding to a blood relationship which renders marriage unlawful}}
\hadithdefcmd{bukhari}{5099}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عِنْدَهَا، وَأَنَّهَا سَمِعَتْ صَوْتَ رَجُلٍ يَسْتَأْذِنُ فِي بَيْتِ حَفْصَةَ، قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا رَجُلٌ يَسْتَأْذِنُ فِي بَيْتِكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أُرَاهُ فُلاَنًا ‏"‏‏.‏ لِعَمِّ حَفْصَةَ مِنَ الرَّضَاعَةِ‏.‏ قَالَتْ عَائِشَةُ لَوْ كَانَ فُلاَنٌ حَيًّا، لِعَمِّهَا مِنَ الرَّضَاعَةِ دَخَلَ عَلَىَّ فَقَالَ ‏"‏ نَعَمِ الرَّضَاعَةُ تُحَرِّمُ مَا تُحَرِّمُ الْوِلاَدَةُ ‏"‏‏.‏\hadithno{5099}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) that while Allah's Messenger (ﷺ) was with her, she heard a voice of a man asking permission to enter the house of Hafsa. `Aisha added: I said, "O Allah's Messenger (ﷺ)! This man is asking permission to enter your house." The Prophet (ﷺ) said, "I think he is so-and-so," naming the foster-uncle of Hafsa. `Aisha said, "If so-and-so," naming her foster uncle, "were living, could he enter upon me?" The Prophet (ﷺ) said, "Yes, for foster suckling relations make all those things unlawful which are unlawful through corresponding birth (blood) relations}}
\hadithdefcmd{bukhari}{5100}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم أَلاَ تَزَوَّجُ ابْنَةَ حَمْزَةَ قَالَ ‏ "‏ إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ ‏"‏‏.‏ وَقَالَ بِشْرُ بْنُ عُمَرَ حَدَّثَنَا شُعْبَةُ سَمِعْتُ قَتَادَةَ سَمِعْتُ جَابِرَ بْنَ زَيْدٍ مِثْلَهُ‏.‏\hadithno{5100}\hadithtrans{Narrated Ibn `Abbas:It was said to the Prophet, "Won't you marry the daughter of Hamza?" He said, "She is my foster niece (brother's daughter)}}
\hadithdefcmd{bukhari}{5101}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ أَنَّ أُمَّ حَبِيبَةَ بِنْتَ أَبِي سُفْيَانَ أَخْبَرَتْهَا أَنَّهَا، قَالَتْ يَا رَسُولَ اللَّهِ انْكِحْ أُخْتِي بِنْتَ أَبِي سُفْيَانَ فَقَالَ ‏"‏ أَوَتُحِبِّينَ ذَلِكَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ، لَسْتُ لَكَ بِمُخْلِيَةٍ، وَأَحَبُّ مَنْ شَارَكَنِي فِي خَيْرٍ أُخْتِي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ ذَلِكَ لاَ يَحِلُّ لِي ‏"‏‏.‏ قُلْتُ فَإِنَّا نُحَدَّثُ أَنَّكَ تُرِيدُ أَنْ تَنْكِحَ بِنْتَ أَبِي سَلَمَةَ‏.‏ قَالَ ‏"‏ بِنْتَ أُمِّ سَلَمَةَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَقَالَ ‏"‏ لَوْ أَنَّهَا لَمْ تَكُنْ رَبِيبَتِي فِي حَجْرِي مَا حَلَّتْ لِي إِنَّهَا لاَبْنَةُ أَخِي مِنَ الرَّضَاعَةِ، أَرْضَعَتْنِي وَأَبَا سَلَمَةَ ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏‏.‏ قَالَ عُرْوَةُ وَثُوَيْبَةُ مَوْلاَةٌ لأَبِي لَهَبٍ كَانَ أَبُو لَهَبٍ أَعْتَقَهَا فَأَرْضَعَتِ النَّبِيَّ صلى الله عليه وسلم فَلَمَّا مَاتَ أَبُو لَهَبٍ أُرِيَهُ بَعْضُ أَهْلِهِ بِشَرِّ حِيبَةٍ قَالَ لَهُ مَاذَا لَقِيتَ قَالَ أَبُو لَهَبٍ لَمْ أَلْقَ بَعْدَكُمْ غَيْرَ أَنِّي سُقِيتُ فِي هَذِهِ بِعَتَاقَتِي ثُوَيْبَةَ‏.‏\hadithno{5101}\hadithtrans{Narrated Um Habiba:(daughter of Abu Sufyan) I said, "O Allah's Messenger (ﷺ)! Marry my sister. the daughter of Abu Sufyan." The Prophet (ﷺ) said, "Do you like that?" I replied, "Yes, for even now I am not your only wife and I like that my sister should share the good with me." The Prophet (ﷺ) said, "But that is not lawful for me." I said, We have heard that you want to marry the daughter of Abu Salama." He said, "(You mean) the daughter of Um Salama?" I said, "Yes." He said, "Even if she were not my step-daughter, she would be unlawful for me to marry as she is my foster niece. I and Abu Salama were suckled by Thuwaiba. So you should not present to me your daughters or your sisters (in marriage)." Narrated 'Urwa: Thuwaiba was the freed slave girl of Abu Lahb whom he had manumitted, and then she suckled the Prophet. When Abu Lahb died, one of his relatives saw him in a dream in a very bad state and asked him, "What have you encountered?" Abu Lahb said, "I have not found any rest since I left you, except that I have been given water to drink in this (the space between his thumb and other fingers) and that is because of my manumitting Thuwaiba}}
\hadithdefcmd{bukhari}{5102}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَشْعَثِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا وَعِنْدَهَا رَجُلٌ، فَكَأَنَّهُ تَغَيَّرَ وَجْهُهُ، كَأَنَّهُ كَرِهَ ذَلِكَ فَقَالَتْ إِنَّهُ أَخِي‏.‏ فَقَالَ ‏ "‏ انْظُرْنَ مَا إِخْوَانُكُنَّ، فَإِنَّمَا الرَّضَاعَةُ مِنَ الْمَجَاعَةِ ‏"‏‏.‏\hadithno{5102}\hadithtrans{Narrated `Aisha:that the Prophet (ﷺ) entered upon her while a man was sitting with her. Signs of answer seemed to appear on his face as if he disliked that. She said, "Here is my (foster) brother." He said, "Be sure as to who is your foster brother, for foster suckling relationship is established only when milk is the only food of the child}}
\hadithdefcmd{bukhari}{5103}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ أَفْلَحَ، أَخَا أَبِي الْقُعَيْسِ جَاءَ يَسْتَأْذِنُ عَلَيْهَا ـ وَهْوَ عَمُّهَا مِنَ الرَّضَاعَةِ ـ بَعْدَ أَنْ نَزَلَ الْحِجَابُ، فَأَبَيْتُ أَنْ آذَنَ لَهُ، فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَخْبَرْتُهُ بِالَّذِي صَنَعْتُ، فَأَمَرَنِي أَنْ آذَنَ لَهُ‏.‏\hadithno{5103}\hadithtrans{Narrated Aisha:that Aflah the brother of Abu Al-Qu'ais, her foster uncle, came, asking permission to enter upon her after the Verse of Al-Hijab (the use of veils by women) was revealed. `Aisha added: I did not allow him to enter, but when Allah's Messenger (ﷺ) came, I told him what I had done, and he ordered me to give him permission}}
\hadithdefcmd{bukhari}{5104}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ حَدَّثَنِي عُبَيْدُ بْنُ أَبِي مَرْيَمَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ وَقَدْ سَمِعْتُهُ مِنْ، عُقْبَةَ لَكِنِّي لِحَدِيثِ عُبَيْدٍ أَحْفَظُ قَالَ تَزَوَّجْتُ امْرَأَةً، فَجَاءَتْنَا امْرَأَةٌ سَوْدَاءُ فَقَالَتْ أَرْضَعْتُكُمَا‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ تَزَوَّجْتُ فُلاَنَةَ بِنْتَ فُلاَنٍ فَجَاءَتْنَا امْرَأَةٌ سَوْدَاءُ فَقَالَتْ لِي إِنِّي قَدْ أَرْضَعْتُكُمَا‏.‏ وَهْىَ كَاذِبَةٌ فَأَعْرَضَ، فَأَتَيْتُهُ مِنْ قِبَلِ وَجْهِهِ، قُلْتُ إِنَّهَا كَاذِبَةٌ‏.‏ قَالَ ‏ "‏ كَيْفَ بِهَا وَقَدْ زَعَمَتْ أَنَّهَا قَدْ أَرْضَعَتْكُمَا، دَعْهَا عَنْكَ ‏"‏ وَأَشَارَ إِسْمَاعِيلُ بِإِصْبَعَيْهِ السَّبَّابَةِ وَالْوُسْطَى يَحْكِي أَيُّوبَ‏.‏\hadithno{5104}\hadithtrans{Narrated `Uqba bin Al-Harith:I married a woman and then a black lady came to us and said, "I have suckled you both (you and your wife)." So I came to the Prophet (ﷺ) and said, "I married so-and-so and then a black lady came to us and said to me, 'I have suckled both of you.' But I think she is a liar." The Prophet (ﷺ) turned his face away from me and I moved to face his face, and said, "She is a liar." The Prophet (ﷺ) said, "How (can you keep her as your wife) when that lady has said that she has suckled both of you? So abandon (i.e., divorce) her (your wife)}}
\hadithdefcmd{bukhari}{5105}{وَقَالَ لَنَا أَحْمَدُ بْنُ حَنْبَلٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، حَدَّثَنِي حَبِيبٌ، عَنْ سَعِيدٍ، عَنِ ابْنِ عَبَّاسٍ، حَرُمَ مِنَ النَّسَبِ سَبْعٌ، وَمِنَ الصِّهْرِ سَبْعٌ‏.‏ ثُمَّ قَرَأَ ‏\{‏حُرِّمَتْ عَلَيْكُمْ أُمَّهَاتُكُمْ‏\}‏ الآيَةَ‏.‏ وَجَمَعَ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ بَيْنَ ابْنَةِ عَلِيٍّ وَامْرَأَةِ عَلِيٍّ‏.‏ وَقَالَ ابْنُ سِيرِينَ لاَ بَأْسَ بِهِ‏.‏ وَكَرِهَهُ الْحَسَنُ مَرَّةً ثُمَّ قَالَ لاَ بَأْسَ بِهِ‏.‏ وَجَمَعَ الْحَسَنُ بْنُ الْحَسَنِ بْنِ عَلِيٍّ بَيْنَ ابْنَتَىْ عَمٍّ فِي لَيْلَةٍ، وَكَرِهَهُ جَابِرُ بْنُ زَيْدٍ لِلْقَطِيعَةِ، وَلَيْسَ فِيهِ تَحْرِيمٌ لِقَوْلِهِ تَعَالَى ‏\{‏وَأُحِلَّ لَكُمْ مَا وَرَاءَ ذَلِكُمْ‏\}‏ وَقَالَ عِكْرِمَةُ عَنِ ابْنِ عَبَّاسٍ إِذَا زَنَى بِأُخْتِ امْرَأَتِهِ لَمْ تَحْرُمْ عَلَيْهِ امْرَأَتُهُ‏.‏ وَيُرْوَى عَنْ يَحْيَى الْكِنْدِيِّ عَنِ الشَّعْبِيِّ وَأَبِي جَعْفَرٍ، فِيمَنْ يَلْعَبُ بِالصَّبِيِّ إِنْ أَدْخَلَهُ فِيهِ، فَلاَ يَتَزَوَّجَنَّ أُمَّهُ، وَيَحْيَى هَذَا غَيْرُ مَعْرُوفٍ، لَمْ يُتَابَعْ عَلَيْهِ‏.‏ وَقَالَ عِكْرِمَةُ عَنِ ابْنِ عَبَّاسٍ إِذَا زَنَى بِهَا لَمْ تَحْرُمْ عَلَيْهِ امْرَأَتُهُ‏.‏ وَيُذْكَرُ عَنْ أَبِي نَصْرٍ أَنَّ ابْنَ عَبَّاسٍ حَرَّمَهُ‏.‏ وَأَبُو نَصْرٍ هَذَا لَمْ يُعْرَفْ بِسَمَاعِهِ مِنِ ابْنِ عَبَّاسٍ‏.‏ وَيُرْوَى عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَجَابِرِ بْنِ زَيْدٍ وَالْحَسَنِ وَبَعْضِ أَهْلِ الْعِرَاقِ تَحْرُمُ عَلَيْهِ‏.‏ وَقَالَ أَبُو هُرَيْرَةَ لاَ تَحْرُمُ حَتَّى يُلْزِقَ بِالأَرْضِ يَعْنِي يُجَامِعَ‏.‏ وَجَوَّزَهُ ابْنُ الْمُسَيَّبِ وَعُرْوَةُ وَالزُّهْرِيُّ‏.‏ وَقَالَ الزُّهْرِيُّ قَالَ عَلِيٌّ لاَ تَحْرُمُ‏.‏ وَهَذَا مُرْسَلٌ‏.‏\hadithno{5105}\hadithtrans{Ibn 'Abbas further said, "Seven types of marriages are unlawful because of blood relations, and seven because of marriage relations." Then Ibn 'Abbas recited the Verse:"Forbidden for you (for marriages) are your mothers..." (4:23). 'Abdullah bin Ja'far married the daughter and wife of 'Ali at the same time (they were step-daughter and mother). Ibn Sirin said, "There is no harm in that." But Al-Hasan Al-Basri disapproved of it at first, but then said that there was no harm in it. Al-Hasan bin Al-Hasan bin 'Ali married two of his cousins in one night. Ja'far bin Zaid disapproved of that because of it would bring hatred (between the two cousins), but it is not unlawful, as Allah said, "Lawful to you are all others [beyond those (mentioned)]. (4:24). Ibn 'Abbas said: "If somebody commits illegal sexual intercourse with his wife's sister, his wife does not become unlawful for him." And narrated Abu Ja'far, "If a person commits homosexuality with a boy, then the mother of that boy is unlawful for him to marry." Narrated Ibn 'Abbas, "If one commits illegal sexual intercourse with his mother in law, then his married relation to his wife does not become unlawful." Abu Nasr reported to have said that Ibn 'Abbas in the above case, regarded his marital relation to his wife unlawful, but Abu Nasr is not known well for hearing Hadith from Ibn 'Abbas. Imran bin Hussain, Jabir b. Zaid, Al-Hasan and some other Iraqi's, are reported to have judged that his marital relations to his wife would be unlawful. In the above case Abu Hurairah said, "The marital relation to one's wife does not become unlawful except if one as had sexual intercourse (with her mother)." Ibn Al-Musaiyab, 'Urwa, and Az-Zuhri allows such person to keep his wife. 'Ali said, "His marital relations to his wife does not become unlawful}}
\hadithdefcmd{bukhari}{5106}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ، عَنْ أُمِّ حَبِيبَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ هَلْ لَكَ فِي بِنْتِ أَبِي سُفْيَانَ قَالَ ‏"‏ فَأَفْعَلُ مَاذَا ‏"‏‏.‏ قُلْتُ تَنْكِحُ‏.‏ قَالَ ‏"‏ أَتُحِبِّينَ ‏"‏‏.‏ قُلْتُ لَسْتُ لَكَ بِمُخْلِيَةٍ، وَأَحَبُّ مَنْ شَرِكَنِي فِيكَ أُخْتِي‏.‏ قَالَ ‏"‏ إِنَّهَا لاَ تَحِلُّ لِي ‏"‏‏.‏ قُلْتُ بَلَغَنِي أَنَّكَ تَخْطُبُ‏.‏ قَالَ ‏"‏ ابْنَةَ أُمِّ سَلَمَةَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ لَوْ لَمْ تَكُنْ رَبِيبَتِي مَا حَلَّتْ لِي، أَرْضَعَتْنِي وَأَبَاهَا ثُوَيْبَةُ، فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنَا هِشَامٌ دُرَّةُ بِنْتُ أَبِي سَلَمَةَ‏.‏\hadithno{5106}\hadithtrans{Narrated Um Habiba:I said, "O Allah's Messenger (ﷺ)! Do you like to have (my sister) the daughter of Abu Sufyan?" The Prophet (ﷺ) said, "What shall I do (with her)?" I said, "Marry her." He said, "Do you like that?" I said, "(Yes), for even now I am not your only wife, so I like that my sister should share you with me." He said, "She is not lawful for me (to marry)." I said, "We have heard that you want to marry." He said, "The daughter of Um Salama?" I said, "Yes." He said, "Even if she were not my stepdaughter, she should be unlawful for me to marry, for Thuwaiba suckled me and her father (Abu Salama). So you should neither present your daughters, nor your sisters, to me}}
\hadithdefcmd{bukhari}{5107}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، أَخْبَرَهُ أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ أَخْبَرَتْهُ أَنَّ أُمَّ حَبِيبَةَ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ انْكِحْ أُخْتِي بِنْتَ أَبِي سُفْيَانَ‏.‏ قَالَ ‏"‏ وَتُحِبِّينَ ‏"‏‏.‏ قُلْتُ نَعَمْ، لَسْتُ بِمُخْلِيَةٍ، وَأَحَبُّ مَنْ شَارَكَنِي فِي خَيْرٍ أُخْتِي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ ذَلِكَ لاَ يَحِلُّ لِي ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَوَاللَّهِ إِنَّا لَنَتَحَدَّثُ أَنَّكَ تُرِيدُ أَنْ تَنْكِحَ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ‏.‏ قَالَ ‏"‏ بِنْتَ أُمِّ سَلَمَةَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَوَاللَّهِ لَوْ لَمْ تَكُنْ فِي حَجْرِي مَا حَلَّتْ لِي إِنَّهَا لاَبْنَةُ أَخِي مِنَ الرَّضَاعَةِ، أَرْضَعَتْنِي وَأَبَا سَلَمَةَ ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏‏.‏\hadithno{5107}\hadithtrans{Narrated Um Habiba:I said, "O Allah's Messenger (ﷺ)! Marry my sister, the daughter of Abu Sufyan." He said, "Do you like that?" I said, "Yes, for even now I am not your only wife; and the most beloved person to share the good with me is my sister." The Prophet (ﷺ) said, "But that is not lawful for me (i.e., to be married to two sisters at a time.)" I said, "O Allah's Messenger (ﷺ)! By Allah, we have heard that you want to marry Durra, the daughter of Abu Salama." He said, "You mean the daughter of Um Salama?" I said, "Yes." He said, "By Allah ! Even if she were not my stepdaughter, she would not be lawful for me to marry, for she is my foster niece, for Thuwaiba has suckled me and Abu Salama; so you should neither present your daughters, nor your sisters to me}}
\hadithdefcmd{bukhari}{5108}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عَاصِمٌ، عَنِ الشَّعْبِيِّ، سَمِعَ جَابِرًا، رضى الله عنه قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوْ خَالَتِهَا‏.‏ وَقَالَ دَاوُدُ وَابْنُ عَوْنٍ عَنِ الشَّعْبِيِّ عَنْ أَبِي هُرَيْرَةَ‏.‏\hadithno{5108}\hadithtrans{Narrated Jabir:Allah's Messenger (ﷺ) forbade that a woman should be married to man along with her paternal or maternal aunt}}
\hadithdefcmd{bukhari}{5109}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُجْمَعُ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا، وَلاَ بَيْنَ الْمَرْأَةِ وَخَالَتِهَا ‏"‏‏.‏\hadithno{5109}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A woman and her paternal aunt should not be married to the same man; and similarly, a woman and her maternal aunt should not be married to the same man}}
\hadithdefcmd{bukhari}{5111}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي قَبِيصَةُ بْنُ ذُؤَيْبٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا وَالْمَرْأَةُ وَخَالَتُهَا‏.‏ فَنُرَى خَالَةَ أَبِيهَا بِتِلْكَ الْمَنْزِلَةِ‏.‏ لأَنَّ عُرْوَةَ حَدَّثَنِي عَنْ عَائِشَةَ، قَالَتْ حَرِّمُوا مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ النَّسَبِ‏.‏\hadithno{5111}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) forbade that a woman should be married to a man along with her paternal aunt or with her maternal aunt (at the same time). Az-Zuhri (the sub-narrator) said: There is a similar order for the paternal aunt of the father of one's wife, for 'Urwa told me that `Aisha said, "What is unlawful because of blood relations, is also unlawful because of the corresponding foster suckling relations}}
\hadithdefcmd{bukhari}{5112}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ، وَالشِّغَارُ أَنْ يُزَوِّجَ الرَّجُلُ ابْنَتَهُ عَلَى أَنْ يُزَوِّجَهُ الآخَرُ ابْنَتَهُ، لَيْسَ بَيْنَهُمَا صَدَاقٌ‏.‏\hadithno{5112}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) forbade Ash-Shighar, which means that somebody marries his daughter to somebody else, and the latter marries his daughter to the former without paying Mahr}}
\hadithdefcmd{bukhari}{5113}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، قَالَ كَانَتْ خَوْلَةُ بِنْتُ حَكِيمٍ مِنَ اللاَّئِي وَهَبْنَ أَنْفُسَهُنَّ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَتْ عَائِشَةُ أَمَا تَسْتَحِي الْمَرْأَةُ أَنْ تَهَبَ نَفْسَهَا لِلرَّجُلِ فَلَمَّا نَزَلَتْ ‏\{‏تُرْجِئُ مَنْ تَشَاءُ مِنْهُنَّ‏\}‏ قُلْتُ يَا رَسُولَ اللَّهِ مَا أَرَى رَبَّكَ إِلاَّ يُسَارِعُ فِي هَوَاكَ‏.‏ رَوَاهُ أَبُو سَعِيدٍ الْمُؤَدِّبُ وَمُحَمَّدُ بْنُ بِشْرٍ وَعَبْدَةُ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ عَائِشَةَ يَزِيدُ بَعْضُهُمْ عَلَى بَعْضٍ‏.‏\hadithno{5113}\hadithtrans{Narrated Hisham's father:Khaula bint Hakim was one of those ladies who presented themselves to the Prophet (ﷺ) for marriage. `Aisha said, "Doesn't a lady feel ashamed for presenting herself to a man?" But when the Verse: "(O Muhammad) You may postpone (the turn of) any of them (your wives) that you please,' (33.51) was revealed, " `Aisha said, 'O Allah's Messenger (ﷺ)! I do not see, but, that your Lord hurries in pleasing you}}
\hadithdefcmd{bukhari}{5114}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، أَخْبَرَنَا عَمْرٌو، حَدَّثَنَا جَابِرُ بْنُ زَيْدٍ، قَالَ أَنْبَأَنَا ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ تَزَوَّجَ النَّبِيُّ صلى الله عليه وسلم وَهْوَ مُحْرِمٌ‏.‏\hadithno{5114}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) got married while he was in the state of Ihram}}
\hadithdefcmd{bukhari}{5115}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، أَنَّهُ سَمِعَ الزُّهْرِيَّ، يَقُولُ أَخْبَرَنِي الْحَسَنُ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ، وَأَخُوهُ عَبْدُ اللَّهِ، عَنْ أَبِيهِمَا، أَنَّ عَلِيًّا ـ رضى الله عنه ـ قَالَ لاِبْنِ عَبَّاسٍ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُتْعَةِ وَعَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ زَمَنَ خَيْبَرَ‏.‏\hadithno{5115}\hadithtrans{Narrated `Ali:I said to Ibn `Abbas, "During the battle of Khaibar the Prophet (ﷺ) forbade (Nikah) Al-Mut'a and the eating of donkey's meat}}
\hadithdefcmd{bukhari}{5116}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، سُئِلَ عَنْ مُتْعَةِ النِّسَاءِ، فَرَخَّصَ فَقَالَ لَهُ مَوْلًى لَهُ إِنَّمَا ذَلِكَ فِي الْحَالِ الشَّدِيدِ وَفِي النِّسَاءِ قِلَّةٌ أَوْ نَحْوَهُ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ نَعَمْ‏.‏\hadithno{5116}\hadithtrans{Narrated Abu Jamra:I heard Ibn `Abbas (giving a verdict) when he was asked about the Mut'a with the women, and he permitted it (Nikah-al-Mut'a). On that a freed slave of his said to him, "That is only when it is very badly needed and women are scarce." On that, Ibn `Abbas said, "Yes}}
\hadithdefcmd{bukhari}{5118}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو عَنِ الْحَسَنِ بْنِ مُحَمَّدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، وَسَلَمَةَ بْنِ الأَكْوَعِ، قَالاَ كُنَّا فِي جَيْشٍ فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّهُ قَدْ أُذِنَ لَكُمْ أَنْ تَسْتَمْتِعُوا فَاسْتَمْتِعُوا ‏"‏‏.‏\hadithno{5118}\hadithtrans{Narrated Jabir bin `Abdullah and Salama bin Al-Akwa`:While we were in an army, Allah's Messenger (ﷺ) came to us and said, "You have been allowed to do the Mut'a (marriage), so do it}}
\hadithdefcmd{bukhari}{5119}{وَقَالَ ابْنُ أَبِي ذِئْبٍ حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ وَامْرَأَةٍ تَوَافَقَا فَعِشْرَةُ مَا بَيْنَهُمَا ثَلاَثُ لَيَالٍ فَإِنْ أَحَبَّا أَنْ يَتَزَايَدَا أَوْ يَتَتَارَكَا تَتَارَكَا ‏"‏‏.‏ فَمَا أَدْرِي أَشَىْءٌ كَانَ لَنَا خَاصَّةً أَمْ لِلنَّاسِ عَامَّةً‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَبَيَّنَهُ عَلِيٌّ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ مَنْسُوخٌ‏.‏\hadithno{5119}\hadithtrans{Salama bin Al-Akwa` said:Allah's Messenger (ﷺ) said, "If a man and a woman agree (to marry temporarily), their marriage should last for three nights, and if they like to continue, they can do so; and if they want to separate, they can do so." I do not know whether that was only for us or for all the people in general. Abu `Abdullah (Al-Bukhari) said: `Ali made it clear that the Prophet said, "The Mut'a marriage has been cancelled (made unlawful)}}
\hadithdefcmd{bukhari}{5120}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَرْحُومٌ، قَالَ سَمِعْتُ ثَابِتًا الْبُنَانِيَّ، قَالَ كُنْتُ عِنْدَ أَنَسٍ وَعِنْدَهُ ابْنَةٌ لَهُ، قَالَ أَنَسٌ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم تَعْرِضُ عَلَيْهِ نَفْسَهَا قَالَتْ يَا رَسُولَ اللَّهِ أَلَكَ بِي حَاجَةٌ، فَقَالَتْ بِنْتُ أَنَسٍ مَا أَقَلَّ حَيَاءَهَا وَاسَوْأَتَاهْ وَاسَوْأَتَاهْ‏.‏ قَالَ هِيَ خَيْرٌ مِنْكِ رَغِبَتْ فِي النَّبِيِّ صلى الله عليه وسلم فَعَرَضَتْ عَلَيْهِ نَفْسَهَا‏.‏\hadithno{5120}\hadithtrans{Narrated Thabit Al-Banani:I was with Anas while his daughter was present with him. Anas said, "A woman came to Allah's Apostle and presented herself to him, saying, 'O Allah's Messenger (ﷺ), have you any need for me (i.e. would you like to marry me)?' "Thereupon Anas's daughter said, "What a shameless lady she was ! Shame! Shame!" Anas said, "She was better than you; she had a liking for the Prophet (ﷺ) so she presented herself for marriage to him}}
\hadithdefcmd{bukhari}{5121}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ، أَنَّ امْرَأَةً، عَرَضَتْ نَفْسَهَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ رَجُلٌ يَا رَسُولَ اللَّهِ زَوِّجْنِيهَا‏.‏ فَقَالَ ‏"‏ مَا عِنْدَكَ ‏"‏‏.‏ قَالَ مَا عِنْدِي شَىْءٌ‏.‏ قَالَ ‏"‏ اذْهَبْ فَالْتَمِسْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ مَا وَجَدْتُ شَيْئًا، وَلاَ خَاتَمًا مِنْ حَدِيدٍ، وَلَكِنْ هَذَا إِزَارِي وَلَهَا نِصْفُهُ ـ قَالَ سَهْلٌ وَمَا لَهُ رِدَاءٌ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَمَا تَصْنَعُ بِإِزَارِكَ إِنْ لَبِسْتَهُ لَمْ يَكُنْ عَلَيْهَا مِنْهُ شَىْءٌ، وَإِنْ لَبِسَتْهُ لَمْ يَكُنْ عَلَيْكَ مِنْهُ شَىْءٌ ‏"‏‏.‏ فَجَلَسَ الرَّجُلُ حَتَّى إِذَا طَالَ مَجْلَسُهُ قَامَ فَرَآهُ النَّبِيُّ صلى الله عليه وسلم فَدَعَاهُ أَوْ دُعِي لَهُ فَقَالَ ‏"‏ مَاذَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏ فَقَالَ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا لِسُوَرٍ يُعَدِّدُهَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمْلَكْنَاكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5121}\hadithtrans{Narrated Sahl bin Sa`d:A woman presented herself to the Prophet (for marriage). A man said to him, "O Allah's Messenger (ﷺ)! (If you are not in need of her) marry her to me." The Prophet (ﷺ) said, "What have you got?" The man said, "I have nothing." The Prophet (ﷺ) said (to him), "Go and search for something) even if it were an iron ring." The man went and returned saying, "No, I have not found anything, not even an iron ring; but this is my (Izar) waist sheet, and half of it is for her." He had no Rida' (upper garment). The Prophet (ﷺ) said, "What will she do with your waist sheet? If you wear it, she will have nothing over her; and if she wears it, you will have nothing over you." So the man sat down and when he had sat a long time, he got up (to leave). When the Prophet (ﷺ) saw him (leaving), he called him back, or the man was called (for him), and he said to the man, "How much of the Qur'an do you know (by heart)?" The man replied I know such Sura and such Sura (by heart)," naming the Suras The Prophet (ﷺ) said, "I have married her to you for what you know of the Qur'an}}
\hadithdefcmd{bukhari}{5122}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يُحَدِّثُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ حِينَ تَأَيَّمَتْ حَفْصَةُ بِنْتُ عُمَرَ مِنْ خُنَيْسِ بْنِ حُذَافَةَ السَّهْمِيِّ ـ وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَتُوُفِّيَ بِالْمَدِينَةِ ـ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ أَتَيْتُ عُثْمَانَ بْنَ عَفَّانَ فَعَرَضْتُ عَلَيْهِ حَفْصَةَ فَقَالَ سَأَنْظُرُ فِي أَمْرِي‏.‏ فَلَبِثْتُ لَيَالِيَ ثُمَّ لَقِيَنِي فَقَالَ قَدْ بَدَا لِي أَنْ لاَ أَتَزَوَّجَ يَوْمِي هَذَا‏.‏ قَالَ عُمَرُ فَلَقِيتُ أَبَا بَكْرٍ الصِّدِّيقَ فَقُلْتُ إِنْ شِئْتَ زَوَّجْتُكَ حَفْصَةَ بِنْتَ عُمَرَ‏.‏ فَصَمَتَ أَبُو بَكْرٍ فَلَمْ يَرْجِعْ إِلَىَّ شَيْئًا، وَكُنْتُ أَوْجَدَ عَلَيْهِ مِنِّي عَلَى عُثْمَانَ، فَلَبِثْتُ لَيَالِيَ ثُمَّ خَطَبَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَنْكَحْتُهَا إِيَّاهُ، فَلَقِيَنِي أَبُو بَكْرٍ فَقَالَ لَعَلَّكَ وَجَدْتَ عَلَىَّ حِينَ عَرَضْتَ عَلَىَّ حَفْصَةَ فَلَمْ أَرْجِعْ إِلَيْكَ شَيْئًا‏.‏ قَالَ عُمَرُ قُلْتُ نَعَمْ‏.‏ قَالَ أَبُو بَكْرٍ فَإِنَّهُ لَمْ يَمْنَعْنِي أَنْ أَرْجِعَ إِلَيْكَ فِيمَا عَرَضْتَ عَلَىَّ إِلاَّ أَنِّي كُنْتُ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ ذَكَرَهَا، فَلَمْ أَكُنْ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوْ تَرَكَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَبِلْتُهَا‏.‏\hadithno{5122}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab said, "When Hafsa bint `Umar became a widow after the death of (her husband) Khunais bin Hudhafa As-Sahmi who had been one of the companions of the Prophet, and he died at Medina. I went to `Uthman bin `Affan and presented Hafsa (for marriage) to him. He said, "I will think it over.' I waited for a few days, then he met me and said, 'It seems that it is not possible for me to marry at present.' " `Umar further said, "I met Abu Bakr As-Siddique and said to him, 'If you wish, I will marry my daughter Hafsa to you." Abu Bakr kept quiet and did not say anything to me in reply. I became more angry with him than with `Uthman. I waited for a few days and then Allah's Messenger (ﷺ) asked for her hand, and I gave her in marriage to him. Afterwards I met Abu Bakr who said, 'Perhaps you became angry with me when you presented Hafsa to me and I did not give you a reply?' I said, 'Yes.' Abu Bakr said, 'Nothing stopped me to respond to your offer except that I knew that Allah's Apostle had mentioned her, and I never wanted to let out the secret of Allah's Messenger (ﷺ). And if Allah's Apostle had refused her, I would have accepted her}}
\hadithdefcmd{bukhari}{5123}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ أَنَّ أُمَّ حَبِيبَةَ قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّا قَدْ تَحَدَّثْنَا أَنَّكَ نَاكِحٌ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعَلَى أُمِّ سَلَمَةَ لَوْ لَمْ أَنْكِحْ أُمَّ سَلَمَةَ مَا حَلَّتْ لِي، إِنَّ أَبَاهَا أَخِي مِنَ الرَّضَاعَةِ ‏"‏‏.‏\hadithno{5123}\hadithtrans{Narrated Zainab bint Salama:Um Habiba said to Allah's Messenger (ﷺ) "We have heard that you want to marry Durra bint Abu-Salama." Allah's Messenger (ﷺ) said, "Can she be married along with Um Salama (her mother)? Even if I have not married Um Salama, she would not be lawful for me to marry, for her father is my foster brother}}
\hadithdefcmd{bukhari}{5124}{وَقَالَ لِي طَلْقٌ حَدَّثَنَا زَائِدَةُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏فِيمَا عَرَّضْتُمْ‏\}‏ يَقُولُ إِنِّي أُرِيدُ التَّزْوِيجَ، وَلَوَدِدْتُ أَنَّهُ تَيَسَّرَ لِي امْرَأَةٌ صَالِحَةٌ‏.‏ وَقَالَ الْقَاسِمُ يَقُولُ إِنَّكِ عَلَىَّ كَرِيمَةٌ، وَإِنِّي فِيكِ لَرَاغِبٌ، وَإِنَّ اللَّهَ لَسَائِقٌ إِلَيْكِ خَيْرًا‏.‏ أَوْ نَحْوَ هَذَا‏.‏ وَقَالَ عَطَاءٌ يُعَرِّضُ وَلاَ يَبُوحُ يَقُولُ إِنَّ لِي حَاجَةً وَأَبْشِرِي، وَأَنْتِ بِحَمْدِ اللَّهِ نَافِقَةٌ‏.‏ وَتَقُولُ هِيَ قَدْ أَسْمَعُ مَا تَقُولُ‏.‏ وَلاَ تَعِدُ شَيْئًا وَلاَ يُوَاعِدُ وَلِيُّهَا بِغَيْرِ عِلْمِهَا، وَإِنْ وَاعَدَتْ رَجُلاً فِي عِدَّتِهَا ثُمَّ نَكَحَهَا بَعْدُ لَمْ يُفَرَّقْ بَيْنَهُمَا‏.‏ وَقَالَ الْحَسَنُ ‏\{‏لاَ تُوَاعِدُوهُنَّ سِرًّا‏\}‏ الزِّنَا‏.‏ وَيُذْكَرُ عَنِ ابْنِ عَبَّاسٍ ‏\{‏الْكِتَابُ أَجَلَهُ‏\}‏ تَنْقَضِي الْعِدَّةُ‏.‏\hadithno{5124}\hadithtrans{Ibn `Abbas said: "Hint your intention of marrying' is made by saying (to the widow) for example: "I want to marry, and I wish that Allah will make a righteous lady available for me.' " Al-Qasim said: One may say to the widow: 'I hold all respect for you, and I am interested in you; Allah will bring you much good, or something similar 'Ata said: One should hint his intention, and should not declare it openly. One may say: 'I have some need. Have good tidings. Praise be to Allah; you are fit to remarry.' She (the widow) may say in reply: I am listening to what you say,' but she should not make a promise. Her guardian should not make a promise (to somebody to get her married to him) without her knowledge. But if, while still in the Iddat period, she makes a promise to marry somebody, and he ultimately marries her, they are not to be separated by divorce (i.e., the marriage is valid)}}
\hadithdefcmd{bukhari}{5125}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُكِ فِي الْمَنَامِ يَجِيءُ بِكِ الْمَلَكُ فِي سَرَقَةٍ مِنْ حَرِيرٍ فَقَالَ لِي هَذِهِ امْرَأَتُكَ‏.‏ فَكَشَفْتُ عَنْ وَجْهِكِ الثَّوْبَ، فَإِذَا أَنْتِ هِيَ فَقُلْتُ إِنْ يَكُ هَذَا مِنْ عِنْدِ اللَّهِ يُمْضِهِ ‏"‏‏.‏\hadithno{5125}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said (to me), "You were shown to me in a dream. An angel brought you to me, wrapped in a piece of silken cloth, and said to me, 'This is your wife.' I removed the piece of cloth from your face, and there you were. I said to myself. 'If it is from Allah, then it will surely be}}
\hadithdefcmd{bukhari}{5126}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ امْرَأَةً، جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ جِئْتُ لأَهَبَ لَكَ نَفْسِي‏.‏ فَنَظَرَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَعَّدَ النَّظَرَ إِلَيْهَا وَصَوَّبَهُ، ثُمَّ طَأْطَأَ رَأْسَهُ، فَلَمَّا رَأَتِ الْمَرْأَةُ أَنَّهُ لَمْ يَقْضِ فِيهَا شَيْئًا جَلَسَتْ، فَقَامَ رَجُلٌ مِنْ أَصْحَابِهِ فَقَالَ أَىْ رَسُولَ اللَّهِ إِنْ لَمْ تَكُنْ لَكَ بِهَا حَاجَةٌ فَزَوِّجْنِيهَا‏.‏ فَقَالَ ‏"‏ هَلْ عِنْدَكَ مِنْ شَىْءٍ ‏"‏‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ اذْهَبْ إِلَى أَهْلِكَ فَانْظُرْ هَلْ تَجِدُ شَيْئًا ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا وَجَدْتُ شَيْئًا‏.‏ قَالَ ‏"‏ انْظُرْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ وَلاَ خَاتَمًا مِنْ حَدِيدٍ، وَلَكِنْ هَذَا إِزَارِي ـ قَالَ سَهْلٌ مَا لَهُ رِدَاءٌ ـ فَلَهَا نِصْفُهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَصْنَعُ بِإِزَارِكَ إِنْ لَبِسْتَهُ لَمْ يَكُنْ عَلَيْهَا مِنْهُ شَىْءٌ، وَإِنْ لَبِسَتْهُ لَمْ يَكُنْ عَلَيْكَ شَىْءٌ ‏"‏‏.‏ فَجَلَسَ الرَّجُلُ حَتَّى طَالَ مَجْلَسُهُ ثُمَّ قَامَ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مُوَلِّيًا فَأَمَرَ بِهِ فَدُعِيَ فَلَمَّا جَاءَ قَالَ ‏"‏ مَاذَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏ قَالَ مَعِي سُورَةَ كَذَا وَسُورَةَ كَذَا وَسُورَةَ كَذَا‏.‏ عَدَّدَهَا‏.‏ قَالَ ‏"‏ أَتَقْرَؤُهُنَّ عَنْ ظَهْرِ قَلْبِكَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ اذْهَبْ فَقَدْ مَلَّكْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5126}\hadithtrans{Narrated Sahl bin Sa`d:A woman came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! I have come to you to present myself to you (for marriage)." Allah's Messenger (ﷺ) glanced at her. He looked at her carefully and fixed his glance on her and then lowered his head. When the lady saw that he did not say anything, she sat down. A man from his companions got up and said, "O Allah's Messenger (ﷺ)! If you are not in need of her, then marry her to me." The Prophet (ﷺ) said, "Have you got anything to offer." The man said, 'No, by Allah, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said (to him), "Go to your family and try to find something." So the man went and returned, saying, "No, by Allah, O Allah's Messenger (ﷺ)! I have not found anything." The Prophet said, "Go again and look for something, even if it were an iron ring." He went and returned, saying, "No, by Allah, O Allah's Messenger (ﷺ)! I could not find even an iron ring, but this is my Izar (waist sheet).' He had no Rida (upper garment). He added, "I give half of it to her." Allah's Messenger (ﷺ) said "What will she do with your Izar? If you wear it, she will have nothing over herself thereof (will be naked); and if she wears it, then you will have nothing over yourself thereof ' So the man sat for a long period and then got up (to leave). When Allah's Messenger (ﷺ) saw him leaving, he ordered that he e called back. When he came, the Prophet (ﷺ) asked (him), "How much of the Qur'an do you know (by heart)?" The man replied, I know such Sura and such Sura and such Sura," naming the suras. The Prophet (ﷺ) said, "Can you recite it by heart?" He said, 'Yes." The Prophet (ﷺ) said, "Go I let you marry her for what you know of the Qur'an (as her Mahr)}}
\hadithdefcmd{bukhari}{5127}{قَالَ يَحْيَى بْنُ سُلَيْمَانَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ،‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ النِّكَاحَ فِي الْجَاهِلِيَّةِ كَانَ عَلَى أَرْبَعَةِ أَنْحَاءٍ فَنِكَاحٌ مِنْهَا نِكَاحُ النَّاسِ الْيَوْمَ، يَخْطُبُ الرَّجُلُ إِلَى الرَّجُلِ وَلِيَّتَهُ أَوِ ابْنَتَهُ، فَيُصْدِقُهَا ثُمَّ يَنْكِحُهَا، وَنِكَاحٌ آخَرُ كَانَ الرَّجُلُ يَقُولُ لاِمْرَأَتِهِ إِذَا طَهُرَتْ مِنْ طَمْثِهَا أَرْسِلِي إِلَى فُلاَنٍ فَاسْتَبْضِعِي مِنْهُ‏.‏ وَيَعْتَزِلُهَا زَوْجُهَا، وَلاَ يَمَسُّهَا أَبَدًا، حَتَّى يَتَبَيَّنَ حَمْلُهَا مِنْ ذَلِكَ الرَّجُلِ الَّذِي تَسْتَبْضِعُ مِنْهُ، فَإِذَا تَبَيَّنَ حَمْلُهَا أَصَابَهَا زَوْجُهَا إِذَا أَحَبَّ، وَإِنَّمَا يَفْعَلُ ذَلِكَ رَغْبَةً فِي نَجَابَةِ الْوَلَدِ، فَكَانَ هَذَا النِّكَاحُ نِكَاحَ الاِسْتِبْضَاعِ، وَنِكَاحٌ آخَرُ يَجْتَمِعُ الرَّهْطُ مَا دُونَ الْعَشَرَةِ فَيَدْخُلُونَ عَلَى الْمَرْأَةِ كُلُّهُمْ يُصِيبُهَا‏.‏ فَإِذَا حَمَلَتْ وَوَضَعَتْ، وَمَرَّ عَلَيْهَا لَيَالِيَ بَعْدَ أَنْ تَضَعَ حَمْلَهَا، أَرْسَلَتْ إِلَيْهِمْ فَلَمْ يَسْتَطِعْ رَجُلٌ مِنْهُمْ أَنْ يَمْتَنِعَ حَتَّى يَجْتَمِعُوا عِنْدَهَا تَقُولُ لَهُمْ قَدْ عَرَفْتُمُ الَّذِي كَانَ مِنْ أَمْرِكُمْ، وَقَدْ وَلَدْتُ فَهُوَ ابْنُكَ يَا فُلاَنُ‏.‏ تُسَمِّي مَنْ أَحَبَّتْ بِاسْمِهِ، فَيَلْحَقُ بِهِ وَلَدُهَا، لاَ يَسْتَطِيعُ أَنْ يَمْتَنِعَ بِهِ الرَّجُلُ‏.‏ وَنِكَاحُ الرَّابِعِ يَجْتَمِعُ النَّاسُ الْكَثِيرُ فَيَدْخُلُونَ عَلَى الْمَرْأَةِ لاَ تَمْتَنِعُ مِمَّنْ جَاءَهَا وَهُنَّ الْبَغَايَا كُنَّ يَنْصِبْنَ عَلَى أَبْوَابِهِنَّ رَايَاتٍ تَكُونُ عَلَمًا فَمَنْ أَرَادَهُنَّ دَخَلَ عَلَيْهِنَّ، فَإِذَا حَمَلَتْ إِحْدَاهُنَّ وَوَضَعَتْ حَمْلَهَا جُمِعُوا لَهَا وَدَعَوْا لَهُمُ الْقَافَةَ ثُمَّ أَلْحَقُوا وَلَدَهَا بِالَّذِي يَرَوْنَ فَالْتَاطَ بِهِ، وَدُعِيَ ابْنَهُ لاَ يَمْتَنِعُ مِنْ ذَلِكَ، فَلَمَّا بُعِثَ مُحَمَّدٌ صلى الله عليه وسلم بِالْحَقِّ هَدَمَ نِكَاحَ الْجَاهِلِيَّةِ كُلَّهُ، إِلاَّ نِكَاحَ النَّاسِ الْيَوْمَ‏.‏\hadithno{5127}\hadithtrans{Narrated 'Urwa bin Az-Zubair: 'Aishah, the wife of the Prophet (ﷺ) told him that there were four types of marriage during Pre-Islamic period of Ignorance. One type was similar to that of the present day i.e. a man used to ask somebody else for the hand of a girl under his guardianship or for his daughter's hand, and give her Mahr and then marry her. The second type was that a man would say to his wife after she had become clean from her period. "Send for so-and-so and have sexual intercourse with him." Her husband would then keep away from her and would never sleep with her till she got pregnant from the other man with whom she was sleeping. When her pregnancy became evident, he husband would sleep with her if he wished. Her husband did so (i.e. let his wife sleep with some other man) so that he might have a child of noble breed. Such marriage was called as Al-Istibda'. Another type of marriage was that a group of less than ten men would assemble and enter upon a woman, and all of them would have sexual relation with her. If she became pregnant and delivered a child and some days had passed after delivery, she would sent for all of them and none of them would refuse to come, and when they all gathered before her, she would say to them, "You (all) know waht you have done, and now I have given birth to a child. So, it is your child so-and-so!" naming whoever she liked, and her child would follow him and he could not refuse to take him. The fourth type of marriage was that many people would enter upon a lady and she would never refuse anyone who came to her. Those were the prostitutes who used to fix flags at their doors as sign, and he who would wished, could have sexual intercourse with them. If anyone of them got pregnant and delivered a child, then all those men would be gathered for her and they would call the Qa'if (persons skilled in recognizing the likeness of a child to his father) to them and would let the child follow the man (whom they recognized as his father) and she would let him adhere to him and be called his son. The man would not refuse all that. But when Muhammad (ﷺ) was sent with the Truth, he abolished all the types of marriages observed in pre-Islamic period of Ignorance except the type of marriage the people recognize today}}
\hadithdefcmd{bukhari}{5128}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ‏\{‏وَمَا يُتْلَى عَلَيْكُمْ فِي الْكِتَابِ فِي يَتَامَى النِّسَاءِ اللاَّتِي لاَ تُؤْتُونَهُنَّ مَا كُتِبَ لَهُنَّ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏‏.‏ قَالَتْ هَذَا فِي الْيَتِيمَةِ الَّتِي تَكُونُ عِنْدَ الرَّجُلِ، لَعَلَّهَا أَنْ تَكُونَ شَرِيكَتَهُ فِي مَالِهِ، وَهْوَ أَوْلَى بِهَا، فَيَرْغَبُ أَنْ يَنْكِحَهَا، فَيَعْضُلَهَا لِمَالِهَا، وَلاَ يُنْكِحَهَا غَيْرَهُ، كَرَاهِيَةَ أَنْ يَشْرَكَهُ أَحَدٌ فِي مَالِهَا‏.‏\hadithno{5128}\hadithtrans{Narrated `Aisha:(as regards the Verse): 'And about what is recited unto you in the Book, concerning orphan girls to whom you give not the prescribed portions and yet, whom you desire to marry.' (4.127) This Verse is about the female orphan who is under the guardianship of a man with whom she shares her property and he has more right over her (than anybody else) but does not like to marry her, so he prevents her, from marrying somebody else, lest he should share the property with him}}
\hadithdefcmd{bukhari}{5129}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي سَالِمٌ، أَنَّ ابْنَ عُمَرَ، أَخْبَرَهُ أَنَّ عُمَرَ حِينَ تَأَيَّمَتْ حَفْصَةُ بِنْتُ عُمَرَ مِنِ ابْنِ حُذَافَةَ السَّهْمِيِّ ـ وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْ أَهْلِ بَدْرٍ تُوُفِّيَ بِالْمَدِينَةِ ـ فَقَالَ عُمَرُ لَقِيتُ عُثْمَانَ بْنَ عَفَّانَ فَعَرَضْتُ عَلَيْهِ فَقُلْتُ إِنْ شِئْتَ أَنْكَحْتُكَ حَفْصَةَ‏.‏ فَقَالَ سَأَنْظُرُ فِي أَمْرِي‏.‏ فَلَبِثْتُ لَيَالِيَ ثُمَّ لَقِيَنِي فَقَالَ بَدَا لِي أَنْ لاَ أَتَزَوَّجَ يَوْمِي هَذَا‏.‏ قَالَ عُمَرُ فَلَقِيتُ أَبَا بَكْرٍ فَقُلْتُ إِنْ شِئْتَ أَنْكَحْتُكَ حَفْصَةَ‏.‏\hadithno{5129}\hadithtrans{Narrated `Abdullah bin `Umar:When Hafsa, `Umar's daughter became a widow because of the death of her (husband) Ibn Hudhafa As-Sahmi who was one of the companion of the Prophet (ﷺ) and the one of the Badr warriors and died at Medina, `Umar said, "I met `Uthman bin `Affan and gave him an offer, saying, 'If you wish, I will marry Hafsa to you.' He said. 'I will think it over' I waited for a few days, then he met me and said, 'I have made up my mind not to marry at present' "`Umar added, "Then I met Abu Bakr and said to him, 'If you wish, I will marry Hafsa to you}}
\hadithdefcmd{bukhari}{5130}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي عَمْرٍو، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، ‏\{‏فَلاَ تَعْضُلُوهُنَّ‏\}‏ قَالَ حَدَّثَنِي مَعْقِلُ بْنُ يَسَارٍ، أَنَّهَا نَزَلَتْ فِيهِ قَالَ زَوَّجْتُ أُخْتًا لِي مِنْ رَجُلٍ فَطَلَّقَهَا، حَتَّى إِذَا انْقَضَتْ عِدَّتُهَا جَاءَ يَخْطُبُهَا، فَقُلْتُ لَهُ زَوَّجْتُكَ وَفَرَشْتُكَ وَأَكْرَمْتُكَ، فَطَلَّقْتَهَا، ثُمَّ جِئْتَ تَخْطُبُهَا، لاَ وَاللَّهِ لاَ تَعُودُ إِلَيْكَ أَبَدًا، وَكَانَ رَجُلاً لاَ بَأْسَ بِهِ وَكَانَتِ الْمَرْأَةُ تُرِيدُ أَنَّ تَرْجِعَ إِلَيْهِ فَأَنْزَلَ اللَّهُ هَذِهِ الآيَةَ ‏\{‏فَلاَ تَعْضُلُوهُنَّ‏\}‏ فَقُلْتُ الآنَ أَفْعَلُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ فَزَوَّجَهَا إِيَّاهُ‏.‏\hadithno{5130}\hadithtrans{Narrated Al-Hasan:concerning the Verse: 'Do not prevent them' (2.232) Ma'qil bin Yasar told me that it was revealed in his connection. He said, "I married my sister to a man and he divorced her, and when her days of 'Idda (three menstrual periods) were over, the man came again and asked for her hand, but I said to him, 'I married her to you and made her your bed (your wife) and favored you with her, but you divorced her. Now you come to ask for her hand again? No, by Allah, she will never go back to you (again)!' That man was not a bad man and his wife wanted to go back to him. So Allah revealed this Verse: 'Do not prevent them.' (2.232) So I said, 'Now I will do it (let her go back to him), O Allah's Messenger (ﷺ)."So he married her to him again}}
\hadithdefcmd{bukhari}{5131}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ فِي قَوْلِهِ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ قُلِ اللَّهُ يُفْتِيكُمْ فِيهِنَّ‏\}‏ إِلَى آخِرِ الآيَةِ، قَالَتْ هِيَ الْيَتِيمَةُ تَكُونُ فِي حَجْرِ الرَّجُلِ، قَدْ شَرِكَتْهُ فِي مَالِهِ، فَيَرْغَبُ عَنْهَا أَنْ يَتَزَوَّجَهَا، وَيَكْرَهُ أَنْ يُزَوِّجَهَا غَيْرَهُ، فَيَدْخُلَ عَلَيْهِ فِي مَالِهِ، فَيَحْبِسُهَا، فَنَهَاهُمُ اللَّهُ عَنْ ذَلِكَ‏.‏\hadithno{5131}\hadithtrans{Narrated `Aisha:(regarding His Statement): 'They ask your instruction concerning the women. Say: Allah instructs you about them ...' (4.127) It is about the female orphan who is under the guardianship of a man with whom she shares her property and he does not want to marry her and dislikes that someone else should marry her, lest he should share the property with him, so he prevents her from marrying. So Allah forbade such a guardian to do so (i.e. to prevent her from marrying)}}
\hadithdefcmd{bukhari}{5132}{حَدَّثَنَا أَحْمَدُ بْنُ الْمِقْدَامِ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا أَبُو حَازِمٍ، حَدَّثَنَا سَهْلُ بْنُ سَعْدٍ، كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم جُلُوسًا فَجَاءَتْهُ امْرَأَةٌ تَعْرِضُ نَفْسَهَا عَلَيْهِ فَخَفَّضَ فِيهَا النَّظَرَ وَرَفَعَهُ فَلَمْ يُرِدْهَا، فَقَالَ رَجُلٌ مِنْ أَصْحَابِهِ زَوِّجْنِيهَا يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ أَعِنْدَكَ مِنْ شَىْءٍ ‏"‏‏.‏ قَالَ مَا عِنْدِي مِنْ شَىْءٍ‏.‏ قَالَ ‏"‏ وَلاَ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ قَالَ وَلاَ خَاتَمًا مِنَ حَدِيدٍ وَلَكِنْ أَشُقُّ بُرْدَتِي هَذِهِ فَأُعْطِيهَا النِّصْفَ، وَآخُذُ النِّصْفَ‏.‏ قَالَ ‏"‏ لاَ، هَلْ مَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ اذْهَبْ فَقَدْ زَوَّجْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5132}\hadithtrans{Narrated Sahl bin Sa`d:While we were sitting in the company of the Prophet (ﷺ) a woman came to him and presented herself (for marriage) to him. The Prophet (ﷺ) looked at her, lowering his eyes and raising them, but did not give a reply. One of his companions said, "Marry her to me O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) asked (him), "Have you got anything?" He said, "I have got nothing." The Prophet (ﷺ) said, "Not even an iron ring?" He Sa`d, "Not even an iron ring, but I will tear my garment into two halves and give her one half and keep the other half." The Prophet; said, "No. Do you know some of the Qur'an (by heart)?" He said, "Yes." The Prophet (ﷺ) said, "Go, I have agreed to marry her to you with what you know of the Qur'an (as her Mahr)}}
\hadithdefcmd{bukhari}{5133}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَهَا وَهْىَ بِنْتُ سِتِّ سِنِينَ، وَأُدْخِلَتْ عَلَيْهِ وَهْىَ بِنْتُ تِسْعٍ، وَمَكَثَتْ عِنْدَهُ تِسْعًا‏.‏\hadithno{5133}\hadithtrans{Narrated `Aisha:that the Prophet (ﷺ) married her when she was six years old and he consummated his marriage when she was nine years old, and then she remained with him for nine years (i.e., till his death)}}
\hadithdefcmd{bukhari}{5134}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَهَا وَهْىَ بِنْتُ سِتِّ سِنِينَ، وَبَنَى بِهَا وَهْىَ بِنْتُ تِسْعِ سِنِينَ‏.‏ قَالَ هِشَامٌ وَأُنْبِئْتُ أَنَّهَا كَانَتْ عِنْدَهُ تِسْعَ سِنِينَ‏.‏\hadithno{5134}\hadithtrans{Narrated `Aisha:that the Prophet (ﷺ) married her when she was six years old and he consummated his marriage when she was nine years old. Hisham said: I have been informed that `Aisha remained with the Prophet (ﷺ) for nine years (i.e. till his death)}}
\hadithdefcmd{bukhari}{5135}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي وَهَبْتُ مِنْ نَفْسِي‏.‏ فَقَامَتْ طَوِيلاً فَقَالَ رَجُلٌ زَوِّجْنِيهَا، إِنْ لَمْ تَكُنْ لَكَ بِهَا حَاجَةٌ‏.‏ قَالَ ‏"‏ هَلْ عِنْدَكَ مِنْ شَىْءٍ تُصْدِقُهَا ‏"‏‏.‏ قَالَ مَا عِنْدِي إِلاَّ إِزَارِي‏.‏ فَقَالَ ‏"‏ إِنْ أَعْطَيْتَهَا إِيَّاهُ جَلَسْتَ لاَ إِزَارَ لَكَ، فَالْتَمِسْ شَيْئًا ‏"‏‏.‏ فَقَالَ مَا أَجِدُ شَيْئًا‏.‏ فَقَالَ ‏"‏ الْتَمِسْ وَلَوْ خَاتَمًا مِنْ حَدِيدِ ‏"‏‏.‏ فَلَمْ يَجِدْ‏.‏ فَقَالَ ‏"‏ أَمَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏‏.‏ قَالَ نَعَمْ سُورَةُ كَذَا وَسُورَةُ كَذَا لِسُوَرٍ سَمَّاهَا‏.‏ فَقَالَ ‏"‏ زَوَّجْنَاكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5135}\hadithtrans{Narrated Sahl bin Sa`d:A woman came to Allah's Messenger (ﷺ) and said, "I present myself (to you) (for marriage). She stayed for a long while, then a man said, "If you are not in need of her then marry her to me." The Prophet (ﷺ) said, "Have you got anything m order to pay her Mahr?" He said, "I have nothing with me except my Izar (waist sheet)." The Prophet (ﷺ) said, "If you give her your Izar, you will have no Izar to wear, (so go) and search for something. He said, "I could not find anything." The Prophet (ﷺ) said, "Try (to find something), even if it were an iron ring But he was not able to find (even that) The Prophet (ﷺ) said (to him). "Do you memorize something of the Qur'an?" "Yes. ' he said, "such Sura and such Sura," naming those Suras The Prophet (ﷺ) said, "We have married her to you for what you know of the Qur'an (by heart)}}
\hadithdefcmd{bukhari}{5136}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُنْكَحُ الأَيِّمُ حَتَّى تُسْتَأْمَرَ وَلاَ تُنْكَحُ الْبِكْرُ حَتَّى تُسْتَأْذَنَ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ إِذْنُهَا قَالَ ‏"‏ أَنْ تَسْكُتَ ‏"‏‏.‏\hadithno{5136}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A matron should not be given in marriage except after consulting her; and a virgin should not be given in marriage except after her permission." The people asked, "O Allah's Messenger (ﷺ)! How can we know her permission?" He said, "Her silence (indicates her permission)}}
\hadithdefcmd{bukhari}{5137}{حَدَّثَنَا عَمْرُو بْنُ الرَّبِيعِ بْنِ طَارِقٍ، قَالَ أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أَبِي عَمْرٍو، مَوْلَى عَائِشَةَ عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ الْبِكْرَ تَسْتَحِي‏.‏ قَالَ ‏ "‏ رِضَاهَا صَمْتُهَا ‏"‏‏.‏\hadithno{5137}\hadithtrans{Narrated `Aisha:I said, "O Allah's Messenger (ﷺ)! A virgin feels shy." He said, "Her consent is (expressed by) her silence}}
\hadithdefcmd{bukhari}{5138}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ، وَمُجَمِّعٍ، ابْنَىْ يَزِيدَ بْنِ جَارِيَةَ عَنْ خَنْسَاءَ بِنْتِ خِذَامٍ الأَنْصَارِيَّةِ، أَنَّ أَبَاهَا، زَوَّجَهَا وَهْىَ ثَيِّبٌ، فَكَرِهَتْ ذَلِكَ فَأَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَدَّ نِكَاحَهُ‏.‏\hadithno{5138}\hadithtrans{Narrated Khansa bint Khidam Al-Ansariya:that her father gave her in marriage when she was a matron and she disliked that marriage. So she went to Allah's Messenger (ﷺ) and he declared that marriage invalid}}
\hadithdefcmd{bukhari}{5139}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا يَزِيدُ، أَخْبَرَنَا يَحْيَى، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، حَدَّثَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ وَمُجَمِّعَ بْنَ يَزِيدَ حَدَّثَاهُ أَنَّ رَجُلاً يُدْعَى خِذَامًا أَنْكَحَ ابْنَةً لَهُ‏.‏ نَحْوَهُ‏.‏\hadithno{5139}\hadithtrans{Narrated `Abdur-Rahman bin Yazid and Majammi bin Yazid:The same ,Hadith above: A man called Khidam married a daughter of his (to somebody) against her consent. 'If you fear that you shall not be able to deal justly with the orphan girls then marry (other) women of your choice.' (4.3) And if somebody says to the guardian (of a woman), "Marry me to so-and-so," and the guardian remained silent or said to him, "What have you got?" And the other said, "I have so much and so much (Mahr)," or kept quiet, and then the guardian said, "I have married her to you," then the marriage is valid (legal). This narration was told by Sahl on the authority of the Prophet}}
\hadithdefcmd{bukhari}{5140}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَأَلَ عَائِشَةَ ـ رضى الله عنها ـ قَالَ لَهَا يَا أُمَّتَاهْ ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى‏\}‏ إِلَى ‏\{‏مَا مَلَكَتْ أَيْمَانُكُمْ‏\}‏ قَالَتْ عَائِشَةُ يَا ابْنَ أُخْتِي هَذِهِ الْيَتِيمَةُ تَكُونُ فِي حَجْرِ وَلِيِّهَا، فَيَرْغَبُ فِي جَمَالِهَا وَمَالِهَا، وَيُرِيدُ أَنْ يَنْتَقِصَ مِنْ صَدَاقِهَا، فَنُهُوا عَنْ نِكَاحِهِنَّ‏.‏ إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ فِي إِكْمَالِ الصَّدَاقِ وَأُمِرُوا بِنِكَاحِ مَنْ سِوَاهُنَّ مِنَ النِّسَاءِ، قَالَتْ عَائِشَةُ اسْتَفْتَى النَّاسُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ فَأَنْزَلَ اللَّهُ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ‏\}‏ إِلَى ‏\{‏وَتَرْغَبُونَ‏\}‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ لَهُمْ فِي هَذِهِ الآيَةِ أَنَّ الْيَتِيمَةَ إِذَا كَانَتْ ذَاتَ مَالٍ وَجَمَالٍ، رَغِبُوا فِي نِكَاحِهَا وَنَسَبِهَا وَالصَّدَاقِ، وَإِذَا كَانَتْ مَرْغُوبًا عَنْهَا فِي قِلَّةِ الْمَالِ وَالْجَمَالِ، تَرَكُوهَا وَأَخَذُوا غَيْرَهَا مِنَ النِّسَاءِ ـ قَالَتْ ـ فَكَمَا يَتْرُكُونَهَا حِينَ يَرْغَبُونَ عَنْهَا، فَلَيْسَ لَهُمْ أَنْ يَنْكِحُوهَا إِذَا رَغِبُوا فِيهَا، إِلاَّ أَنْ يُقْسِطُوا لَهَا وَيُعْطُوهَا حَقَّهَا الأَوْفَى مِنَ الصَّدَاقِ‏.‏\hadithno{5140}\hadithtrans{Narrated 'Urwa bin Az-Zubair:that he asked `Aisha, saying to her, "O Mother! (In what connection was this Verse revealed): 'If you fear that you shall not be able to deal justly with orphan girls (to the end of the verse) that your right hands possess?" (4.3) Aisha said, "O my nephew! It was about the female orphan under the protection of her guardian who was interested in her beauty and wealth and wanted to marry her with a little or reduced Mahr. So such guardians were forbidden to marry female orphans unless they deal with them justly and give their full Mahr; and they were ordered to marry women other than them."`Aisha added, "(Later) the people asked Allah's Messenger (ﷺ), for instructions, and then Allah revealed: 'They ask your instruction concerning the women . . . And yet whom you desire to marry.' (4.127) So Allah revealed to them in this Verse that-if a female orphan had wealth and beauty, they desired to marry her and were interested in her noble descent and the reduction of her Mahr; but if she was not desired by them because of her lack in fortune and beauty they left her and married some other woman. So, as they used to leave her when they had no interest in her, they had no right to marry her if they had the desire to do so, unless they deal justly with her and gave her a full amount of Mahr}}
\hadithdefcmd{bukhari}{5141}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلٍ، أَنَّ امْرَأَةً، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَعَرَضَتْ عَلَيْهِ نَفْسَهَا فَقَالَ ‏"‏ مَا لِي الْيَوْمَ فِي النِّسَاءِ مِنْ حَاجَةٍ ‏"‏‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ زَوِّجْنِيهَا‏.‏ قَالَ ‏"‏ مَا عِنْدَكَ ‏"‏‏.‏ قَالَ مَا عِنْدِي شَىْءٌ‏.‏ قَالَ ‏"‏ أَعْطِهَا وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ قَالَ مَا عِنْدِي شَىْءٌ‏.‏ قَالَ ‏"‏ فَمَا عِنْدَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏ قَالَ عِنْدِي كَذَا وَكَذَا‏.‏ قَالَ ‏"‏ فَقَدْ مَلَّكْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5141}\hadithtrans{Narrated Sahl:A woman came to the Prophet,, and presented herself to him (for marriage). He said, "I am not in need of women these days." Then a man said, "O Allah's Messenger (ﷺ)! Marry her to me." The Prophet (ﷺ) asked him, "What have you got?" He said, "I have got nothing." The Prophet (ﷺ) said, "Give her something, even an iron ring." He said, "I have got nothing." The Prophet (ﷺ) asked (him), "How much of the Qur'an do you know (by heart)?" He said, "So much and so much." The Prophet (ﷺ) said, "I have married her to you for what you know of the Qur'an}}
\hadithdefcmd{bukhari}{5142}{حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ نَافِعًا، يُحَدِّثُ أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يَقُولُ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَبِيعَ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ، وَلاَ يَخْطُبَ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ، حَتَّى يَتْرُكَ الْخَاطِبُ قَبْلَهُ، أَوْ يَأْذَنَ لَهُ الْخَاطِبُ‏.‏\hadithno{5142}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) decreed that one should not try to cancel a bargain already agreed upon between some other persons (by offering a bigger price). And a man should not ask for the hand of a girl who is already engaged to his Muslim brother, unless the first suitor gives her up, or allows him to ask for her hand}}
\hadithdefcmd{bukhari}{5144}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، قَالَ قَالَ أَبُو هُرَيْرَةَ يَأْثُرُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالظَّنَّ، فَإِنَّ الظَّنَّ أَكْذَبُ الْحَدِيثِ، وَلاَ تَجَسَّسُوا، وَلاَ تَحَسَّسُوا، وَلاَ تَبَاغَضُوا، وَكُونُوا إِخْوَانًا ‏"‏‏.‏ وَلَا يَخْطُبُ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ حَتَّى يَنْكِحَ أَوْ يَتْرُكَ\hadithno{5144}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Beware of suspicion (about others), as suspicion is the falsest talk, and do not spy upon each other, and do not listen to the evil talk of the people about others' affairs, and do not have enmity with one another, but be brothers. And none should ask for the hand of a girl who is already engaged to his (Muslim) brother, but one should wait till the first suitor marries her or leaves her}}
\hadithdefcmd{bukhari}{5145}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يُحَدِّثُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ حِينَ تَأَيَّمَتْ حَفْصَةُ قَالَ عُمَرُ لَقِيتُ أَبَا بَكْرٍ فَقُلْتُ إِنْ شِئْتَ أَنْكَحْتُكَ حَفْصَةَ بِنْتَ عُمَرَ‏.‏ فَلَبِثْتُ لَيَالِيَ ثُمَّ خَطَبَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَقِيَنِي أَبُو بَكْرٍ فَقَالَ إِنَّهُ لَمْ يَمْنَعْنِي أَنْ أَرْجِعَ إِلَيْكَ فِيمَا عَرَضْتَ إِلاَّ أَنِّي قَدْ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ ذَكَرَهَا فَلَمْ أَكُنْ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوْ تَرَكَهَا لَقَبِلْتُهَا‏.‏ تَابَعَهُ يُونُسُ وَمُوسَى بْنُ عُقْبَةَ وَابْنُ أَبِي عَتِيقٍ عَنِ الزُّهْرِيِّ‏.‏\hadithno{5145}\hadithtrans{Narrated `Abdullah bin `Umar:"When Hafsa became a widow," `Umar said, "I met Abu Bakr and said to him, 'If you wish I will marry Hafsa bint `Umar to you.' I waited for a few days then Allah's Messenger (ﷺ) asked for her hand. Later Abu Bakr met me and said, 'Nothing stopped me from returning to you concerning your offer except that I knew that Allah's Messenger (ﷺ) had mentioned (his wish to marry) her, and I could never let out the secret of Allah's Messenger (ﷺ) . If he had left her, I would have accepted her}}
\hadithdefcmd{bukhari}{5146}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ جَاءَ رَجُلاَنِ مِنَ الْمَشْرِقِ فَخَطَبَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الْبَيَانِ لَسِحْرً‏"‏‏.‏\hadithno{5146}\hadithtrans{Narrated Ibn `Umar:Two men came from the east and delivered speeches, and the Prophet (ﷺ) said, "Some eloquent speech has the influence of magic." (e.g., some people refuse to do something and then a good eloquent speaker addresses them and then they agree to do that very thing after his speech)}}
\hadithdefcmd{bukhari}{5147}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا خَالِدُ بْنُ ذَكْوَانَ، قَالَ قَالَتِ الرُّبَيِّعُ بِنْتُ مُعَوِّذٍ ابْنِ عَفْرَاءَ‏.‏ جَاءَ النَّبِيُّ صلى الله عليه وسلم فَدَخَلَ حِينَ بُنِيَ عَلَىَّ، فَجَلَسَ عَلَى فِرَاشِي كَمَجْلِسِكَ مِنِّي، فَجَعَلَتْ جُوَيْرِيَاتٌ لَنَا يَضْرِبْنَ بِالدُّفِّ وَيَنْدُبْنَ مَنْ قُتِلَ مِنْ آبَائِي يَوْمَ بَدْرٍ، إِذْ قَالَتْ إِحْدَاهُنَّ وَفِينَا نَبِيٌّ يَعْلَمُ مَا فِي غَدٍ‏.‏ فَقَالَ ‏ "‏ دَعِي هَذِهِ، وَقُولِي بِالَّذِي كُنْتِ تَقُولِينَ ‏"‏‏.‏\hadithno{5147}\hadithtrans{Narrated Ar-Rabi`:(the daughter of Muawwidh bin Afra) After the consummation of my marriage, the Prophet (ﷺ) came and sat on my bed as far from me as you are sitting now, and our little girls started beating the tambourines and reciting elegiac verses mourning my father who had been killed in the battle of Badr. One of them said, "Among us is a Prophet who knows what will happen tomorrow." On that the Prophet said, "Leave this (saying) and keep on saying the verses which you had been saying before}}
\hadithdefcmd{bukhari}{5148}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، تَزَوَّجَ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ، فَرَأَى النَّبِيُّ صلى الله عليه وسلم بَشَاشَةَ الْعُرْسِ فَسَأَلَهُ فَقَالَ إِنِّي تَزَوَّجْتُ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ‏.‏ وَعَنْ قَتَادَةَ عَنْ أَنَسٍ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ تَزَوَّجَ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ‏.‏\hadithno{5148}\hadithtrans{Narrated Anas:`Abdur Rahman bin `Auf married a woman and gave her gold equal to the weight of a date stone (as Mahr). When the Prophet (ﷺ) noticed the signs of cheerfulness of the marriage (on his face) and asked him about it, he said, "I have married a woman and gave (her) gold equal to a date stone in weight (as Mahr)}}
\hadithdefcmd{bukhari}{5149}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، سَمِعْتُ أَبَا حَازِمٍ، يَقُولُ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، يَقُولُ إِنِّي لَفِي الْقَوْمِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ قَامَتِ امْرَأَةٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ وَهَبَتْ نَفْسَهَا لَكَ فَرَ فِيهَا رَأْيَكَ فَلَمْ يُجِبْهَا شَيْئًا ثُمَّ قَامَتْ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ وَهَبَتْ نَفْسَهَا لَكَ فَرَ فِيهَا رَأْيَكَ فَلَمْ يُجِبْهَا شَيْئًا ثُمَّ قَامَتِ الثَّالِثَةَ فَقَالَتْ إِنَّهَا قَدْ وَهَبَتْ نَفْسَهَا لَكَ فَرَ فِيهَا رَأْيَكَ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَنْكِحْنِيهَا‏.‏ قَالَ ‏"‏ هَلْ عِنْدَكَ مِنْ شَىْءٍ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ اذْهَبْ فَاطْلُبْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ فَذَهَبَ فَطَلَبَ ثُمَّ جَاءَ فَقَالَ مَا وَجَدْتُ شَيْئًا وَلاَ خَاتَمًا مِنْ حَدِيدٍ‏.‏ فَقَالَ ‏"‏ هَلْ مَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏‏.‏ قَالَ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا‏.‏ قَالَ ‏"‏ اذْهَبْ فَقَدْ أَنْكَحْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5149}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:While I was (sitting) among the people in the company of Allah's Messenger (ﷺ) a woman stood up and said, "O Allah's Messenger (ﷺ)! She has given herself in marriage to you; please give your opinion of her." The Prophet did not give her any reply. She again stood up and said, "O Allah's Messenger (ﷺ)! She has given herself (in marriage) to you; so please give your opinion of her. The Prophet (ﷺ) did not give her any reply. She again stood up for the third time and said, "She has given herself in marriage to you: so give your opinion of her." So a man stood up and said, "O Allah's Messenger (ﷺ)! Marry her to me." The Prophet asked him, "Have you got anything?" He said, "No." The Prophet (ﷺ) said, "Go and search for something, even if it were an iron ring." The man went and searched and then returned saying, "I could not find anything, not even an iron ring." Then the Prophet (ﷺ) said, "Do you know something of the Qur'an (by heart)?" He replied, "I know (by heart) such Sura and such Sura." The Prophet (ﷺ) said, "Go! I have married her to you for what you know of the Qur'an (by heart)}}
\hadithdefcmd{bukhari}{5150}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏ "‏ تَزَوَّجْ وَلَوْ بِخَاتَمٍ مِنْ حَدِيدٍ ‏"‏‏.‏\hadithno{5150}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said to a man, "Marry, even with (a Mahr equal to) an iron ring}}
\hadithdefcmd{bukhari}{5151}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَحَقُّ مَا أَوْفَيْتُمْ مِنَ الشُّرُوطِ أَنْ تُوفُوا بِهِ مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏‏.‏\hadithno{5151}\hadithtrans{Narrated `Uqba:The Prophet (ﷺ) said: "The stipulations most entitled to be abided by are those with which you are given the right to enjoy the (women's) private parts (i.e. the stipulations of the marriage contract)}}
\hadithdefcmd{bukhari}{5152}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ زَكَرِيَّاءَ ـ هُوَ ابْنُ أَبِي زَائِدَةَ ـ عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تَسْأَلُ طَلاَقَ أُخْتِهَا لِتَسْتَفْرِغَ صَحْفَتَهَا، فَإِنَّمَا لَهَا مَا قُدِّرَ لَهَا ‏"‏‏.‏\hadithno{5152}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "It is not lawful for a woman (at the time of wedding) to ask for the divorce of her sister (i.e. the other wife of her would-be husband) in order to have everything for herself, for she will take only what has been written for her}}
\hadithdefcmd{bukhari}{5153}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، رضى الله عنه أَنَّ عَبْدَ، الرَّحْمَنِ بْنَ عَوْفٍ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَبِهِ أَثَرُ صُفْرَةٍ فَسَأَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ أَنَّهُ تَزَوَّجَ امْرَأَةً مِنَ الأَنْصَارِ قَالَ ‏"‏ كَمْ سُقْتَ إِلَيْهَا ‏"‏‏.‏ قَالَ زِنَةَ نَوَاةٍ مِنْ ذَهَبٍ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{5153}\hadithtrans{Narrated Anas bin Malik:`Abdur-Rahman bin `Auf came to Allah's Messenger (ﷺ) and he had marks of Sufra (yellow perfume). Allah's Messenger (ﷺ) asked him (about those marks). `AbdurRahman bin `Auf told him that he had married a woman from the Ansar. The Prophet (ﷺ) asked, "How much Mahr did you pay her?" He said, "I paid gold equal to the weight of a date stone." Allah's Messenger (ﷺ) said to him, "Give a wedding banquet, even if with one sheep}}
\hadithdefcmd{bukhari}{5154}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ أَوْلَمَ النَّبِيُّ صلى الله عليه وسلم بِزَيْنَبَ فَأَوْسَعَ الْمُسْلِمِينَ خَيْرًا فَخَرَجَ ـ كَمَا يَصْنَعُ إِذَا تَزَوَّجَ ـ فَأَتَى حُجَرَ أُمَّهَاتِ الْمُؤْمِنِينَ يَدْعُو وَيَدْعُونَ ‏\{‏لَهُ‏\}‏ ثُمَّ انْصَرَفَ فَرَأَى رَجُلَيْنِ فَرَجَعَ لاَ أَدْرِي آخْبَرْتُهُ أَوْ أُخْبِرَ بِخُرُوجِهِمَا‏.‏\hadithno{5154}\hadithtrans{Narrated Anas:The Prophet (ﷺ) offered a wedding banquet on the occasion of his marriage to Zainab, and provided a good meal for the Muslims. Then he went out as was his custom on marrying, he came to the dwelling places of the mothers of the Believers (i.e. his wives) invoking good (on them), and they were invoking good (on him). Then he departed (and came back) and saw two men (still sitting there). So he left again. I do not remember whether I informed him or he was informed (by somebody else) of their departure}}
\hadithdefcmd{bukhari}{5155}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ ـ هُوَ ابْنُ زَيْدٍ ـ عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى عَلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَثَرَ صُفْرَةٍ قَالَ ‏"‏ مَا هَذَا ‏"‏‏.‏ قَالَ إِنِّي تَزَوَّجْتُ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ‏.‏ قَالَ ‏"‏ بَارَكَ اللَّهُ لَكَ، أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{5155}\hadithtrans{Narrated Anas:The Prophet (ﷺ) saw the traces of Sufra (yellow perfume) on `Abdur-Rahman bin `Auf and said, "What is this?" `Abdur-Rahman, said, "I have married a woman and have paid gold equal to the weight of a datestone (as her Mahr). The Prophet (ﷺ) said to him, "May Allah bless you: Offer a wedding banquet even with one sheep}}
\hadithdefcmd{bukhari}{5156}{حَدَّثَنَا فَرْوَةُ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ تَزَوَّجَنِي النَّبِيُّ صلى الله عليه وسلم فَأَتَتْنِي أُمِّي فَأَدْخَلَتْنِي الدَّارَ، فَإِذَا نِسْوَةٌ مِنَ الأَنْصَارِ فِي الْبَيْتِ فَقُلْنَ عَلَى الْخَيْرِ وَالْبَرَكَةِ، وَعَلَى خَيْرِ طَائِرٍ‏.‏\hadithno{5156}\hadithtrans{Narrated `Aisha:When the Prophet (ﷺ) married me, my mother came to me and made me enter the house where I saw some women from the Ansar who said, "May you prosper and have blessings and have good omen}}
\hadithdefcmd{bukhari}{5157}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ غَزَا نَبِيٌّ مِنَ الأَنْبِيَاءِ فَقَالَ لِقَوْمِهِ لاَ يَتْبَعْنِي رَجُلٌ مَلَكَ بُضْعَ امْرَأَةٍ وَهْوَ يُرِيدُ أَنْ يَبْنِيَ بِهَا وَلَمْ يَبْنِ بِهَا ‏"‏‏.‏\hadithno{5157}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A prophet among the prophets went for a military expedition and said to his people: "A man who has married a lady and wants to consummate his marriage with her and he has not done so yet, should not accompany me}}
\hadithdefcmd{bukhari}{5158}{حَدَّثَنَا قَبِيصَةُ بْنُ عُقْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، تَزَوَّجَ النَّبِيُّ صلى الله عليه وسلم عَائِشَةَ وَهْىَ ابْنَةُ سِتٍّ وَبَنَى بِهَا وَهْىَ ابْنَةُ تِسْعٍ وَمَكَثَتْ عِنْدَهُ تِسْعًا‏.‏\hadithno{5158}\hadithtrans{Narrated 'Urwa:The Prophet (ﷺ) wrote the (marriage contract) with `Aisha while she was six years old and consummated his marriage with her while she was nine years old and she remained with him for nine years (i.e. till his death)}}
\hadithdefcmd{bukhari}{5159}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ أَقَامَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ خَيْبَرَ وَالْمَدِينَةِ ثَلاَثًا يُبْنَى عَلَيْهِ بِصَفِيَّةَ بِنْتِ حُيَىٍّ فَدَعَوْتُ الْمُسْلِمِينَ إِلَى وَلِيمَتِهِ، فَمَا كَانَ فِيهَا مِنْ خُبْزٍ وَلاَ لَحْمٍ، أَمَرَ بِالأَنْطَاعِ فَأُلْقِيَ فِيهَا مِنَ التَّمْرِ وَالأَقِطِ وَالسَّمْنِ فَكَانَتْ وَلِيمَتَهُ، فَقَالَ الْمُسْلِمُونَ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ أَوْ مِمَّا مَلَكَتْ يَمِينُهُ فَقَالُوا إِنْ حَجَبَهَا فَهْىَ مِنْ أُمَّهَاتِ الْمُؤْمِنِينَ، وَإِنْ لَمْ يَحْجُبْهَا فَهْىَ مِمَّا مَلَكَتْ يَمِينُهُ فَلَمَّا ارْتَحَلَ وَطَّى لَهَا خَلْفَهُ وَمَدَّ الْحِجَابَ بَيْنَهَا وَبَيْنَ النَّاسِ‏.‏\hadithno{5159}\hadithtrans{Narrated Anas:The Prophet (ﷺ) stayed for three days at a place between Khaibar and Medina, and there he consummated his marriage with Safiyya bint Huyay. I invited the Muslims to a banquet which included neither meat nor bread. The Prophet (ﷺ) ordered for the leather dining sheets to be spread, and then dates, dried yogurt and butter were provided over it, and that was the Walima (banquet) of the Prophet. The Muslims asked whether Safiyya would be considered as his wife or as a slave girl of what his right hands possessed. Then they said, "If the Prophet (ﷺ) screens her from the people, then she Is the Prophet's wife but if he does not screen her, then she is a slave girl." So when the Prophet (ﷺ) proceeded, he made a place for her (on the camel) behind him and screened her from people}}
\hadithdefcmd{bukhari}{5160}{حَدَّثَنِي فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ تَزَوَّجَنِي النَّبِيُّ صلى الله عليه وسلم فَأَتَتْنِي أُمِّي فَأَدْخَلَتْنِي الدَّارَ، فَلَمْ يَرُعْنِي إِلاَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ضُحًى‏.‏\hadithno{5160}\hadithtrans{Narrated Aisha:When the Prophet (ﷺ) married me, my mother came to me and made me enter the house (of the Prophet) and nothing surprised me but the coming of Allah's Messenger (ﷺ) to me in the forenoon}}
\hadithdefcmd{bukhari}{5161}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلِ اتَّخَذْتُمْ أَنْمَاطًا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ وَأَنَّى لَنَا أَنْمَاطٌ‏.‏ قَالَ ‏"‏ إِنَّهَا سَتَكُونُ ‏"‏‏.‏\hadithno{5161}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "Did you get Anmat?" I said, 'O Allah's Messenger (ﷺ)! From where can we have Anmat?" The Prophet (ﷺ) said, "Soon you will have them (Anmat)}}
\hadithdefcmd{bukhari}{5162}{حَدَّثَنَا الْفَضْلُ بْنُ يَعْقُوبَ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا زَفَّتِ امْرَأَةً إِلَى رَجُلٍ مِنَ الأَنْصَارِ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ مَا كَانَ مَعَكُمْ لَهْوٌ فَإِنَّ الأَنْصَارَ يُعْجِبُهُمُ اللَّهْوُ ‏"‏‏.‏\hadithno{5162}\hadithtrans{Narrated 'Aisha: that she prepared a lady for a man from the Ansar as his bride and the Prophet said, "O 'Aisha! Haven't you got any amusement (during the marriage ceremony) as the Ansar like amusement?}}
\hadithdefcmd{bukhari}{5163}{وَقَالَ إِبْرَاهِيمُ عَنْ أَبِي عُثْمَانَ ـ وَاسْمُهُ الْجَعْدُ ـ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَرَّ بِنَا فِي مَسْجِدِ بَنِي رِفَاعَةَ فَسَمِعْتُهُ يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا مَرَّ بِجَنَبَاتِ أُمِّ سُلَيْمٍ دَخَلَ عَلَيْهَا فَسَلَّمَ عَلَيْهَا، ثُمَّ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم عَرُوسًا بِزَيْنَبَ فَقَالَتْ لِي أُمُّ سُلَيْمٍ لَوْ أَهْدَيْنَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم هَدِيَّةً فَقُلْتُ لَهَا افْعَلِي‏.‏ فَعَمَدَتْ إِلَى تَمْرٍ وَسَمْنٍ وَأَقِطٍ، فَاتَّخَذَتْ حَيْسَةً فِي بُرْمَةٍ، فَأَرْسَلَتْ بِهَا مَعِي إِلَيْهِ، فَانْطَلَقْتُ بِهَا إِلَيْهِ فَقَالَ لِي ‏"‏ ضَعْهَا ‏"‏‏.‏ ثُمَّ أَمَرَنِي فَقَالَ ‏"‏ ادْعُ لِي رِجَالاً ـ سَمَّاهُمْ ـ وَادْعُ لِي مَنْ لَقِيتَ ‏"‏‏.‏ قَالَ فَفَعَلْتُ الَّذِي أَمَرَنِي فَرَجَعْتُ فَإِذَا الْبَيْتُ غَاصٌّ بِأَهْلِهِ، فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَضَعَ يَدَيْهِ عَلَى تِلْكَ الْحَيْسَةِ، وَتَكَلَّمَ بِهَا مَا شَاءَ اللَّهُ، ثُمَّ جَعَلَ يَدْعُو عَشَرَةً عَشَرَةً، يَأْكُلُونَ مِنْهُ، وَيَقُولُ لَهُمُ ‏"‏ اذْكُرُوا اسْمَ اللَّهِ، وَلْيَأْكُلْ كُلُّ رَجُلٍ مِمَّا يَلِيهِ ‏"‏‏.‏ قَالَ حَتَّى تَصَدَّعُوا كُلُّهُمْ عَنْهَا، فَخَرَجَ مِنْهُمْ مَنْ خَرَجَ، وَبَقِيَ نَفَرٌ يَتَحَدَّثُونَ قَالَ وَجَعَلْتُ أَغْتَمُّ، ثُمَّ خَرَجَ النَّبِيُّ صلى الله عليه وسلم نَحْوَ الْحُجُرَاتِ، وَخَرَجْتُ فِي إِثْرِهِ فَقُلْتُ إِنَّهُمْ قَدْ ذَهَبُوا‏.‏ فَرَجَعَ فَدَخَلَ الْبَيْتَ، وَأَرْخَى السِّتْرَ، وَإِنِّي لَفِي الْحُجْرَةِ، وَهْوَ يَقُولُ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ إِلاَّ أَنْ يُؤْذَنَ لَكُمْ إِلَى طَعَامٍ غَيْرَ نَاظِرِينَ إِنَاهُ وَلَكِنْ إِذَا دُعِيتُمْ فَادْخُلُوا فَإِذَا طَعِمْتُمْ فَانْتَشِرُوا وَلاَ مُسْتَأْنِسِينَ لِحَدِيثٍ إِنَّ ذَلِكُمْ كَانَ يُؤْذِي النَّبِيَّ فَيَسْتَحْيِي مِنْكُمْ وَاللَّهُ لاَ يَسْتَحْيِي مِنَ الْحَقِّ‏\}‏‏.‏ قَالَ أَبُو عُثْمَانَ قَالَ أَنَسٌ إِنَّهُ خَدَمَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَشْرَ سِنِينَ‏.‏\hadithno{5163}\hadithtrans{Narrated Anas bin Malik: "Whenever the Prophet (ﷺ) passed by (my mother Um-Sulaim) he used to enter her and greet her. Anas further said: Once the Prophet (ﷺ) way a bridegroom during his marriage with Zainab, Um Sulaim said to me, "Let us give a gift to Allah's Messenger (ﷺ) ." I said to her, "Do it." So she prepared Haisa (a sweet dish) made from dates, butter and dried yoghurt and she sent it with me to him. I took it to him and he said, "Put it down," and ordered me to call some men whom he named, and to invite whomever I would meet. I did what he ordered me to do, and when I returned, I found the house crowded with people and saw the Prophet (ﷺ) keeping his hand over the Haisa and saying over it whatever Allah wished (him to say). Then he called the men in batches of ten to eat of it, and he said to them, "Mention the Name of Allah, and each man should eat of the dish the nearest to him." When all of them had finished their meals, some of them left and a few remained there talking, over which I felt unhappy. Then the Prophet (ﷺ) went out towards the dwelling places (of his wives) and I too, went out after him and told him that those people had left. Then he returned and entered his dwelling place and let the curtains fall while I was in (his) dwelling place, and he was reciting the Verses:-- 'O you who believe! Enter not the Prophet's house until leave is given you for a meal, (and then) not (as early as) to what for its preparation. But when you are invited, enter, and when you have taken your meals, disperse without sitting for a talk. Verily such (behavior) annoys the Prophet; and he would be shy of (asking) you (to go), but Allah is not shy of (telling you) the Truth.' (33-53) Abu Uthman said: Anas said, "I served the Prophet for ten years}}
\hadithdefcmd{bukhari}{5164}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا اسْتَعَارَتْ مِنْ أَسْمَاءَ قِلاَدَةً، فَهَلَكَتْ، فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاسًا مِنْ أَصْحَابِهِ فِي طَلَبِهَا، فَأَدْرَكَتْهُمُ الصَّلاَةُ فَصَلَّوْا بِغَيْرِ وُضُوءٍ، فَلَمَّا أَتَوُا النَّبِيَّ صلى الله عليه وسلم شَكَوْا ذَلِكَ إِلَيْهِ، فَنَزَلَتْ آيَةُ التَّيَمُّمِ‏.‏ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ جَزَاكِ اللَّهُ خَيْرًا، فَوَاللَّهِ مَا نَزَلَ بِكِ أَمْرٌ قَطُّ، إِلاَّ جَعَلَ لَكِ مِنْهُ مَخْرَجًا، وَجُعِلَ لِلْمُسْلِمِينَ فِيهِ بَرَكَةٌ‏.‏\hadithno{5164}\hadithtrans{Narrated `Aisha:That she borrowed a necklace from Asma' and then it got lost. So Allah's Messenger (ﷺ) sent some people from his companions in search of it. In the meantime the stated time for the prayer became due and they offered their prayer without ablution. When they came to the Prophet, they complained about it to him, so the Verse regarding Tayammum was revealed . Usaid bin Hudair said, "(O `Aisha!) may Allah bless you with a good reward, for by Allah, never did a difficulty happen in connection with you, but Allah made an escape from it for you, and brought Allah's Blessings for the Muslims}}
\hadithdefcmd{bukhari}{5165}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَمَا لَوْ أَنَّ أَحَدَهُمْ يَقُولُ حِينَ يَأْتِي أَهْلَهُ بِاسْمِ اللَّهِ، اللَّهُمَّ جَنِّبْنِي الشَّيْطَانَ، وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا، ثُمَّ قُدِّرَ بَيْنَهُمَا فِي ذَلِكَ، أَوْ قُضِيَ وَلَدٌ، لَمْ يَضُرَّهُ شَيْطَانٌ أَبَدًا ‏"‏‏.‏\hadithno{5165}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "If anyone of you, when having sexual intercourse with his wife, says: Bismillah, Allahumma jannibni-Sh-Shaitan wa jannib-ish-Shaitan ma razaqtana, and if it is destined that they should have a child, then Satan will never be able to harm him}}
\hadithdefcmd{bukhari}{5166}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ كَانَ ابْنَ عَشْرِ سِنِينَ مَقْدَمَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ، فَكَانَ أُمَّهَاتِي يُوَاظِبْنَنِي عَلَى خِدْمَةِ النَّبِيِّ صلى الله عليه وسلم فَخَدَمْتُهُ عَشْرَ سِنِينَ، وَتُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم وَأَنَا ابْنُ عِشْرِينَ سَنَةً، فَكُنْتُ أَعْلَمَ النَّاسِ بِشَأْنِ الْحِجَابِ حِينَ أُنْزِلَ، وَكَانَ أَوَّلَ مَا أُنْزِلَ فِي مُبْتَنَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِزَيْنَبَ ابْنَةِ جَحْشٍ، أَصْبَحَ النَّبِيُّ صلى الله عليه وسلم بِهَا عَرُوسًا، فَدَعَا الْقَوْمَ فَأَصَابُوا مِنَ الطَّعَامِ، ثُمَّ خَرَجُوا وَبَقِيَ رَهْطٌ مِنْهُمْ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَطَالُوا الْمُكْثَ، فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَخَرَجَ وَخَرَجْتُ مَعَهُ لِكَىْ يَخْرُجُوا، فَمَشَى النَّبِيُّ صلى الله عليه وسلم وَمَشَيْتُ، حَتَّى جَاءَ عَتَبَةَ حُجْرَةِ عَائِشَةَ، ثُمَّ ظَنَّ أَنَّهُمْ خَرَجُوا فَرَجَعَ وَرَجَعْتُ مَعَهُ، حَتَّى إِذَا دَخَلَ عَلَى زَيْنَبَ فَإِذَا هُمْ جُلُوسٌ لَمْ يَقُومُوا، فَرَجَعَ النَّبِيُّ صلى الله عليه وسلم وَرَجَعْتُ مَعَهُ، حَتَّى إِذَا بَلَغَ عَتَبَةَ حُجْرَةِ عَائِشَةَ، وَظَنَّ أَنَّهُمْ خَرَجُوا، فَرَجَعَ وَرَجَعْتُ مَعَهُ فَإِذَا هُمْ قَدْ خَرَجُوا فَضَرَبَ النَّبِيُّ صلى الله عليه وسلم بَيْنِي وَبَيْنَهُ بِالسِّتْرِ، وَأُنْزِلَ الْحِجَابُ‏.‏\hadithno{5166}\hadithtrans{Narrated Anas bin Malik:I was ten years old when Allah's Messenger (ﷺ) arrived at Medina. My mother and aunts used to urge me to serve the Prophet (ﷺ) regularly, and I served him for ten years. When the Prophet (ﷺ) died I was twenty years old, and I knew about the order of Al-Hijab (veiling of ladies) more than any other person when it was revealed. It was revealed for the first time when Allah's Messenger (ﷺ) had consummated his marriage with Zainab bint Jahsh. When the day dawned, the Prophet (ﷺ) was a bridegroom and he invited the people to a banquet, so they came, ate, and then all left except a few who remained with the Prophet (ﷺ) for a long time. The Prophet (ﷺ) got up and went out, and I too went out with him so that those people might leave too. The Prophet (ﷺ) proceeded and so did I, till he came to the threshold of `Aisha's dwelling place. Then thinking that these people have left by then, he returned and so did I along with him till he entered upon Zainab and behold, they were still sitting and had not gone. So the Prophet (ﷺ) again went away and I went away along with him. When we reached the threshold of `Aisha's dwelling place, he thought that they had left, and so he returned and I too, returned along with him and found those people had left. Then the Prophet (ﷺ) drew a curtain between me and him, and the Verses of Al-Hijab were revealed}}
\hadithdefcmd{bukhari}{5167}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي حُمَيْدٌ، أَنَّهُ سَمِعَ أَنَسًا ـ رضى الله عنه ـ قَالَ سَأَلَ النَّبِيُّ صلى الله عليه وسلم عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ وَتَزَوَّجَ امْرَأَةً مِنَ الأَنْصَارِ ‏"‏ كَمْ أَصْدَقْتَهَا ‏"‏‏.‏ قَالَ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ‏.‏ وَعَنْ حُمَيْدٍ سَمِعْتُ أَنَسًا قَالَ لَمَّا قَدِمُوا الْمَدِينَةَ نَزَلَ الْمُهَاجِرُونَ عَلَى الأَنْصَارِ فَنَزَلَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ عَلَى سَعْدِ بْنِ الرَّبِيعِ فَقَالَ أُقَاسِمُكَ مَالِي وَأَنْزِلُ لَكَ عَنْ إِحْدَى امْرَأَتَىَّ‏.‏ قَالَ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ ��َمَالِكَ‏.‏ فَخَرَجَ إِلَى السُّوقِ فَبَاعَ وَاشْتَرَى فَأَصَابَ شَيْئًا مِنْ أَقِطٍ وَسَمْنٍ فَتَزَوَّجَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏‏.‏\hadithno{5167}\hadithtrans{Narrated Anas:When `Abdur-Rahman bin `Auf married an Ansari woman, the Prophet (ﷺ) asked him, "How much Mahr did you give her?" `Abdur-Rahman said, "Gold equal to the weight of a date stone." Anas added: When they (i.e. the Prophet (ﷺ) and his companions) arrived at Medina, the emigrants stayed at the Ansar's houses. `Abdur-Rahman bin `Auf stayed at Sa`d bin Ar-Rabi's house. Sa`d said to `Abdur- Rahman, "I will divide and share my property with you and will give one of my two wives to you." `Abdur-Rahman said, "May Allah bless you, your wives and property (I am not in need of that; but kindly show me the way to the market)." So `Abdur-Rahman went to the market and traded there gaining a profit of some dried yoghurt and butter, and married (an Ansari woman). The Prophet (ﷺ) said to him, "Give a banquet, even if with one sheep}}
\hadithdefcmd{bukhari}{5168}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ مَا أَوْلَمَ النَّبِيُّ صلى الله عليه وسلم عَلَى شَىْءٍ مِنْ نِسَائِهِ، مَا أَوْلَمَ عَلَى زَيْنَبَ أَوْلَمَ بِشَاةٍ‏.‏\hadithno{5168}\hadithtrans{Narrated Anas:The Prophet (ﷺ) did not give a better wedding banquet on the occasion of marrying any of his wives than the one he gave on marrying Zainab, and that banquet was with (consisted of) one sheep}}
\hadithdefcmd{bukhari}{5169}{حَدَّثَنَا مُسَدَّدٌ، عَنْ عَبْدِ الْوَارِثِ، عَنْ شُعَيْبٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْتَقَ صَفِيَّةَ، وَتَزَوَّجَهَا وَجَعَلَ عِتْقَهَا صَدَاقَهَا، وَأَوْلَمَ عَلَيْهَا بِحَيْسٍ‏.‏\hadithno{5169}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) manumitted Safiyya and then married her, and her Mahr was her manumission, and he gave a wedding banquet with Hais (a sort of sweet dish made from butter, cheese and dates)}}
\hadithdefcmd{bukhari}{5170}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، عَنْ بَيَانٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ بَنَى النَّبِيُّ صلى الله عليه وسلم بِامْرَأَةٍ فَأَرْسَلَنِي فَدَعَوْتُ رِجَالاً إِلَى الطَّعَامِ‏.‏\hadithno{5170}\hadithtrans{Narrated Anas:The Prophet (ﷺ) consummated his marriage with a woman (Zainab), so he sent me to invite men to the meals}}
\hadithdefcmd{bukhari}{5171}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، قَالَ ذُكِرَ تَزْوِيجُ زَيْنَبَ ابْنَةِ جَحْشٍ عِنْدَ أَنَسٍ فَقَالَ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم أَوْلَمَ عَلَى أَحَدٍ مِنْ نِسَائِهِ مَا أَوْلَمَ عَلَيْهَا أَوْلَمَ بِشَاةٍ‏.‏\hadithno{5171}\hadithtrans{Narrated Thabit:The marriage of Zainab bint Jahash was mentioned in the presence of Anas and he said, "I did not see the Prophet (ﷺ) giving a better banquet on marrying any of his wives than the one he gave on marrying Zainab. He then gave a banquet with one sheep}}
\hadithdefcmd{bukhari}{5172}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورِ ابْنِ صَفِيَّةَ، عَنْ أُمِّهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ قَالَتْ أَوْلَمَ النَّبِيُّ صلى الله عليه وسلم عَلَى بَعْضِ نِسَائِهِ بِمُدَّيْنِ مِنْ شَعِيرٍ‏.‏\hadithno{5172}\hadithtrans{Narrated Safiyya bint Shaiba:The Prophet (ﷺ) gave a banquet with two Mudds of barley on marrying some of his wives. (1 Mudd= 1 3/4 of a kilogram)}}
\hadithdefcmd{bukhari}{5173}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى الْوَلِيمَةِ فَلْيَأْتِهَا ‏"‏‏.‏\hadithno{5173}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "If anyone of you is invited to a wedding banquet, he must go for it (accept the invitation)}}
\hadithdefcmd{bukhari}{5174}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فُكُّوا الْعَانِيَ، وَأَجِيبُوا الدَّاعِيَ، وَعُودُوا الْمَرِيضَ ‏"‏‏.‏\hadithno{5174}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "Set the captives free, accept the invitation (to a wedding banquet), and visit the patients}}
\hadithdefcmd{bukhari}{5175}{حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَشْعَثِ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدٍ، قَالَ الْبَرَاءُ بْنُ عَازِبٍ ـ رضى الله عنهما ـ أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم بِسَبْعٍ، وَنَهَانَا عَنْ سَبْعٍ، أَمَرَنَا بِعِيَادَةِ الْمَرِيضِ، وَاتِّبَاعِ الْجِنَازَةِ، وَتَشْمِيتِ الْعَاطِسِ، وَإِبْرَارِ الْقَسَمِ، وَنَصْرِ الْمَظْلُومِ، وَإِفْشَاءِ السَّلاَمِ، وَإِجَابَةِ الدَّاعِي، وَنَهَانَا عَنْ خَوَاتِيمِ الذَّهَبِ، وَعَنْ آنِيَةِ الْفِضَّةِ، وَعَنِ الْمَيَاثِرِ، وَالْقَسِّيَّةِ، وَالإِسْتَبْرَقِ وَالدِّيبَاجِ‏.‏ تَابَعَهُ أَبُو عَوَانَةَ وَالشَّيْبَانِيُّ عَنْ أَشْعَثَ فِي إِفْشَاءِ السَّلاَمِ‏.‏\hadithno{5175}\hadithtrans{Narrated Al-Bara' bin `Azib:The Prophet (ﷺ) ordered us to do seven (things) and forbade us from seven. He ordered us to visit the patients, to follow the funeral procession, to reply to the sneezer (i.e., say to him, 'Yarhamuka-l-lah (May Allah bestow His Mercy upon you), if he says 'Al-hamduli l-lah' (Praise be to Allah), to help others to fulfill their oaths, to help the oppressed, to greet (whomever one should meet), and to accept the invitation (to a wedding banquet). He forbade us to wear golden rings, to use silver utensils, to use Maiyathir (cushions of silk stuffed with cotton and placed under the rider on the saddle), the Qasiyya (linen clothes containing silk brought from an Egyptian town), the Istibraq (thick silk) and the Dibaj (another kind of silk). (See Hadith No. 539 and)}}
\hadithdefcmd{bukhari}{5176}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ دَعَا أَبُو أُسَيْدٍ السَّاعِدِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي عُرْسِهِ، وَكَانَتِ امْرَأَتُهُ يَوْمَئِذٍ خَادِمَهُمْ وَهْىَ الْعَرُوسُ، قَالَ سَهْلٌ تَدْرُونَ مَا سَقَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْقَعَتْ لَهُ تَمَرَاتٍ مِنَ اللَّيْلِ، فَلَمَّا أَكَلَ سَقَتْهُ إِيَّاهُ‏.‏\hadithno{5176}\hadithtrans{Narrated Sahl bin Sa`d:Abu Usaid As-Sa'di invited Allah's Messenger (ﷺ) to his wedding party and his wife who was the bride, served them on that day. Do you know what drink she gave Allah's Messenger (ﷺ)? She had soaked some dates for him (in water) overnight, and when he had finished his meal she gave him that drink (of soaked dates)}}
\hadithdefcmd{bukhari}{5177}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّهُ كَانَ يَقُولُ شَرُّ الطَّعَامِ طَعَامُ الْوَلِيمَةِ يُدْعَى لَهَا الأَغْنِيَاءُ، وَيُتْرَكُ الْفُقَرَاءُ، وَمَنْ تَرَكَ الدَّعْوَةَ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ صلى الله عليه وسلم‏.‏\hadithno{5177}\hadithtrans{Narrated Abu Huraira:The worst food is that of a wedding banquet to which only the rich are invited while the poor are not invited. And he who refuses an invitation (to a banquet) disobeys Allah and His Apostle}}
\hadithdefcmd{bukhari}{5178}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ دُعِيتُ إِلَى كُرَاعٍ لأَجَبْتُ، وَلَوْ أُهْدِيَ إِلَىَّ ذِرَاعٌ لَقَبِلْتُ ‏"‏‏.‏\hadithno{5178}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If I am invited to a meal of trotters I will accept it; and if I am given a trotter as a present I will accept it}}
\hadithdefcmd{bukhari}{5179}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا الْحَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَجِيبُوا هَذِهِ الدَّعْوَةَ إِذَا دُعِيتُمْ لَهَا ‏"‏‏.‏ قَالَ كَانَ عَبْدُ اللَّهِ يَأْتِي الدَّعْوَةَ فِي الْعُرْسِ وَغَيْرِ الْعُرْسِ وَهْوَ صَائِمٌ‏.‏\hadithno{5179}\hadithtrans{Narrated Nafi`:`Abdullah bin `Umar said, "Allah's Messenger (ﷺ) said, 'Accept the marriage invitation if you are invited to it.' " Ibn `Umar used to accept the invitation whether to a wedding banquet or to any other party, even when he was fasting}}
\hadithdefcmd{bukhari}{5180}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ أَبْصَرَ النَّبِيُّ صلى الله عليه وسلم نِسَاءً وَصِبْيَانًا مُقْبِلِينَ مِنْ عُرْسٍ، فَقَامَ مُمْتَنًّا فَقَالَ ‏ "‏ اللَّهُمَّ أَنْتُمْ مِنْ أَحَبِّ النَّاسِ إِلَىَّ ‏"‏‏.‏\hadithno{5180}\hadithtrans{Narrated Anas bin Malik:Once the Prophet (ﷺ) saw some women and children coming from a wedding party. He got up energetically and happily and said, "By Allah! You (i.e., the Ansar) are the most beloved of all people to me}}
\hadithdefcmd{bukhari}{5181}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا أَخْبَرَتْهُ أَنَّهَا اشْتَرَتْ نُمْرُقَةً فِيهَا تَصَاوِيرُ، فَلَمَّا رَآهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْبَابِ فَلَمْ يَدْخُلْ، فَعَرَفْتُ فِي وَجْهِهِ الْكَرَاهِيَةَ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتُوبُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ، مَاذَا أَذْنَبْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا بَالُ هَذِهِ النِّمْرِقَةِ ‏"‏‏.‏ قَالَتْ فَقُلْتُ اشْتَرَيْتُهَا لَكَ لِتَقْعُدَ عَلَيْهَا وَتَوَسَّدَهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ، وَيُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏‏.‏ وَقَالَ ‏"‏ إِنَّ الْبَيْتَ الَّذِي فِيهِ الصُّوَرُ لاَ تَدْخُلُهُ الْمَلاَئِكَةُ ‏"‏‏.‏\hadithno{5181}\hadithtrans{Narrated Aisha:(the wife of the Prophet) I bought a cushion having on it pictures (of animals). When Allah's Messenger (ﷺ) saw it, he stood at the door and did not enter. I noticed the sign of disapproval on his face and said, "O Allah's Messenger (ﷺ)! I repent to Allah and His Apostle. What sin have I committed?' Allah's Messenger (ﷺ) said. "What is this cushion?" I said, "I have bought it for you so that you may sit on it and recline on it." Allah's Messenger (ﷺ) said, "The makers of these pictures will be punished on the Day of Resurrection, and it will be said to them, 'Give life to what you have created (i.e., these pictures).' " The Prophet (ﷺ) added, "The Angels of (Mercy) do not enter a house in which there are pictures (of animals)}}
\hadithdefcmd{bukhari}{5182}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ، قَالَ لَمَّا عَرَّسَ أَبُو أُسَيْدٍ السَّاعِدِيُّ دَعَا النَّبِيَّ صلى الله عليه وسلم وَأَصْحَابَهُ، فَمَا صَنَعَ لَهُمْ طَعَامًا وَلاَ قَرَّبَهُ إِلَيْهِمْ إِلاَّ امْرَأَتُهُ أُمُّ أُسَيْدٍ، بَلَّتْ تَمَرَاتٍ فِي تَوْرٍ مِنْ حِجَارَةٍ مِنَ اللَّيْلِ، فَلَمَّا فَرَغَ النَّبِيُّ صلى الله عليه وسلم مِنَ الطَّعَامِ أَمَاثَتْهُ لَهُ فَسَقَتْهُ، تُتْحِفُهُ بِذَلِكَ‏.‏\hadithno{5182}\hadithtrans{Narrated Sahl:When Abu Usaid As-Sa`idi got married, he invited the Prophet (ﷺ) and his companions. None prepared the food for them and brought it to them but his wife. She soaked some dates in water in a stone pot overnight, and when the Prophet (ﷺ) had finished his food, she provided him with that drink (of soaked dates)}}
\hadithdefcmd{bukhari}{5183}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ، عَنْ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ، أَنَّ أَبَا أُسَيْدٍ السَّاعِدِيَّ، دَعَا النَّبِيَّ صلى الله عليه وسلم لِعُرْسِهِ، فَكَانَتِ امْرَأَتُهُ خَادِمَهُمْ يَوْمَئِذٍ وَهْىَ الْعَرُوسُ، فَقَالَتْ أَوْ قَالَ أَتَدْرُونَ مَا أَنْقَعَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنْقَعَتْ لَهُ تَمَرَاتٍ مِنَ اللَّيْلِ فِي تَوْرٍ‏.‏\hadithno{5183}\hadithtrans{Narrated Sahl bin Sa`d:Abu Usaid As-Sa`idi invited the Prophet (ﷺ) to his wedding party and his wife served him on that day, and she was the bride. She said (or Sahl said), "Do you know what she soaked for Allah's Messenger (ﷺ)? She soaked some dates for him (in water) in a drinking bowl overnight}}
\hadithdefcmd{bukhari}{5184}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَرْأَةُ كَالضِّلَعِ، إِنْ أَقَمْتَهَا كَسَرْتَهَا، وَإِنِ اسْتَمْتَعْتَ بِهَا اسْتَمْتَعْتَ بِهَا وَفِيهَا عِوَجٌ ‏"‏‏.‏\hadithno{5184}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The woman is like a rib; if you try to straighten her, she will break. So if you want to get benefit from her, do so while she still has some crookedness}}
\hadithdefcmd{bukhari}{5186}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ مَيْسَرَةَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يُؤْذِي جَارَهُ ‏"‏‏.‏ وَاسْتَوْصُوا بِالنِّسَاءِ خَيْرًا فَإِنَّهُنَّ خُلِقْنَ مِنْ ضِلَعٍ وَإِنَّ أَعْوَجَ شَيْءٍ فِي الضِّلَعِ أَعْلَاهُ فَإِنْ ذَهَبْتَ تُقِيمُهُ كَسَرْتَهُ وَإِنْ تَرَكْتَهُ لَمْ يَزَلْ أَعْوَجَ فَاسْتَوْصُوا بِالنِّسَاءِ خَيْرًا\hadithno{5186}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever believes in Allah and the Last Day should not hurt (trouble) his neighbor. And I advise you to take care of the women, for they are created from a rib and the most crooked portion of the rib is its upper part; if you try to straighten it, it will break, and if you leave it, it will remain crooked, so I urge you to take care of the women}}
\hadithdefcmd{bukhari}{5187}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا نَتَّقِي الْكَلاَمَ وَالاِنْبِسَاطَ إِلَى نِسَائِنَا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم هَيْبَةَ أَنْ يُنْزَلَ فِينَا شَىْءٌ فَلَمَّا تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم تَكَلَّمْنَا وَانْبَسَطْنَا‏.‏\hadithno{5187}\hadithtrans{Narrated Ibn `Umar:During the lifetime of the Prophet (ﷺ) we used to avoid chatting leisurely and freely with our wives lest some Divine inspiration might be revealed concerning us. But when the Prophet (ﷺ) had died, we started chatting leisurely and freely (with them)}}
\hadithdefcmd{bukhari}{5188}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ، فَالإِمَامُ رَاعٍ وَهْوَ مَسْئُولٌ وَالرَّجُلُ رَاعٍ عَلَى أَهْلِهِ وَهْوَ مَسْئُولٌ وَالْمَرْأَةُ رَاعِيَةٌ عَلَى بَيْتِ زَوْجِهَا وَهْىَ مَسْئُولَةٌ، وَالْعَبْدُ رَاعٍ عَلَى مَالِ سَيِّدِهِ وَهُوَ مَسْئُولٌ، أَلاَ فَكُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ ‏"‏‏.‏\hadithno{5188}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "Everyone of you is a guardian and everyone of you is responsible (for his wards). A ruler is a guardian and is responsible(for his subjects); a man is a guardian of his family and responsible (for them); a wife is a guardian of her husband's house and she is responsible (for it), a slave is a guardian of his master's property and is responsible (for that). Beware! All of you are guardians and are responsible (for your wards)}}
\hadithdefcmd{bukhari}{5189}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَلَسَ إِحْدَى عَشْرَةَ امْرَأَةً، فَتَعَاهَدْنَ وَتَعَاقَدْنَ أَنْ لاَ يَكْتُمْنَ مِنْ أَخْبَارِ أَزْوَاجِهِنَّ شَيْئًا‏.‏ قَالَتِ الأُولَى زَوْجِي لَحْمُ جَمَلٍ، غَثٌّ عَلَى رَأْسِ جَبَلٍ، لاَ سَهْلٍ فَيُرْتَقَى، وَلاَ سَمِينٍ فَيُنْتَقَلُ‏.‏ قَالَتِ الثَّانِيَةُ زَوْجِي لاَ أَبُثُّ خَبَرَهُ، إِنِّي أَخَافُ أَنْ لاَ أَذَرَهُ، إِنْ أَذْكُرْهُ أَذْكُرْ عُجَرَهُ وَبُجَرَهُ‏.‏ قَالَتِ الثَّالِثَةُ زَوْجِي الْعَشَنَّقُ، إِنْ أَنْطِقْ أُطَلَّقْ وَإِنْ أَسْكُتْ أُعَلَّقْ‏.‏ قَالَتِ الرَّابِعَةُ زَوْجِي كَلَيْلِ تِهَامَةَ، لاَ حَرٌّ، وَلاَ قُرٌّ، وَلاَ مَخَافَةَ، وَلاَ سَآمَةَ‏.‏ قَالَتِ الْخَامِسَةُ زَوْجِي إِنْ دَخَلَ فَهِدَ، وَإِنْ خَرَجَ أَسِدَ، وَلاَ يَسْأَلُ عَمَّا عَهِدَ‏.‏ قَالَتِ السَّادِسَةُ زَوْجِي إِنْ أَكَلَ لَفَّ، وَإِنْ شَرِبَ اشْتَفَّ، وَإِنِ اضْطَجَعَ الْتَفَّ، وَلاَ يُولِجُ الْكَفَّ لِيَعْلَمَ الْبَثَّ، قَالَتِ السَّابِعَةُ زَوْجِي غَيَايَاءُ أَوْ عَيَايَاءُ طَبَاقَاءُ، كُلُّ دَاءٍ لَهُ دَاءٌ، شَجَّكِ أَوْ فَلَّكِ أَوْ جَمَعَ كُلاًّ لَكِ‏.‏ قَالَتِ الثَّامِنَةُ زَوْجِي الْمَسُّ مَسُّ أَرْنَبٍ، وَالرِّيحُ رِيحُ زَرْنَبٍ‏.‏ قَالَتِ التَّاسِعَةُ زَوْجِي رَفِيعُ الْعِمَادِ، طَوِيلُ النِّجَادِ، عَظِيمُ الرَّمَادِ، قَرِيبُ الْبَيْتِ مِنَ النَّادِ‏.‏ قَالَتِ الْعَاشِرَةُ زَوْجِي مَالِكٌ وَمَا مَالِكٌ، مَالِكٌ خَيْرٌ مِنْ ذَلِكِ، لَهُ إِبِلٌ كَثِيرَاتُ الْمَبَارِكِ قَلِيلاَتُ الْمَسَارِحِ، وَإِذَا سَمِعْنَ صَوْتَ الْمِزْهَرِ أَيْقَنَّ أَنَّهُنَّ هَوَالِكُ‏.‏ قَالَتِ الْحَادِيَةَ عَشْرَةَ زَوْجِي أَبُو زَرْعٍ فَمَا أَبُو زَرْعٍ أَنَاسَ مِنْ حُلِيٍّ أُذُنَىَّ، وَمَلأَ مِنْ شَحْمٍ عَضُدَىَّ، وَبَجَّحَنِي فَبَجِحَتْ إِلَىَّ نَفْسِي، وَجَدَنِي فِي أَهْلِ غُنَيْمَةٍ بِشِقٍّ، فَجَعَلَنِي فِي أَهْلِ صَهِيلٍ وَأَطِيطٍ وَدَائِسٍ وَمُنَقٍّ، فَعِنْدَهُ أَقُولُ فَلاَ أُقَبَّحُ وَأَرْقُدُ فَأَتَصَبَّحُ، وَأَشْرَبُ فَأَتَقَنَّحُ، أُمُّ أَبِي زَرْعٍ فَمَا أُمُّ أَبِي زَرْعٍ عُكُومُهَا رَدَاحٌ، وَبَيْتُهَا فَسَاحٌ، ابْنُ أَبِي زَرْعٍ، فَمَا ابْنُ أَبِي زَرْعٍ مَضْجِعُهُ كَمَسَلِّ شَطْبَةٍ، وَيُشْبِعُهُ ذِرَاعُ الْجَفْرَةِ، بِنْتُ أَبِي زَرْعٍ فَمَا بِنْتُ أَبِي زَرْعٍ طَوْعُ أَبِيهَا، وَطَوْعُ أُمِّهَا، وَمِلْءُ كِسَائِهَا، وَغَيْظُ جَارَتِهَا، جَارِيَةُ أَبِي زَرْعٍ، فَمَا جَارِيَةُ أَبِي زَرْعٍ لاَ تَبُثُّ حَدِيثَنَا تَبْثِيثًا، وَلاَ تُنَقِّثُ مِيرَتَنَا تَنْقِيثًا، وَلاَ تَمْلأُ بَيْتَنَا تَعْشِيشًا، قَالَتْ خَرَجَ أَبُو زَرْعٍ وَالأَوْطَابُ تُمْخَضُ، فَلَقِيَ امْرَأَةً مَعَهَا وَلَدَانِ لَهَا كَالْفَهْدَيْنِ يَلْعَبَانِ مِنْ تَحْتِ خَصْرِهَا بِرُمَّانَتَيْنِ، فَطَلَّقَنِي وَنَكَحَهَا، فَنَكَحْتُ بَعْدَهُ رَجُلاً سَرِيًّا، رَكِبَ شَرِيًّا وَأَخَذَ خَطِّيًّا وَأَرَاحَ عَلَىَّ نَعَمًا ثَرِيًّا، وَأَعْطَانِي مِنْ كُلِّ رَائِحَةٍ زَوْجًا وَقَالَ كُلِي أُمَّ زَرْعٍ، وَمِيرِي أَهْلَكِ‏.‏ قَالَتْ فَلَوْ جَمَعْتُ كُلَّ شَىْءٍ أَعْطَانِيهِ مَا بَلَغَ أَصْغَرَ آنِيَةِ أَبِي زَرْعٍ‏.‏ قَالَتْ عَائِشَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُنْتُ لَكِ كَأَبِي زَرْعٍ لأُمِّ زَرْعٍ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ سَعِيدُ بْنُ سَلَمَةَ عَنْ هِشَامٍ وَلاَ تُعَشِّشُ بَيْتَنَا تَعْشِيشًا‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ بَعْضُهُمْ فَأَتَقَمَّحُ‏.‏ بِالْمِيمِ، وَهَذَا أَصَحُّ‏.‏\hadithno{5189}\hadithtrans{Narrated `Aisha:Eleven women sat (at a place) and promised and contracted that they would not conceal anything of the news of their husbands. The first one said, "My husband is like the meat of a slim weak camel which is kept on the top of a mountain which is neither easy to climb, nor is the meat fat, so that one might put up with the trouble of fetching it." The second one said, "I shall not relate my husband's news, for I fear that I may not be able to finish his story, for if I describe him, I will mention all his defects and bad traits." The third one said, "My husband, the "too-tall"! if I describe him (and he hears of that) he will divorce me, and if I keep quiet, he will keep me hanging (neither divorcing me nor treating me as a wife)." The fourth one said, "My husband is (moderate in temper) like the night of Tihama: neither hot nor cold; I am neither afraid of him, nor am I discontented with him." The fifth one said, "My husband, when entering (the house) is a leopard (sleeps a lot), and when going out, is a lion (boasts a lot). He does not ask about whatever is in the house." The sixth one said, "If my husband eats, he eats too much (leaving the dishes empty), and if he drinks he leaves nothing; if he sleeps he sleeps he rolls himself (alone in our blankets); and he does not insert his palm to inquire about my feelings." The seventh one said, "My husband is a wrong-doer or weak and foolish. All the defects are present in him. He may injure your head or your body or may do both." The eighth one said, "My husband is soft to touch like a rabbit and smells like a Zarnab (a kind of good smelling grass)." The ninth one said, "My husband is a tall generous man wearing a long strap for carrying his sword. His ashes are abundant (i.e. generous to his guests) and his house is near to the people (who would easily consult him)." The tenth one said, "My husband is Malik (possessor), and what is Malik? Malik is greater than whatever I say about him. (He is beyond and above all praises which can come to my mind). Most of his camels are kept at home (ready to be slaughtered for the guests) and only a few are taken to the pastures. When the camels hear the sound of the lute (or the tambourine) they realize that they are going to be slaughtered for the guests." The eleventh one said, "My husband is Abu Zar` and what is Abu Zar` (i.e., what should I say about him)? He has given me many ornaments and my ears are heavily loaded with them and my arms have become fat (i.e., I have become fat). And he has pleased me, and I have become so happy that I feel proud of myself. He found me with my family who were mere owners of sheep and living in poverty, and brought me to a respected family having horses and camels and threshing and purifying grain. Whatever I say, he does not rebuke or insult me. When I sleep, I sleep till late in the morning, and when I drink water (or milk), I drink my fill. The mother of Abu Zar and what may one say in praise of the mother of Abu Zar? Her saddle bags were always full of provision and her house was spacious. As for the son of Abu Zar, what may one say of the son of Abu Zar? His bed is as narrow as an unsheathed sword and an arm of a kid (of four months) satisfies his hunger. As for the daughter of Abu Zar, she is obedient to her father and to her mother. She has a fat well-built body and that arouses the jealousy of her husband's other wife. As for the (maid) slave girl of Abu Zar, what may one say of the (maid) slavegirl of Abu Zar? She does not uncover our secrets but keeps them, and does not waste our provisions and does not leave the rubbish scattered everywhere in our house." The eleventh lady added, "One day it so happened that Abu Zar went out at the time when the milk was being milked from the animals, and he saw a woman who had two sons like two leopards playing with her two breasts. (On seeing her) he divorced me and married her. Thereafter I married a noble man who used to ride a fast tireless horse and keep a spear in his hand. He gave me many things, and also a pair of every kind of livestock and said, Eat (of this), O Um Zar, and give provision to your relatives." She added, "Yet, all those things which my second husband gave me could not fill the smallest utensil of Abu Zar's." `Aisha then said: Allah's Messenger (ﷺ) said to me, "I am to you as Abu Zar was to his wife Um Zar}}
\hadithdefcmd{bukhari}{5190}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ الْحَبَشُ يَلْعَبُونَ بِحِرَابِهِمْ، فَسَتَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَنْظُرُ، فَمَا زِلْتُ أَنْظُرُ حَتَّى كُنْتُ أَنَا أَنْصَرِفُ فَاقْدُرُوا قَدْرَ الْجَارِيَةِ الْحَدِيثَةِ السِّنِّ تَسْمَعُ اللَّهْوَ‏.‏\hadithno{5190}\hadithtrans{Narrated 'Urwa:Aisha said, "While the Ethiopians were playing with their small spears, Allah's Messenger (ﷺ) screened me behind him and I watched (that display) and kept on watching till I left on my own." So you may estimate of what age a little girl may listen to amusement}}
\hadithdefcmd{bukhari}{5191}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمْ أَزَلْ حَرِيصًا أَنْ أَسْأَلَ عُمَرَ بْنَ الْخَطَّابِ عَنِ الْمَرْأَتَيْنِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَيْنِ قَالَ اللَّهُ تَعَالَى ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا‏\}‏ حَتَّى حَجَّ وَحَجَجْتُ مَعَهُ، وَعَدَلَ وَعَدَلْتُ مَعَهُ بِإِدَاوَةٍ، فَتَبَرَّزَ، ثُمَّ جَاءَ فَسَكَبْتُ عَلَى يَدَيْهِ مِنْهَا فَتَوَضَّأَ فَقُلْتُ لَهُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ الْمَرْأَتَانِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَانِ قَالَ اللَّهُ تَعَالَى ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا‏\}‏ قَالَ وَاعَجَبًا لَكَ يَا ابْنَ عَبَّاسٍ، هُمَا عَائِشَةُ وَحَفْصَةُ‏.‏ ثُمَّ اسْتَقْبَلَ عُمَرُ الْحَدِيثَ يَسُوقُهُ قَالَ كُنْتُ أَنَا وَجَارٌ لِي مِنَ الأَنْصَارِ فِي بَنِي أُمَيَّةَ بْنِ زَيْدٍ، وَهُمْ مِنْ عَوَالِي الْمَدِينَةِ، وَكُنَّا نَتَنَاوَبُ النُّزُولَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَيَنْزِلُ يَوْمًا وَأَنْزِلُ يَوْمًا، فَإِذَا نَزَلْتُ جِئْتُهُ بِمَا حَدَثَ مِنْ خَبَرِ ذَلِكَ الْيَوْمِ مِنَ الْوَحْىِ أَوْ غَيْرِهِ، وَإِذَا نَزَلَ فَعَلَ مِثْلَ ذَلِكَ، وَكُنَّا مَعْشَرَ قُرَيْشٍ نَغْلِبُ النِّسَاءَ، فَلَمَّا قَدِمْنَا عَلَى الأَنْصَارِ إِذَا قَوْمٌ تَغْلِبُهُمْ نِسَاؤُهُمْ، فَطَفِقَ نِسَاؤُنَا يَأْخُذْنَ مِنْ أَدَبِ نِسَاءِ الأَنْصَارِ، فَصَخِبْتُ عَلَى امْرَأَتِي فَرَاجَعَتْنِي فَأَنْكَرْتُ أَنْ تُرَاجِعَنِي قَالَتْ وَلِمَ تُنْكِرُ أَنْ أُرَاجِعَكَ فَوَاللَّهِ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم لَيُرَاجِعْنَهُ، وَإِنَّ إِحْدَاهُنَّ لَتَهْجُرُهُ الْيَوْمَ حَتَّى اللَّيْلِ‏.‏ فَأَفْزَعَنِي ذَلِكَ وَقُلْتُ لَهَا وَقَدْ خَابَ مَنْ فَعَلَ ذَلِكَ مِنْهُنَّ‏.‏ ثُمَّ جَمَعْتُ عَلَىَّ ثِيَابِي فَنَزَلْتُ فَدَخَلْتُ عَلَى حَفْصَةَ فَقُلْتُ لَهَا أَىْ حَفْصَةُ أَتُغَاضِبُ إِحْدَاكُنَّ النَّبِيَّ صلى الله عليه وسلم الْيَوْمَ حَتَّى اللَّيْلِ قَالَتْ نَعَمْ‏.‏ فَقُلْتُ قَدْ خِبْتِ وَخَسِرْتِ، أَفَتَأْمَنِينَ أَنْ يَغْضَبَ اللَّهُ لِغَضَبِ رَسُولِهِ صلى الله عليه وسلم فَتَهْلِكِي لاَ تَسْتَكْثِرِي النَّبِيَّ صلى الله عليه وسلم وَلاَ تُرَاجِعِيهِ فِي شَىْءٍ، وَلاَ تَهْجُرِيهِ، وَسَلِينِي مَا بَدَا لَكِ، وَلاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ أَوْضَأَ مِنْكِ، وَأَحَبَّ إِلَى النَّبِيِّ صلى الله عليه وسلم ـ يُرِيدُ عَائِشَةَ ـ قَالَ عُمَرُ وَكُنَّا قَدْ تَحَدَّثْنَا أَنَّ غَسَّانَ تُنْعِلُ الْخَيْلَ لِغَزْوِنَا، فَنَزَلَ صَاحِبِي الأَنْصَارِيُّ يَوْمَ نَوْبَتِهِ، فَرَجَعَ إِلَيْنَا عِشَاءً فَضَرَبَ بَابِي ضَرْبًا شَدِيدًا وَقَالَ أَثَمَّ هُوَ فَفَزِعْتُ فَخَرَجْتُ إِلَيْهِ، فَقَالَ قَدْ حَدَثَ الْيَوْمَ أَمْرٌ عَظِيمٌ‏.‏ قُلْتُ مَا هُوَ، أَجَاءَ غَسَّانُ قَالَ لاَ بَلْ أَعْظَمُ مِنْ ذَلِكَ وَأَهْوَلُ، طَلَّقَ النَّبِيُّ صلى الله عليه وسلم نِسَاءَهُ‏.‏ فَقُلْتُ خَابَتْ حَفْصَةُ وَخَسِرَتْ، قَدْ كُنْتُ أَظُنُّ هَذَا يُوشِكُ أَنْ يَكُونَ، فَجَمَعْتُ عَلَىَّ ثِيَابِي فَصَلَّيْتُ صَلاَةَ الْفَجْرِ مَعَ النَّبِيِّ صلى الله عليه وسلم فَدَخَلَ النَّبِيُّ صلى الله عليه وسلم مَشْرُبَةً لَهُ، فَاعْتَزَلَ فِيهَا، وَدَخَلْتُ عَلَى حَفْصَةَ فَإِذَا هِيَ تَبْكِي فَقُلْتُ مَا يُبْكِيكِ أَلَمْ أَكُنْ حَذَّرْتُكِ هَذَا أَطَلَّقَكُنَّ النَّبِيُّ صلى الله عليه وسلم قَالَتْ لاَ أَدْرِي هَا هُوَ ذَا مُعْتَزِلٌ فِي الْمَشْرُبَةِ‏.‏ فَخَرَجْتُ فَجِئْتُ إِلَى الْمِنْبَرِ فَإِذَا حَوْلَهُ رَهْطٌ يَبْكِي بَعْضُهُمْ، فَجَلَسْتُ مَعَهُمْ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَجِدُ، فَجِئْتُ الْمَشْرُبَةَ الَّتِي فِيهَا النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ لِغُلاَمٍ لَهُ أَسْوَدَ اسْتَأْذِنْ لِعُمَرَ‏.‏ فَدَخَلَ الْغُلاَمُ فَكَلَّمَ النَّبِيَّ صلى الله عليه وسلم ثُمَّ رَجَعَ فَقَالَ كَلَّمْتُ النَّبِيَّ صلى الله عليه وسلم وَذَكَرْتُكَ لَهُ، فَصَمَتَ‏.‏ فَانْصَرَفْتُ حَتَّى جَلَسْتُ مَعَ الرَّهْطِ الَّذِينَ عِنْدَ الْمِنْبَرِ، ثُمَّ غَلَبَنِي مَا أَجِدُ فَجِئْتُ فَقُلْتُ لِلْغُلاَمِ اسْتَأْذِنْ لِعُمَرَ‏.‏ فَدَخَلَ ثُمَّ رَجَعَ فَقَالَ قَدْ ذَكَرْتُكَ لَهُ فَصَمَتَ‏.‏ فَرَجَعْتُ فَجَلَسْتُ مَعَ الرَّهْطِ الَّذِينَ عِنْدَ الْمِنْبَرِ، ثُمَّ غَلَبَنِي مَا أَجِدُ فَجِئْتُ الْغُلاَمَ فَقُلْتُ اسْتَأْذِنْ لِعُمَرَ‏.‏ فَدَخَلَ ثُمَّ رَجَعَ إِلَىَّ فَقَالَ قَدْ ذَكَرْتُكَ لَهُ فَصَمَتَ‏.‏ فَلَمَّا وَلَّيْتُ مُنْصَرِفًا ـ قَالَ ـ إِذَا الْغُلاَمُ يَدْعُونِي فَقَالَ قَدْ أَذِنَ لَكَ النَّبِيُّ صلى الله عليه وسلم فَدَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا هُوَ مُضْطَجِعٌ عَلَى رِمَالِ حَصِيرٍ، لَيْسَ بَيْنَهُ وَبَيْنَهُ فِرَاشٌ، قَدْ أَثَّرَ الرِّمَالُ بِجَنْبِهِ مُتَّكِئًا عَلَى وِسَادَةٍ مِنْ أَدَمٍ حَشْوُهَا لِيفٌ، فَسَلَّمْتُ عَلَيْهِ ثُمَّ قُلْتُ وَأَنَا قَائِمٌ يَا رَسُولَ اللَّهِ أَطَلَّقْتَ نِسَاءَكَ‏.‏ فَرَفَعَ إِلَىَّ بَصَرَهُ فَقَالَ ‏"‏ لاَ ‏"‏‏.‏ فَقُلْتُ اللَّهُ أَكْبَرُ‏.‏ ثُمَّ قُلْتُ وَأَنَا قَائِمٌ أَسْتَأْنِسُ يَا رَسُولَ اللَّهِ لَوْ رَأَيْتَنِي، وَكُنَّا مَعْشَرَ قُرَيْشٍ نَغْلِبُ النِّسَاءَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ إِذَا قَوْمٌ تَغْلِبُهُمْ نِسَاؤُهُمْ، فَتَبَسَّمَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قُلْتُ يَا رَسُولَ اللَّهِ لَوْ رَأَيْتَنِي وَدَخَلْتُ عَلَى حَفْصَةَ فَقُلْتُ لَهَا لاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ أَوْضَأَ مِنْكِ وَأَحَبَّ إِلَى النَّبِيِّ صلى الله عليه وسلم يُرِيدُ عَائِشَةَ فَتَبَسَّمَ النَّبِيُّ صلى الله عليه وسلم تَبَسُّمَةً أُخْرَى، فَجَلَسْتُ حِينَ رَأَيْتُهُ تَبَسَّمَ، فَرَفَعْتُ بَصَرِي فِي بَيْتِهِ، فَوَاللَّهِ مَا رَأَيْتُ فِي بَيْتِهِ شَيْئًا يَرُدُّ الْبَصَرَ غَيْرَ أَهَبَةٍ ثَلاَثَةٍ، فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ فَلْيُوَسِّعْ عَلَى أُمَّتِكَ، فَإِنَّ فَارِسًا وَالرُّومَ قَدْ وُسِّعَ عَلَيْهِمْ، وَأُعْطُوا الدُّنْيَا وَهُمْ لاَ يَعْبُدُونَ اللَّهَ‏.‏ فَجَلَسَ النَّبِيُّ صلى الله عليه وسلم وَكَانَ مُتَّكِئًا‏.‏ فَقَالَ ‏"‏ أَوَفِي هَذَا أَنْتَ يَا ابْنَ الْخَطَّابِ، إِنَّ أُولَئِكَ قَوْمٌ عُجِّلُوا طَيِّبَاتِهِمْ فِي الْحَيَاةِ الدُّنْيَا ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ اسْتَغْفِرْ لِي‏.‏ فَاعْتَزَلَ النَّبِيُّ صلى الله عليه وسلم نِسَاءَهُ مِنْ أَجْلِ ذَلِكَ الْحَدِيثِ حِينَ أَفْشَتْهُ حَفْصَةُ إِلَى عَائِشَةَ تِسْعًا وَعِشْرِينَ لَيْلَةً وَكَانَ قَالَ ‏"‏ مَا أَنَا بِدَاخِلٍ عَلَيْهِنَّ شَهْرًا ‏"‏‏.‏ مِنْ شِدَّةِ مَوْجِدَتِهِ عَلَيْهِنَّ حِينَ عَاتَبَهُ اللَّهُ، فَلَمَّا مَضَتْ تِسْعٌ وَعِشْرُونَ لَيْلَةً دَخَلَ عَلَى عَائِشَةَ فَبَدَأَ بِهَا فَقَالَتْ لَهُ عَائِشَةُ يَا رَسُولَ اللَّهِ إِنَّكَ كُنْتَ قَدْ أَقْسَمْتَ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا، وَإِنَّمَا أَصْبَحْتَ مِنْ تِسْعٍ وَعِشْرِينَ لَيْلَةً أَعُدُّهَا عَدًّا‏.‏ فَقَالَ ‏"‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏‏.‏ فَكَانَ ذَلِكَ الشَّهْرُ تِسْعًا وَعِشْرِينَ لَيْلَةً‏.‏ قَالَتْ عَائِشَةُ ثُمَّ أَنْزَلَ اللَّهُ تَعَالَى آيَةَ التَّخَيُّرِ فَبَدَأَ بِي أَوَّلَ امْرَأَةٍ مِنْ نِسَائِهِ فَاخْتَرْتُهُ، ثُمَّ خَيَّرَ نِسَاءَهُ كُلَّهُنَّ فَقُلْنَ مِثْلَ مَا قَالَتْ عَائِشَةُ‏.‏\hadithno{5191}\hadithtrans{Narrated Ibn `Abbas:I had been eager to ask `Umar bin Al-Khattab about the two ladies from among the wives of the Prophet regarding whom Allah said 'If you two (wives of the Prophet (ﷺ) namely Aisha and Hafsa) turn in repentance to Allah, your hearts are indeed so inclined (to oppose what the Prophet (ﷺ) likes). (66.4) till `Umar performed the Hajj and I too, performed the Hajj along with him. (On the way) `Umar went aside to answer the call of nature, and I also went aside along with him carrying a tumbler full of water, and when `Umar had finished answering the call of nature, I poured water over his hands and he performed the ablution. Then I said to him, "O chief of the Believers! Who were the two ladies from among the wives of the Prophet (ﷺ) regarding whom Allah said: 'If you two (wives of the Prophet) turn in repentance to Allah your hearts are indeed so inclined (to oppose what the Prophet (ﷺ) likes)?" (66.4) He said, "I am astonished at your question, O Ibn `Abbas. They were `Aisha and Hafsa." Then `Umar went on narrating the Hadith and said, "I and an Ansari neighbor of mine from Bani Umaiyya bin Zaid who used to live in `Awali-al-Medina, used to visit the Prophet (ﷺ) in turn. He used to go one day and I another day. When I went, I would bring him the news of what had happened that day regarding the Divine Inspiration and other things, and when he went, he used to do the same for me. We, the people of Quraish used to have the upper hand over our wives, but when we came to the Ansar, we found that their women had the upper hand over their men, so our women also started learning the ways of the Ansari women. I shouted at my wife and she retorted against me and I disliked that she should answer me back. She said to me, 'Why are you so surprised at my answering you back? By Allah, the wives of the Prophet answer him back and some of them may leave (does not speak to) him throughout the day till the night.' The (talk) scared me and I said to her, 'Whoever has done so will be ruined!' Then I proceeded after dressing myself, and entered upon Hafsa and said to her, 'Does anyone of you keep the Prophet (ﷺ) angry till night?' She said, 'Yes.' I said, 'You are a ruined losing person! Don't you fear that Allah may get angry for the anger of Allah's Messenger (ﷺ) and thus you will be ruined? So do not ask more from the Prophet (ﷺ) and do not answer him back and do not give up talking to him. Ask me whatever you need and do not be tempted to imitate your neighbor (i.e., `Aisha) in her manners for she is more charming than you and more beloved to the Prophet (ﷺ) ." `Umar added,"At that time a talk was circulating among us that (the tribe of) Ghassan were preparing their horses to invade us. My Ansari companion, on the day of his turn, went (to the town) and returned to us at night and knocked at my door violently and asked if I was there. I became horrified and came out to him. He said, 'Today a great thing has happened.' I asked, 'What is it? Have (the people of) Ghassan come?' He said, 'No, but (What has happened) is greater and more horrifying than that: Allah's Messenger (ﷺ); has divorced his wives. `Umar added, "The Prophet (ﷺ) kept away from his wives and I said "Hafsa is a ruined loser.' I had already thought that most probably this (divorce) would happen in the near future. So I dressed myself and offered the morning prayer with the Prophet (ﷺ) and then the Prophet; entered an upper room and stayed there in seclusion. I entered upon Hafsa and saw her weeping. I asked, 'What makes you weep? Did I not warn you about that? Did the Prophet (ﷺ) divorce you all?' She said, 'I do not know. There he is retired alone in the upper room.' I came out and sat near the pulpit and saw a group of people sitting around it and some of them were weeping. I sat with them for a while but could not endure the situation, so I went to the upper room where the Prophet; was and said to a black slave of his, 'Will you get the permission (of the Prophet (ﷺ) ) for `Umar (to enter)?' The slave went in, talked to the Prophet (ﷺ) about it and then returned saying, 'I have spoken to the Prophet (ﷺ) and mentioned you but he kept quiet.' Then I returned and sat with the group of people sitting near the pulpit. but I could not bear the situation and once again I said to the slave, 'Will you get the permission for `Umar?' He went in and returned saying, 'I mentioned you to him but he kept quiet.' So I returned again and sat with the group of people sitting near the pulpit, but I could not bear the situation, and so I went to the slave and said, 'Will you get the permission for `Umar?' He went in and returned to me saying, 'I mentioned you to him but he kept quiet.' When I was leaving, behold! The slave called me, saying, 'The Prophet (ﷺ) has given you permission.' Then I entered upon Allah's Messenger (ﷺ) and saw him Lying on a bed made of stalks of date palm leaves and there was no bedding between it and him. The stalks left marks on his side and he was leaning on a leather pillow stuffed with date-palm fibres. I greeted him and while still standing I said, 'O Allah's Apostle! Have you divorced your wives?' He looked at me and said, 'No.' I said, 'Allah Akbar!' And then, while still standing, I said chatting, 'Will you heed what I say, O Allah's Messenger (ﷺ)? We, the people of Quraish used to have power over our women, but when we arrived at Medina we found that the men (here) were overpowered by their women.' The Prophet (ﷺ) smiled and then I said to him, 'Will you heed what I say, O Allah's Messenger (ﷺ)? I entered upon Hafsa and said to her, "Do not be tempted to imitate your companion (`Aisha), for she is more charming than you and more beloved to the Prophet.' " The Prophet (ﷺ) smiled for a second time. When I saw him smiling, I sat down. Then I looked around his house, and by Allah, I could not see anything of importance in his house except three hides, so I said, 'O Allah's Messenger (ﷺ)! Invoke Allah to make your followers rich, for the Persians and the Romans have been made prosperous and they have been given (the pleasures of the world), although they do not worship Allah.' Thereupon the Prophet (ﷺ) sat up as he was reclining. and said, 'Are you of such an opinion, O the son of Al-Khattab? These are the people who have received the rewards for their good deeds in this world.' I said, 'O Allah's Messenger (ﷺ)! Ask Allah to forgive me.' Then the Prophet (ﷺ) kept away from his wives for twenty-nine days because of the story which Hafsa had disclosed to `Aisha. The Prophet (ﷺ) had said, 'I will not enter upon them (my wives) for one month,' because of his anger towards them, when Allah had admonished him. So, when twenty nine days had passed, the Prophet (ﷺ) first entered upon `Aisha. `Aisha said to him, 'O Allah's Messenger (ﷺ)! You had sworn that you would not enter upon us for one month, but now only twenty-nine days have passed, for I have been counting them one by one.' The Prophet (ﷺ) said, 'The (present) month is of twenty nine days.' `Aisha added, 'Then Allah revealed the Verses of the option. (2) And out of all his-wives he asked me first, and I chose him.' Then he gave option to his other wives and they said what `Aisha had said . " (1) The Prophet, ' had decided to abstain from eating a certain kind of food because of a certain event, so Allah blamed him for doing so. Some of his wives were the cause of him taking that decision, therefore he deserted them for one month. See Qur'an:}}
\hadithdefcmd{bukhari}{5192}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لاَ تَصُومُ الْمَرْأَةُ وَبَعْلُهَا شَاهِدٌ إِلاَّ بِإِذْنِهِ ‏"‏‏.‏\hadithno{5192}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A woman should not fast (optional fasts) except with her husband's permission if he is at home (staying with her)}}
\hadithdefcmd{bukhari}{5193}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَعَا الرَّجُلُ امْرَأَتَهُ إِلَى فِرَاشِهِ فَأَبَتْ أَنْ تَجِيءَ لَعَنَتْهَا الْمَلاَئِكَةُ حَتَّى تُصْبِحَ ‏"‏‏.‏\hadithno{5193}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If a man Invites his wife to sleep with him and she refuses to come to him, then the angels send their curses on her till morning}}
\hadithdefcmd{bukhari}{5194}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا بَاتَتِ الْمَرْأَةُ مُهَاجِرَةً فِرَاشَ زَوْجِهَا لَعَنَتْهَا الْمَلاَئِكَةُ حَتَّى تَرْجِعَ ‏"‏‏.‏\hadithno{5194}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If a woman spends the night deserting her husband's bed (does not sleep with him), then the angels send their curses on her till she comes back (to her husband)}}
\hadithdefcmd{bukhari}{5195}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِلْمَرْأَةِ أَنْ تَصُومَ وَزَوْجُهَا شَاهِدٌ إِلاَّ بِإِذْنِهِ، وَلاَ تَأْذَنَ فِي بَيْتِهِ إِلاَّ بِإِذْنِهِ، وَمَا أَنْفَقَتْ مِنْ نَفَقَةٍ عَنْ غَيْرِ أَمْرِهِ فَإِنَّهُ يُؤَدَّى إِلَيْهِ شَطْرُهُ ‏"‏‏.‏ وَرَوَاهُ أَبُو الزِّنَادِ أَيْضًا عَنْ مُوسَى عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ فِي الصَّوْمِ‏.‏\hadithno{5195}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "It is not lawful for a lady to fast (Nawafil) without the permission of her husband when he is at home; and she should not allow anyone to enter his house except with his permission; and if she spends of his wealth (on charitable purposes) without being ordered by him, he will get half of the reward}}
\hadithdefcmd{bukhari}{5196}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قُمْتُ عَلَى باب الْجَنَّةِ فَكَانَ عَامَّةَ مَنْ دَخَلَهَا الْمَسَاكِينُ، وَأَصْحَابُ الْجَدِّ مَحْبُوسُونَ، غَيْرَ أَنَّ أَصْحَابَ النَّارِ قَدْ أُمِرَ بِهِمْ إِلَى النَّارِ، وَقُمْتُ عَلَى باب النَّارِ فَإِذَا عَامَّةُ مَنْ دَخَلَهَا النِّسَاءُ ‏"‏‏.‏\hadithno{5196}\hadithtrans{Narrated Usama:The Prophet (ﷺ) said, "I stood at the gate of Paradise and saw that the majority of the people who entered it were the poor, while the wealthy were stopped at the gate (for the accounts). But the companions of the Fire were ordered to be taken to the Fire. Then I stood at the gate of the Fire and saw that the majority of those who entered it were women}}
\hadithdefcmd{bukhari}{5197}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مَعَهُ، فَقَامَ قِيَامًا طَوِيلاً نَحْوًا مِنْ سُورَةِ الْبَقَرَةِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ سَجَدَ، ثُمَّ قَامَ فَقَامَ قِيَامًا طَوِيلاً وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ ثُمَّ سَجَدَ، ثُمَّ انْصَرَفَ، وَقَدْ تَجَلَّتِ الشَّمْسُ، فَقَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمْ ذَلِكَ فَاذْكُرُوا اللَّهَ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ رَأَيْنَاكَ تَنَاوَلْتَ شَيْئًا فِي مَقَامِكَ هَذَا، ثُمَّ رَأَيْنَاكَ تَكَعْكَعْتَ‏.‏ فَقَالَ ‏"‏ إِنِّي رَأَيْتُ الْجَنَّةَ ـ أَوْ أُرِيتُ الْجَنَّةَ ـ فَتَنَاوَلْتُ مِنْهَا عُنْقُودًا وَلَوْ أَخَذْتُهُ لأَكَلْتُمْ مِنْهُ مَا بَقِيَتِ الدُّنْيَا، وَرَأَيْتُ النَّارَ فَلَمْ أَرَ كَالْيَوْمِ مَنْظَرًا قَطُّ وَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏‏.‏ قَالُوا لِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِكُفْرِهِنَّ ‏"‏‏.‏ قِيلَ يَكْفُرْنَ بِاللَّهِ قَالَ ‏"‏ يَكْفُرْنَ الْعَشِيرَ، وَيَكْفُرْنَ الإِحْسَانَ، وَلَوْ أَحْسَنْتَ إِلَى إِحْدَاهُنَّ الدَّهْرَ، ثُمَّ رَأَتْ مِنْكَ شَيْئًا قَالَتْ مَا رَأَيْتُ مِنْكَ خَيْرًا قَطُّ ‏"‏‏.‏\hadithno{5197}\hadithtrans{Narrated `Abdullah bin `Abbas:During the lifetime of Allah's Messenger (ﷺ), the sun eclipsed. Allah's Messenger (ﷺ) offered the prayer of (the) eclipse) and so did the people along with him. He performed a long Qiyam (standing posture) during which Surat-al-Baqara could have been recited; then he performed a pro-longed bowing, then raised his head and stood for a long time which was slightly less than that of the first Qiyam (and recited Qur'an). Then he performed a prolonged bowing again but the period was shorter than the period of the first bowing, then he stood up and then prostrated. Again he stood up, but this time the period of standing was less than the first standing. Then he performed a prolonged bowing but of a lesser duration than the first, then he stood up again for a long time but for a lesser duration than the first. Then he performed a prolonged bowing but of lesser duration than the first, and then he again stood up, and then prostrated and then finished his prayer. By then the sun eclipse had cleared. The Prophet (ﷺ) then said, "The sun and the moon are two signs among the signs of Allah, and they do not eclipse because of the death or birth of someone, so when you observe the eclipse, remember Allah (offer the eclipse prayer)." They (the people) said, "O Allah's Messenger (ﷺ)! We saw you stretching your hand to take something at this place of yours, then we saw you stepping backward." He said, "I saw Paradise (or Paradise was shown to me), and I stretched my hand to pluck a bunch (of grapes), and had I plucked it, you would have eaten of it as long as this world exists. Then I saw the (Hell) Fire, and I have never before, seen such a horrible sight as that, and I saw that the majority of its dwellers were women." The people asked, "O Allah's Messenger (ﷺ)! What is the reason for that?" He replied, "Because of their ungratefulness." It was said. "Do they disbelieve in Allah (are they ungrateful to Allah)?" He replied, "They are not thankful to their husbands and are ungrateful for the favors done to them. Even if you do good to one of them all your life, when she seems some harshness from you, she will say, "I have never seen any good from you}}
\hadithdefcmd{bukhari}{5198}{حَدَّثَنَا عُثْمَانُ بْنُ الْهَيْثَمِ، حَدَّثَنَا عَوْفٌ، عَنْ أَبِي رَجَاءٍ، عَنْ عِمْرَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اطَّلَعْتُ فِي الْجَنَّةِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا الْفُقَرَاءَ، وَاطَّلَعْتُ فِي النَّارِ، فَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏‏.‏ تَابَعَهُ أَيُّوبُ وَسَلْمُ بْنُ زَرِيرٍ‏.‏\hadithno{5198}\hadithtrans{Narrated `Imran:The Prophet (ﷺ) said, "I looked at Paradise and saw that the majority of its residents were the poor; and I looked at the (Hell) Fire and saw that the majority of its residents were women}}
\hadithdefcmd{bukhari}{5199}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَبْدَ اللَّهِ أَلَمْ أُخْبَرْ أَنَّكَ تَصُومُ النَّهَارَ وَتَقُومُ اللَّيْلَ ‏"‏‏.‏ قُلْتُ بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلْ، صُمْ وَأَفْطِرْ، وَقُمْ وَنَمْ، فَإِنَّ لِجَسَدِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِعَيْنِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِزَوْجِكَ عَلَيْكَ حَقًّا ‏"‏‏.‏\hadithno{5199}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:Allah's Messenger (ﷺ) said, "O `Abdullah! Have I not been formed that you fast all the day and stand in prayer all night?" I said, "Yes, O Allah's Messenger (ﷺ)!" He said, "Do not do that! Observe the fast sometimes and also leave them (the fast) at other times; stand up for the prayer at night and also sleep at night. Your body has a right over you, your eyes have a right over you and your wife has a right over you}}
\hadithdefcmd{bukhari}{5200}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّكُمْ رَاعٍ، وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالأَمِيرُ رَاعٍ، وَالرَّجُلُ رَاعٍ عَلَى أَهْلِ بَيْتِهِ، وَالْمَرْأَةُ رَاعِيَةٌ عَلَى بَيْتِ زَوْجِهَا وَوَلَدِهِ، فَكُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏\hadithno{5200}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "All of you are guardians and are responsible for your wards. The ruler is a guardian and the man is a guardian of his family; the lady is a guardian and is responsible for her husband's house and his offspring; and so all of you are guardians and are responsible for your wards}}
\hadithdefcmd{bukhari}{5201}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ آلَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نِسَائِهِ شَهْرًا وَقَعَدَ فِي مَشْرُبَةٍ لَهُ فَنَزَلَ لِتِسْعٍ وَعِشْرِينَ فَقِيلَ يَا رَسُولَ اللَّهِ إِنَّكَ آلَيْتَ عَلَى شَهْرٍ‏.‏ قَالَ ‏ "‏ إِنَّ الشَّهْرَ تِسْعٌ وَعِشْرُونَ ‏"‏‏.‏\hadithno{5201}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) took an oath that he would not visit his wives for one month, and he sat in an upper room belonging to him. Then, on the twenty ninth day he came down. It was said, "O Allah's Messenger (ﷺ)! You had taken an oath not to visit your wives for one month." He said, "The (present) month is of twenty-nine days}}
\hadithdefcmd{bukhari}{5202}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ،‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، أَنَّ عِكْرِمَةَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، أَخْبَرَهُ أَنَّ أُمَّ سَلَمَةَ أَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم حَلَفَ لاَ يَدْخُلُ عَلَى بَعْضِ أَهْلِهِ شَهْرًا، فَلَمَّا مَضَى تِسْعَةٌ وَعِشْرُونَ يَوْمًا غَدَا عَلَيْهِنَّ أَوْ رَاحَ فَقِيلَ لَهُ يَا نَبِيَّ اللَّهِ حَلَفْتَ أَنْ لاَ تَدْخُلَ عَلَيْهِنَّ شَهْرًا قَالَ ‏ "‏ إِنَّ الشَّهْرَ يَكُونُ تِسْعَةً وَعِشْرِينَ يَوْمًا ‏"‏‏.‏\hadithno{5202}\hadithtrans{Narrated Um Salama:The Prophet (ﷺ) took an oath that he would not enter upon some of his wives for one month. But when twenty nine days had elapsed, he went to them in the morning or evening. It was said to him, "O Allah's Prophet! You had taken an oath that you would not enter upon them for one month." He replied, "The month can be of twenty nine days}}
\hadithdefcmd{bukhari}{5203}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا أَبُو يَعْفُورٍ، قَالَ تَذَاكَرْنَا عِنْدَ أَبِي الضُّحَى فَقَالَ حَدَّثَنَا ابْنُ عَبَّاسٍ، قَالَ أَصْبَحْنَا يَوْمًا وَنِسَاءُ النَّبِيِّ صلى الله عليه وسلم يَبْكِينَ، عِنْدَ كُلِّ امْرَأَةٍ مِنْهُنَّ أَهْلُهَا، فَخَرَجْتُ إِلَى الْمَسْجِدِ، فَإِذَا هُوَ مَلآنُ مِنَ النَّاسِ فَجَاءَ عُمَرُ بْنُ الْخَطَّابِ فَصَعِدَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ فِي غُرْفَةٍ لَهُ، فَسَلَّمَ فَلَمْ يُجِبْهُ أَحَدٌ، ثُمَّ سَلَّمَ فَلَمْ يُجِبْهُ أَحَدٌ، ثُمَّ سَلَّمَ فَلَمْ يُجِبْهُ أَحَدٌ، فَنَادَاهُ فَدَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَطَلَّقْتَ نِسَاءَكَ فَقَالَ ‏ "‏ لاَ وَلَكِنْ آلَيْتُ مِنْهُنَّ شَهْرًا ‏"‏‏.‏ فَمَكَثَ تِسْعًا وَعِشْرِينَ، ثُمَّ دَخَلَ عَلَى نِسَائِهِ‏.‏\hadithno{5203}\hadithtrans{Narrated Ibn `Abbas:One morning we saw the wives of the Prophet (ﷺ) weeping, and everyone of them had her family with her, I went to the mosque and found that it was crowded with people. Then `Umar bin Al-Khattab came and went up to the Prophet (ﷺ) who was in his upper room. He greeted him but nobody answered. He greeted again, but nobody answered. Then the gatekeeper called him and he entered upon the Prophet, and asked, "Have you divorced your wives?" The Prophet, said, "No, but I have taken an oath not to go to them for one month." So the Prophet (ﷺ) stayed away (from his wives) for twenty nine days and then entered upon them}}
\hadithdefcmd{bukhari}{5204}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجْلِدُ أَحَدُكُمُ امْرَأَتَهُ جَلْدَ الْعَبْدِ، ثُمَّ يُجَامِعُهَا فِي آخِرِ الْيَوْمِ ‏"‏‏.‏\hadithno{5204}\hadithtrans{Narrated `Abdullah bin Zam`a:The Prophet (ﷺ) said, "None of you should flog his wife as he flogs a slave and then have sexual intercourse with her in the last part of the day}}
\hadithdefcmd{bukhari}{5205}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ الْحَسَنِ ـ هُوَ ابْنُ مُسْلِمٍ ـ عَنْ صَفِيَّةَ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، مِنَ الأَنْصَارِ زَوَّجَتِ ابْنَتَهَا فَتَمَعَّطَ شَعَرُ رَأْسِهَا، فَجَاءَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ، فَقَالَتْ إِنَّ زَوْجَهَا أَمَرَنِي أَنْ أَصِلَ فِي شَعَرِهَا‏.‏ فَقَالَ ‏ "‏ لاَ إِنَّهُ قَدْ لُعِنَ الْمُوصِلاَتُ ‏"‏‏.‏\hadithno{5205}\hadithtrans{Narrated `Aisha:An Ansari woman gave her daughter in marriage and the hair of the latter started falling out. The Ansari women came to the Prophet (ﷺ) and mentioned that to him and said, "Her (my daughter's) husband suggested that I should let her wear false hair." The Prophet (ﷺ) said, "No, (don't do that) for Allah sends His curses upon such ladies who lengthen their hair artificially}}
\hadithdefcmd{bukhari}{5206}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ ‏\{‏وَإِنِ امْرَأَةٌ خَافَتْ مِنْ بَعْلِهَا نُشُوزًا أَوْ إِعْرَاضًا‏\}‏ قَالَتْ هِيَ الْمَرْأَةُ تَكُونُ عِنْدَ الرَّجُلِ، لاَ يَسْتَكْثِرُ مِنْهَا فَيُرِيدُ طَلاَقَهَا، وَيَتَزَوَّجُ غَيْرَهَا، تَقُولُ لَهُ أَمْسِكْنِي وَلاَ تُطَلِّقْنِي، ثُمَّ تَزَوَّجْ غَيْرِي، فَأَنْتَ فِي حِلٍّ مِنَ النَّفَقَةِ عَلَىَّ وَالْقِسْمَةِ لِي، فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏فَلاَ جُنَاحَ عَلَيْهِمَا أَنْ يَصَّالَحَا بَيْنَهُمَا صُلْحًا وَالصُّلْحُ خَيْرٌ‏\}‏\hadithno{5206}\hadithtrans{(Narrated Aisha:regarding the Verse: 'If a wife fears cruelty or desertion on her husband's part ...') (4.128) It concerns the woman whose husband does not want to keep her with him any longer, but wants to divorce her and marry some other lady, so she says to him: 'Keep me and do not divorce me, and then marry another woman, and you may neither spend on me, nor sleep with me.' This is indicated by the Statement of Allah: 'There is no blame on them if they arrange an amicable settlement between them both, and (such) settlement is better}}
\hadithdefcmd{bukhari}{5207}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَعْزِلُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5207}\hadithtrans{Narrated Jabir:We used to practice coitus interruptus during the lifetime of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{5209}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو أَخْبَرَنِي عَطَاءٌ، سَمِعَ جَابِرًا، رضى الله عنه قَالَ كُنَّا نَعْزِلُ وَالْقُرْآنُ يَنْزِلُ‏.‏ وَعَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَعْزِلُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَالْقُرْآنُ يَنْزِلُ‏.‏\hadithno{5209}\hadithtrans{Narrated Jabir:We used to practice coitus interruptus while the Qur'an was being revealed. Jabir added: We used to practice coitus interruptus during the lifetime of Allah's Messenger (ﷺ) while the Qur'an was being Revealed}}
\hadithdefcmd{bukhari}{5210}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ مُحَيْرِيزٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَصَبْنَا سَبْيًا فَكُنَّا نَعْزِلُ فَسَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَوَإِنَّكُمْ لَتَفْعَلُونَ قَالَهَا ثَلاَثًا مَا مِنْ نَسَمَةٍ كَائِنَةٍ إِلَى يَوْمِ الْقِيَامَةِ إِلاَّ هِيَ كَائِنَةٌ ‏"‏‏.‏\hadithno{5210}\hadithtrans{Narrated Abu Sa`id Al-Khudri:We got female captives in the war booty and we used to do coitus interruptus with them. So we asked Allah's Messenger (ﷺ) about it and he said, "Do you really do that?" repeating the question thrice, "There is no soul that is destined to exist but will come into existence, till the Day of Resurrection}}
\hadithdefcmd{bukhari}{5211}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ، قَالَ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ أَقْرَعَ بَيْنَ نِسَائِهِ، فَطَارَتِ الْقُرْعَةُ لِعَائِشَةَ وَحَفْصَةَ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا كَانَ بِاللَّيْلِ سَارَ مَعَ عَائِشَةَ يَتَحَدَّثُ، فَقَالَتْ حَفْصَةُ أَلاَ تَرْكَبِينَ اللَّيْلَةَ بَعِيرِي وَأَرْكَبُ بَعِيرَكِ تَنْظُرِينَ وَأَنْظُرُ، فَقَالَتْ بَلَى فَرَكِبَتْ فَجَاءَ النَّبِيُّ صلى الله عليه وسلم إِلَى جَمَلِ عَائِشَةَ وَعَلَيْهِ حَفْصَةُ فَسَلَّمَ عَلَيْهَا ثُمَّ سَارَ حَتَّى نَزَلُوا وَافْتَقَدَتْهُ عَائِشَةُ، فَلَمَّا نَزَلُوا جَعَلَتْ رِجْلَيْهَا بَيْنَ الإِذْخِرِ وَتَقُولُ يَا رَبِّ سَلِّطْ عَلَىَّ عَقْرَبًا أَوْ حَيَّةً تَلْدَغُنِي، وَلاَ أَسْتَطِيعُ أَنْ أَقُولَ لَهُ شَيْئًا‏.‏\hadithno{5211}\hadithtrans{Narrated al-Qasim:Aisha said that whenever the Prophet (ﷺ) intended to go on a journey, he drew lots among his wives (so as to take one of them along with him). During one of his journeys the lot fell on `Aisha and Hafsa. When night fell the Prophet (ﷺ) would ride beside `Aisha and talk with her. One night Hafsa said to `Aisha, "Won't you ride my camel tonight and I ride yours, so that you may see (me) and I see (you) (in new situation)?" `Aisha said, "Yes, (I agree.)" So `Aisha rode, and then the Prophet (ﷺ) came towards `Aisha's camel on which Hafsa was riding. He greeted Hafsa and then proceeded (beside her) till they dismounted (on the way). `Aisha missed him, and so, when they dismounted, she put her legs in the Idhkhir and said, "O Lord (Allah)! Send a scorpion or a snake to bite me for I am not to blame him (the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{5212}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلُ، حَدَّثَنَا زُهَيْرٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ سَوْدَةَ بِنْتَ زَمْعَةَ، وَهَبَتْ، يَوْمَهَا لِعَائِشَةَ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَقْسِمُ لِعَائِشَةَ بِيَوْمِهَا وَيَوْمِ سَوْدَةَ‏.‏\hadithno{5212}\hadithtrans{Narrated `Aisha:Sauda bint Zam`a gave up her turn to me (`Aisha), and so the Prophet (ﷺ) used to give me (`Aisha) both my day and the day of Sauda}}
\hadithdefcmd{bukhari}{5213}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ وَلَوْ شِئْتُ أَنْ أَقُولَ قَالَ النَّبِيُّ صلى الله عليه وسلم وَلَكِنْ قَالَ السُّنَّةُ إِذَا تَزَوَّجَ الْبِكْرَ أَقَامَ عِنْدَهَا سَبْعًا، وَإِذَا تَزَوَّجَ الثَّيِّبَ أَقَامَ عِنْدَهَا ثَلاَثًا‏.‏\hadithno{5213}\hadithtrans{Narrated Anas:The tradition, (of the Prophet) is that if someone marries a virgin and he has already a matron wife (with him), then he should stay with the virgin for seven days; and if someone marries a matron (and he has already a virgin wife with him) then he should stay with her for three days}}
\hadithdefcmd{bukhari}{5214}{حَدَّثَنَا يُوسُفُ بْنُ رَاشِدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سُفْيَانَ، حَدَّثَنَا أَيُّوبُ، وَخَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ مِنَ السُّنَّةِ إِذَا تَزَوَّجَ الرَّجُلُ الْبِكْرَ عَلَى الثَّيِّبِ أَقَامَ عِنْدَهَا سَبْعًا وَقَسَمَ، وَإِذَا تَزَوَّجَ الثَّيِّبَ عَلَى الْبِكْرِ أَقَامَ عِنْدَهَا ثَلاَثًا ثُمَّ قَسَمَ‏.‏ قَالَ أَبُو قِلاَبَةَ وَلَوْ شِئْتُ لَقُلْتُ إِنَّ أَنَسًا رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ عَبْدُ الرَّزَّاقِ أَخْبَرَنَا سُفْيَانُ عَنْ أَيُّوبَ وَخَالِدٍ قَالَ خَالِدٌ وَلَوْ شِئْتُ قُلْتُ رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5214}\hadithtrans{Narrated Anas:It is the Prophet's tradition that if someone marries a virgin and he has already a matron wife then he should stay for seven days with her (the virgin) and then by turns; and if someone marries a matron and he has already a virgin wife then he should stay with her (the matron) for three days, and then by turns}}
\hadithdefcmd{bukhari}{5215}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ فِي اللَّيْلَةِ الْوَاحِدَةِ، وَلَهُ يَوْمَئِذٍ تِسْعُ نِسْوَةٍ‏.‏\hadithno{5215}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) used to pass by (have sexual relation with) all his wives in one night, and at that time he had nine wives}}
\hadithdefcmd{bukhari}{5216}{حَدَّثَنَا فَرْوَةُ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا انْصَرَفَ مِنَ الْعَصْرِ دَخَلَ عَلَى نِسَائِهِ، فَيَدْنُو مِنْ إِحْدَاهُنَّ، فَدَخَلَ عَلَى حَفْصَةَ، فَاحْتَبَسَ أَكْثَرَ مَا كَانَ يَحْتَبِسُ‏.‏\hadithno{5216}\hadithtrans{Narrated `Aisha:Whenever Allah's Messenger (ﷺ) finished his `Asr prayer, he would enter upon his wives and stay with one of them. One day he went to Hafsa and stayed with her longer than usual}}
\hadithdefcmd{bukhari}{5217}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ هِشَامُ بْنُ عُرْوَةَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسْأَلُ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ ‏ "‏ أَيْنَ أَنَا غَدًا أَيْنَ أَنَا غَدًا ‏"‏‏.‏ يُرِيدُ يَوْمَ عَائِشَةَ، فَأَذِنَ لَهُ أَزْوَاجُهُ يَكُونُ حَيْثُ شَاءَ، فَكَانَ فِي بَيْتِ عَائِشَةَ حَتَّى مَاتَ عِنْدَهَا‏.‏ قَالَتْ عَائِشَةُ فَمَاتَ فِي الْيَوْمِ الَّذِي كَانَ يَدُورُ عَلَىَّ فِيهِ فِي بَيْتِي، فَقَبَضَهُ اللَّهُ، وَإِنَّ رَأْسَهُ لَبَيْنَ نَحْرِي وَسَحْرِي، وَخَالَطَ رِيقُهُ رِيقِي‏.‏\hadithno{5217}\hadithtrans{Narrated `Aisha:that during his fatal ailment, Allah's Messenger (ﷺ), used to ask his wives, "Where shall I stay tomorrow? Where shall I stay tomorrow?" He was looking forward to Aisha's turn. So all his wives allowed him to stay where he wished, and he stayed at `Aisha's house till he died there. `Aisha added: He died on the day of my usual turn at my house. Allah took him unto Him while his head was between my chest and my neck and his saliva was mixed with my saliva}}
\hadithdefcmd{bukhari}{5218}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ، عَنْ يَحْيَى، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، سَمِعَ ابْنَ عَبَّاسٍ، عَنْ عُمَرَ ـ رضى الله عنهم ـ دَخَلَ عَلَى حَفْصَةَ فَقَالَ يَا بُنَيَّةِ لاَ يَغُرَّنَّكِ هَذِهِ الَّتِي أَعْجَبَهَا حُسْنُهَا حُبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم إِيَّاهَا ـ يُرِيدُ عَائِشَةَ ـ فَقَصَصْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَبَسَّمَ‏.‏\hadithno{5218}\hadithtrans{Narrated Ibn `Abbas:that `Umar entered upon Hafsa and said, "O my daughter! Do not be misled by the manners of her who is proud of her beauty because of the love of Allah's Messenger (ﷺ) for her." By 'her' he meant `Aisha. `Umar added, "Then I told that to Allah's Messenger (ﷺ) and he smiled (on hearing that)}}
\hadithdefcmd{bukhari}{5219}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، حَدَّثَتْنِي فَاطِمَةُ، عَنْ أَسْمَاءَ، أَنَّ امْرَأَةً، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ لِي ضَرَّةً، فَهَلْ عَلَىَّ جُنَاحٌ إِنْ تَشَبَّعْتُ مِنْ زَوْجِي غَيْرَ الَّذِي يُعْطِينِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُتَشَبِّعُ بِمَا لَمْ يُعْطَ كَلاَبِسِ ثَوْبَىْ زُورٍ ‏"‏‏.‏\hadithno{5219}\hadithtrans{Narrated Asma:Some lady said, "O Allah's Messenger (ﷺ)! My husband has another wife, so it is sinful of me to claim that he has given me what he has not given me (in order to tease her)?" Allah's Messenger (ﷺ) said, The one who pretends that he has been given what he has not been given, is just like the (false) one who wears two garments of falsehood}}
\hadithdefcmd{bukhari}{5220}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ أَحَدٍ أَغْيَرُ مِنَ اللَّهِ، مِنْ أَجْلِ ذَلِكَ حَرَّمَ الْفَوَاحِشَ، وَمَا أَحَدٌ أَحَبَّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ ‏"‏‏.‏\hadithno{5220}\hadithtrans{Narrated `Abdullah bin Masud:The Prophet, said, "There is none having a greater sense of Ghira than Allah. And for that He has forbidden the doing of evil actions (illegal sexual intercourse etc.) There is none who likes to be praised more than Allah does}}
\hadithdefcmd{bukhari}{5221}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَا أُمَّةَ مُحَمَّدٍ مَا أَحَدٌ أَغْيَرَ مِنَ اللَّهِ أَنْ يَرَى عَبْدَهُ أَوْ أَمَتَهُ تَزْنِي يَا أُمَّةَ مُحَمَّدٍ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏‏.‏\hadithno{5221}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "O followers of Muhammad! There is none, who has a greater sense of Ghira (self-respect) than Allah, so He has forbidden that His slave commits illegal sexual intercourse or His slave girl commits illegal sexual intercourse. O followers of Muhammad! If you but knew what I know, you would laugh less and weep more}}
\hadithdefcmd{bukhari}{5222}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ عَنْ أُمِّهِ، أَسْمَاءَ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ شَىْءَ أَغْيَرُ مِنَ اللَّهِ ‏"‏‏.‏\hadithno{5222}\hadithtrans{Narrated Asma':I heard Allah's Messenger (ﷺ) saying, "There is nothing (none) having a greater sense of Ghira (self-respect) than Allah." And narrated Abu Huraira that he heard the Prophet (saying the same)}}
\hadithdefcmd{bukhari}{5223}{وَعَنْ يَحْيَى، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ أَنَّ أَبَا هُرَيْرَةَ حَدَّثَهُ أَنَّهُ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ اللَّهَ يَغَارُ وَغَيْرَةُ اللَّهِ أَنْ يَأْتِيَ الْمُؤْمِنُ مَا حَرَّمَ اللَّهُ ‏"‏‏.‏\hadithno{5223}\hadithtrans{Narrated Abu Huraira:The Prophet; said, "Allah has a sense of Ghira, and Allah's sense of Ghira is provoked when a believer does something which Allah has prohibited}}
\hadithdefcmd{bukhari}{5224}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَنِي أَبِي، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ تَزَوَّجَنِي الزُّبَيْرُ، وَمَا لَهُ فِي الأَرْضِ مِنْ مَالٍ، وَلاَ مَمْلُوكٍ، وَلاَ شَىْءٍ غَيْرَ نَاضِحٍ، وَغَيْرَ فَرَسِهِ، فَكُنْتُ أَعْلِفُ فَرَسَهُ، وَأَسْتَقِي الْمَاءَ، وَأَخْرِزُ غَرْبَهُ وَأَعْجِنُ، وَلَمْ أَكُنْ أُحْسِنُ أَخْبِزُ، وَكَانَ يَخْبِزُ جَارَاتٌ لِي مِنَ الأَنْصَارِ وَكُنَّ نِسْوَةَ صِدْقٍ، وَكُنْتُ أَنْقُلُ النَّوَى مِنْ أَرْضِ الزُّبَيْرِ الَّتِي أَقْطَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَأْسِي، وَهْىَ مِنِّي عَلَى ثُلُثَىْ فَرْسَخٍ، فَجِئْتُ يَوْمًا وَالنَّوَى عَلَى رَأْسِي فَلَقِيتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَعَهُ نَفَرٌ مِنَ الأَنْصَارِ فَدَعَانِي ثُمَّ قَالَ ‏ "‏ إِخْ إِخْ ‏"‏‏.‏ لِيَحْمِلَنِي خَلْفَهُ، فَاسْتَحْيَيْتُ أَنْ أَسِيرَ مَعَ الرِّجَالِ، وَذَكَرْتُ الزُّبَيْرَ وَغَيْرَتَهُ، وَكَانَ أَغْيَرَ النَّاسِ، فَعَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنِّي قَدِ اسْتَحْيَيْتُ فَمَضَى، فَجِئْتُ الزُّبَيْرَ فَقُلْتُ لَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَى رَأْسِي النَّوَى، وَمَعَهُ نَفَرٌ مِنْ أَصْحَابِهِ، فَأَنَاخَ لأَرْكَبَ، فَاسْتَحْيَيْتُ مِنْهُ وَعَرَفْتُ غَيْرَتَكَ‏.‏ فَقَالَ وَاللَّهِ لَحَمْلُكِ النَّوَى كَانَ أَشَدَّ عَلَىَّ مِنْ رُكُوبِكِ مَعَهُ‏.‏ قَالَتْ حَتَّى أَرْسَلَ إِلَىَّ أَبُو بَكْرٍ بَعْدَ ذَلِكَ بِخَادِمٍ يَكْفِينِي سِيَاسَةَ الْفَرَسِ، فَكَأَنَّمَا أَعْتَقَنِي‏.‏\hadithno{5224}\hadithtrans{Narrated Asma' bint Abu Bakr:When Az-Zubair married me, he had no real property or any slave or anything else except a camel which drew water from the well, and his horse. I used to feed his horse with fodder and drew water and sew the bucket for drawing it, and prepare the dough, but I did not know how to bake bread. So our Ansari neighbors used to bake bread for me, and they were honorable ladies. I used to carry the date stones on my head from Zubair's land given to him by Allah's Messenger (ﷺ) and this land was two third Farsakh (about two miles) from my house. One day, while I was coming with the date stones on my head, I met Allah's Messenger (ﷺ) along with some Ansari people. He called me and then, (directing his camel to kneel down) said, "Ikh! Ikh!" so as to make me ride behind him (on his camel). I felt shy to travel with the men and remembered Az-Zubair and his sense of Ghira, as he was one of those people who had the greatest sense of Ghira. Allah's Messenger (ﷺ) noticed that I felt shy, so he proceeded. I came to Az-Zubair and said, "I met Allah's Messenger (ﷺ) while I was carrying a load of date stones on my head, and he had some companions with him. He made his camel kneel down so that I might ride, but I felt shy in his presence and remembered your sense of Ghira (See the glossary). On that Az-Zubair said, "By Allah, your carrying the date stones (and you being seen by the Prophet (ﷺ) in such a state) is more shameful to me than your riding with him." (I continued serving in this way) till Abu Bakr sent me a servant to look after the horse, whereupon I felt as if he had set me free}}
\hadithdefcmd{bukhari}{5225}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم عِنْدَ بَعْضِ نِسَائِهِ فَأَرْسَلَتْ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ بِصَحْفَةٍ فِيهَا طَعَامٌ، فَضَرَبَتِ الَّتِي النَّبِيُّ صلى الله عليه وسلم فِي بَيْتِهَا يَدَ الْخَادِمِ فَسَقَطَتِ الصَّحْفَةُ فَانْفَلَقَتْ، فَجَمَعَ النَّبِيُّ صلى الله عليه وسلم فِلَقَ الصَّحْفَةِ، ثُمَّ جَعَلَ يَجْمَعُ فِيهَا الطَّعَامَ الَّذِي كَانَ فِي الصَّحْفَةِ وَيَقُولُ ‏ "‏ غَارَتْ أُمُّكُمْ ‏"‏، ثُمَّ حَبَسَ الْخَادِمَ حَتَّى أُتِيَ بِصَحْفَةٍ مِنْ عِنْدِ الَّتِي هُوَ فِي بَيْتِهَا، فَدَفَعَ الصَّحْفَةَ الصَّحِيحَةَ إِلَى الَّتِي كُسِرَتْ صَحْفَتُهَا، وَأَمْسَكَ الْمَكْسُورَةَ فِي بَيْتِ الَّتِي كَسَرَتْ فِيه.‏\hadithno{5225}\hadithtrans{Narrated Anas:While the Prophet (ﷺ) was in the house of one of his wives, one of the mothers of the believers sent a meal in a dish. The wife at whose house the Prophet (ﷺ) was, struck the hand of the servant, causing the dish to fall and break. The Prophet (ﷺ) gathered the broken pieces of the dish and then started collecting on them the food which had been in the dish and said, "Your mother (my wife) felt jealous." Then he detained the servant till a (sound) dish was brought from the wife at whose house he was. He gave the sound dish to the wife whose dish had been broken and kept the broken one at the house where it had been broken}}
\hadithdefcmd{bukhari}{5226}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ دَخَلْتُ الْجَنَّةَ ـ أَوْ أَتَيْتُ الْجَنَّةَ ـ فَأَبْصَرْتُ قَصْرًا فَقُلْتُ لِمَنْ هَذَا قَالُوا لِعُمَرَ بْنِ الْخَطَّابِ‏.‏ فَأَرَدْتُ أَنْ أَدْخُلَهُ فَلَمْ يَمْنَعْنِي إِلاَّ عِلْمِي بِغَيْرَتِكَ ‏"‏‏.‏ قَالَ عُمَرُ بْنُ الْخَطَّابِ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي يَا نَبِيَّ اللَّهِ أَوَعَلَيْكَ أَغَارُ‏.‏\hadithno{5226}\hadithtrans{Narrated Jabir:The Prophet, said, "I entered Paradise and saw a palace and asked whose palace is this? They (the Angels) said, "This palace belongs to `Umar bin Al-Khattab.' I intended to enter it, and nothing stopped me except my knowledge about your sense of Ghira (self-respect (O `Umar)." `Umar said, "O Allah's Messenger (ﷺ)! Let my father and mother be sacrificed for you! O Allah's Prophet! How dare I think of my Ghira (self-respect) being offended by you?}}
\hadithdefcmd{bukhari}{5227}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي ابْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم جُلُوسٌ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَمَا أَنَا نَائِمٌ رَأَيْتُنِي فِي الْجَنَّةِ، فَإِذَا امْرَأَةٌ تَتَوَضَّأُ إِلَى جَانِبِ قَصْرٍ، فَقُلْتُ لِمَنْ هَذَا قَالَ هَذَا لِعُمَرَ‏.‏ فَذَكَرْتُ غَيْرَتَهُ فَوَلَّيْتُ مُدْبِرًا ‏"‏‏.‏ فَبَكَى عُمَرُ وَهْوَ فِي الْمَجْلِسِ ثُمَّ قَالَ أَوَعَلَيْكَ يَا رَسُولَ اللَّهِ أَغَارُ‏.‏\hadithno{5227}\hadithtrans{Narrated Abu Huraira:While we were sitting with Allah's Messenger (ﷺ), (he) Allah's Messenger (ﷺ) said, "While I was sleeping, I saw a woman performing ablution beside a palace. I asked, "Whose palace is this?' It was said, 'This palace belongs to `Umar.' Then I remembered his sense of Ghira and returned." On that `Umar started weeping in that gathering and said, "O Allah's Messenger (ﷺ)! How dare I think of my self-respect being offended by you?}}
\hadithdefcmd{bukhari}{5228}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لأَعْلَمُ إِذَا كُنْتِ عَنِّي رَاضِيَةً، وَإِذَا كُنْتِ عَلَىَّ غَضْبَى ‏"‏‏.‏ قَالَتْ فَقُلْتُ مِنْ أَيْنَ تَعْرِفُ ذَلِكَ فَقَالَ ‏"‏ أَمَّا إِذَا كُنْتِ عَنِّي رَاضِيَةً فَإِنَّكِ تَقُولِينَ لاَ وَرَبِّ مُحَمَّدٍ، وَإِذَا كُنْتِ غَضْبَى قُلْتِ لاَ وَرَبِّ إِبْرَاهِيمَ ‏"‏‏.‏ قَالَتْ قُلْتُ أَجَلْ وَاللَّهِ يَا رَسُولَ اللَّهِ، مَا أَهْجُرُ إِلاَّ اسْمَكَ‏.‏\hadithno{5228}\hadithtrans{Narrated Aisha:That Allah's Messenger (ﷺ) said to her, "I know when you are pleased with me or angry with me." I said, "Whence do you know that?" He said, "When you are pleased with me, you say, 'No, by the Lord of Muhammad,' but when you are angry with me, then you say, 'No, by the Lord of Abraham.' " Thereupon I said, "Yes (you are right), but by Allah, O Allah's Messenger (ﷺ), I leave nothing but your name}}
\hadithdefcmd{bukhari}{5229}{حَدَّثَنِي أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا النَّضْرُ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مَا غِرْتُ عَلَى امْرَأَةٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم كَمَا غِرْتُ عَلَى خَدِيجَةَ، لِكَثْرَةِ ذِكْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِيَّاهَا وَثَنَائِهِ عَلَيْهَا، وَقَدْ أُوحِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ يُبَشِّرَهَا بِبَيْتٍ لَهَا فِي الْجَنَّةِ مِنْ قَصَبٍ‏.‏\hadithno{5229}\hadithtrans{Narrated `Aisha:I never felt so jealous of any wife of Allah's Messenger (ﷺ) as I did of Khadija because Allah's Messenger (ﷺ) used to remember and praise her too often and because it was revealed to Allah's Messenger (ﷺ) that he should give her (Khadija) the glad tidings of her having a palace of Qasab in Paradise}}
\hadithdefcmd{bukhari}{5230}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهْوَ عَلَى الْمِنْبَرِ ‏ "‏ إِنَّ بَنِي هِشَامِ بْنِ الْمُغِيرَةِ اسْتَأْذَنُوا فِي أَنْ يُنْكِحُوا ابْنَتَهُمْ عَلِيَّ بْنَ أَبِي طَالِبٍ فَلاَ آذَنُ، ثُمَّ لاَ آذَنُ، ثُمَّ لاَ آذَنُ، إِلاَّ أَنْ يُرِيدَ ابْنُ أَبِي طَالِبٍ أَنْ يُطَلِّقَ ابْنَتِي وَيَنْكِحَ ابْنَتَهُمْ، فَإِنَّمَا هِيَ بَضْعَةٌ مِنِّي، يُرِيبُنِي مَا أَرَابَهَا وَيُؤْذِينِي مَا آذَاهَا ‏"‏‏.‏ هَكَذَا قَالَ‏.‏\hadithno{5230}\hadithtrans{Narrated Al-Miswar bin Makhrama:I heard Allah's Messenger (ﷺ) who was on the pulpit, saying, "Banu Hisham bin Al-Mughira have requested me to allow them to marry their daughter to `Ali bin Abu Talib, but I don't give permission, and will not give permission unless `Ali bin Abi Talib divorces my daughter in order to marry their daughter, because Fatima is a part of my body, and I hate what she hates to see, and what hurts her, hurts me}}
\hadithdefcmd{bukhari}{5231}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ الْحَوْضِيُّ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لأُحَدِّثَنَّكُمْ حَدِيثًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ يُحَدِّثُكُمْ بِهِ أَحَدٌ غَيْرِي، سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يُرْفَعَ الْعِلْمُ، وَيَكْثُرَ الْجَهْلُ وَيَكْثُرَ الزِّنَا، وَيَكْثُرَ شُرْبُ الْخَمْرِ، وَيَقِلَّ الرِّجَالُ، وَيَكْثُرَ النِّسَاءُ حَتَّى يَكُونَ لِخَمْسِينَ امْرَأَةً الْقَيِّمُ الْوَاحِدُ ‏"‏‏.‏\hadithno{5231}\hadithtrans{Narrated Anas:I will narrate to you a Habith I heard from Allah's Messenger (ﷺ) and none other than I will tell you of it. I heard Allah's Messenger (ﷺ) saying, "From among the portents of the Hour are the following: Religious knowledge will be taken away; General ignorance (in religious matters) will increase; illegal Sexual intercourse will prevail: Drinking of alcoholic drinks will prevail. Men will decrease in number, and women will increase in number, so much so that fifty women will be looked after by one man}}
\hadithdefcmd{bukhari}{5232}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالدُّخُولَ عَلَى النِّسَاءِ ‏"‏‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ يَا رَسُولَ اللَّهِ أَفَرَأَيْتَ الْحَمْوَ‏.‏ قَالَ ‏"‏ الْحَمْوُ الْمَوْتُ ‏"‏‏.‏\hadithno{5232}\hadithtrans{Narrated `Uqba bin 'Amir:Allah's Messenger (ﷺ) said, "Beware of entering upon the ladies." A man from the Ansar said, "Allah's Apostle! What about Al-Hamu the in-laws of the wife (the brothers of her husband or his nephews etc.)?" The Prophet (ﷺ) replied: The in-laws of the wife are death itself}}
\hadithdefcmd{bukhari}{5233}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَخْلُوَنَّ رَجُلٌ بِامْرَأَةٍ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ امْرَأَتِي خَرَجَتْ حَاجَّةً وَاكْتُتِبْتُ فِي غَزْوَةِ كَذَا وَكَذَا‏.‏ قَالَ ‏"‏ ارْجِعْ فَحُجَّ مَعَ امْرَأَتِكَ ‏"‏‏.‏\hadithno{5233}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "No man should stay with a lady in seclusion except in the presence of a Dhu-Mahram." A man stood up and said, "O Allah's Messenger (ﷺ)! My wife has gone out intending to perform the Hajj and I have been enrolled (in the army) for such-and-such campaign." The Prophet (ﷺ) said, "Return and perform the Hajj with your wife}}
\hadithdefcmd{bukhari}{5234}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ جَاءَتِ امْرَأَةٌ مِنَ الأَنْصَارِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَخَلاَ بِهَا فَقَالَ ‏ "‏ وَاللَّهِ إِنَّكُنَّ لأَحَبُّ النَّاسِ إِلَىَّ ‏"‏‏.‏\hadithno{5234}\hadithtrans{Narrated Anas bin Malik:An Ansari woman came to the Prophet (ﷺ) and he took her aside and said (to her). "By Allah, you (Ansar) are the most beloved people to me}}
\hadithdefcmd{bukhari}{5235}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ عِنْدَهَا وَفِي الْبَيْتِ مُخَنَّثٌ، فَقَالَ الْمُخَنَّثُ لأَخِي أُمِّ سَلَمَةَ عَبْدِ اللَّهِ بْنِ أَبِي أُمَيَّةَ إِنْ فَتَحَ اللَّهُ عَلَيْكُمُ الطَّائِفَ غَدًا أَدُلُّكَ عَلَى ابْنَةِ غَيْلاَنَ، فَإِنَّهَا تُقْبِلُ بِأَرْبَعٍ وَتُدْبِرُ بِثَمَانٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلَنَّ هَذَا عَلَيْكُنَّ ‏"‏‏.‏\hadithno{5235}\hadithtrans{Narrated Um Salama:that while the Prophet (ﷺ) was with her, there was an effeminate man in the house. The effeminate man said to Um Salama's brother, `Abdullah bin Abi Umaiyya, "If Allah should make you conquer Ta'if tomorrow, I recommend that you take the daughter of Ghailan (in marriage) for (she is so fat) that she shows four folds of flesh when facing you and eight when she turns her back." Thereupon the Prophet (ﷺ) said (to us), "This (effeminate man) should not enter upon you (anymore)}}
\hadithdefcmd{bukhari}{5236}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، عَنْ عِيسَى، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتُرُنِي بِرِدَائِهِ، وَأَنَا أَنْظُرُ إِلَى الْحَبَشَةِ يَلْعَبُونَ فِي الْمَسْجِدِ، حَتَّى أَكُونَ أَنَا الَّذِي أَسْأَمُ، فَاقْدُرُوا قَدْرَ الْجَارِيَةِ الْحَدِيثَةِ السِّنِّ الْحَرِيصَةِ عَلَى اللَّهْوِ‏.‏\hadithno{5236}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) was screening me with his Rida' (garment covering the upper part of the body) while I was looking at the Ethiopians who were playing in the courtyard of the mosque. (I continued watching) till I was satisfied. So you may deduce from this event how a little girl (who has not reached the age of puberty) who is eager to enjoy amusement should be treated in this respect}}
\hadithdefcmd{bukhari}{5237}{حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجَتْ سَوْدَةُ بِنْتُ زَمْعَةَ لَيْلاً فَرَآهَا عُمَرُ فَعَرَفَهَا فَقَالَ إِنَّكِ وَاللَّهِ يَا سَوْدَةُ مَا تَخْفَيْنَ عَلَيْنَا، فَرَجَعَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ، وَهْوَ فِي حُجْرَتِي يَتَعَشَّى، وَإِنَّ فِي يَدِهِ لَعَرْقًا، فَأُنْزِلَ عَلَيْهِ فَرُفِعَ عَنْهُ وَهُوَ يَقُولُ ‏ "‏ قَدْ أَذِنَ لَكُنَّ أَنْ تَخْرُجْنَ لِحَوَائِجِكُنَّ ‏"‏‏.‏\hadithno{5237}\hadithtrans{Narrated `Aisha:Once Sa`da bint Zam`a went out at night for some need, and `Umar saw her, and recognizing her, he said (to her), "By Allah, O Sa`da! You cannot hide yourself from us." So she returned to the Prophet (ﷺ) and mentioned that to him while he was sitting in my dwelling taking his supper and holding a bone covered with meat in his hand. Then the Divine Inspiration was revealed to him and when that state was over, he (the Prophet (ﷺ) was saying: "O women! You have been allowed by Allah to go out for your needs}}
\hadithdefcmd{bukhari}{5238}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَأْذَنَتِ امْرَأَةُ أَحَدِكُمْ إِلَى الْمَسْجِدِ فَلاَ يَمْنَعْهَا ‏"‏‏.‏\hadithno{5238}\hadithtrans{Narrated Salim's father:The Prophet (ﷺ) said, "If the wife of anyone of you asks permission to go to the mosque, he should not forbid her}}
\hadithdefcmd{bukhari}{5239}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ جَاءَ عَمِّي مِنَ الرَّضَاعَةِ فَاسْتَأْذَنَ عَلَىَّ فَأَبَيْتُ أَنْ آذَنَ لَهُ حَتَّى أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ عَنْ ذَلِكَ فَقَالَ ‏"‏ إِنَّهُ عَمُّكِ فَأْذَنِي لَهُ ‏"‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ عَمُّكِ فَلْيَلِجْ عَلَيْكِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ وَذَلِكَ بَعْدَ أَنْ ضُرِبَ عَلَيْنَا الْحِجَابُ‏.‏ قَالَتْ عَائِشَةُ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ الْوِلاَدَةِ‏.‏\hadithno{5239}\hadithtrans{Narrated `Aisha:My foster uncle came and asked permission (to enter) but I refused to admit him till I asked Allah's Apostle about that. He said, "He is your uncle, so allow him to come in." I said, "O Allah's Messenger (ﷺ)! I have been suckled by a woman and not by a man." Allah's Messenger (ﷺ) said, "He is your uncle, so let him enter upon you." And that happened after the order of Al-Hijab (compulsory veiling) was revealed. All things which become unlawful because of blood relations are unlawful because of the corresponding foster suckling relations}}
\hadithdefcmd{bukhari}{5240}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُبَاشِرِ الْمَرْأَةُ الْمَرْأَةَ فَتَنْعَتَهَا لِزَوْجِهَا، كَأَنَّهُ يَنْظُرُ إِلَيْهَا ‏"‏‏.‏\hadithno{5240}\hadithtrans{Narrated `Abdullah bin Mas`ud:The Prophet (ﷺ) said, "A woman should not look at or touch another woman to describe her to her husband in such a way as if he was actually looking at her}}
\hadithdefcmd{bukhari}{5241}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُبَاشِرِ الْمَرْأَةُ الْمَرْأَةَ فَتَنْعَتَهَا لِزَوْجِهَا كَأَنَّهُ يَنْظُرُ إِلَيْهَا ‏"‏‏.‏\hadithno{5241}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "A woman should not look at or touch another woman to describe her to her husband in such a way as if he was actually looking at her}}
\hadithdefcmd{bukhari}{5242}{حَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏"‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ ـ عَلَيْهِمَا السَّلاَمُ ـ لأَطُوفَنَّ اللَّيْلَةَ بِمِائَةِ امْرَأَةٍ، تَلِدُ كُلُّ امْرَأَةٍ غُلاَمًا، يُقَاتِلُ فِي سَبِيلِ اللَّهِ، فَقَالَ لَهُ الْمَلَكُ قُلْ إِنْ شَاءَ اللَّهُ‏.‏ فَلَمْ يَقُلْ وَنَسِيَ، فَأَطَافَ بِهِنَّ، وَلَمْ تَلِدْ مِنْهُنَّ إِلاَّ امْرَأَةٌ نِصْفَ إِنْسَانٍ ‏"‏‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ قَالَ إِنْ شَاءَ اللَّهُ لَمْ يَحْنَثْ، وَكَانَ أَرْجَى لِحَاجَتِهِ ‏"‏‏.‏\hadithno{5242}\hadithtrans{Narrated Abu Huraira:(The Prophet) Solomon son of (the Prophet) David said, "Tonight I will go round (i.e. have sexual relations with) one hundred women (my wives) everyone of whom will deliver a male child who will fight in Allah's Cause." On that an Angel said to him, "Say: 'If Allah will.' " But Solomon did not say it and forgot to say it. Then he had sexual relations with them but none of them delivered any child except one who delivered a half person. The Prophet (ﷺ) said, "If Solomon had said: 'If Allah will,' Allah would have fulfilled his (above) desire and that saying would have made him more hopeful}}
\hadithdefcmd{bukhari}{5243}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَارِبُ بْنُ دِثَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَكْرَهُ أَنْ يَأْتِيَ الرَّجُلُ أَهْلَهُ طُرُوقًا‏.‏\hadithno{5243}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) disliked that one should go to one's family at night (on returning from a journey)}}
\hadithdefcmd{bukhari}{5244}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عَاصِمُ بْنُ سُلَيْمَانَ، عَنِ الشَّعْبِيِّ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَطَالَ أَحَدُكُمُ الْغَيْبَةَ فَلاَ يَطْرُقْ أَهْلَهُ لَيْلاً ‏"‏‏.‏\hadithno{5244}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "When anyone of you is away from his house for a long time, he should not return to his family at night}}
\hadithdefcmd{bukhari}{5245}{حَدَّثَنَا مُسَدَّدٌ، عَنْ هُشَيْمٍ، عَنْ سَيَّارٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ، فَلَمَّا قَفَلْنَا تَعَجَّلْتُ عَلَى بَعِيرٍ قَطُوفٍ فَلَحِقَنِي رَاكِبٌ مِنْ خَلْفِي، فَالْتَفَتُّ فَإِذَا أَنَا بِرَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا يُعْجِلُكَ ‏"‏‏.‏ قُلْتُ إِنِّي حَدِيثُ عَهْدٍ بِعُرْسٍ‏.‏ قَالَ ‏"‏ فَبِكْرًا تَزَوَّجْتَ أَمْ ثَيِّبًا ‏"‏‏.‏ قُلْتُ بَلْ ثَيِّبًا‏.‏ قَالَ ‏"‏ فَهَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏‏.‏ قَالَ فَلَمَّا قَدِمْنَا ذَهَبْنَا لِنَدْخُلَ فَقَالَ ‏"‏ أَمْهِلُوا حَتَّى تَدْخُلُوا لَيْلاً ـ أَىْ عِشَاءً ـ لِكَىْ تَمْتَشِطَ الشَّعِثَةُ وَتَسْتَحِدَّ الْمُغِيبَةُ ‏"‏‏.‏ قَالَ وَحَدَّثَنِي الثِّقَةُ أَنَّهُ قَالَ فِي هَذَا الْحَدِيثِ ‏"‏ الْكَيْسَ الْكَيْسَ يَا جَابِرُ ‏"‏‏.‏ يَعْنِي الْوَلَدَ‏.‏\hadithno{5245}\hadithtrans{Narrated Jabir:I was with Allah's Messenger (ﷺ) in a Ghazwa, and when we returned, I wanted to hurry, while riding a slow camel. A rider came behind me. I looked back and saw that the rider was Allah's Messenger (ﷺ) . He said (to me), "What makes you in such a hurry?" I replied, "I am newly married." He said, "Did you marry a virgin or a matron?" I replied, "(Not a virgin but) a matron." He said, "Why didn't you marry a young girl with whom you could play and who could play with you?" Then when we approached (Medina) and were going to enter (it), the Prophet (ﷺ) said, "Wait till you enter (your homes) at night (in the first part of the night) so that the ladies with unkempt hair may comb their hair, and those whose husbands have been absent (for a long time) may shave their pubic hair." (The sub-narrator, Hashim said: A reliable narrator told me that the Prophet (ﷺ) added in this Hadith: "(Seek to beget) children! Children, O Jabir}}
\hadithdefcmd{bukhari}{5246}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَيَّارٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا دَخَلْتَ لَيْلاً فَلاَ تَدْخُلْ عَلَى أَهْلِكَ حَتَّى تَسْتَحِدَّ الْمُغِيبَةُ وَتَمْتَشِطَ الشَّعِثَةُ ‏"‏‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَعَلَيْكَ بِالْكَيْسِ الْكَيْسِ ‏"‏‏.‏ تَابَعَهُ عُبَيْدُ اللَّهِ عَنْ وَهْبٍ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْكَيْسِ‏.‏\hadithno{5246}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "If you enter (your town) at night (after coming from a journey), do not enter upon your family till the woman whose husband was absent (from the house) shaves her pubic hair and the woman with unkempt hair, combs her hair" Allah's Messenger (ﷺ) further said, "(O Jabir!) Seek to have offspring, seek to have offspring}}
\hadithdefcmd{bukhari}{5247}{حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَزْوَةٍ، فَلَمَّا قَفَلْنَا كُنَّا قَرِيبًا مِنَ الْمَدِينَةِ تَعَجَّلْتُ عَلَى بَعِيرٍ لِي قَطُوفٍ، فَلَحِقَنِي رَاكِبٌ مِنْ خَلْفِي فَنَخَسَ بَعِيرِي بِعَنَزَةٍ كَانَتْ مَعَهُ، فَسَارَ بَعِيرِي كَأَحْسَنِ مَا أَنْتَ رَاءٍ مِنَ الإِبِلِ، فَالْتَفَتُّ فَإِذَا أَنَا بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي حَدِيثُ عَهْدٍ بِعُرْسٍ‏.‏ قَالَ ‏"‏ أَتَزَوَّجْتَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ أَبِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ قَالَ قُلْتُ بَلْ ثَيِّبًا‏.‏ قَالَ ‏"‏ فَهَلاَّ بِكْرًا تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏‏.‏ قَالَ فَلَمَّا قَدِمْنَا ذَهَبْنَا لِنَدْخُلَ، فَقَالَ ‏"‏ أَمْهِلُوا حَتَّى تَدْخُلُوا لَيْلاً ـ أَىْ عِشَاءً ـ لِكَىْ تَمْتَشِطَ الشَّعِثَةُ، وَتَسْتَحِدَّ الْمُغِيبَةُ ‏"‏‏.‏\hadithno{5247}\hadithtrans{Narrated Jabir bin `Abdullah:We were with the Prophet (ﷺ) in Ghazwa, and when we returned and approached Medina, I wanted to hurry while riding a slow camel. A rider overtook me and pricked my camel with a spear which he had, whereupon my camel started running as fast as any other fast camel you may see. I looked back, and behold, the rider was Allah's Messenger (ﷺ) . I said, "O Allah's Messenger (ﷺ)! I am newly married " He asked, "Have you got married?" I replied, "Yes." He said, "A virgin or a matron?" I replied, "(Not a virgin) but a matron" He said, "Why didn't you marry a young girl so that you could play with her and she with you?" When we reached (near Medina) and were going to enter it, the Prophet (ﷺ) said, "Wait till you enter your home early in the night so that the lady whose hair is unkempt may comb her hair and that the lady whose husband has been away may shave her pubic hair}}
\hadithdefcmd{bukhari}{5248}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي حَازِمٍ، قَالَ اخْتَلَفَ النَّاسُ بِأَىِّ شَىْءٍ دُووِيَ جُرْحُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ، فَسَأَلُوا سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، وَكَانَ مِنْ آخِرِ مَنْ بَقِيَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ، فَقَالَ وَمَا بَقِيَ مِنَ النَّاسِ أَحَدٌ أَعْلَمُ بِهِ مِنِّي، كَانَتْ فَاطِمَةُ عَلَيْهَا السَّلاَمُ تَغْسِلُ الدَّمَ عَنْ وَجْهِهِ، وَعَلِيٌّ يَأْتِي بِالْمَاءِ عَلَى تُرْسِهِ، فَأُخِذَ حَصِيرٌ، فَحُرِّقَ فَحُشِيَ بِهِ جُرْحُهُ‏.‏\hadithno{5248}\hadithtrans{Narrated Abu Hazim:The people differed about the type of treatment which had been given to Allah's Messenger (ﷺ) on the day (of the battle) of Uhud. So they asked Sahl bin Sa`d As-Sa`id who was the only surviving Companion (of the Prophet) at Medina. He replied, "Nobody Is left at Medina who knows it better than I. Fatima was washing the blood off his face and `Ali was bringing water in his shield, and then a mat of datepalm leaves was burnt and (the ash) was inserted into the wound}}
\hadithdefcmd{bukhari}{5249}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ سَأَلَهُ رَجُلٌ شَهِدْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعِيدَ أَضْحًى أَوْ فِطْرًا قَالَ نَعَمْ لَوْلاَ مَكَانِي مِنْهُ مَا شَهِدْتُهُ ـ يَعْنِي مِنْ صِغَرِهِ ـ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى ثُمَّ خَطَبَ، وَلَمْ يَذْكُرْ أَذَانًا وَلاَ إِقَامَةً، ثُمَّ أَتَى النِّسَاءَ فَوَعَظَهُنَّ وَذَكَّرَهُنَّ وَأَمَرَهُنَّ بِالصَّدَقَةِ، فَرَأَيْتُهُنَّ يَهْوِينَ إِلَى آذَانِهِنَّ وَحُلُوقِهِنَّ يَدْفَعْنَ إِلَى بِلاَلٍ، ثُمَّ ارْتَفَعَ هُوَ وَبِلاَلٌ إِلَى بَيْتِهِ‏.‏\hadithno{5249}\hadithtrans{Narrated `Abdur-Rahman bin `Abis:I heard Ibn `Abbas answering a man who asked him, "Did you attend the prayer of `Id al Adha or `Idal- Fitr with Allah's Messenger (ﷺ)?" Ibn `Abbas replied, "Yes, and had it not been for my close relationship with him, I could not have offered it." (That was because of his young age). Ibn `Abbas further said, Allah's Messenger (ﷺ) went out and offered the Id prayer and then delivered the sermon." Ibn `Abbas did not mention anything about the Adhan (the call for prayer) or the Iqama. He added, "Then the Prophet (ﷺ) went to the women and instructed them and gave them religious advice and ordered them to give alms and I saw them reaching out (their hands to) their ears and necks (to take off the earrings and necklaces, etc.) and throwing (it) towards Bilal. Then the Prophet (ﷺ) returned with Bilal to his house}}
\hadithdefcmd{bukhari}{5250}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ عَاتَبَنِي أَبُو بَكْرٍ وَجَعَلَ يَطْعُنُنِي بِيَدِهِ فِي خَاصِرَتِي فَلاَ يَمْنَعُنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَأْسُهُ عَلَى فَخِذِي‏.‏\hadithno{5250}\hadithtrans{Narrated `Aisha:Abu Bakr admonished me and poked me with his hands in the flank, and nothing stopped me from moving at that time except the position of Allah's Messenger (ﷺ) whose head was on my thigh}}
