% Auto-generated chapter 49 for tirmidhi
% Hadiths in this chapter: 351

\hadithdefcmd{tirmidhi}{3605}{حَدَّثَنَا خَلاَّدُ بْنُ أَسْلَمَ الْبَغْدَادِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ أَبِي عَمَّارٍ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ اصْطَفَى مِنْ وَلَدِ إِبْرَاهِيمَ إِسْمَاعِيلَ وَاصْطَفَى مِنْ وَلَدِ إِسْمَاعِيلَ بَنِي كِنَانَةَ وَاصْطَفَى مِنْ بَنِي كِنَانَةَ قُرَيْشًا وَاصْطَفَى مِنْ قُرَيْشٍ بَنِي هَاشِمٍ وَاصْطَفَانِي مِنْ بَنِي هَاشِمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3605}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Wathilah bin Al-Asqa':that the Messenger of Allah (ﷺ) said: "Indeed Allah has chosen Isma'il from the children of Ibrahim, and He chose Banu Kinanah from the children of Isma'il, and He chose the Quraish from Banu Kinanah, and He chose Banu Hashim from Quraish, and He chose me from Banu Hashim}}
\hadithdefcmd{tirmidhi}{3606}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي شَدَّادٌ أَبُو عَمَّارٍ، حَدَّثَنِي وَاثِلَةُ بْنُ الأَسْقَعِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ اصْطَفَى كِنَانَةَ مِنْ وَلَدِ إِسْمَاعِيلَ وَاصْطَفَى قُرَيْشًا مِنْ كِنَانَةَ وَاصْطَفَى هَاشِمًا مِنْ قُرَيْشٍ وَاصْطَفَانِي مِنْ بَنِي هَاشِمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3606}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Wathilah bin Al-Asqa':that the Messenger of Allah (ﷺ) said: "Indeed, Allah chose Kinanah from the children of Isma'il, and He chose Quraish from Kinanah, and He chose Hashim from Quraish, and He chose me from Banu Hashim}}
\hadithdefcmd{tirmidhi}{3607}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى الْقَطَّانُ الْبَغْدَادِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ قُرَيْشًا جَلَسُوا فَتَذَاكَرُوا أَحْسَابَهُمْ بَيْنَهُمْ فَجَعَلُوا مَثَلَكَ كَمَثَلِ نَخْلَةٍ فِي كَبْوَةٍ مِنَ الأَرْضِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ خَلَقَ الْخَلْقَ فَجَعَلَنِي مِنْ خَيْرِهِمْ مِنْ خَيْرِ فِرَقِهِمْ وَخَيْرِ الْفَرِيقَيْنِ ثُمَّ تَخَيَّرَ الْقَبَائِلَ فَجَعَلَنِي مِنْ خَيْرِ قَبِيلَةٍ ثُمَّ تَخَيَّرَ الْبُيُوتَ فَجَعَلَنِي مِنْ خَيْرِ بُيُوتِهِمْ فَأَنَا خَيْرُهُمْ نَفْسًا وَخَيْرُهُمْ بَيْتًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَعَبْدُ اللَّهِ بْنُ الْحَارِثِ هُوَ ابْنُ نَوْفَلٍ ‏.‏\hadithno{3607}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-'Abbas bin 'Abdul-Muttalib:"I said: 'O Messenger of Allah! Indeed the Quraish have sat and spoken between themselves about the best of them, and they made your likeness as that of a palm tree in a wasteland.' So the Prophet (ﷺ) said: 'Indeed, Allah created the creation and made me [from the best of them,] from the best of their categories, and the best of the two categories (Arabs and Non-Arabs), then He chose between the tribes and made me from the best tribe, then He chose between the houses and made me from the best house. So I am the best of them in person and the best of them in house}}
\hadithdefcmd{tirmidhi}{3608}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ، قَالَ جَاءَ الْعَبَّاسُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَأَنَّهُ سَمِعَ شَيْئًا فَقَامَ النَّبِيُّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ مَنْ أَنَا ‏"‏ ‏.‏ قَالُوا أَنْتَ رَسُولُ اللَّهِ عَلَيْكَ السَّلاَمُ ‏.‏ قَالَ ‏"‏ أَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْمُطَّلِبِ إِنَّ اللَّهَ خَلَقَ الْخَلْقَ فَجَعَلَنِي فِي خَيْرِهِمْ ثُمَّ جَعَلَهُمْ فِرْقَتَيْنِ فَجَعَلَنِي فِي خَيْرِهِمْ فِرْقَةً ثُمَّ جَعَلَهُمْ قَبَائِلَ فَجَعَلَنِي فِي خَيْرِهِمْ قَبِيلَةً ثُمَّ جَعَلَهُمْ بُيُوتًا فَجَعَلَنِي فِي خَيْرِهِمْ بَيْتًا وَخَيْرِهِمْ نَفْسًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرُوِيَ عَنْ سُفْيَانَ الثَّوْرِيِّ عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ نَحْوُ حَدِيثِ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ ‏.‏\hadithno{3608}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Muttalib bin Abi Wada'ah:"Al-Abbas came to the Messenger of Allah (ﷺ), and it is as if he heard something, so the Prophet (ﷺ) stood upon the Minbar and said: 'Who am I?' They said: 'You are the Messenger of Allah, upon you be peace.' He said: 'I am Muhammad bin 'Abdullah bin 'Abdul-Muttalib, indeed Allah created the creation, and He put me in the best [group] of them, then He made them into two groups, so He put me in the best group of them, then He made them into tribes, so He put me in the best of them in tribe, then He made them into houses, so He put me in the best of them in tribe and lineage}}
\hadithdefcmd{tirmidhi}{3609}{حَدَّثَنَا أَبُو هَمَّامٍ الْوَلِيدُ بْنُ شُجَاعِ بْنِ الْوَلِيدِ الْبَغْدَادِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ مَتَى وَجَبَتْ لَكَ النُّبُوَّةُ قَالَ ‏ "‏ وَآدَمُ بَيْنَ الرُّوحِ وَالْجَسَدِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي هُرَيْرَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ مَيْسَرَةَ الْفَجْرِ ‏.‏\hadithno{3609}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:"They said: 'O Messenger of Allah (ﷺ)! When was the Prophethood established for you?' He said: 'While Adam was between (being) soul and body}}
\hadithdefcmd{tirmidhi}{3610}{حَدَّثَنَا الْحُسَيْنُ بْنُ يَزِيدَ الْكُوفِيُّ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ لَيْثٍ، عَنِ الرَّبِيعِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَوَّلُ النَّاسِ خُرُوجًا إِذَا بُعِثُوا وَأَنَا خَطِيبُهُمْ إِذَا وَفَدُوا وَأَنَا مُبَشِّرُهُمْ إِذَا أَيِسُوا لِوَاءُ الْحَمْدِ يَوْمَئِذٍ بِيَدِي وَأَنَا أَكْرَمُ وَلَدِ آدَمَ عَلَى رَبِّي وَلاَ فَخْرَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3610}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "I am the first of the people to appear upon their being resurrected, and I am their spokesman whenever they gather, and I am the one that gives them glad tidings whenever they give up hope. And the Banner of Praise will be in my hand that day, and I am the most noble of the children of Adam with my Lord, and I am not boasting}}
\hadithdefcmd{tirmidhi}{3611}{حَدَّثَنَا الْحُسَيْنُ بْنُ يَزِيدَ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ يَزِيدَ أَبِي خَالِدٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَوَّلُ مَنْ تَنْشَقُّ عَنْهُ الأَرْضُ فَأُكْسَى الْحُلَّةَ مِنْ حُلَلِ الْجَنَّةِ ثُمَّ أَقُومُ عَنْ يَمِينِ الْعَرْشِ لَيْسَ أَحَدٌ مِنَ الْخَلاَئِقِ يَقُومُ ذَلِكَ الْمَقَامَ غَيْرِي ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3611}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah [may Allah be pleased with him]:that the Messenger of Allah (ﷺ) said: "I am the first for whom the earth will be split, and then I will be adorned with garments from the garments of Paradise. Then I will stand at the right of the Throne. No one from the creation will in that place other than I}}
\hadithdefcmd{tirmidhi}{3612}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ لَيْثٍ، وَهُوَ ابْنُ أَبِي سُلَيْمٍ حَدَّثَنِي كَعْبٌ، حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَلُوا اللَّهَ لِيَ الْوَسِيلَةَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا الْوَسِيلَةُ قَالَ ‏"‏ أَعْلَى دَرَجَةٍ فِي الْجَنَّةِ لاَ يَنَالُهَا إِلاَّ رَجُلٌ وَاحِدٌ أَرْجُو أَنْ أَكُونَ أَنَا هُوَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ إِسْنَادُهُ لَيْسَ بِالْقَوِيِّ ‏.‏ وَكَعْبٌ لَيْسَ هُوَ بِمَعْرُوفٍ وَلاَ نَعْلَمُ أَحَدًا رَوَى عَنْهُ غَيْرَ لَيْثِ بْنِ أَبِي سُلَيْمٍ ‏.‏\hadithno{3612}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Ask Allah to grant me Al-Wasilah." They said: "O Messenger of Allah! And what is Al-Wasilah?" He said: "The highest level of Paradise. No one will attain it except for one man, and I hope that I am him}}
\hadithdefcmd{tirmidhi}{3613}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الطُّفَيْلِ بْنِ أُبَىِّ بْنِ كَعْبٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَثَلِي فِي النَّبِيِّينَ كَمَثَلِ رَجُلٍ بَنَى دَارًا فَأَحْسَنَهَا وَأَكْمَلَهَا وَأَجْمَلَهَا وَتَرَكَ مِنْهَا مَوْضِعَ لَبِنَةٍ فَجَعَلَ النَّاسُ يَطُوفُونَ بِالْبِنَاءِ وَيَعْجَبُونَ مِنْهُ وَيَقُولُونَ لَوْ تَمَّ مَوْضِعُ تِلْكَ اللَّبِنَةِ وَأَنَا فِي النَّبِيِّينَ مَوْضِعُ تِلْكَ اللَّبِنَةِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا كَانَ يَوْمُ الْقِيَامَةِ كُنْتُ إِمَامَ النَّبِيِّينَ وَخَطِيبَهُمْ وَصَاحِبَ شَفَاعَتِهِمْ غَيْرُ فَخْرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3613}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated At-Tufail bin Ubayy bin Ka'b:from his father that the Messenger of Allah (ﷺ) said: "The parable of me and the Prophets is that of a man who built a house, and he built it well, completing it, and beautifying it, but he left a space for one brick. So the people began going around the house amazed at it, saying "If only the space for that brick was filled.' And I am, with regards to the Prophets, in the position of that brick." And with this chain, from the Prophet (ﷺ) that he said: "Upon the Day of Judgement I will be the leader of the Prophets and their spokesman, and the bearer of their intercession, without bragging}}
\hadithdefcmd{tirmidhi}{3614}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ، أَخْبَرَنَا كَعْبُ بْنُ عَلْقَمَةَ، سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ جُبَيْرٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَمِعْتُمُ الْمُؤَذِّنَ فَقُولُوا مِثْلَ مَا يَقُولُ الْمُؤَذِّنُ ثُمَّ صَلُّوا عَلَىَّ فَإِنَّهُ مَنْ صَلَّى عَلَىَّ صَلاَةً صَلَّى اللَّهُ عَلَيْهِ بِهَا عَشْرًا ثُمَّ سَلُوا لِيَ الْوَسِيلَةَ فَإِنَّهَا مَنْزِلَةٌ فِي الْجَنَّةِ لاَ تَنْبَغِي إِلاَّ لِعَبْدٍ مِنْ عِبَادِ اللَّهِ وَأَرْجُو أَنْ أَكُونَ أَنَا هُوَ وَمَنْ سَأَلَ لِيَ الْوَسِيلَةَ حَلَّتْ عَلَيْهِ الشَّفَاعَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ مُحَمَّدٌ عَبْدُ الرَّحْمَنِ بْنُ جُبَيْرٍ هَذَا قُرَشِيٌّ مِصْرِيٌّ مَدَنِيٌّ وَعَبْدُ الرَّحْمَنِ بْنُ جُبَيْرِ بْنِ نُفَيْرٍ شَامِيٌّ ‏.‏\hadithno{3614}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Messenger of Allah (ﷺ) said: "If you hear the Muadh-dhin then say as he says. Then send Salat upon me, because whoever sends Salat upon me, Allah will send Salat upon him ten times due to it. Then ask Allah that He gives me Al-Wasilah, because it is a place in Paradise which is not for anyone except for a slave from the slaves of Allah, and I hope that I am him. And whoever asks that I have Al-Wasilah, then (my) intercession will be made lawful for him}}
\hadithdefcmd{tirmidhi}{3615}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُدْعَانَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا سَيِّدُ وَلَدِ آدَمَ يَوْمَ الْقِيَامَةِ وَلاَ فَخْرَ وَبِيَدِي لِوَاءُ الْحَمْدِ وَلاَ فَخْرَ وَمَا مِنْ نَبِيٍّ يَوْمَئِذٍ آدَمُ فَمَنْ سِوَاهُ إِلاَّ تَحْتَ لِوَائِي وَأَنَا أَوَّلُ مَنْ تَنْشَقُّ عَنْهُ الأَرْضُ وَلاَ فَخْرَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْحَدِيثِ قِصَّةٌ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ بِهَذَا الإِسْنَادِ عَنْ أَبِي نَضْرَةَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3615}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed:that the Messenger of Allah (ﷺ) said: "I am the master of the children of Adam on the Day of Judgement, and I am not boasting. The Banner of Praise will be in my hand, and I am not boasting. There will not be a Prophet on that day, not Adam nor anyone other than him, except that he will be under my banner. And I am the first one for whom the earth will be opened for, and I am not bragging}}
\hadithdefcmd{tirmidhi}{3616}{حَدَّثَنَا عَلِيُّ بْنُ نَصْرِ بْنِ عَلِيٍّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنْ سَلَمَةَ بْنِ وَهْرَامَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَلَسَ نَاسٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَنْتَظِرُونَهُ قَالَ فَخَرَجَ حَتَّى إِذَا دَنَا مِنْهُمْ سَمِعَهُمْ يَتَذَاكَرُونَ فَسَمِعَ حَدِيثَهُمْ فَقَالَ بَعْضُهُمْ عَجَبًا إِنَّ اللَّهَ عَزَّ وَجَلَّ اتَّخَذَ مِنْ خَلْقِهِ خَلِيلاً اتَّخَذَ إِبْرَاهِيمَ خَلِيلاً ‏.‏ وَقَالَ آخَرُ مَاذَا بِأَعْجَبَ مِنْ كَلاَمِ مُوسَى كَلَّمَهُ تَكْلِيمًا وَقَالَ آخَرُ فَعِيسَى كَلِمَةُ اللَّهِ وَرُوحُهُ ‏.‏ وَقَالَ آخَرُ آدَمُ اصْطَفَاهُ اللَّهُ فَخَرَجَ عَلَيْهِمْ فَسَلَّمَ وَقَالَ ‏ "‏ قَدْ سَمِعْتُ كَلاَمَكُمْ وَعَجَبَكُمْ إِنَّ إِبْرَاهِيمَ خَلِيلُ اللَّهِ وَهُوَ كَذَلِكَ وَمُوسَى نَجِيُّ اللَّهِ وَهُوَ كَذَلِكَ وَعِيسَى رُوحُ اللَّهِ وَكَلِمَتُهُ وَهُوَ كَذَلِكَ وَآدَمُ اصْطَفَاهُ اللَّهُ وَهُوَ كَذَلِكَ أَلاَ وَأَنَا حَبِيبُ اللَّهِ وَلاَ فَخْرَ وَأَنَا حَامِلُ لِوَاءِ الْحَمْدِ يَوْمَ الْقِيَامَةِ وَلاَ فَخْرَ وَأَنَا أَوَّلُ شَافِعٍ وَأَوَّلُ مُشَفَّعٍ يَوْمَ الْقِيَامَةِ وَلاَ فَخْرَ وَأَنَا أَوَّلُ مَنْ يُحَرِّكُ حِلَقَ الْجَنَّةِ فَيَفْتَحُ اللَّهُ لِيَ فَيُدْخِلُنِيهَا وَمَعِي فُقَرَاءُ الْمُؤْمِنِينَ وَلاَ فَخْرَ وَأَنَا أَكْرَمُ الأَوَّلِينَ وَالآخِرِينَ وَلاَ فَخْرَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{3616}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:that a group of people from the Companions of the Messenger of Allah (ﷺ) sat waiting for him. He said: "Then he came out, such that when he came close to them, he heard them talking, and he heard what they were saying. So some of them said: 'It's amazing that Allah, the Mighty and Sublime, has taken a Khalil (close friend) from His creation. He took Ibrahim as a Khalil.' And some of them said: 'That is not more amazing than speaking to Musa, He spoke to him with real speech.' And some said: 'And 'Eisa is the word of Allah and His Spirit.' And some said: 'Adam was chosen by Allah.' So he (ﷺ) came out upon them and said his Salam, and said: 'I have heard your words, and your amazement that Ibrahim is the Khalil of Allah, and he is such, and that Musa is the one spoken to by Allah, and he is such, and that 'Eisa is the spirit of Allah and His Word, and he is such, and that Adam was chosen by Allah, and he is such. Indeed I am the beloved of Allah and I am not boasting, and I am the carrier of the Banner of Praise on the Day of Judgement, and I am not boasting. And I am the first intercessor, and the first to have intercession accepted from him on the Day of Judgement, and I am not boasting. And I am the first to shake the rings of Paradise (meaning on the gates of Paradise) and so Allah will open it for me and admit me into it. And with me will be the poor people from the believers, and I am not boasting. And I am the most noble among the first ones and the last ones, and I am not boasting}}
\hadithdefcmd{tirmidhi}{3617}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ الْبَصْرِيُّ، حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ حَدَّثَنِي أَبُو مَوْدُودٍ الْمَدَنِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ الضَّحَّاكِ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ مَكْتُوبٌ فِي التَّوْرَاةِ صِفَةُ مُحَمَّدٍ وَعِيسَى ابْنِ مَرْيَمَ يُدْفَنُ مَعَهُ ‏.‏ قَالَ فَقَالَ أَبُو مَوْدُودٍ وَقَدْ بَقِيَ فِي الْبَيْتِ مَوْضِعُ قَبْرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ هَكَذَا قَالَ عُثْمَانُ بْنُ الضَّحَّاكِ وَالْمَعْرُوفُ الضَّحَّاكُ بْنُ عُثْمَانَ الْمَدَنِيُّ ‏.‏\hadithno{3617}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah bin Salam:"The description of Muhammad is written in the Tawrah, [and the description that] 'Eisa will be buried next to him." (One of the narrators) Abu Mawdud said: "[And] there is a place for a grave left in the house}}
\hadithdefcmd{tirmidhi}{3618}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ الْبَصْرِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا كَانَ الْيَوْمُ الَّذِي دَخَلَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ أَضَاءَ مِنْهَا كُلُّ شَيْءٍ فَلَمَّا كَانَ الْيَوْمُ الَّذِي مَاتَ فِيهِ أَظْلَمَ مِنْهَا كُلُّ شَيْءٍ وَمَا نَفَضْنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم الأَيْدِي وَإِنَّا لَفِي دَفْنِهِ حَتَّى أَنْكَرْنَا قُلُوبَنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3618}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas bin Malik:"On the day in which the Messenger of Allah (ﷺ) entered Al-Madinah, everything in it was illuminated. Then, on the day in which he died, everything in it was dark. And we did not remove our hands from the Messenger of Allah (ﷺ), while we were burying him because our hearts felt so estranged}}
\hadithdefcmd{tirmidhi}{3619}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ الْعَبْدِيُّ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ مُحَمَّدَ بْنَ إِسْحَاقَ، يُحَدِّثُ عَنِ الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسِ بْنِ مَخْرَمَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ وُلِدْتُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم عَامَ الْفِيلِ ‏.‏ وَسَأَلَ عُثْمَانُ بْنُ عَفَّانَ قُبَاثَ بْنَ أَشْيَمَ أَخَا بَنِي يَعْمُرَ بْنِ لَيْثٍ أَأَنْتَ أَكْبَرُ أَمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَكْبَرُ مِنِّي وَأَنَا أَقْدَمُ مِنْهُ فِي الْمِيلاَدِ وُلِدَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ الْفِيلِ وَرَفَعَتْ بِي أُمِّي عَلَى الْمَوْضِعِ قَالَ وَرَأَيْتُ خَذْقَ الْفِيلِ أَخْضَرَ مُحِيلاً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ إِسْحَاقَ ‏.‏\hadithno{3619}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Muttalib bin 'Abdullah bin Qais bin Makhramah:from his father, from his grandfather, that he said: "I and the Messenger of Allah (ﷺ), were born in the Year of the Elephant" - he said: "And 'Uthman bin 'Affan asked Qubath bin Ashyam, the brother of Banu Ya'mar bin Laith - 'Are you greater (in age) or the Messenger of Allah (ﷺ)?'" He said: "The Messenger of Allah (ﷺ) is greater than me, but I have an earlier birthday." He said: "And I saw the defecation of the birds turning green}}
\hadithdefcmd{tirmidhi}{3620}{حَدَّثَنَا الْفَضْلُ بْنُ سَهْلٍ أَبُو الْعَبَّاسِ الأَعْرَجُ الْبَغْدَادِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ غَزْوَانَ أَبُو نُوحٍ، أَخْبَرَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، قَالَ خَرَجَ أَبُو طَالِبٍ إِلَى الشَّامِ وَخَرَجَ مَعَهُ النَّبِيُّ صلى الله عليه وسلم فِي أَشْيَاخٍ مِنْ قُرَيْشٍ فَلَمَّا أَشْرَفُوا عَلَى الرَّاهِبِ هَبَطُوا فَحَلُّوا رِحَالَهُمْ فَخَرَجَ إِلَيْهِمُ الرَّاهِبُ وَكَانُوا قَبْلَ ذَلِكَ يَمُرُّونَ بِهِ فَلاَ يَخْرُجُ إِلَيْهِمْ وَلاَ يَلْتَفِتُ ‏.‏ قَالَ فَهُمْ يَحُلُّونَ رِحَالَهُمْ فَجَعَلَ يَتَخَلَّلُهُمُ الرَّاهِبُ حَتَّى جَاءَ فَأَخَذَ بِيَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ هَذَا سَيِّدُ الْعَالَمِينَ هَذَا رَسُولُ رَبِّ الْعَالَمِينَ يَبْعَثُهُ اللَّهُ رَحْمَةً لِلْعَالَمِينَ ‏.‏ فَقَالَ لَهُ أَشْيَاخٌ مِنْ قُرَيْشٍ مَا عِلْمُكَ فَقَالَ إِنَّكُمْ حِينَ أَشْرَفْتُمْ مِنَ الْعَقَبَةِ لَمْ يَبْقَ شَجَرٌ وَلاَ حَجَرٌ إِلاَّ خَرَّ سَاجِدًا وَلاَ يَسْجُدَانِ إِلاَّ لِنَبِيٍّ وَإِنِّي أَعْرِفُهُ بِخَاتَمِ النُّبُوَّةِ أَسْفَلَ مِنْ غُضْرُوفِ كَتِفِهِ مِثْلَ التُّفَّاحَةِ ‏.‏ ثُمَّ رَجَعَ فَصَنَعَ لَهُمْ طَعَامًا فَلَمَّا أَتَاهُمْ بِهِ وَكَانَ هُوَ فِي رِعْيَةِ الإِبِلِ قَالَ أَرْسِلُوا إِلَيْهِ فَأَقْبَلَ وَعَلَيْهِ غَمَامَةٌ تُظِلُّهُ فَلَمَّا دَنَا مِنَ الْقَوْمِ وَجَدَهُمْ قَدْ سَبَقُوهُ إِلَى فَىْءِ الشَّجَرَةِ فَلَمَّا جَلَسَ مَالَ فَىْءُ الشَّجَرَةِ عَلَيْهِ فَقَالَ انْظُرُوا إِلَى فَىْءِ الشَّجَرَةِ مَالَ عَلَيْهِ ‏.‏ قَالَ فَبَيْنَمَا هُوَ قَائِمٌ عَلَيْهِمْ وَهُوَ يُنَاشِدُهُمْ أَنْ لاَ يَذْهَبُوا بِهِ إِلَى الرُّومِ فَإِنَّ الرُّومَ إِذَا رَأَوْهُ عَرَفُوهُ بِالصِّفَةِ فَيَقْتُلُونَهُ فَالْتَفَتَ فَإِذَا بِسَبْعَةٍ قَدْ أَقْبَلُوا مِنَ الرُّومِ فَاسْتَقْبَلَهُمْ فَقَالَ مَا جَاءَ بِكُمْ قَالُوا جِئْنَا أَنَّ هَذَا النَّبِيَّ خَارِجٌ فِي هَذَا الشَّهْرِ فَلَمْ يَبْقَ طَرِيقٌ إِلاَّ بُعِثَ إِلَيْهِ بِأُنَاسٍ وَإِنَّا قَدْ أُخْبِرْنَا خَبَرَهُ بُعِثْنَا إِلَى طَرِيقِكَ هَذَا فَقَالَ هَلْ خَلْفَكُمْ أَحَدٌ هُوَ خَيْرٌ مِنْكُمْ قَالُوا إِنَّمَا أُخْبِرْنَا خَبَرَهُ بِطَرِيقِكَ هَذَا ‏.‏ قَالَ أَفَرَأَيْتُمْ أَمْرًا أَرَادَ اللَّهُ أَنْ يَقْضِيَهُ هَلْ يَسْتَطِيعُ أَحَدٌ مِنَ النَّاسِ رَدَّهُ قَالُوا لاَ ‏.‏ قَالَ فَبَايَعُوهُ وَأَقَامُوا مَعَهُ قَالَ أَنْشُدُكُمُ اللَّهَ أَيُّكُمْ وَلِيُّهُ قَالُوا أَبُو طَالِبٍ فَلَمْ يَزَلْ يُنَاشِدُهُ حَتَّى رَدَّهُ أَبُو طَالِبٍ وَبَعَثَ مَعَهُ أَبُو بَكْرٍ بِلاَلاً وَزَوَّدَهُ الرَّاهِبُ مِنَ الْكَعْكِ وَالزَّيْتِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3620}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Musa Al-Ash'ari:"Abu Talib departed to Ash-Sham, and the Prophet (ﷺ) left with him, along with some older men from the Quraish. When they came across the monk they stopped there and began setting up their camp, and the monk came out to them. Before that they used to pass by him and he wouldn't come out nor pay attention to them." He said: "They were setting up their camp when the monk was walking amidst them, until he came and took the hand of the Messenger of Allah (ﷺ). Then he said: 'This is the master of the men and jinn, this is the Messenger of the Lord of the worlds. Allah will raise him as a mercy to the men and jinn.' So some of the older people from the Quraish said: 'What do you know?' He said: 'When you people came along from the road, not a rock nor a tree was left, except that it prostrated, and they do not prostrate except for a Prophet. And I can recognize him by the seal of the Prophethood which is below his shoulder blade, like an apple.' Then he went back, and made them some food, and when he brought it to them, he [the Prophet (ﷺ)] was tending to the camels. So he said: 'Send for him.' So he came, and there was a cloud over him that was shading him. When he came close to the people, he found that they had beaten him to the tree's shade. So when he sat down, the shade of the tree leaned towards him. He (the monk) said: 'Look at the shade of the tree leaning towards him.'" He said: "So while he was standing over them, telling them not to take him to Rome with him - because if the Romans were to see him, they would recognize him by his description, and they would kill him - he turned, and there were seven people who had come from Rome. So he faced them and said: 'Why have you come?' They said: 'We came because this Prophet is going to appear during this month, and there isn't a road left except that people have been sent to it, and we have been informed of him, and we have been send to this road of yours.' So he said: 'Is there anyone better than you behind you?' They said: 'We only have news of him from this road of yours.' He said: 'Do you think that if there is a matter which Allah wishes to bring about, there is anyone among the people who can turn it away?' They said: 'No.'" He said: "So they gave him their pledge, and they stayed with him. And he said: 'I ask you by Allah, which of you is his guardian?' They said: 'Abu Talib.' So he kept adjuring him until Abu Talib returned him (back to Makkah) and he sent Abu Bakr and Bilal with him. And the monk gave him provisions of Ka'k (a type of bread) and olive oil}}
\hadithdefcmd{tirmidhi}{3621}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُنْزِلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ ابْنُ أَرْبَعِينَ فَأَقَامَ بِمَكَّةَ ثَلاَثَ عَشْرَةَ وَبِالْمَدِينَةِ عَشْرًا وَتُوُفِّيَ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3621}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) received Revelation when he was forty years old. So he stayed in Makkah for thirteen years and in Al-Madinah for ten. And he died when he was sixty-three years old}}
\hadithdefcmd{tirmidhi}{3622}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قُبِضَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ ابْنُ خَمْسٍ وَسِتِّينَ وَهَكَذَا حَدَّثَنَا هُوَ يَعْنِي ابْنَ بَشَّارٍ وَرَوَى عَنْهُ مُحَمَّدُ بْنُ إِسْمَاعِيلَ مِثْلَ ذَلِكَ ‏.‏\hadithno{3622}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) died when he was sixty-five years old}}
\hadithdefcmd{tirmidhi}{3623}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، وَحَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالطَّوِيلِ الْبَائِنِ وَلاَ بِالْقَصِيرِ الْمُتَرَدِّدِ وَلاَ بِالأَبْيَضِ الأَمْهَقِ وَلاَ بِالآدَمِ وَلَيْسَ بِالْجَعْدِ الْقَطَطِ وَلاَ بِالسَّبِطِ بَعَثَهُ اللَّهُ عَلَى رَأْسِ أَرْبَعِينَ سَنَةً فَأَقَامَ بِمَكَّةَ عَشْرَ سِنِينَ وَبِالْمَدِينَةِ عَشْرَ سِنِينَ وَتَوَفَّاهُ اللَّهُ عَلَى رَأْسِ سِتِّينَ سَنَةً وَلَيْسَ فِي رَأْسِهِ وَلِحْيَتِهِ عِشْرُونَ شَعْرَةً بَيْضَاءَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3623}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:"The Messenger of Allah (ﷺ) was not very tall nor was he [very] short, nor was he pale white, nor was he brown, nor was the wave of his hair completely curly nor straight. Allah sent him at the beginning of his forties and he stayed in Makkah for ten years, and in Al-Madinah for ten years. And Allah took him at the beginning of his sixties, and there were not more than twenty white hairs on his head or in his beard}}
\hadithdefcmd{tirmidhi}{3624}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ أَنْبَأَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ مُعَاذٍ الضَّبِّيُّ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ بِمَكَّةَ حَجَرًا كَانَ يُسَلِّمُ عَلَىَّ لَيَالِيَ بُعِثْتُ إِنِّي لأَعْرِفُهُ الآنَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3624}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Simak bin Harb:from Jabir bin Samurah, that the Messenger of Allah (ﷺ) said: "Indeed in Makkah there is a rock that used to give me Salam during the night of my advent, and I know it even now}}
\hadithdefcmd{tirmidhi}{3625}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي الْعَلاَءِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَتَدَاوَلُ مِنْ قَصْعَةٍ مِنْ غُدْوَةٍ حَتَّى اللَّيْلِ يَقُومُ عَشَرَةٌ وَيَقْعُدُ عَشَرَةٌ ‏.‏ قُلْنَا فَمَا كَانَتْ تُمَدُّ قَالَ مِنْ أَىِّ شَيْءٍ تَعْجَبُ مَا كَانَتْ تُمَدُّ إِلاَّ مِنْ هَا هُنَا وَأَشَارَ بِيَدِهِ إِلَى السَّمَاءِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو الْعَلاَءِ اسْمُهُ يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ ‏.‏\hadithno{3625}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Al-'Ala:from Samurah bin Jundab that he said: "We were with the Prophet (ﷺ) and we would take turns (eating) from a bowl from the morning till the evening. Ten would stand and ten would sit." We said: "So what was filling it up?' He said: "What are you amazed at? It wasn't filled up from anywhere but here, and he pointed with his hand towards the sky}}
\hadithdefcmd{tirmidhi}{3626}{حَدَّثَنَا عَبَّادُ بْنُ يَعْقُوبَ الْكُوفِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ أَبِي ثَوْرٍ، عَنِ السُّدِّيِّ، عَنْ عَبَّادِ بْنِ أَبِي يَزِيدَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِمَكَّةَ فَخَرَجْنَا فِي بَعْضِ نَوَاحِيهَا فَمَا اسْتَقْبَلَهُ جَبَلٌ وَلاَ شَجَرٌ إِلاَّ وَهُوَ يَقُولُ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَى غَيْرُ وَاحِدٍ عَنِ الْوَلِيدِ بْنِ أَبِي ثَوْرٍ وَقَالُوا عَنْ عَبَّادٍ أَبِي يَزِيدَ مِنْهُمْ فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ ‏.‏\hadithno{3626}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali bin Abi Talib:"I was with the Prophet (ﷺ) in Makkah. We departed to one of its suburbs, and no mountain or tree was before him, except that it said: 'Peace be upon you O Messenger of Allah}}
\hadithdefcmd{tirmidhi}{3627}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ إِلَى لِزْقِ جِذْعٍ وَاتَّخَذُوا لَهُ مِنْبَرًا فَخَطَبَ عَلَيْهِ فَحَنَّ الْجِذْعُ حَنِينَ النَّاقَةِ فَنَزَلَ النَّبِيُّ صلى الله عليه وسلم فَمَسَّهُ فَسَكَنَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أُبَىٍّ وَجَابِرٍ وَابْنِ عُمَرَ وَسَهْلِ بْنِ سَعْدٍ وَابْنِ عَبَّاسٍ وَأُمِّ سَلَمَةَ وَحَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3627}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas bin Malik:"The Messenger of Allah (ﷺ) used to give Khutbah next to a tree, and then they made a Minbar for him, so he gave Khutbahs on it, so the tree whimpered like a camel. So the Prophet (ﷺ) rubbed it, and it quieted}}
\hadithdefcmd{tirmidhi}{3628}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدٍ، حَدَّثَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ أَبِي ظَبْيَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ بِمَ أَعْرِفُ أَنَّكَ نَبِيٌّ قَالَ ‏"‏ إِنْ دَعَوْتُ هَذَا الْعِذْقَ مِنْ هَذِهِ النَّخْلَةِ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَدَعَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَنْزِلُ مِنَ النَّخْلَةِ حَتَّى سَقَطَ إِلَى النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ ارْجِعْ ‏"‏ ‏.‏ فَعَادَ فَأَسْلَمَ الأَعْرَابِيُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3628}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:"A Bedouin came to the Messenger of Allah (ﷺ) and said: 'How shall I know that you are a Prophet?' He said: 'If I were to call this date cluster from this palm tree, would you bear witness that I am the Messenger of Allah?' So the Messenger of Allah (ﷺ) called it and they started to fall from the tree, until they fell towards the Prophet (ﷺ), then he said: 'Go back,' and it went back. So the Bedouin accepted Islam}}
\hadithdefcmd{tirmidhi}{3629}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، بُنْدَارٌ حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ، حَدَّثَنَا عِلْبَاءُ بْنُ أَحْمَرَ، حَدَّثَنَا أَبُو زَيْدِ بْنُ أَخْطَبَ، قَالَ مَسَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ عَلَى وَجْهِي وَدَعَا لِي قَالَ عَزْرَةُ إِنَّهُ عَاشَ مِائَةً وَعِشْرِينَ سَنَةً وَلَيْسَ فِي رَأْسِهِ إِلاَّ شَعَرَاتٌ بِيضٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو زَيْدٍ اسْمُهُ عَمْرُو بْنُ أَخْطَبَ ‏.‏\hadithno{3629}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Zaid bin Akhtab:"The Messenger of Allah (ﷺ) wiped his hand over my face and supplicated for me." 'Azrah (one of the narrators) said: "Indeed he lived for one-hundred and twenty years, and there weren't upon his head except for a few small grey hairs}}
\hadithdefcmd{tirmidhi}{3630}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، قَالَ عَرَضْتُ عَلَى مَالِكِ بْنِ أَنَسٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ أَبُو طَلْحَةَ لأُمِّ سُلَيْمٍ لَقَدْ سَمِعْتُ صَوْتَ، رَسُولِ اللَّهِ صلى الله عليه وسلم - يَعْنِي ضَعِيفًا - أَعْرِفُ فِيهِ الْجُوعَ فَهَلْ عِنْدَكِ مِنْ شَيْءٍ فَقَالَتْ نَعَمْ ‏.‏ فَأَخْرَجَتْ أَقْرَاصًا مِنْ شَعِيرٍ ثُمَّ أَخْرَجَتْ خِمَارًا لَهَا فَلَفَّتِ الْخُبْزَ بِبَعْضِهِ ثُمَّ دَسَّتْهُ فِي يَدِي وَرَدَّتْنِي بِبَعْضِهِ ثُمَّ أَرْسَلَتْنِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَذَهَبْتُ بِهِ إِلَيْهِ فَوَجَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم جَالِسًا فِي الْمَسْجِدِ وَمَعَهُ النَّاسُ قَالَ فَقُمْتُ عَلَيْهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسَلَكَ أَبُو طَلْحَةَ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ بِطَعَامٍ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَنْ مَعَهُ ‏"‏ قُومُوا ‏"‏ ‏.‏ قَالَ فَانْطَلَقُوا فَانْطَلَقْتُ بَيْنَ أَيْدِيهِمْ حَتَّى جِئْتُ أَبَا طَلْحَةَ فَأَخْبَرْتُهُ فَقَالَ أَبُو طَلْحَةَ يَا أُمَّ سُلَيْمٍ قَدْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مَعَهُ وَلَيْسَ عِنْدَنَا مَا نُطْعِمُهُمْ ‏.‏ قَالَتْ أُمُّ سُلَيْمٍ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ فَانْطَلَقَ أَبُو طَلْحَةَ حَتَّى لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو طَلْحَةَ مَعَهُ حَتَّى دَخَلاَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلُمِّي يَا أُمَّ سُلَيْمٍ مَا عِنْدَكِ ‏"‏ ‏.‏ فَأَتَتْ بِذَلِكَ الْخُبْزِ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَفُتَّ وَعَصَرَتْ أُمُّ سُلَيْمٍ عُكَّةً لَهَا فَآدَمَتْهُ ثُمَّ قَالَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ أَنْ يَقُولَ ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏ ‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏ ‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا فَأَكَلَ الْقَوْمُ كُلُّهُمْ وَشَبِعُوا وَالْقَوْمُ سَبْعُونَ أَوْ ثَمَانُونَ رَجُلاً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3630}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:"Abu Talhah said to Umm Sulaim: 'I heard the voice of the Messenger of Allah (ﷺ) sounding weak and I sensed some hunger in it. Do you have anything? She said: 'Yes.' So she got some loaves of wheat bread, then she took out a Khimar of hers, and put the bread in it. Then she put it under my arm, and wrapped my upper body with part of it, and she sent me to the Messenger of Allah (ﷺ)." He said: "So I brought it to him, and I found the Messenger of Allah (ﷺ) sitting in the Masjid, and there were people with him. So I stood among them, and the Messenger of Allah (ﷺ) said: 'Has Abu Talhah sent you?' I said: 'Yes.' He said: 'With food?' I said: 'Yes.' So the Messenger of Allah (ﷺ) said to those with him: 'Stand up.'" So they left, and I left in front of them, until I came to Abu Talhah, and I told him (that they were coming). Abu Talhah said: 'O Umm Sulaim! The Messenger of Allah (ﷺ) is coming with people, and we don't have anything to feed them.' Umm Sulaim said: 'Allah and His Messenger know best.'" He said: "So Abu Talhah departed until he met up with the Messenger of Allah (ﷺ). The Messenger of Allah came, while Abu Talhah was with him, until they entered, when the Messenger of Allah (ﷺ) said: 'Come O Umm Sulaim! What do you have?' So she brought him that bread, and he (ﷺ) ordered that it be broken into pieces. Umm Sulaim poured some butter from an oil-skin upon them, then the Messenger of Allah (ﷺ) recited whatever Allah willed for him to say over it. Then he said: 'Let ten come.' So ten were admitted, and they ate until they were full, and then they left. Then he said: 'Let ten come.' So ten were admitted, and they ate until they were full, and they left. Then he said: 'Let ten come.' So ten were admitted, and they ate until they were full, and there were seventy or eighty men}}
\hadithdefcmd{tirmidhi}{3631}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَحَانَتْ صَلاَةُ الْعَصْرِ وَالْتَمَسَ النَّاسُ الْوَضُوءَ فَلَمْ يَجِدُوهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَضُوءٍ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ فِي ذَلِكَ الإِنَاءِ وَأَمَرَ النَّاسَ أَنْ يَتَوَضَّئُوا مِنْهُ ‏.‏ قَالَ فَرَأَيْتُ الْمَاءَ يَنْبُعُ مِنْ تَحْتِ أَصَابِعِهِ فَتَوَضَّأَ النَّاسُ حَتَّى تَوَضَّئُوا مِنْ عِنْدِ آخِرِهِمْ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَابْنِ مَسْعُودٍ وَجَابِرٍ وَزِيَادِ بْنِ الْحَارِثِ الصُّدَائِيِّ وَحَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3631}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:"I saw the Messenger of Allah (ﷺ) at the time when the 'Asr prayer had drawn near, and the people were searching for water for Wudu, bu they did not find any. So the Messenger of Allah (ﷺ) was brought some water for Wudu, and the Messenger of Allah (ﷺ) put his hand in the container and ordered that the people make Wudu from it." He said: "So I saw water springing out from under his fingers. The people performed Wudu until the last of them made Wudu}}
\hadithdefcmd{tirmidhi}{3632}{حَدَّثَنَا الأَنْصَارِيُّ، إِسْحَاقُ بْنُ مُوسَى حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنِي الزُّهْرِيُّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ أَوَّلُ مَا ابْتُدِئَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ النُّبُوَّةِ حِينَ أَرَادَ اللَّهُ كَرَامَتَهُ وَرَحْمَةَ الْعِبَادِ بِهِ أَنْ لاَ يَرَى شَيْئًا إِلاَّ جَاءَتْ مِثْلَ فَلَقِ الصُّبْحِ فَمَكَثَ عَلَى ذَلِكَ مَا شَاءَ اللَّهُ أَنْ يَمْكُثَ وَحُبِّبَ إِلَيْهِ الْخَلْوَةُ فَلَمْ يَكُنْ شَيْءٌ أَحَبَّ إِلَيْهِ مِنْ أَنْ يَخْلُوَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3632}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:"The first of what the Messenger of Allah (ﷺ) initiated with of Prophethood, when Allah wanted to honor him and grant His mercy upon His creatures, was that he would not see anything (in a dream) except that it would occur like the break of dawn. So he continued upon that for as long as Allah willed for him to continue, and seclusion was made beloved to him, such that there was not anything more beloved to him than being alone}}
\hadithdefcmd{tirmidhi}{3633}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ إِنَّكُمْ تَعُدُّونَ الآيَاتِ عَذَابًا وَإِنَّا كُنَّا نَعُدُّهَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم بَرَكَةً لَقَدْ كُنَّا نَأْكُلُ الطَّعَامَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَنَحْنُ نَسْمَعُ تَسْبِيحَ الطَّعَامِ ‏.‏ قَالَ وَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِإِنَاءٍ فَوَضَعَ يَدَهُ فِيهِ فَجَعَلَ الْمَاءُ يَنْبُعُ مِنْ بَيْنِ أَصَابِعِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ حَىَّ عَلَى الْوَضُوءِ الْمُبَارَكِ وَالْبَرَكَةِ مِنَ السَّمَاءِ ‏"‏ ‏.‏ حَتَّى تَوَضَّأْنَا كُلُّنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3633}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Abdullah:"You consider the signs to be punishment, whereas we used to think of them as a blessing during the time of the Messenger of Allah (ﷺ). We used to eat food with the Prophet (ﷺ) and we would hear the food's Tasbih." He said: "And the Prophet (ﷺ) was brought a container, so he put his hand it in, and the water began to spring from between his fingers. So the Prophet (ﷺ) said: 'Hasten to the blessed Wudu and the blessing from the heavens' until all of had performed Wudu}}
\hadithdefcmd{tirmidhi}{3634}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ الْحَارِثَ بْنَ هِشَامٍ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم كَيْفَ يَأْتِيكَ الْوَحْىُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحْيَانًا يَأْتِينِي فِي مِثْلِ صَلْصَلَةِ الْجَرَسِ وَهُوَ أَشَدُّ عَلَىَّ وَأَحْيَانًا يَتَمَثَّلُ لِي الْمَلَكُ رَجُلاً فَيُكَلِّمُنِي فَأَعِي مَا يَقُولُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْزِلُ عَلَيْهِ الْوَحْىُ فِي الْيَوْمِ الشَّدِيدِ الْبَرْدِ فَيَفْصِمُ عَنْهُ وَإِنَّ جَبِينَهُ لَيَتَفَصَّدُ عَرَقًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3634}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:that Al-Harith bin Hisham asked the Prophet (ﷺ): 'How does the Revelation come to you?' The Messenger of Allah (ﷺ) said: 'Sometimes it comes to me like the ringing of a bell and that is the hardest upon me, and sometimes the angel will appear to me like a man, and he will speak to me such that I understand what he says.'" 'Aishah said: "I saw the Messenger of Allah (ﷺ) while the Revelation was descending upon him on an extremely cold day. Then it ceased and his forehead was flooded with sweat}}
\hadithdefcmd{tirmidhi}{3635}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ مَا رَأَيْتُ مِنْ ذِي لِمَّةٍ فِي حُلَّةٍ حَمْرَاءَ أَحْسَنَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَهُ شَعْرٌ يَضْرِبُ مَنْكِبَيْهِ بَعِيدٌ مَا بَيْنَ الْمَنْكِبَيْنِ لَمْ يَكُنْ بِالْقَصِيرِ وَلاَ بِالطَّوِيلِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3635}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Bara:"I have not seen anyone with hair past his shoulders in a red Hullah more handsome than the Messenger of Allah (ﷺ). He had hair that would flow on his shoulders, having broad shoulders, not too short and not too tall}}
\hadithdefcmd{tirmidhi}{3636}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَأَلَ رَجُلٌ الْبَرَاءَ أَكَانَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَ السَّيْفِ قَالَ لاَ مِثْلَ الْقَمَرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3636}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Abu Ishaq:"A man asked Al-Bara: 'Was the face of the Messenger of Allah (ﷺ) like a sword?' He said: 'No, like the moon}}
\hadithdefcmd{tirmidhi}{3637}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ عُثْمَانَ بْنِ مُسْلِمِ بْنِ هُرْمُزَ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ عَلِيٍّ، قَالَ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالطَّوِيلِ وَلاَ بِالْقَصِيرِ شَثْنَ الْكَفَّيْنِ وَالْقَدَمَيْنِ ضَخْمَ الرَّأْسِ ضَخْمَ الْكَرَادِيسِ طَوِيلَ الْمَسْرُبَةِ إِذَا مَشَى تَكَفَّأَ تَكَفُّؤًا كَأَنَّمَا انْحَطَّ مِنْ صَبَبٍ لَمْ أَرَ قَبْلَهُ وَلاَ بَعْدَهُ مِثْلَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنِ الْمَسْعُودِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3637}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Ali:"The Prophet (ﷺ) was not tall nor was he short, his hands and feet were thick, his head was large, he was big-boned, he had a long Masrubah (the line of hair from the chest to the navel), and whenever he walked, he leaned forward as if he was going down a decline. I have not seen anyone before him nor after him that resembled him (ﷺ)}}
\hadithdefcmd{tirmidhi}{3638}{حَدَّثَنَا أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الْحُسَيْنِ بْنِ أَبِي حَلِيمَةَ مِنْ قَصْرِ الأَحْنَفِ وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ وَعَلِيُّ بْنُ حُجْرٍ الْمَعْنَى وَاحِدٌ قَالُوا حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ اللَّهِ، مَوْلَى غُفْرَةَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدٍ، مِنْ وَلَدِ عَلِيِّ بْنِ أَبِي طَالِبٍ قَالَ كَانَ عَلِيٌّ رضى الله عنه إِذَا وَصَفَ النَّبِيَّ صلى الله عليه وسلم قَالَ لَمْ يَكُنْ بِالطَّوِيلِ الْمُمَغَّطِ وَلاَ بِالْقَصِيرِ الْمُتَرَدِّدِ وَكَانَ رَبْعَةً مِنَ الْقَوْمِ وَلَمْ يَكُنْ بِالْجَعْدِ الْقَطَطِ وَلاَ بِالسَّبِطِ كَانَ جَعْدًا رَجِلاً وَلَمْ يَكُنْ بِالْمُطَهَّمِ وَلاَ بِالْمُكَلْثَمِ وَكَانَ فِي الْوَجْهِ تَدْوِيرٌ أَبْيَضُ مُشْرَبٌ أَدْعَجُ الْعَيْنَيْنِ أَهْدَبُ الأَشْفَارِ جَلِيلُ الْمُشَاشِ وَالْكَتِدِ أَجْرَدُ ذُو مَسْرُبَةٍ شَثْنُ الْكَفَّيْنِ وَالْقَدَمَيْنِ إِذَا مَشَى تَقَلَّعَ كَأَنَّمَا يَمْشِي فِي صَبَبٍ وَإِذَا الْتَفَتَ الْتَفَتَ مَعًا بَيْنَ كَتِفَيْهِ خَاتَمُ النُّبُوَّةِ وَهُوَ خَاتَمُ النَّبِيِّينَ أَجْوَدُ النَّاسِ كَفًّا وَأَشْرَحُهُمْ صَدْرًا وَأَصْدَقُ النَّاسِ لَهْجَةً وَأَلْيَنُهُمْ عَرِيكَةً وَأَكْرَمُهُمْ عِشْرَةً مَنْ رَآهُ بَدِيهَةً هَابَهُ وَمَنْ خَالَطَهُ مَعْرِفَةً أَحَبَّهُ يَقُولُ نَاعِتُهُ لَمْ أَرَ قَبْلَهُ وَلاَ بَعْدَهُ مِثْلَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏ قَالَ أَبُو جَعْفَرٍ سَمِعْتُ الأَصْمَعِيَّ يَقُولُ فِي تَفْسِيرِهِ صِفَةَ النَّبِيِّ صلى الله عليه وسلم الْمُمَغَّطِ الذَّاهِبُ طُولاً ‏.‏ وَسَمِعْتُ أَعْرَابِيًّا يَقُولُ تَمَغَّطَ فِي نَشَّابَةٍ أَىْ مَدَّهَا مَدًّا شَدِيدًا ‏.‏ وَأَمَّا الْمُتَرَدِّدُ فَالدَّاخِلُ بَعْضُهُ فِي بَعْضٍ قِصَرًا وَأَمَّا الْقَطَطُ فَالشَّدِيدُ الْجُعُودَةِ وَالرَّجِلُ الَّذِي فِي شَعَرِهِ حُجُونَةٌ قَلِيلاً وَأَمَّا الْمُطَهَّمُ فَالْبَادِنُ الْكَثِيرُ اللَّحْمِ وَأَمَّا الْمُكَلْثَمُ فَالْمُدَوَّرُ الْوَجْهِ ‏.‏ وَأَمَّا الْمُشْرَبُ فَهُوَ الَّذِي فِي بَيَاضِهِ حُمْرَةٌ وَالأَدْعَجُ الشَّدِيدُ سَوَادِ الْعَيْنِ وَالأَهْدَبُ الطَّوِيلُ الأَشْفَارِ وَالْكَتِدُ مُجْتَمَعُ الْكَتِفَيْنِ وَهُوَ الْكَاهِلُ وَالْمَسْرُبَةُ هُوَ الشَّعْرُ الدَّقِيقُ الَّذِي هُوَ كَأَنَّهُ قَضِيبٌ مِنَ الصَّدْرِ إِلَى السُّرَّةِ ‏.‏ وَالشَّثْنُ الْغَلِيظُ الأَصَابِعِ مِنَ الْكَفَّيْنِ وَالْقَدَمَيْنِ وَالتَّقَلُّعُ أَنْ يَمْشِيَ بِقُوَّةٍ وَالصَّبَبُ الْحُدُورُ يَقُولُ انْحَدَرْنَا فِي صَبُوبٍ وَصَبَبٍ وَقَوْلُهُ جَلِيلُ الْمُشَاشِ يُرِيدُ رُءُوسَ الْمَنَاكِبِ وَالْعَشِيرَةُ الصُّحْبَةُ وَالْعَشِيرُ الصَّاحِبُ وَالْبَدِيهَةُ الْمُفَاجَأَةُ يُقَالَ بَدَهْتُهُ بِأَمْرٍ أَىْ فَجَأْتُهُ ‏.‏\hadithno{3638}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibrahim bin Muhammad, one of the offspring of 'Ali bin Abi Talib:said: "When 'Ali [may Allah be pleased with him] described the Prophet (ﷺ) he would say: 'He was not extremely tall (Mummaghit), nor was he extremely short (Mutaraddid), and he was of medium height in relation to the people. The wave of his hair was not completely curly (Qatat), nor straight, but it was in between. He did not have a large head, nor a small head (Mukaltham), his face was round and a blended-white color (Mushrab), his eyes were dark black (Ad'aj), his eye-lashes were long (Ahdab). He was big-boned and broad shouldered (Al-Katad), his body hair was well-placed, and he had a Masrubah, his hands and feet were thick (Shathn). When he walked he walked briskly (Taqalla'), he leaned forward as if he was walking on a decline (Sabab). And if he turned his head, his body turned as well, between his two shoulders was the seal of Prophethood, and he was the seal of the Prophets. He was the most generous of people [in hand, and the most big-hearted of them] in breast. He was the most truthful of people in speech, the softest of them in nature, and the most noble of them in his relations ('Ishrah). Whoever saw him for the first time (Badihah) would fear him, and whoever got to know him, loved him. The one who tried to describe him would have to say: 'I have not seen before him or after him anyone who resembles him (ﷺ)}}
\hadithdefcmd{tirmidhi}{3639}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا حُمَيْدُ بْنُ الأَسْوَدِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْرُدُ سَرْدَكُمْ هَذَا وَلَكِنَّهُ كَانَ يَتَكَلَّمُ بِكَلاَمٍ بَيْنَهُ فَصْلٌ يَحْفَظُهُ مَنْ جَلَسَ إِلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الزُّهْرِيِّ وَقَدْ رَوَاهُ يُونُسُ بْنُ يَزِيدَ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{3639}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Urwah:that 'Aishah said: "The Messenger of Allah (ﷺ) did not speak quickly like you do now, rather he would speak so clearly, unmistakably, that those who sat with him would memorize it}}
\hadithdefcmd{tirmidhi}{3640}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُثَنَّى، عَنْ ثُمَامَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعِيدُ الْكَلِمَةَ ثَلاَثًا لِتُعْقَلَ عَنْهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ الْمُثَنَّى ‏.‏\hadithno{3640}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) would repeat a statement three times so that it could be understood}}
\hadithdefcmd{tirmidhi}{3641}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ الْمُغِيرَةِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ جَزْءٍ، قَالَ مَا رَأَيْتُ أَحَدًا أَكْثَرَ تَبَسُّمًا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3641}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Jaz:"I have not seen anyone who smiled more than the Messenger of Allah (ﷺ)}}
\hadithdefcmd{tirmidhi}{3642}{وَقَدْ رُوِيَ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ جَزْءٍ، مِثْلُ هَذَا ‏.‏ حَدَّثَنَا بِذَلِكَ، أَحْمَدُ بْنُ خَالِدٍ الْخَلاَّلُ حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ السَّيْلَحَانِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ جَزْءٍ، قَالَ مَا كَانَ ضَحِكُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ تَبَسُّمًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ لَيْثِ بْنِ سَعْدٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3642}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn Jaz:"The laughter of the Messenger of Allah (ﷺ) was not but smiling}}
\hadithdefcmd{tirmidhi}{3643}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنِ الْجَعْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، يَقُولُ ذَهَبَتْ بِي خَالَتِي إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَ أُخْتِي وَجِعٌ فَمَسَحَ بِرَأْسِي وَدَعَا لِي بِالْبَرَكَةِ وَتَوَضَّأَ فَشَرِبْتُ مِنْ وَضُوئِهِ فَقُمْتُ خَلْفَ ظَهْرِهِ فَنَظَرْتُ إِلَى الْخَاتَمِ بَيْنَ كَتِفَيْهِ فَإِذَا هُوَ مِثْلُ زِرِّ الْحَجَلَةِ ‏.‏ قَالَ أَبُو عِيسَى الزِّرُّ يُقَالُ بَيْضٌ لَهَا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ سَلْمَانَ وَقُرَّةَ بْنِ إِيَاسٍ الْمُزَنِيِّ وَجَابِرِ بْنِ سَمُرَةَ وَأَبِي رِمْثَةَ وَبُرَيْدَةَ الأَسْلَمِيِّ وَعَبْدِ اللَّهِ بْنِ سَرْجِسَ وَعَمْرِو بْنِ أَخْطَبَ وَأَبِي سَعِيدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3643}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated As-Sa'ib bin Yazid:"My maternal aunt took me to the Prophet (ﷺ), and said: 'O Messenger of Allah! Indeed my nephew is in pain.' So he wiped over my head and supplicated for blessings for me. And he performed Wudu and I drank from the water of his Wudu. Then I stood behind his back, and I looked at the seal between his two shoulder blades, and it resembled the egg of a partridge}}
\hadithdefcmd{tirmidhi}{3644}{حَدَّثَنَا سَعِيدُ بْنُ يَعْقُوبَ الطَّالْقَانِيُّ، حَدَّثَنَا أَيُّوبُ بْنُ جَابِرٍ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ خَاتَمُ رَسُولِ اللَّهِ صلى الله عليه وسلم - يَعْنِي الَّذِي بَيْنَ كَتِفَيْهِ غُدَّةً حَمْرَاءَ مِثْلَ بَيْضَةِ الْحَمَامَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3644}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin Samurah:"The seal of the Messenger of Allah (ﷺ)" - meaning the one which was between his two shoulder blades - "was fleshy and red, resembling the egg of a pigeon}}
\hadithdefcmd{tirmidhi}{3645}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، أَخْبَرَنَا الْحَجَّاجُ، هُوَ ابْنُ أَرْطَاةَ عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ فِي سَاقَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم حُمُوشَةٌ وَكَانَ لاَ يَضْحَكُ إِلاَّ تَبَسُّمًا وَكُنْتُ إِذَا نَظَرْتُ إِلَيْهِ قُلْتُ أَكْحَلَ الْعَيْنَيْنِ وَلَيْسَ بِأَكْحَلَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3645}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin Samurah:"The two shins of the Messenger of Allah (ﷺ) were thin, and he would not laugh except as a smile, and whenever I looked at him I would say: "He put kohl on his eyes,' but he (ﷺ) did not use kohl}}
\hadithdefcmd{tirmidhi}{3646}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو قَطَنٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم ضَلِيعَ الْفَمِ أَشْكَلَ الْعَيْنَيْنِ مَنْهُوسَ الْعَقِبِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3646}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin Samurah:"The Messenger of Allah (ﷺ) had a wide mouth (Dali' Al-Fam), his eyes were Ashkal, and he had thin heals (Manhus Al-'Aqib)}}
\hadithdefcmd{tirmidhi}{3647}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم ضَلِيعَ الْفَمِ أَشْكَلَ الْعَيْنَيْنِ مَنْهُوشَ الْعَقِبِ ‏.‏ قَالَ شُعْبَةُ قُلْتُ لِسِمَاكٍ مَا ضَلِيعُ الْفَمِ قَالَ وَاسِعُ الْفَمِ ‏.‏ قُلْتُ مَا أَشْكَلُ الْعَيْنِ قَالَ طَوِيلُ شَقِّ الْعَيْنِ ‏.‏ قَالَ قُلْتُ مَا مَنْهُوشُ الْعَقِبِ قَالَ قَلِيلُ اللَّحْمِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3647}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin Samurah:"The Messenger of Allah (ﷺ) had a wide mouth (Dali' Al-Fam), his eyes were Ashkal, and he had thin heels (Manhus Al-'Aqib). Shu'bah (one of the narrators) said: "I said to Simak: 'What is "Dali' Al-Fam?"' He said: 'A wide mouth.' I said: 'What is "Ashkal Al-'Ainain?"' He said: 'Having long eyes.'" [He said:] "I said: 'What is "Manhus Al-'Aqib?"' He said: 'Little flesh}}
\hadithdefcmd{tirmidhi}{3648}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي يُونُسَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا رَأَيْتُ شَيْئًا أَحْسَنَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم كَأَنَّ الشَّمْسَ تَجْرِي فِي وَجْهِهِ وَمَا رَأَيْتُ أَحَدًا أَسْرَعَ فِي مَشْيِهِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم كَأَنَّمَا الأَرْضُ تُطْوَى لَهُ إِنَّا لَنُجْهِدُ أَنْفُسَنَا وَإِنَّهُ لَغَيْرُ مُكْتَرِثٍ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{3648}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:"I have not seen anything more beautiful than the Messenger of Allah (ﷺ). It was as if the sun flowed upon his face. And I have not seen anyone quicker in his walking than the Messenger of Allah (ﷺ). It was as if the earth was made easy for him. We would be exerting ourselves while he would not be struggling}}
\hadithdefcmd{tirmidhi}{3649}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُرِضَ عَلَىَّ الأَنْبِيَاءُ فَإِذَا مُوسَى ضَرْبٌ مِنَ الرِّجَالِ كَأَنَّهُ مِنْ رِجَالِ شَنُوءَةَ وَرَأَيْتُ عِيسَى ابْنَ مَرْيَمَ فَإِذَا أَقْرَبُ النَّاسِ مَنْ رَأَيْتُ بِهِ شَبَهًا عُرْوَةُ بْنُ مَسْعُودٍ وَرَأَيْتُ إِبْرَاهِيمَ فَإِذَا أَقْرَبُ مَنْ رَأَيْتُ بِهِ شَبَهًا صَاحِبُكُمْ نَفْسَهُ وَرَأَيْتُ جِبْرِيلَ فَإِذَا أَقْرَبُ مَنْ رَأَيْتُ بِهِ شَبَهًا دِحْيَةُ ‏"‏ ‏.‏ هُوَ ابْنُ خَلِيفَةَ الْكَلْبِيُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3649}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir:that the Messenger of Allah (ﷺ) said: "The Prophets were presented to me, and Musa was a thin man, it was as if he was from the men of Shanu'ah. And I saw 'Eisa bin Mariam, and the closest of the people in resemblance to him. from those I have seen, is 'Urwah bin Mas'ud. And I saw Ibrahim, and the closest of the people in resemblance to him, from those I have seen, is your companion" - meaning himself - "And I saw Jibril, and the closest of the people in resemblance to him, from those I have seen, is Dihyah." [And he is Ibn Khalifah Al-Kalbi]}}
\hadithdefcmd{tirmidhi}{3650}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ خَالِدٍ الْحَذَّاءِ، حَدَّثَنِي عَمَّارٌ، مَوْلَى بَنِي هَاشِمٍ قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ ابْنُ خَمْسٍ وَسِتِّينَ ‏.‏\hadithno{3650}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) died when he was sixty-five years old}}
\hadithdefcmd{tirmidhi}{3651}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ،قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ،قَالَ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ،قَالَ حَدَّثَنَا عَمَّارٌ، مَوْلَى بَنِي هَاشِمٍ قَالَ حَدَّثَنَا ابْنُ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تُوُفِّيَ وَهُوَ ابْنُ خَمْسٍ وَسِتِّينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنُ الإِسْنَادِ صَحِيحٌ ‏.‏\hadithno{3651}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) died when he was sixty-five years old}}
\hadithdefcmd{tirmidhi}{3652}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَكَثَ النَّبِيُّ صلى الله عليه وسلم بِمَكَّةَ ثَلاَثَ عَشْرَةَ - يَعْنِي يُوحَى إِلَيْهِ وَتُوُفِّيَ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَنَسِ بْنِ مَالِكٍ وَدَغْفَلِ بْنِ حَنْظَلَةَ وَلاَ يَصِحُّ لِدَغْفَلٍ سَمَاعٌ مِنَ النَّبِيِّ صلى الله عليه وسلم وَلاَ رُؤْيَةٌ ‏.‏ وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ عَمْرِو بْنِ دِينَارٍ ‏.‏\hadithno{3652}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) stayed in Makkah for thirteen years - meaning while he was receiving Revelation - and he died when he was sixty-three years old}}
\hadithdefcmd{tirmidhi}{3653}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّهُ قَالَ سَمِعْتُهُ يَخْطُبُ، يَقُولُ مَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ وَأَبُو بَكْرٍ وَعُمَرُ وَأَنَا ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3653}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir [bin 'Abdullah]:that he heard Mu'awiyah bin Abi Sufyan giving a Khutbah, saying: "The Messenger of Allah (ﷺ) died when he was sixty-three years old, and so did Abu Bakr and 'Umar, and I am sixty-three years old}}
\hadithdefcmd{tirmidhi}{3654}{حَدَّثَنَا الْعَبَّاسُ الْعَنْبَرِيُّ وَالْحُسَيْنُ بْنُ مَهْدِيٍّ الْبَصْرِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أُخْبِرْتُ عَنِ ابْنِ شِهَابٍ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، وَقَالَ الْحُسَيْنُ بْنُ مَهْدِيٍّ، فِي حَدِيثِهِ ابْنُ جُرَيْجٍ عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَاتَ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ ابْنُ أَخِي الزُّهْرِيِّ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ مِثْلَ هَذَا ‏.‏\hadithno{3654}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah [may Allah be pleased with her]:"The Prophet (ﷺ) died when he was sixty-three years old}}
\hadithdefcmd{tirmidhi}{3655}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا الثَّوْرِيُّ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبْرَأُ إِلَى كُلِّ خَلِيلٍ مِنْ خِلِّهِ وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ ابْنَ أَبِي قُحَافَةَ خَلِيلاً وَإِنَّ صَاحِبَكُمْ خَلِيلُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَابْنِ الزُّبَيْرِ وَابْنِ عَبَّاسٍ ‏.‏\hadithno{3655}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated 'Abdullah:that the Messenger of Allah (ﷺ) said: "I free myself of the friendship of every Khalil, and if I were to take a Khalil then I would have taken Ibn Abi Quhafah as a Khalil. And indeed your companion is Allah's Khalil}}
\hadithdefcmd{tirmidhi}{3656}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ أَبُو بَكْرٍ سَيِّدُنَا وَخَيْرُنَا وَأَحَبُّنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3656}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Umar bin Al-Khattab:"Abu Bakr is our chief, and the best of us, and the most beloved of us to the Messenger of Allah (ﷺ)}}
\hadithdefcmd{tirmidhi}{3657}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ أَىُّ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ أَحَبَّ إِلَى رَسُولِ اللَّهِ قَالَتْ أَبُو بَكْرٍ ‏.‏ قُلْتُ ثُمَّ مَنْ قَالَتْ عُمَرُ ‏.‏ قُلْتُ ثُمَّ مَنْ قَالَتْ ثُمَّ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏.‏ قُلْتُ ثُمَّ مَنْ قَالَ فَسَكَتَتْ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3657}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin Shaqiq:"I said to 'Aishah: 'Which of the Companions of the Prophet (ﷺ) were the most beloved to the Messenger of Allah (ﷺ)?' She said: 'Abu Bakr.' I said: 'Then who?' She said: ''Umar.' I said: "Then who?' She said: 'Then Abu 'Ubaidah bin Al-Jarrah.'" He said: "I said: 'Then who?''" He said: "Then she was silent}}
\hadithdefcmd{tirmidhi}{3658}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ سَالِمِ بْنِ أَبِي حَفْصَةَ، وَالأَعْمَشِ، وَعَبْدِ اللَّهِ بْنِ صُهْبَانَ، وَابْنِ أَبِي لَيْلَى، وَكَثِيرٍ النَّوَّاءِ، كُلِّهِمْ عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَهْلَ الدَّرَجَاتِ الْعُلَى لَيَرَاهُمْ مَنْ تَحْتَهُمْ كَمَا تَرَوْنَ النَّجْمَ الطَّالِعَ فِي أُفُقِ السَّمَاءِ وَإِنَّ أَبَا بَكْرٍ وَعُمَرَ مِنْهُمْ وَأَنْعَمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ ‏.‏\hadithno{3658}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Sa'eed:that the Messenger of Allah (ﷺ) said: "Indeed the people of the higher levels, will be seen by those who are beneath them like the stars which appear far off in the sky. And indeed Abu Bakr and 'Umar are among them, and they have done well}}
\hadithdefcmd{tirmidhi}{3659}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنِ ابْنِ أَبِي الْمُعَلَّى، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ يَوْمًا فَقَالَ ‏"‏ إِنَّ رَجُلاً خَيَّرَهُ رَبُّهُ بَيْنَ أَنْ يَعِيشَ فِي الدُّنْيَا مَا شَاءَ أَنْ يَعِيشَ وَيَأْكُلَ فِي الدُّنْيَا مَا شَاءَ أَنْ يَأْكُلَ وَبَيْنَ لِقَاءِ رَبِّهِ فَاخْتَارَ لِقَاءَ رَبِّهِ ‏"‏ ‏.‏ قَالَ فَبَكَى أَبُو بَكْرٍ فَقَالَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم أَلاَ تَعْجَبُونَ مِنْ هَذَا الشَّيْخِ إِذْ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً صَالِحًا خَيَّرَهُ رَبُّهُ بَيْنَ الدُّنْيَا وَبَيْنَ لِقَاءِ رَبِّهِ فَاخْتَارَ لِقَاءَ رَبِّهِ ‏.‏ قَالَ فَكَانَ أَبُو بَكْرٍ أَعْلَمَهُمْ بِمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ أَبُو بَكْرٍ بَلْ نَفْدِيكَ بِآبَائِنَا وَأَمْوَالِنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنَ النَّاسِ أَحَدٌ أَمَنَّ إِلَيْنَا فِي صُحْبَتِهِ وَذَاتِ يَدِهِ مِنِ ابْنِ أَبِي قُحَافَةَ وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ ابْنَ أَبِي قُحَافَةَ خَلِيلاً وَلَكِنْ وُدٌّ وَإِخَاءُ إِيمَانٍ وُدٌّ وَإِخَاءُ إِيمَانٍ مَرَّتَيْنِ أَوْ ثَلاَثًا وَإِنَّ صَاحِبَكُمْ خَلِيلُ اللَّهِ ‏"‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَبِي عَوَانَةَ عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ بِإِسْنَادٍ غَيْرِ هَذَا ‏.‏ وَمَعْنَى قَوْلِهِ أَمَنَّ إِلَيْنَا يَعْنِي أَمَنَّ عَلَيْنَا ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3659}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Abi Mu'alla:from his father: "The Messenger of Allah (ﷺ) gave a Khutbah one day and said: 'Indeed there is a man whose Lord has given him the choice between living in this life as long as he wishes to live, and eating from this life as much as he wishes to eat, and between meeting his Lord.'" He said: "So Abu Bakr cried. The Companions of the Prophet (ﷺ) said: 'Are you not amazed at this old man, when the Messenger of Allah (ﷺ) mentioned a righteous man whose Lord gave him the choice between this life or meeting his Lord, and he chose meeting his Lord.'" He said: "But Abu Bakr was the most knowledgeable one of them regarding what the Messenger of Allah (ﷺ) had said. So Abu Bakr said: 'Rather we will ransom our fathers and wealth for you.' So the Messenger of Allah (ﷺ) said: 'There is no one among people more beneficial to us (Amanna Ilaina) in his companionship, or generous with his wealth than Ibn Abi Quhafah. And, if I were to take a Khalil, I would have taken Ibn Abi Quhafah as a Khalil. But rather love and the brotherhood of faith' - saying that two or three times - 'Indeed your companion is the Khalil of Allah}}
\hadithdefcmd{tirmidhi}{3660}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي النَّضْرِ، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَلَسَ عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ إِنَّ عَبْدًا خَيَّرَهُ اللَّهُ بَيْنَ أَنْ يُؤْتِيَهُ مِنْ زَهْرَةِ الدُّنْيَا مَا شَاءَ وَبَيْنَ مَا عِنْدَهُ فَاخْتَارَ مَا عِنْدَهُ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ فَدَيْنَاكَ يَا رَسُولَ اللَّهِ بِآبَائِنَا وَأُمَّهَاتِنَا ‏.‏ قَالَ فَعَجِبْنَا فَقَالَ النَّاسُ انْظُرُوا إِلَى هَذَا الشَّيْخِ يُخْبِرُ رَسُولُ اللَّهِ عَنْ عَبْدٍ خَيَّرَهُ اللَّهُ بَيْنَ أَنْ يُؤْتِيَهُ مِنْ زَهْرَةِ الدُّنْيَا مَا شَاءَ وَبَيْنَ مَا عِنْدَ اللَّهِ وَهُوَ يَقُولُ فَدَيْنَاكَ بِآبَائِنَا وَأُمَّهَاتِنَا ‏.‏ قَالَ فَكَانَ رَسُولُ اللَّهِ هُوَ الْمُخَيَّرَ وَكَانَ أَبُو بَكْرٍ هُوَ أَعْلَمَنَا بِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ أَمَنِّ النَّاسِ عَلَىَّ فِي صُحْبَتِهِ وَمَالِهِ أَبُو بَكْرٍ وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ خَلِيلاً وَلَكِنْ أُخُوَّةُ الإِسْلاَمِ لاَ تَبْقَيَنَّ فِي الْمَسْجِدِ خَوْخَةٌ إِلاَّ خَوْخَةُ أَبِي بَكْرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3660}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:"The Messenger of Allah (ﷺ) sat upon the Minbar and said: 'Indeed a worshiper has been given a choice by Allah, between Him giving him from the bounty of this life as much as he wishes, and between what is with Him. So he chose what is with Him.' So Abu Bakr said: 'We will ransom our fathers and mothers for you O Messenger of Allah!'" He said: "So we were amazed. Then the people said: 'Look at this old man. The Messenger of Allah (ﷺ) informs about a worshiper whom Allah gave the choice, between Him giving him from the bounty of this life as much as he wishes, and between that which is with Allah, and he says: 'We will ransom our fathers and mothers for you?' But the Messenger of Allah (ﷺ) was the one given the choice, and Abu Bakr was the most knowledgeable of it among them. So the Prophet (ﷺ) said: 'From those who were most beneficial to me among the people in their companionship and their wealth was Abu Bakr. And if I were to take a Khalil, I would would have taken Abu Bakr as a Khalil. But rather, the brotherhood of Islam. Let there not remain a door in the Masjid except the door of Abu Bakr}}
\hadithdefcmd{tirmidhi}{3661}{حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ الْكُوفِيُّ،قَالَ حَدَّثَنَا مَحْبُوبُ بْنُ مُحْرِزٍ الْقَوَارِيرِيُّ، عَنْ دَاوُدَ بْنِ يَزِيدَ الأَوْدِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا لأَحَدٍ عِنْدَنَا يَدٌ إِلاَّ وَقَدْ كَافَيْنَاهُ مَا خَلاَ أَبَا بَكْرٍ فَإِنَّ لَهُ عِنْدَنَا يَدًا يُكَافِئُهُ اللَّهُ بِهَا يَوْمَ الْقِيَامَةِ وَمَا نَفَعَنِي مَالُ أَحَدٍ قَطُّ مَا نَفَعَنِي مَالُ أَبِي بَكْرٍ وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ خَلِيلاً أَلاَ وَإِنَّ صَاحِبَكُمْ خَلِيلُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3661}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "There is no favor due upon us from anyone, except that we have repaid him, with the exception of Abu Bakr. Verily upon us, there is a favor due to him, which Allah will repay him on the Day of Judgement. No one's wealth has benefited me as Abu Bakr's wealth has benefited me. And if I were to take a Khalil, then I would have taken Abu Bakr as a Khalil, and indeed your companion is Allah's Khalil}}
\hadithdefcmd{tirmidhi}{3662}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيٍّ، وَهُوَ ابْنُ حِرَاشٍ عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْتَدُوا بِاللَّذَيْنِ مِنْ بَعْدِي أَبِي بَكْرٍ وَعُمَرَ ‏"‏ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَغَيْرُ وَاحِدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ نَحْوَهُ وَكَانَ سُفْيَانُ بْنُ عُيَيْنَةَ يُدَلِّسُ فِي هَذَا الْحَدِيثِ فَرُبَّمَا ذَكَرَهُ عَنْ زَائِدَةَ عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ وَرُبَّمَا لَمْ يَذْكُرْ فِيهِ عَنْ زَائِدَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَفِيهِ عَنِ ابْنِ مَسْعُودٍ ‏.‏ وَرَوَى سُفْيَانُ الثَّوْرِيُّ هَذَا الْحَدِيثَ عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ عَنْ مَوْلًى لِرِبْعِيٍّ عَنْ رِبْعِيٍّ عَنْ حُذَيْفَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ أَيْضًا عَنْ رِبْعِيٍّ عَنْ حُذَيْفَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ سَالِمٌ الأَنْعُمِيُّ كُوفِيٌّ عَنْ رِبْعِيِّ بْنِ حِرَاشَ عَنْ حُذَيْفَةَ\hadithno{3662}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Hudhaifah:that the Messenger of Allah (ﷺ) said: "Stick to the two after me, Abu Bakr and 'Umar}}
\hadithdefcmd{tirmidhi}{3663}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سَالِمٍ أَبِي الْعَلاَءِ الْمُرَادِيِّ، عَنْ عَمْرِو بْنِ هَرِمٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، رضى الله عنه قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنِّي لاَ أَدْرِي مَا بَقَائِي فِيكُمْ فَاقْتَدُوا بِاللَّذَيْنِ مِنْ بَعْدِي ‏"‏ ‏.‏ وَأَشَارَ إِلَى أَبِي بَكْرٍ وَعُمَرَ ‏.‏\hadithno{3663}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hudhaifah [may Allah be pleased with him]:"We were sitting with the Prophet (ﷺ) and he said: 'I do not know how long I will be with you, so stick to the two after me,' and he signaled towards Abu Bakr and 'Umar}}
\hadithdefcmd{tirmidhi}{3664}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ الْعَبْدِيُّ، عَنِ الأَوْزَاعِيِّ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي بَكْرٍ وَعُمَرَ ‏ "‏ هَذَانِ سَيِّدَا كُهُولِ أَهْلِ الْجَنَّةِ مِنَ الأَوَّلِينَ وَالآخِرِينَ إِلاَّ النَّبِيِّينَ وَالْمُرْسَلِينَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3664}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas:that the Messenger of Allah (ﷺ) said about Abu Bakr and 'Umar: "These two are the masters of the elder people among the inhabitants of Paradise. From the first ones and the last ones, not including the Prophets and the Messengers. But do not inform them O 'Ali}}
\hadithdefcmd{tirmidhi}{3665}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا الْوَلِيدُ بْنُ مُحَمَّدٍ الْمُوَقَّرِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ طَلَعَ أَبُو بَكْرٍ وَعُمَرُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَذَانِ سَيِّدَا كُهُولِ أَهْلِ الْجَنَّةِ مِنَ الأَوَّلِينَ وَالآخِرِينَ إِلاَّ النَّبِيِّينَ وَالْمُرْسَلِينَ يَا عَلِيُّ لاَ تُخْبِرْهُمَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْوَلِيدُ بْنُ مُحَمَّدٍ الْمُوَقَّرِيُّ يُضَعَّفُ فِي الْحَدِيثِ وَلَمْ يَسْمَعْ عَلِيُّ بْنُ الْحُسَيْنِ مِنْ عَلِيِّ بْنِ أَبِي طَالِبٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَلِيٍّ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ أَنَسٍ وَابْنِ عَبَّاسٍ ‏.‏\hadithno{3665}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali bin Abi Talib:"I was with the Messenger of Allah (ﷺ), and Abu Bakr and 'Umar came up (in discussion), so the Messenger of Allah (ﷺ) said: 'These two are the masters of the elder people among the inhabitants of Paradise. From the first ones and the last ones, not including the Prophets and the Messengers. But do not inform them O 'Ali}}
\hadithdefcmd{tirmidhi}{3666}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قَالَ ذَكَرَ دَاوُدُ عَنِ الشَّعْبِيِّ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَبُو بَكْرٍ وَعُمَرُ سَيِّدَا كُهُولِ أَهْلِ الْجَنَّةِ مِنَ الأَوَّلِينَ وَالآخِرِينَ مَا خَلاَ النَّبِيِّينَ وَالْمُرْسَلِينَ لاَ تُخْبِرْهُمَا يَا عَلِيُّ ‏"‏ ‏.‏\hadithno{3666}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:that the Prophet (ﷺ) said: "Abu Bakr and 'Umar are the masters of the elder people among the inhabitants of Paradise, from the first ones and the last ones, not including the Prophets and the Messengers. Do not inform them O 'Ali}}
\hadithdefcmd{tirmidhi}{3667}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ أَبُو بَكْرٍ أَلَسْتُ أَحَقَّ النَّاسِ بِهَا أَلَسْتُ أَوَّلَ مَنْ أَسْلَمَ أَلَسْتُ صَاحِبَ كَذَا أَلَسْتُ صَاحِبَ كَذَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ قَدْ رَوَاهُ بَعْضُهُمْ، عَنْ شُعْبَةَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، قَالَ قَالَ أَبُو بَكْرٍ وَهَذَا أَصَحُّ ‏.‏ حَدَّثَنَا بِذَلِكَ، مُحَمَّدُ بْنُ بَشَّارٍ قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، قَالَ قَالَ أَبُو بَكْرٍ فَذَكَرَ نَحْوَهُ بِمَعْنَاهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي سَعِيدٍ وَهَذَا أَصَحُّ ‏.‏\hadithno{3667}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:that Abu Bakr said: "Am I not the most deserving of it among the people, am I not the first to become Muslim, am I not the person of such and such, am I not the person of such and such}}
\hadithdefcmd{tirmidhi}{3668}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا الْحَكَمُ بْنُ عَطِيَّةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْرُجُ عَلَى أَصْحَابِهِ مِنَ الْمُهَاجِرِينَ وَالأَنْصَارِ وَهُمْ جُلُوسٌ فِيهِمْ أَبُو بَكْرٍ وَعُمَرُ فَلاَ يَرْفَعُ إِلَيْهِ أَحَدٌ مِنْهُمْ بَصَرَهُ إِلاَّ أَبُو بَكْرٍ وَعُمَرُ فَإِنَّهُمَا كَانَا يَنْظُرَانِ إِلَيْهِ وَيَنْظُرُ إِلَيْهِمَا وَيَتَبَسَّمَانِ إِلَيْهِ وَيَتَبَسَّمُ إِلَيْهِمَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْحَكَمِ بْنِ عَطِيَّةَ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُهُمْ فِي الْحَكَمِ بْنِ عَطِيَّةَ ‏.‏\hadithno{3668}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas:that the Messenger of Allah (ﷺ) used to go out to his Companions from The Muhajirin and the Ansar while they were sitting, and Abu Bakr and 'Umar would be with them. No one would lift their sight towards him except Abu Bakr and 'Umar, because they used to look at him, and he would look at them, and they would smile at him, and he would smile at them}}
\hadithdefcmd{tirmidhi}{3669}{حَدَّثَنَا عُمَرُ بْنُ إِسْمَاعِيلَ بْنِ مُجَالِدِ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ مَسْلَمَةَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ ذَاتَ يَوْمٍ وَدَخَلَ الْمَسْجِدَ وَأَبُو بَكْرٍ وَعُمَرُ أَحَدُهُمَا عَنْ يَمِينِهِ وَالآخَرُ عَنْ شِمَالِهِ وَهُوَ آخِذٌ بِأَيْدِيهِمَا وَقَالَ ‏ "‏ هَكَذَا نُبْعَثُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏. قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ ‏ وَسَعِيدُ بْنُ مَسْلَمَةَ لَيْسَ عِنْدَهُمْ بِالْقَوِيِّ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ أَيْضًا مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{3669}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) departed one day and entered the Masjid, along with Abu Bakr and 'Umar. One was on his right and the other was on his left, and he was holding their hands, and he said: "This is how we will be resurrected on the Day of Judgement}}
\hadithdefcmd{tirmidhi}{3670}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى الْقَطَّانُ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، عَنْ مَنْصُورِ بْنِ أَبِي الأَسْوَدِ، قَالَ حَدَّثَنِي كَثِيرٌ أَبُو إِسْمَاعِيلَ، عَنْ جُمَيْعِ بْنِ عُمَيْرٍ التَّيْمِيِّ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأَبِي بَكْرٍ ‏ "‏ أَنْتَ صَاحِبِي عَلَى الْحَوْضِ وَصَاحِبِي فِي الْغَارِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3670}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said to Abu Bakr: "You are my companion at the Hawd, and my companion in the cave}}
\hadithdefcmd{tirmidhi}{3671}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ الْمُطَّلِبِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى أَبَا بَكْرٍ وَعُمَرَ فَقَالَ ‏ "‏ هَذَانِ السَّمْعُ وَالْبَصَرُ ‏"‏ ‏.‏وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَهَذَا حَدِيثٌ مُرْسَلٌ وَعَبْدُ اللَّهِ بْنُ حَنْطَبٍ لَمْ يُدْرِكِ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{3671}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Hantab:that the Prophet (ﷺ) saw Abu Bakr and 'Umar and said: "These two are the hearing and the seeing}}
\hadithdefcmd{tirmidhi}{3672}{حَدَّثَنَاإِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ مَقَامَكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ فَأْمُرْ عُمَرَ فَلْيُصَلِّ بِالنَّاسِ ‏.‏ قَالَتْ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ لِحَفْصَةَ قُولِي لَهُ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ مَقَامَكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ فَأْمُرْ عُمَرَ فَلْيُصَلِّ بِالنَّاسِ فَفَعَلَتْ حَفْصَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبُ يُوسُفَ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَقَالَتْ حَفْصَةُ لِعَائِشَةَ مَا كُنْتُ لأُصِيبَ مِنْكِ خَيْرًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي مُوسَى وَابْنِ عَبَّاسٍ وَسَالِمِ بْنِ عُبَيْدٍ وَعَبْدِ اللَّهِ بْنِ زَمْعَةَ ‏.‏\hadithno{3672}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:that the Prophet (ﷺ) said: "Order Abu Bakr to lead the people in Salat." 'Aishah said: "O Messenger of Allah! If Abu Bakr takes your place, the people will not be able to hear due to his crying, so order 'Umar to lead the people in Salat." She said: "So he said: 'Order Abu Bakr to lead the people in Salat.'" 'Aishah said: "So I said to Hafsah: 'Tell him that if Abu Bakr takes your place, then the people will not be able to hear due to his crying, so order 'Umar to lead the people in Salat.'" Upon this Hafsah did it. So the Messenger of Allah (ﷺ) said: "Indeed you are but like the companions of Yusuf! Order Abu Bakr to lead the people in Salat." So Hafsah said to 'Aishah: "I never received any good from you}}
\hadithdefcmd{tirmidhi}{3673}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ بَشِيرٍ، عَنْ عِيسَى بْنِ مَيْمُونٍ الأَنْصَارِيِّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْبَغِي لِقَوْمٍ فِيهِمْ أَبُو بَكْرٍ أَنْ يَؤُمَّهُمْ غَيْرُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3673}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah:that the Messenger of Allah (ﷺ) said: "It is not befitting that a group, among whom is Abu Bakr, be led by other than him}}
\hadithdefcmd{tirmidhi}{3674}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ نُودِيَ فِي الْجَنَّةِ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ بَابِ الصَّلاَةِ وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ بَابِ الْجِهَادِ وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ بَابِ الصَّدَقَةِ وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ بَابِ الرَّيَّانِ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ بِأَبِي أَنْتَ وَأُمِّي مَا عَلَى مَنْ دُعِيَ مِنْ هَذِهِ الأَبْوَابِ مِنْ ضَرُورَةٍ فَهَلْ يُدْعَى أَحَدٌ مِنْ تِلْكَ الأَبْوَابِ كُلِّهَا قَالَ ‏"‏ نَعَمْ وَأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3674}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever spends a pair of things in the path of Allah, he will be called in Paradise: 'O Worshiper of Allah, this is good.' And whoever is among the people of Salat, he will be called from the gate of Salat, and whoever was among from the people of Jihad, he will be called from the gate of Jihad. And whoever was among the people of charity, then he will be called from the gate of charity, and whoever was from the people of fasting, then he will be called from the gate of Ar-Rayyan." So Abu Bakr said: "May my father and mother be ransomed for you! The one who is called from these gates will be free of all worries. But will anyone be called from all of those gates?" He (ﷺ) said: "Yes, and I hope that you are among them}}
\hadithdefcmd{tirmidhi}{3675}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَتَصَدَّقَ فَوَافَقَ ذَلِكَ عِنْدِي مَالاً فَقُلْتُ الْيَوْمَ أَسْبِقُ أَبَا بَكْرٍ إِنْ سَبَقْتُهُ يَوْمًا قَالَ فَجِئْتُ بِنِصْفِ مَالِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَبْقَيْتَ لأَهْلِكَ ‏"‏ ‏.‏ قُلْتُ مِثْلَهُ وَأَتَى أَبُو بَكْرٍ بِكُلِّ مَا عِنْدَهُ فَقَالَ ‏"‏ يَا أَبَا بَكْرٍ مَا أَبْقَيْتَ لأَهْلِكَ ‏"‏ ‏.‏ قَالَ أَبْقَيْتُ لَهُمُ اللَّهَ وَرَسُولَهُ قُلْتُ وَاللَّهِ لاَ أَسْبِقُهُ إِلَى شَيْءٍ أَبَدًا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3675}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zaid bin Aslam:"I heard 'Umar bin Al-Khattab saying: 'We were ordered by the Messenger of Allah (ﷺ) to give in charity, and that coincided with a time in which I had some wealth, so I said, "Today I will beat Abu Bakr, if ever I beat him."' So I came with half of my wealth, and the Messenger of Allah (ﷺ) said: "What did you leave for your family?" I said: "The like of it." And Abu Bakr came with everything he had, so he said: "O Abu Bakr! What did you leave for your family?" He said: "I left Allah and His Messenger for them." I said: '[By Allah] I will never be able to beat him to something}}
\hadithdefcmd{tirmidhi}{3676}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، جُبَيْرِ بْنِ مُطْعِمٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَتْهُ امْرَأَةٌ فَكَلَّمَتْهُ فِي شَيْءٍ وَأَمَرَهَا بِأَمْرٍ فَقَالَتْ أَرَأَيْتَ يَا رَسُولَ اللَّهِ إِنْ لَمْ أَجِدْكَ قَالَ ‏ "‏ فَإِنْ لَمْ تَجِدِينِي فَأْتِ أَبَا بَكْرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3676}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jubair bin Mut'im:that a woman came to the Messenger of Allah (ﷺ) to speak to him about something. Then he ordered her with something, and she said: "What should I do O Messenger of Allah if I do not find you?" He said: "If you do not find me, then go to Abu Bakr}}
\hadithdefcmd{tirmidhi}{3677}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَيْنَا رَجُلٌ رَاكِبٌ بَقَرَةً إِذْ قَالَتْ لَمْ أُخْلَقْ لِهَذَا إِنَّمَا خُلِقْتُ لِلْحَرْثِ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ آمَنْتُ بِذَلِكَ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏ قَالَ أَبُو سَلَمَةَ وَمَا هُمَا فِي الْقَوْمِ يَوْمَئِذٍ وَاللَّهُ أَعْلَمُ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3677}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Salamah bin 'Abdur-Rahman:from Abu Hurairah, who said that the Messenger of Allah (ﷺ) said: "While a man was riding a cow it said: "I was not created for this, I was only created to till.'" So the Messenger of Allah (ﷺ) said: "I believe in that, myself, and Abu Bakr, 'Umar." Abu Salamah said: "And the two of them were not among the people that day [and Allah knows best]}}
\hadithdefcmd{tirmidhi}{3678}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُخْتَارِ، عَنْ إِسْحَاقَ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِسَدِّ الأَبْوَابِ إِلاَّ بَابَ أَبِي بَكْرٍ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏\hadithno{3678}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Aishah:that the Prophet (ﷺ) ordered the closing of all the gates, except for the gate of Abu Bakr. And there is a narration on this topic from Abu Sa'eed}}
\hadithdefcmd{tirmidhi}{3679}{حَدَّثَنَا الأَنْصَارِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ يَحْيَى بْنِ طَلْحَةَ، عَنْ عَمِّهِ إِسْحَاقَ بْنِ طَلْحَةَ عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ، دَخَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَنْتَ عَتِيقُ اللَّهِ مِنَ النَّارِ ‏"‏ ‏.‏ فَيَوْمَئِذٍ سُمِّيَ عَتِيقًا ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ مَعْنٍ وَقَالَ عَنْ مُوسَى بْنِ طَلْحَةَ عَنْ عَائِشَةَ ‏.‏\hadithno{3679}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:that Abu Bakr entered upon the Messenger of Allah (ﷺ), so he said: "You are Allah's 'Atiq from the Fire." From that day on he was called 'Atiq}}
\hadithdefcmd{tirmidhi}{3680}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا تَلِيدُ بْنُ سُلَيْمَانَ، عَنْ أَبِي الْجَحَّافِ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ نَبِيٍّ إِلاَّ لَهُ وَزِيرَانِ مِنْ أَهْلِ السَّمَاءِ وَوَزِيرَانِ مِنْ أَهْلِ الأَرْضِ فَأَمَّا وَزِيرَاىَ مِنْ أَهْلِ السَّمَاءِ فَجِبْرِيلُ وَمِيكَائِيلُ وَأَمَّا وَزِيرَاىَ مِنْ أَهْلِ الأَرْضِ فَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو الْجَحَّافِ اسْمُهُ دَاوُدُ بْنُ أَبِي عَوْفٍ ‏.‏ وَيُرْوَى عَنْ سُفْيَانَ الثَّوْرِيِّ ‏.‏ قَالَ حَدَّثَنَا أَبُو الْجَحَّافِ وَكَانَ مَرْضِيًّا وَتَلِيدُ بْنُ سُلَيْمَانَ يُكْنَى أَبَا إِدْرِيسَ وَهُوَ شِيعِيٌّ ‏.‏\hadithno{3680}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:that the Messenger of Allah (ﷺ) said: "There is no Prophet except that he has two ministers among the inhabitants of the heavens, and two ministers among the inhabitants of the earth. As for my two ministers from the inhabitants of the heavens, then they are Jibril and Mika'il, and as for my two ministers from the inhabitants of the earth, then they are Abu Bakr and 'Umar}}
\hadithdefcmd{tirmidhi}{3681}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا خَارِجَةُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ أَعِزَّ الإِسْلاَمَ بِأَحَبِّ هَذَيْنِ الرَّجُلَيْنِ إِلَيْكَ بِأَبِي جَهْلٍ أَوْ بِعُمَرَ بْنِ الْخَطَّابِ ‏"‏ ‏.‏ قَالَ وَكَانَ أَحَبَّهُمَا إِلَيْهِ عُمَرُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عُمَرَ ‏.‏\hadithno{3681}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "O Allah! Honor Islam through the most dear of these two men to you: Through Abu Jahl or through 'Umar bin Al-Khattab." He said: "And the most dear of them to Him was 'Umar}}
\hadithdefcmd{tirmidhi}{3682}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا خَارِجَةُ بْنُ عَبْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ جَعَلَ الْحَقَّ عَلَى لِسَانِ عُمَرَ وَقَلْبِهِ ‏"‏ ‏.‏ وَقَالَ ابْنُ عُمَرَ مَا نَزَلَ بِالنَّاسِ أَمْرٌ قَطُّ فَقَالُوا فِيهِ وَقَالَ فِيهِ عُمَرُ أَوْ قَالَ ابْنُ الْخَطَّابِ فِيهِ شَكَّ خَارِجَةُ إِلاَّ نَزَلَ فِيهِ الْقُرْآنُ عَلَى نَحْوِ مَا قَالَ عُمَرُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ الْفَضْلِ بْنِ الْعَبَّاسِ وَأَبِي ذَرٍّ وَأَبِي هُرَيْرَةَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَخَارِجَةُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ هُوَ ابْنُ سُلَيْمَانَ بْنِ زَيْدِ بْنِ ثَابِتِ وَهُوَ ثِقَةٌ ‏.‏\hadithno{3682}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Nafi':from Ibn 'Umar, that the Messenger of Allah (ﷺ) said: "Indeed Allah has put the truth upon the tongue and in the heart of 'Umar." He said: "And Ibn 'Umar said: 'No affair occurred among the people, except that they said something about it, and 'Umar said something about it'" or he said - "Ibn Al-Khattab" - Kharijah (one of the narrators) had a doubt about it - "except that the Qur'an was revealed in line with what 'Umar had said}}
\hadithdefcmd{tirmidhi}{3683}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنِ النَّضْرِ أَبِي عُمَرَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ أَعِزَّ الإِسْلاَمَ بِأَبِي جَهْلِ بْنِ هِشَامٍ أَوْ بِعُمَرَ ‏"‏ ‏.‏ قَالَ فَأَصْبَحَ فَغَدَا عُمَرُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَسْلَمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُهُمْ فِي النَّضْرِ أَبِي عُمَرَ وَهُوَ يَرْوِي مَنَاكِيرَ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{3683}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:that the Prophet (ﷺ) said: "O Allah honor Islam through Abu Jahl bin Hisham or through 'Umar bin Al-Khattab." He said: "So it happened that 'Umar came the next day to the Messenger of Allah (ﷺ) and accepted Islam}}
\hadithdefcmd{tirmidhi}{3684}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ الْوَاسِطِيُّ أَبُو مُحَمَّدٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ ابْنُ أَخِي مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ عُمَرُ لأَبِي بَكْرٍ يَا خَيْرَ النَّاسِ بَعْدَ رَسُولِ اللَّهِ ‏.‏ فَقَالَ أَبُو بَكْرٍ أَمَا إِنَّكَ إِنْ قُلْتَ ذَاكَ فَلَقَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا طَلَعَتِ الشَّمْسُ عَلَى رَجُلٍ خَيْرٍ مِنْ عُمَرَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ بِذَاكَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي الدَّرْدَاءِ ‏.‏\hadithno{3684}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin 'Abdullah:that 'Umar said to Abu Bakr: "O best of people after the Messenger of Allah (ﷺ)!" So Abu Bakr said: "If you say that, then I have heard the Messenger of Allah (ﷺ) say: 'The sun has not risen upon a man better than 'Umar}}
\hadithdefcmd{tirmidhi}{3685}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ مَا أَظُنُّ رَجُلاً يَنْتَقِصُ أَبَا بَكْرٍ وَعُمَرَ يُحِبُّ النَّبِيَّ صلى الله عليه وسلم ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3685}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muhammad bin Sirin:"I don't think that a man who degrades Abu Bakr and 'Umar loves the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{3686}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، قَالَ حَدَّثَنَا الْمُقْرِئُ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، عَنْ بَكْرِ بْنِ عَمْرٍو، عَنْ مِشْرَحِ بْنِ هَاعَانَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ بَعْدِي نَبِيٌّ لَكَانَ عُمَرَ بْنَ الْخَطَّابِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مِشْرَحِ بْنِ هَاعَانَ ‏.‏\hadithno{3686}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Uqbah bin 'Amir:that the Messenger of Allah (ﷺ) said: "If there was to have a Prophet after me, it would have been 'Umar bin Al-Khattab}}
\hadithdefcmd{tirmidhi}{3687}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ رَأَيْتُ كَأَنِّي أُتِيتُ بِقَدَحٍ مِنْ لَبَنٍ فَشَرِبْتُ مِنْهُ فَأَعْطَيْتُ فَضْلِي عُمَرَ بْنَ الْخَطَّابِ ‏"‏ ‏.‏ قَالُوا فَمَا أَوَّلْتَهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْعِلْمَ ‏"‏ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3687}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar:"The Messenger of Allah (ﷺ) said: 'I saw that I was brought a cup of milk, so I drank from it, and I gave my leftover to 'Umar bin Al-Khattab.' They said: 'So what did you interpret it as O Messenger of Allah?' He said: '(It is) Knowledge}}
\hadithdefcmd{tirmidhi}{3688}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ دَخَلْتُ الْجَنَّةَ فَإِذَا أَنَا بِقَصْرٍ مِنْ ذَهَبٍ فَقُلْتُ لِمَنْ هَذَا الْقَصْرُ قَالُوا لِشَابٍّ مِنْ قُرَيْشٍ فَظَنَنْتُ أَنِّي أَنَا هُوَ فَقُلْتُ وَمَنْ هُوَ فَقَالُوا عُمَرُ بْنُ الْخَطَّابِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3688}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas:that the Prophet (ﷺ) said: "I entered Paradise and it was as if I was in a palace of gold. So I said: 'Whose palace is this?' They said: 'A youth's, from the Quraish.' So I thought that I was him. I said: 'And who is he?' They said: "'Umar bin Al-Khattab}}
\hadithdefcmd{tirmidhi}{3689}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ أَبُو عَمَّارٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ حَدَّثَنِي أَبِي، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ حَدَّثَنِي أَبِي بُرَيْدَةُ، قَالَ أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَعَا بِلاَلاً فَقَالَ ‏"‏ يَا بِلاَلُ بِمَ سَبَقْتَنِي إِلَى الْجَنَّةِ مَا دَخَلْتُ الْجَنَّةَ قَطُّ إِلاَّ سَمِعْتُ خَشْخَشَتَكَ أَمَامِي دَخَلْتُ الْبَارِحَةَ الْجَنَّةَ فَسَمِعْتُ خَشْخَشَتَكَ أَمَامِي فَأَتَيْتُ عَلَى قَصْرٍ مُرَبَّعٍ مُشَرَّفٍ مِنْ ذَهَبٍ فَقُلْتُ لِمَنْ هَذَا الْقَصْرُ فَقَالُوا لِرَجُلٍ مِنَ الْعَرَبِ فَقُلْتُ أَنَا عَرَبِيٌّ لِمَنْ هَذَا الْقَصْرُ قَالُوا لِرَجُلٍ مِنْ قُرَيْشٍ قُلْتُ أَنَا قُرَشِيٌّ لِمَنْ هَذَا الْقَصْرُ قَالُوا لِرَجُلٍ مِنْ أُمَّةِ مُحَمَّدٍ قُلْتُ أَنَا مُحَمَّدٌ لِمَنْ هَذَا الْقَصْرُ قَالُوا لِعُمَرَ بْنِ الْخَطَّابِ ‏"‏ ‏.‏ فَقَالَ بِلاَلٌ يَا رَسُولَ اللَّهِ مَا أَذَّنْتُ قَطُّ إِلاَّ صَلَّيْتُ رَكْعَتَيْنِ وَمَا أَصَابَنِي حَدَثٌ قَطُّ إِلاَّ تَوَضَّأْتُ عِنْدَهَا وَرَأَيْتُ أَنَّ لِلَّهِ عَلَىَّ رَكْعَتَيْنِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بِهِمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جَابِرٍ وَمُعَاذٍ وَأَنَسٍ وَأَبِي هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ رَأَيْتُ فِي الْجَنَّةِ قَصْرًا مِنْ ذَهَبٍ فَقُلْتُ لِمَنْ هَذَا فَقِيلَ لِعُمَرَ بْنِ الْخَطَّابِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ أَنِّي دَخَلْتُ الْبَارِحَةَ الْجَنَّةَ يَعْنِي رَأَيْتُ فِي الْمَنَامِ كَأَنِّي دَخَلْتُ الْجَنَّةَ هَكَذَا رُوِيَ فِي بَعْضِ الْحَدِيثِ ‏.‏ وَيُرْوَى عَنِ ابْنِ عَبَّاسٍ أَنَّهُ قَالَ رُؤْيَا الأَنْبِيَاءِ وَحْىٌ ‏.‏\hadithno{3689}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Buraidah:"The Messenger of Allah (ﷺ) awoke in the morning and called for Bilal, then said: 'O Bilal! By what have you preceded me to Paradise? I have not entered Paradise at all, except that I heard your footsteps before me. I entered Paradise last night, and I heard your footsteps before me, and I came upon a square palace having balconies made of gold. So I said: 'Whose palace is this?' They said: 'A man among the Arabs.' So I said: 'I am an Arab, whose palace is this?' They said: 'A man among the Quraish.' So I said: 'I am from the Quraish, whose palace is this?' They said: 'A man from the Ummah of Muhammad (ﷺ).' So I said: 'I am Muhammad, whose palace is this?' They said: ''Umar bin Al-Khattab's.' So Bilal said: 'O Allah's Messenger! I have never called the Adhan except that I prayed two Rak'ah, and I never committed Hadath except that I performed Wudu upon that, and I considered that I owed Allah two Rak'ah.' So the Messenger of Allah (ﷺ) said: 'For those two}}
\hadithdefcmd{tirmidhi}{3690}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، حَدَّثَنِي أَبِي، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ سَمِعْتُ أَبِي بُرَيْدَةَ، يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ مَغَازِيهِ فَلَمَّا انْصَرَفَ جَاءَتْ جَارِيَةٌ سَوْدَاءُ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ نَذَرْتُ إِنْ رَدَّكَ اللَّهُ سَالِمًا أَنْ أَضْرِبَ بَيْنَ يَدَيْكَ بِالدُّفِّ وَأَتَغَنَّى ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ كُنْتِ نَذَرْتِ فَاضْرِبِي وَإِلاَّ فَلاَ ‏"‏ ‏.‏ فَجَعَلَتْ تَضْرِبُ فَدَخَلَ أَبُو بَكْرٍ وَهِيَ تَضْرِبُ ثُمَّ دَخَلَ عَلِيٌّ وَهِيَ تَضْرِبُ ثُمَّ دَخَلَ عُثْمَانُ وَهِيَ تَضْرِبُ ثُمَّ دَخَلَ عُمَرُ فَأَلْقَتِ الدُّفَّ تَحْتَ اسْتِهَا ثُمَّ قَعَدَتْ عَلَيْهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الشَّيْطَانَ لَيَخَافُ مِنْكَ يَا عُمَرُ إِنِّي كُنْتُ جَالِسًا وَهِيَ تَضْرِبُ فَدَخَلَ أَبُو بَكْرٍ وَهِيَ تَضْرِبُ ثُمَّ دَخَلَ عَلِيٌّ وَهِيَ تَضْرِبُ ثُمَّ دَخَلَ عُثْمَانُ وَهِيَ تَضْرِبُ فَلَمَّا دَخَلْتَ أَنْتَ يَا عُمَرُ أَلْقَتِ الدُّفَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ بُرَيْدَةَ وَفِي الْبَابِ عَنْ عُمَرَ وَسَعْدِ بْنِ أَبِي وَقَّاصٍ وَعَائِشَةَ ‏.‏\hadithno{3690}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraidah:"The Messenger of Allah (ﷺ) went out for one of his expeditions, then when he came back, a black slave girl came to him and said: 'O Messenger of Allah! I took an oath that if Allah returned you safely, I would beat the Duff before you and sing.' So the Messenger of Allah (ﷺ) said to her: 'If you have taken an oath, then beat it, and if you have not then do not.' So she started to beat the Duff, and Abu Bakr entered while she was beating it. Then 'Ali entered while she was beating it, then 'Uthman entered while she was beating it. Then 'Umar entered, so she put the Duff under her, and sat upon it. So the Messenger of Allah (ﷺ) said: 'Indeed Ash-Shaitan is afraid of you O 'Umar! I was sitting while she beat it, and then Abu Bakr entered while she was beating it, then 'Ali entered while she was beating it, then 'Uthman entered while she was beating it, then when you entered O 'Umar and she put away the Duff}}
\hadithdefcmd{tirmidhi}{3691}{حَدَّثَنَا الْحَسَنُ بْنُ صَبَّاحٍ الْبَزَّارُ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ خَارِجَةَ بْنِ عَبْدِ اللَّهِ ابْنِ سُلَيْمَانَ بْنِ زَيْدِ بْنِ ثَابِتٍ، قَالَ أَخْبَرَنَا يَزِيدُ بْنُ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسًا فَسَمِعْنَا لَغَطًا وَصَوْتَ صِبْيَانٍ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَإِذَا حَبَشِيَّةٌ تُزْفِنُ وَالصِّبْيَانُ حَوْلَهَا فَقَالَ ‏"‏ يَا عَائِشَةُ تَعَالَىْ فَانْظُرِي ‏"‏ ‏.‏ فَجِئْتُ فَوَضَعْتُ لَحْيَىَّ عَلَى مَنْكِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلْتُ أَنْظُرَ إِلَيْهَا مَا بَيْنَ الْمَنْكِبِ إِلَى رَأْسِهِ فَقَالَ لِي ‏"‏ أَمَا شَبِعْتِ أَمَا شَبِعْتِ ‏"‏ ‏.‏ قَالَتْ فَجَعَلْتُ أَقُولُ لاَ لأَنْظُرَ مَنْزِلَتِي عِنْدَهُ إِذْ طَلَعَ عُمَرُ قَالَ فَارْفَضَّ النَّاسُ عَنْهَا قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لأَنْظُرُ إِلَى شَيَاطِينِ الإِنْسِ وَالْجِنِّ قَدْ فَرُّوا مِنْ عُمَرَ ‏"‏ ‏.‏ قَالَتْ فَرَجَعْتُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3691}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:that the Messenger of Allah (ﷺ) was sitting and we heard a scream and the voices of children. So the Messenger of Allah (ﷺ) arose, and it was an Ethiopian woman, prancing around while the children played around her. So he said: 'O 'Aishah, come (and) see.' So I came, and I put my chin upon the shoulder of the Messenger of Allah (ﷺ) and I began to watch her from between his shoulder and his head, and he said to me: 'Have you had enough, have you had enough?'" She said: "So I kept saying: 'No,' to see my status with him. Then 'Umar appeared." She said: "So they dispersed." She said: "So the Messenger of Allah (ﷺ) said: 'Indeed I see the Shayatin among men and jinn have run from 'Umar.' She said: 'So I returned}}
\hadithdefcmd{tirmidhi}{3692}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ عُمَرَ الْعُمَرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَوَّلُ مَنْ تَنْشَقُّ عَنْهُ الأَرْضُ ثُمَّ أَبُو بَكْرٍ ثُمَّ عُمَرُ ثُمَّ آتِي أَهْلَ الْبَقِيعِ فَيُحْشَرُونَ مَعِي ثُمَّ أَنْتَظِرُ أَهْلَ مَكَّةَ حَتَّى أُحْشَرَ بَيْنَ الْحَرَمَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَعَاصِمُ بْنُ عُمَرَ الْعُمَرِيُّ لَيْسَ بِالْحَافِظِ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{3692}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "I am the first for whom the earth will split, then Abu Bakr, then 'Umar. Then the people of Al-Baqi; they will be gathered with me. Then I will await the people of Makkah until they are resurrected between the Two Sacred areas}}
\hadithdefcmd{tirmidhi}{3693}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ كَانَ يَكُونُ فِي الأُمَمِ مُحَدَّثُونَ فَإِنْ يَكُ فِي أُمَّتِي أَحَدٌ فَعُمَرُ بْنُ الْخَطَّابِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.وَ أَخْبَرَنِي بَعْضُ أَصْحَابِ سُفْيَانَ بْنِ عُيَيْنَةَ قَالَ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ مُحَدَّثُونَ يَعْنِي مُفَهَّمُونَ ‏.‏\hadithno{3693}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated 'Aishah:that the Messenger of Allah (ﷺ) said: "Among the nations, there used to be Muhaddathun (those who were given understanding), and if there were one in my nation, it would be 'Umar bin Al-Khattab}}
\hadithdefcmd{tirmidhi}{3694}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْقُدُّوسِ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، عَنْ عَبِيدَةَ السَّلْمَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ يَطْلُعُ عَلَيْكُمْ رَجُلٌ مِنْ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ فَاطَّلَعَ أَبُو بَكْرٍ ثُمَّ قَالَ ‏"‏ يَطْلُعُ عَلَيْكُمْ رَجُلٌ مِنْ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ فَاطَّلَعَ عُمَرُ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي مُوسَى وَجَابِرٍ ‏. هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ مَسْعُودٍ ‏.‏\hadithno{3694}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Mas'ud:that the Prophet (ﷺ) said: "A man among the inhabitants of Paradise will appear before you." So Abu Bakr appeared. Then he said: "A man among the inhabitants of Paradise will appear before you." So 'Umar appeared}}
\hadithdefcmd{tirmidhi}{3695}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، عَنْ شُعْبَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَرْعَى غَنَمًا لَهُ إِذْ جَاءَ ذِئْبٌ فَأَخَذَ شَاةً فَجَاءَ صَاحِبُهَا فَانْتَزَعَهَا مِنْهُ فَقَالَ الذِّئْبُ كَيْفَ تَصْنَعُ بِهَا يَوْمَ السَّبُعِ يَوْمَ لاَ رَاعِيَ لَهَا غَيْرِي ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَآمَنْتُ بِذَلِكَ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏ قَالَ أَبُو سَلَمَةَ وَمَا هُمَا فِي الْقَوْمِ يَوْمَئِذٍ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3695}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "While a man was tending some of his sheep, a wolf came and took a sheep. So its owner came and retrieved it. The wolf said: 'What will you do for it on the Day of the Predator, the Day when there will be no shepherd for it other than me?'" The Messenger of Allah (ﷺ) said: "So I believe in that, I and Abu Bakr, and 'Umar." (One of the narrators) Abu Salamah said: "And the two of them were (present) not among the people that day}}
\hadithdefcmd{tirmidhi}{3696}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَلَى حِرَاءَ هُوَ وَأَبُو بَكْرٍ وَعُمَرُ وَعَلِيٌّ وَعُثْمَانُ وَطَلْحَةُ وَالزُّبَيْرُ رضى الله عنهم فَتَحَرَّكَتِ الصَّخْرَةُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اهْدَأْ إِنَّمَا عَلَيْكَ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدٌ ‏"‏ ‏.‏وَفِي الْبَابِ عَنْ عُثْمَانَ وَسَعِيدِ بْنِ زَيْدٍ وَابْنِ عَبَّاسٍ وَسَهْلِ بْنِ سَعْدٍ وَأَنَسِ بْنِ مَالِكٍ وَبُرَيْدَةَ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{3696}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah [may Allah be pleased with him]:that the Messenger of Allah (ﷺ) was at Hira, him, Abu Bakr, 'Umar, 'Uthman, 'Ali, Talhah and Az-Zubair (may Allah be pleased with them all), and the boulder (mount Hira) shook. So the Prophet (ﷺ) said: "Be calm, for there is none upon you except a Prophet, or a Siddiq, or a martyr}}
\hadithdefcmd{tirmidhi}{3697}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسَ حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَعِدَ أُحُدًا وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ فَرَجَفَ بِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اثْبُتْ أُحُدُ فَإِنَّمَا عَلَيْكَ نَبِيٌّ وَصِدِّيقٌ وَشَهِيدَانِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3697}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas:that the Messenger of Allah (ﷺ), Abu Bakr, 'Umar, and 'Uthman climbed Uhud (mountain) and it shook them, so the Prophet of Allah (ﷺ) said: "Be firm O Uhud! For there is none upon you except a Prophet, a Siddiq, and two martyrs}}
\hadithdefcmd{tirmidhi}{3698}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنْ شَيْخٍ، مِنْ بَنِي زُهْرَةَ عَنِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي ذُبَابٍ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لِكُلِّ نَبِيٍّ رَفِيقٌ وَرَفِيقِي - يَعْنِي فِي الْجَنَّةِ عُثْمَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ وَهُوَ مُنْقَطِعٌ ‏.‏\hadithno{3698}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Talhah bin 'Ubaidullah:that the Messenger of Allah (ﷺ) said: "For every Prophet there is a friend (Rafiq), and my friend" - meaning in Paradise - "is 'Uthman}}
\hadithdefcmd{tirmidhi}{3699}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدٍ، هُوَ ابْنُ أَبِي أُنَيْسَةَ عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، قَالَ لَمَّا حُصِرَ عُثْمَانُ أَشْرَفَ عَلَيْهِمْ فَوْقَ دَارِهِ ثُمَّ قَالَ أُذَكِّرُكُمْ بِاللَّهِ هَلْ تَعْلَمُونَ أَنَّ حِرَاءَ حِينَ انْتَفَضَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اثْبُتْ حِرَاءُ فَلَيْسَ عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدٌ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ أُذَكِّرُكُمْ بِاللَّهِ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي جَيْشِ الْعُسْرَةِ ‏"‏ مَنْ يُنْفِقُ نَفَقَةً مُتَقَبَّلَةً ‏"‏ ‏.‏ وَالنَّاسُ مُجْهَدُونَ مُعْسِرُونَ فَجَهَّزْتُ ذَلِكَ الْجَيْشَ قَالُوا نَعَمْ ‏.‏ ثُمَّ قَالَ أُذَكِّرُكُمْ بِاللَّهِ هَلْ تَعْلَمُونَ أَنَّ بِئْرَ رُومَةَ لَمْ يَكُنْ يَشْرَبُ مِنْهَا أَحَدٌ إِلاَّ بِثَمَنٍ فَابْتَعْتُهَا فَجَعَلْتُهَا لِلْغَنِيِّ وَالْفَقِيرِ وَابْنِ السَّبِيلِ قَالُوا اللَّهُمَّ نَعَمْ وَأَشْيَاءُ عَدَّدَهَا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ عَنْ عُثْمَانَ ‏.‏\hadithno{3699}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu 'Abdur-Rahman As-Sulami:"When 'Uthman was besieged, he looked out over them from atop his house and said: 'I remind you by Allah. Do you know that when (mount) Hira shook, the Messenger of Allah (ﷺ) said: "Be firm O Hira! For there is none upon you except a Prophet, a Siddiq, and a martyr?"' They said: 'Yes.' He said: 'I remind you by Allah! Do you know that the Messenger of Allah (ﷺ) said, about the army of distress (Al-'Usrah): "Who will spend something which shall be accepted (by Allah)?" And the people were struggling during difficult times, so I prepared that army?' They said: 'Yes.' Then he said: 'I remind you by Allah. Do you know that no one drank from the well of Rumah but have to pay for it, then I bought it and made it for the rich, the poor, and the wayfarer?' They said: 'O Allah! Yes!'" And he listed other things. This Hadith is Hasan Sahih Gharib from this route; as a narration of Abu 'Abdur-Rahman As-Sulami from 'Uthman}}
\hadithdefcmd{tirmidhi}{3700}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا السَّكَنُ بْنُ الْمُغِيرَةِ، وَيُكْنَى أَبَا مُحَمَّدٍ، مَوْلًى لآلِ عُثْمَانَ قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ أَبِي هِشَامٍ، عَنْ فَرْقَدٍ أَبِي طَلْحَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ خَبَّابٍ، قَالَ شَهِدْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يَحُثُّ عَلَى جَيْشِ الْعُسْرَةِ فَقَامَ عُثْمَانُ بْنُ عَفَّانَ فَقَالَ يَا رَسُولَ اللَّهِ عَلَىَّ مِائَةُ بَعِيرٍ بِأَحْلاَسِهَا وَأَقْتَابِهَا فِي سَبِيلِ اللَّهِ ‏.‏ ثُمَّ حَضَّ عَلَى الْجَيْشِ فَقَامَ عُثْمَانُ بْنُ عَفَّانَ فَقَالَ يَا رَسُولَ اللَّهِ عَلَىَّ مِائَتَا بَعِيرٍ بِأَحْلاَسِهَا وَأَقْتَابِهَا فِي سَبِيلِ اللَّهِ ‏.‏ ثُمَّ حَضَّ عَلَى الْجَيْشِ فَقَامَ عُثْمَانُ بْنُ عَفَّانَ فَقَالَ يَا رَسُولَ اللَّهِ لِلَّهِ عَلَىَّ ثَلاَثُمِائَةِ بَعِيرٍ بِأَحْلاَسِهَا وَأَقْتَابِهَا فِي سَبِيلِ اللَّهِ ‏.‏ فَأَنَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْزِلُ عَنِ الْمِنْبَرِ وَهُوَ يَقُولُ ‏ "‏ مَا عَلَى عُثْمَانَ مَا عَمِلَ بَعْدَ هَذِهِ مَا عَلَى عُثْمَانَ مَا عَمِلَ بَعْدَ هَذِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ السَّكَنِ بْنِ الْمُغِيرَةِ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ ‏.‏\hadithno{3700}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdur-Rahman bin Khabbab:"I witnessed the Prophet (ﷺ) while he was exhorting support for the 'army of distress.' 'Uthman bin 'Affan stood and said: 'O Messenger of Allah! I will take the responsibility of one-hundred camels, including their saddles and water-skins, in the path of Allah.' Then he [(ﷺ) again] urged support for the army. So 'Uthman [bin 'Affan] stood and said: 'O Messenger of Allah! I will take the responsibility of two-hundred camels, including their saddles and water-skins, in the path of Allah.' Then he [(ﷺ) again] urged support for the army. So 'Uthman bin 'Affan stood and said: '[O Messenger of Allah] I will take the responsibility of three-hundred camels, including their saddles and water-skins, in the path of Allah.' So I saw the Messenger of Allah (ﷺ) descend from the Minbar while he was saying: 'It does not matter what 'Uthman does after this, it does not matter what 'Uthman does after this}}
\hadithdefcmd{tirmidhi}{3701}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ وَاقِعٍ الرَّمْلِيُّ، قَالَ حَدَّثَنَا ضَمْرَةُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ شَوْذَبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْقَاسِمِ، عَنْ كَثِيرٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ عَنْ عَبْدِ الرَّحْمَنِ ابْنِ سَمُرَةَ، قَالَ جَاءَ عُثْمَانُ إِلَى النَّبِيِّ صلى الله عليه وسلم بِأَلْفِ دِينَارٍ - قَالَ الْحَسَنُ بْنُ وَاقِعٍ وَكَانَ فِي مَوْضِعٍ آخَرَ مِنْ كِتَابِي فِي كُمِّهِ حِينَ جَهَّزَ جَيْشَ الْعُسْرَةِ فَنَثَرَهَا فِي حِجْرِهِ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُقَلِّبُهَا فِي حِجْرِهِ وَيَقُولُ ‏ "‏ مَا ضَرَّ عُثْمَانَ مَا عَمِلَ بَعْدَ الْيَوْمِ ‏"‏ ‏.‏ مَرَّتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3701}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdur-Rahman bin Samurah:that 'Uthman went to the Prophet (ﷺ) with one-thousand Dinar" - Al-Hasan bin Waqi (one of the narrators) said: "And in another place in my book: 'In his garment when the 'army of distress' was being prepared. So he poured them into his lap.'" - 'Abdur-Rahman said: "So I saw the Prophet (ﷺ) turning them over in his lap, saying: 'Whatever 'Uthman does after today will not harm him,' two times}}
\hadithdefcmd{tirmidhi}{3702}{حَدَّثَنَا أَبُو زُرْعَةَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا الْحَكَمُ بْنُ عَبْدِ الْمَلِكِ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا أُمِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِبَيْعَةِ الرِّضْوَانِ كَانَ عُثْمَانُ بْنُ عَفَّانَ رَسُولَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى أَهْلِ مَكَّةَ قَالَ فَبَايَعَ النَّاسَ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ عُثْمَانَ فِي حَاجَةِ اللَّهِ وَحَاجَةِ رَسُولِهِ ‏"‏ ‏.‏ فَضَرَبَ بِإِحْدَى يَدَيْهِ عَلَى الأُخْرَى فَكَانَتْ يَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم لِعُثْمَانَ خَيْرًا مِنْ أَيْدِيهِمْ لأَنْفُسِهِمْ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3702}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that when the Messenger of Allah (ﷺ) ordered the pledge of Ridwan, 'Uthman bin 'Affan was the messenger of the Messenger of Allah (ﷺ) to the people of Makkah. He said: "So the people gave the pledge." He said: "So the Messenger of Allah (ﷺ) said: 'Indeed 'Uthman is busy with the affair of Allah and the affair of His Messenger' then he (ﷺ) put one of his hands on the other. The hand of the Messenger of Allah (ﷺ) on behalf of 'Uthman, was better than their own hands for themselves}}
\hadithdefcmd{tirmidhi}{3703}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، وَعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، وَغَيْرُ، وَاحِدٍ الْمَعْنَى، وَاحِدٌ، قَالُوا حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ قَالَ عَبْدُ اللَّهِ أَخْبَرَنَا سَعِيدُ بْنُ عَامِرٍ عَنْ يَحْيَى بْنِ أَبِي الْحَجَّاجِ الْمِنْقَرِيِّ عَنْ أَبِي مَسْعُودٍ الْجُرَيْرِيِّ عَنْ ثُمَامَةَ بْنِ حَزْنٍ الْقُشَيْرِيِّ قَالَ شَهِدْتُ الدَّارَ حِينَ أَشْرَفَ عَلَيْهِمْ عُثْمَانُ فَقَالَ ائْتُونِي بِصَاحِبَيْكُمُ اللَّذَيْنِ أَلَّبَاكُمْ عَلَىَّ ‏.‏ قَالَ فَجِيءَ بِهِمَا فَكَأَنَّهُمَا جَمَلاَنِ أَوْ كَأَنَّهُمَا حِمَارَانِ ‏.‏ قَالَ فَأَشْرَفَ عَلَيْهِمْ عُثْمَانُ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ وَالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِمَ الْمَدِينَةَ وَلَيْسَ بِهَا مَاءٌ يُسْتَعْذَبُ غَيْرَ بِئْرِ رُومَةَ فَقَالَ رَسُولُ اللَّهِ ‏"‏ مَنْ يَشْتَرِي بِئْرَ رُومَةَ فَيَجْعَلُ دَلْوَهُ مَعَ دِلاَءِ الْمُسْلِمِينَ بِخَيْرٍ لَهُ مِنْهَا فِي الْجَنَّةِ ‏"‏ ‏.‏ فَاشْتَرَيْتُهَا مِنْ صُلْبِ مَالِي فَأَنْتُمُ الْيَوْمَ تَمْنَعُونِي أَنْ أَشْرَبَ مِنْهَا حَتَّى أَشْرَبَ مِنْ مَاءِ الْبَحْرِ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ أَنْشُدُكُمْ بِاللَّهِ وَالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنَّ الْمَسْجِدَ ضَاقَ بِأَهْلِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَشْتَرِي بُقْعَةَ آلِ فُلاَنٍ فَيَزِيدُهَا فِي الْمَسْجِدِ بِخَيْرٍ لَهُ مِنْهَا فِي الْجَنَّةِ ‏"‏ ‏.‏ فَاشْتَرَيْتُهَا مِنْ صُلْبِ مَالِي فَأَنْتُمُ الْيَوْمَ تَمْنَعُونِي أَنْ أُصَلِّيَ فِيهَا رَكْعَتَيْنِ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ أَنْشُدُكُمْ بِاللَّهِ وَالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنِّي جَهَّزْتُ جَيْشَ الْعُسْرَةِ مِنْ مَالِي قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ ثُمَّ قَالَ أَنْشُدُكُمْ بِاللَّهِ وَالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَلَى ثَبِيرِ مَكَّةَ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ وَأَنَا فَتَحَرَّكَ الْجَبَلُ حَتَّى تَسَاقَطَتْ حِجَارَتُهُ بِالْحَضِيضِ قَالَ فَرَكَضَهُ بِرِجْلِهِ وَقَالَ ‏"‏ اسْكُنْ ثَبِيرُ فَإِنَّمَا عَلَيْكَ نَبِيٌّ وَصِدِّيقٌ وَشَهِيدَانِ ‏"‏ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ اللَّهُ أَكْبَرُ شَهِدُوا لِي وَرَبِّ الْكَعْبَةِ أَنِّي شَهِيدٌ ثَلاَثًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عُثْمَانَ ‏.‏\hadithno{3703}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Thumamah bin Hazn Al-Qushairi:"I was present at the house when 'Uthman appeared above them saying: 'Bring me your two companions who have gathered you against me.'" He said: "So they were brought as if they were two camels, or as if they were two donkeys." He said: "'Uthman appeared above them and said: 'I ask you by Allah and Islam! Do you know that the Messenger of Allah (ﷺ) came to Al-Madinah and there was no water in it that was sweet except the well of Rumah, so the Messenger of Allah (ﷺ) said: 'Who will purchase the well of Rumah and place his bucket alongside the buckets of the Muslims, in exchange for better than that in Paradise?' So I bought it with the core of my wealth, and today you prevent me from drinking from it, so that I would have to drink from the water of the sea?' They said: 'O Allah! Yes!' He said: 'I ask you by Allah and Islam! Do you know that the Masjid, was insufficient for its people, so the Messenger of Allah (ﷺ) said: 'Who will purchase the land of the family of so-and-so, and add it to the Masjid in exchange for better than that in Paradise?' So I bought it with the core of my wealth, and today you prevent me from praying two Rak'ah in it?' They said: 'O Allah! Yes.' He said: 'I ask you by Allah and Islam! Do you know that I prepared the 'army of distress' from my wealth?' They said: 'O Allah! Yes!' Then he said: 'I ask you by Allah and Islam! Do you know that the Messenger of Allah (ﷺ) was on (mount) Thabir of Makkah, and with him was Abu Bakr, and 'Umar, and myself. The mountain began shaking until its rocks fell to its bottom.' He said: 'So he (ﷺ) stomped it with his foot and said: "Be still O Thabir! For there is none upon except a Prophet, a Siddiq and two martyrs?"' They said: 'O Allah! Yes!' He said: 'Allah is Great! Bear witness by the Lord of the Ka'bah that I am a martyr!' - three times}}
\hadithdefcmd{tirmidhi}{3704}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، أَنَّ خُطَبَاءَ، قَامَتْ بِالشَّامِ وَفِيهِمْ رِجَالٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ آخِرُهُمْ رَجُلٌ يُقَالُ لَهُ مُرَّةُ بْنُ كَعْبٍ فَقَالَ لَوْلاَ حَدِيثٌ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا قُمْتُ ‏.‏ وَذَكَرَ الْفِتَنَ فَقَرَّبَهَا فَمَرَّ رَجُلٌ مُقَنَّعٌ فِي ثَوْبٍ فَقَالَ هَذَا يَوْمَئِذٍ عَلَى الْهُدَى فَقُمْتُ إِلَيْهِ فَإِذَا هُوَ عُثْمَانُ بْنُ عَفَّانَ ‏.‏ قَالَ فَأَقْبَلْتُ عَلَيْهِ بِوَجْهِهِ فَقُلْتُ هَذَا قَالَ نَعَمْ ‏.هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ حَوَالَةَ وَكَعْبِ بْنِ عُجْرَةَ ‏.‏\hadithno{3704}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Al-Ash'ath As-Sana'ani:"Some people were delivering Khutbah in Ash-Sham, and among them were Companions of the Prophet (ﷺ). So the last of them, a man called Murrah bin Ka'b, stood, and he said: 'If it were not for a Hadith I heard from the Messenger of Allah (ﷺ), I would not have stood (to address you). He (ﷺ) mentioned the tribulations, and that they would be coming soon. Then a man who was concealed by a garment passed by. So he said: "This one will be upon guidance that day." So I went towards him, and it was 'Uthman bin 'Affan. I turned, facing him, and I said: "This one?" He said: "Yes}}
\hadithdefcmd{tirmidhi}{3705}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَا عُثْمَانُ إِنَّهُ لَعَلَّ اللَّهَ يُقَمِّصُكَ قَمِيصًا فَإِنْ أَرَادُوكَ عَلَى خَلْعِهِ فَلاَ تَخْلَعْهُ لَهُمْ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3705}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:that the Prophet (ﷺ) said: "O 'Uthman! Indeed Allah may give you a shirt, and if they wish that you take it off, do not take it off for them}}
\hadithdefcmd{tirmidhi}{3706}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، أَنَّ رَجُلاً، مِنْ أَهْلِ مِصْرَ حَجَّ الْبَيْتَ فَرَأَى قَوْمًا جُلُوسًا فَقَالَ مَنْ هَؤُلاَءِ قَالُوا قُرَيْشٌ ‏.‏ قَالَ فَمَنْ هَذَا الشَّيْخُ قَالُوا ابْنُ عُمَرَ ‏.‏ فَأَتَاهُ فَقَالَ إِنِّي سَائِلُكَ عَنْ شَيْءٍ فَحَدِّثْنِي أَنْشُدُكَ اللَّهَ بِحُرْمَةِ هَذَا الْبَيْتِ أَتَعْلَمُ أَنَّ عُثْمَانَ فَرَّ يَوْمَ أُحُدٍ قَالَ نَعَمْ ‏.‏ قَالَ أَتَعْلَمُ أَنَّهُ تَغَيَّبَ عَنْ بَيْعَةِ الرِّضْوَانِ فَلَمْ يَشْهَدْهَا قَالَ نَعَمْ ‏.‏ قَالَ أَتَعْلَمُ أَنَّهُ تَغَيَّبَ يَوْمَ بَدْرٍ فَلَمْ يَشْهَدْ قَالَ نَعَمْ ‏.‏ قَالَ اللَّهُ أَكْبَرُ ‏.‏ فَقَالَ لَهُ ابْنُ عُمَرَ تَعَالَ أُبَيِّنْ لَكَ مَا سَأَلْتَ عَنْهُ أَمَّا فِرَارُهُ يَوْمَ أُحُدٍ فَأَشْهَدُ أَنَّ اللَّهَ قَدْ عَفَا عَنْهُ وَغَفَرَ لَهُ وَأَمَّا تَغَيُّبُهُ يَوْمَ بَدْرٍ فَإِنَّهُ كَانَتْ عِنْدَهُ - أَوْ تَحْتَهُ - ابْنَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَكَ أَجْرُ رَجُلٍ شَهِدَ بَدْرًا وَسَهْمُهُ ‏"‏ ‏.‏ وَأَمَرَهُ أَنْ يَخْلُفَ عَلَيْهَا وَكَانَتْ عَلِيلَةً وَأَمَّا تَغَيُّبُهُ عَنْ بَيْعَةِ الرِّضْوَانِ فَلَوْ كَانَ أَحَدٌ أَعَزَّ بِبَطْنِ مَكَّةَ مِنْ عُثْمَانَ لَبَعَثَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَانَ عُثْمَانَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عُثْمَانَ إِلَى مَكَّةَ وَكَانَتْ بَيْعَةُ الرِّضْوَانِ بَعْدَ مَا ذَهَبَ عُثْمَانُ إِلَى مَكَّةَ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ الْيُمْنَى ‏"‏ هَذِهِ يَدُ عُثْمَانَ ‏"‏ ‏.‏ وَضَرَبَ بِهَا عَلَى يَدِهِ فَقَالَ ‏"‏ هَذِهِ لِعُثْمَانَ ‏"رضى الله عنه‏ ‏.‏ قَالَ لَهُ اذْهَبْ بِهَذَا الآنَ مَعَكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3706}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Uthman bin 'Abdullah bin Mawhab:"A man among the people of Egypt performed Hajj to the House, and saw a group sitting, so he said: 'Who are these?' They said: 'The Quraish.' He said: 'So who is this old man?' They said: 'Ibn 'Umar.' So he went to him and said: 'I will ask you about something, so inform me. I ask you by Allah! By the sanctity of this House! Do you know that 'Uthman fled on the Day of (the battle of) Uhud?' He said: 'Yes.' He said: 'Do you know that he was absent from the Pledge of Ar-Ridwan, that he did not witness it?' He said: 'Yes.' He said: 'Do you know that he was absent on the Day of (the battle of) Badr and did not participate in it?' He said: 'Yes.' So he said: 'Allah is Great' So Ibn 'Umar said to him: 'Come, so I can clarify to you what you have asked about. As for his fleeing on the Day of (the battle of) Uhud, then I bear witness that Allah has pardoned him and forgiven him. As for his being absent on the Day of (the battle of) Badr, then he was married to the daughter of the Messenger of Allah (ﷺ). So the Messenger of Allah (ﷺ) said to him: "You have the reward of a man who participated in (the battle of) Badr, and his share (spoils of war)." [And he ordered him to stay behind with her, as she was ill]. As for his being absent from the Pledge of Ar-Ridwan, then if there was anyone more revered in Makkah than 'Uthman, then the Messenger of Allah (ﷺ) would have sent him instead of 'Uthman. The Messenger of Allah (ﷺ) sent 'Uthman [to Makkah], and the Pledge of Ar-Ridwan was after 'Uthman had departed for Makkah." He said: "So the Messenger of Allah (ﷺ) said with his right hand: "This is the hand of 'Uthman," and he put it upon his own hand, and said: "This is for 'Uthman."' He said to him: "Go now, and take this (clarification) with you}}
\hadithdefcmd{tirmidhi}{3707}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا الْعَلاَءُ بْنُ عَبْدِ الْجَبَّارِ، قَالَ حَدَّثَنَا الْحَارِثُ بْنُ عُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نَقُولُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حَىٌّ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ يُسْتَغْرَبُ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ عُمَرَ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{3707}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Umar:"While the Messenger of Allah (ﷺ) was alive, we used to say: 'Abu Bakr, and (then) 'Umar, and (then) 'Uthman}}
\hadithdefcmd{tirmidhi}{3708}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالَ حَدَّثَنَا شَاذَانُ الأَسْوَدُ بْنُ عَامِرٍ، عَنْ سِنَانِ بْنِ هَارُونَ الْبُرْجُمِيِّ، عَنْ كُلَيْبِ بْنِ وَائِلٍ، عَنِ ابْنِ عُمَرَ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِتْنَةً فَقَالَ ‏ "‏ يُقْتَلُ فِيهَا هَذَا مَظْلُومًا ‏"‏ ‏.‏ لِعُثْمَانَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ابْنِ عُمَرَ ‏.‏\hadithno{3708}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) mentioned the Fitnah and said: "This one will be wrongfully killed during it," about 'Uthman bin 'Affan [may Allah be pleased with him]}}
\hadithdefcmd{tirmidhi}{3709}{حَدَّثَنَا الْفَضْلُ بْنُ أَبِي طَالِبٍ الْبَغْدَادِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عُثْمَانُ بْنُ زُفَرَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِجَنَازَةِ رَجُلٍ يُصَلِّي عَلَيْهِ فَلَمْ يُصَلِّ عَلَيْهِ فَقِيلَ يَا رَسُولَ اللَّهِ مَا رَأَيْنَاكَ تَرَكْتَ الصَّلاَةَ عَلَى أَحَدٍ قَبْلَ هَذَا قَالَ ‏ "‏ إِنَّهُ كَانَ يَبْغَضُ عُثْمَانَ فَأَبْغَضَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمُحَمَّدُ بْنُ زِيَادٍ صَاحِبُ مَيْمُونِ بْنِ مِهْرَانَ ضَعِيفٌ فِي الْحَدِيثِ جِدًّا وَمُحَمَّدُ بْنُ زِيَادٍ صَاحِبُ أَبِي هُرَيْرَةَ هُوَ بَصْرِيٌّ ثِقَةٌ وَيُكْنَى أَبَا الْحَارِثِ وَمُحَمَّدُ بْنُ زِيَادٍ الأَلْهَانِيُّ صَاحِبُ أَبِي أُمَامَةَ ثِقَةٌ يُكْنَى أَبَا سُفْيَانَ شَامِيٌّ ‏.‏\hadithno{3709}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:that the Prophet (ﷺ) was brought the body of a deceased man, to perform Salat for him, but he did not pray over him. It was said: "O Messenger of Allah! We have not seen you avoiding prayer over anyone before this?" He said: "He used to hate 'Uthman, so Allah hates him}}
\hadithdefcmd{tirmidhi}{3710}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ انْطَلَقْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَدَخَلَ حَائِطًا لِلأَنْصَارِ فَقَضَى حَاجَتَهُ فَقَالَ لِي ‏"‏ يَا أَبَا مُوسَى أَمْلِكْ عَلَىَّ الْبَابَ فَلاَ يَدْخُلَنَّ عَلَىَّ أَحَدٌ إِلاَّ بِإِذْنٍ ‏"‏ ‏.‏ فَجَاءَ رَجُلٌ يَضْرِبُ الْبَابَ فَقُلْتُ مَنْ هَذَا فَقَالَ أَبُو بَكْرٍ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا أَبُو بَكْرٍ يَسْتَأْذِنُ ‏.‏ قَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏ ‏.‏ فَدَخَلَ وَبَشَّرْتُهُ بِالْجَنَّةِ وَجَاءَ رَجُلٌ آخَرُ فَضَرَبَ الْبَابَ فَقُلْتُ مَنْ هَذَا فَقَالَ عُمَرُ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا عُمَرُ يَسْتَأْذِنُ ‏.‏ قَالَ ‏"‏ افْتَحْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏ ‏.‏ فَفَتَحْتُ الْبَابَ وَدَخَلَ وَبَشَّرْتُهُ بِالْجَنَّةِ فَجَاءَ رَجُلٌ آخَرُ فَضَرَبَ الْبَابَ فَقُلْتُ مَنْ هَذَا قَالَ عُثْمَانُ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا عُثْمَانُ يَسْتَأْذِنُ ‏.‏ قَالَ ‏"‏ افْتَحْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ عَلَى بَلْوَى تُصِيبُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَابْنِ عُمَرَ ‏.‏\hadithno{3710}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Musa Al-Ash'ari:"I went with the Prophet (ﷺ) and he entered a garden of the Ansar, and he relieved himself. He said to me: 'O Abu Musa! Watch the gate for me, and do not let anyone enter except with permission.' Then a man came and knocked at the gate, so I said: 'Who is it?' He said: 'Abu Bakr.' So I said: 'O Messenger of Allah (ﷺ)! It is Abu Bakr asking permission?' He said: 'Give him permission and give him the glad tidings of Paradise.' So he entered, and I gave him the glad tidings of Paradise. Another man came and knocked at the gate. I said: 'Who is it?' He said: "'Umar.' So I said: 'O Messenger of Allah (ﷺ)! It is 'Umar asking permission?' He said: 'Open it for him, and give him the glad tidings of Paradise.' I opened [the gate], he entered, and I gave him the glad tidings of Paradise. Then another man knocked at the gate. I said: 'Who is it?' So he said: ''Uthman.' I said: 'O Messenger of Allah! It is 'Uthman asking permission.' He said: 'Open it for him, and give him the glad tidings of Paradise due to a calamity that will befall him}}
\hadithdefcmd{tirmidhi}{3711}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا أَبِي وَيَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، قَالَ حَدَّثَنِي أَبُو سَهْلَةَ، قَالَ قَالَ لِي عُثْمَانُ يَوْمَ الدَّارِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ عَهِدَ إِلَىَّ عَهْدًا فَأَنَا صَابِرٌ عَلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ ‏.‏\hadithno{3711}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Sahlah:"The day of the house (when he was besieged), 'Uthman said: 'Indeed the Messenger of Allah (ﷺ) took a covenant from me, and I will abide by it}}
\hadithdefcmd{tirmidhi}{3712}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ يَزِيدَ الرِّشْكِ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَيْشًا وَاسْتَعْمَلَ عَلَيْهِمْ عَلِيَّ بْنَ أَبِي طَالِبٍ فَمَضَى فِي السَّرِيَّةِ فَأَصَابَ جَارِيَةً فَأَنْكَرُوا عَلَيْهِ وَتَعَاقَدَ أَرْبَعَةٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا إِذَا لَقِينَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَخْبَرْنَاهُ بِمَا صَنَعَ عَلِيٌّ وَكَانَ الْمُسْلِمُونَ إِذَا رَجَعُوا مِنَ السَّفَرِ بَدَءُوا بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَسَلَّمُوا عَلَيْهِ ثُمَّ انْصَرَفُوا إِلَى رِحَالِهِمْ فَلَمَّا قَدِمَتِ السَّرِيَّةُ سَلَّمُوا عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَامَ أَحَدُ الأَرْبَعَةِ فَقَالَ يَا رَسُولَ اللَّهِ أَلَمْ تَرَ إِلَى عَلِيِّ بْنِ أَبِي طَالِبٍ صَنَعَ كَذَا وَكَذَا ‏.‏ فَأَعْرَضَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَامَ الثَّانِي فَقَالَ مِثْلَ مَقَالَتِهِ فَأَعْرَضَ عَنْهُ ثُمَّ قَامَ إِلَيْهِ الثَّالِثُ فَقَالَ مِثْلَ مَقَالَتِهِ فَأَعْرَضَ عَنْهُ ثُمَّ قَامَ الرَّابِعُ فَقَالَ مِثْلَ مَا قَالُوا فَأَقْبَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْغَضَبُ يُعْرَفُ فِي وَجْهِهِ فَقَالَ ‏ "‏ مَا تُرِيدُونَ مِنْ عَلِيٍّ مَا تُرِيدُونَ مِنْ عَلِيٍّ مَا تُرِيدُونَ مِنْ عَلِيٍّ إِنَّ عَلِيًّا مِنِّي وَأَنَا مِنْهُ وَهُوَ وَلِيُّ كُلِّ مُؤْمِنٍ مِنْ بَعْدِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ جَعْفَرِ بْنِ سُلَيْمَانَ ‏.‏\hadithno{3712}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Imran bin Husain:that the Messenger of Allah (ﷺ) dispatched an army and he put 'Ali bin Abi Talib in charge of it. He left on the expedition and he entered upon a female slave. So four of the Companions of the Messenger of Allah (ﷺ) scolded him, and they made a pact saying: "[If] we meet the Messenger of Allah (ﷺ) we will inform him of what 'Ali did." When the Muslims returned from the journey, they would begin with the Messenger of Allah (ﷺ) and give him Salam, then they would go to their homes. So when the expedition arrived, they gave Salam to the Prophet (ﷺ), and one of the four stood saying: "O Messenger of Allah! Do you see that 'Ali bin Abi Talib did such and such." The Messenger of Allah (ﷺ) turned away from him. Then the second one stood and said as he said, and he turned away from him. Then the third stood before him, and said as he said, and he turned away from him. Then the fourth stood and said as they had said. The Messenger of Allah (ﷺ) faced him, and the anger was visible on his face, he said: "What do you want from 'Ali?! What do you want from 'Ali?! What do you want from 'Ali?! Indeed 'Ali is from me, and I am from him, and he is the ally of every believer after me}}
\hadithdefcmd{tirmidhi}{3713}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ سَمِعْتُ أَبَا الطُّفَيْلِ، يُحَدِّثُ عَنْ أَبِي سَرِيْحَةَ، أَوْ زَيْدِ بْنِ أَرْقَمَ شَكَّ شُعْبَةُ - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كُنْتُ مَوْلاَهُ فَعَلِيٌّ مَوْلاَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ مَيْمُونٍ أَبِي عَبْدِ اللَّهِ عَنْ زَيْدِ بْنِ أَرْقَمَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَبُو سَرِيحَةَ هُوَ حُذَيْفَةُ بْنُ أَسِيدٍ صَاحِبُ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3713}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Sarihah, or Zaid bin Arqam - Shu'bah had doubt:from the Prophet (ﷺ): "For whomever I am his Mawla then 'Ali is his Mawla}}
\hadithdefcmd{tirmidhi}{3714}{حَدَّثَنَا أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْبَصْرِيُّ قَالَ حَدَّثَنَا أَبُو عَتَّابٍ، سَهْلُ بْنُ حَمَّادٍ قَالَ حَدَّثَنَا الْمُخْتَارُ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا أَبُو حَيَّانَ التَّيْمِيُّ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَحِمَ اللَّهُ أَبَا بَكْرٍ زَوَّجَنِي ابْنَتَهُ وَحَمَلَنِي إِلَى دَارِ الْهِجْرَةِ وَأَعْتَقَ بِلاَلاً مِنْ مَالِهِ رَحِمَ اللَّهُ عُمَرَ يَقُولُ الْحَقَّ وَإِنْ كَانَ مُرًّا تَرَكَهُ الْحَقُّ وَمَالَهُ صَدِيقٌ رَحِمَ اللَّهُ عُثْمَانَ تَسْتَحْيِيهِ الْمَلاَئِكَةُ رَحِمَ اللَّهُ عَلِيًّا اللَّهُمَّ أَدِرِ الْحَقَّ مَعَهُ حَيْثُ دَارَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْمُخْتَارُ بْنُ نَافِعٍ شَيْخٌ بَصْرِيٌّ كَثِيرُ الْغَرَائِبِ وَأَبُو حَيَّانَ التَّيْمِيُّ اسْمُهُ يَحْيَى بْنُ سَعِيدِ بْنِ حَيَّانَ التَّيْمِيُّ كُوفِيٌّ وَهُوَ ثِقَةٌ ‏.‏\hadithno{3714}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali bin Abi Talib:that the Messenger of Allah (ﷺ) said: "May Allah have mercy upon Abu Bakr, he married me to his daughter, and he carried me to the land of Hijrah, and he freed Bilal with his wealth. May Allah have mercy upon 'Umar, he says the truth even if it is sour. The truth caused him to be left without a friend. May Allah have mercy upon 'Uthman, the angels are shy of him. May Allah have mercy upon 'Ali. O Allah! Place the truth with him wherever he turns}}
\hadithdefcmd{tirmidhi}{3715}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ شَرِيكٍ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ أَبِي طَالِبٍ، بِالرَّحَبَةِ قَالَ لَمَّا كَانَ يَوْمُ الْحُدَيْبِيَةِ خَرَجَ إِلَيْنَا نَاسٌ مِنَ الْمُشْرِكِينَ فِيهِمْ سُهَيْلُ بْنُ عَمْرٍو وَأُنَاسٌ مِنْ رُؤَسَاءِ الْمُشْرِكِينَ فَقَالُوا يَا رَسُولَ اللَّهِ خَرَجَ إِلَيْكَ نَاسٌ مِنْ أَبْنَائِنَا وَإِخْوَانِنَا وَأَرِقَّائِنَا وَلَيْسَ لَهُمْ فِقْهٌ فِي الدِّينِ وَإِنَّمَا خَرَجُوا فِرَارًا مِنْ أَمْوَالِنَا وَضِيَاعِنَا فَارْدُدْهُمْ إِلَيْنَا ‏.‏ ‏"‏ فَإِنْ لَمْ يَكُنْ لَهُمْ فِقْهٌ فِي الدِّينِ سَنُفَقِّهُهُمْ ‏"‏ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا مَعْشَرَ قُرَيْشٍ لَتَنْتَهُنَّ أَوْ لَيَبْعَثَنَّ اللَّهُ عَلَيْكُمْ مَنْ يَضْرِبُ رِقَابَكُمْ بِالسَّيْفِ عَلَى الدِّينِ قَدِ امْتَحَنَ اللَّهُ قَلْبَهُ عَلَى الإِيمَانِ ‏"‏ ‏.‏ قَالُوا مَنْ هُوَ يَا رَسُولَ اللَّهِ فَقَالَ لَهُ أَبُو بَكْرٍ مَنْ هُوَ يَا رَسُولَ اللَّهِ وَقَالَ عُمَرُ مَنْ هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هُوَ خَاصِفُ النَّعْلِ ‏"‏ ‏.‏ وَكَانَ أَعْطَى عَلِيًّا نَعْلَهُ يَخْصِفُهَا ثُمَّ الْتَفَتَ إِلَيْنَا عَلِيٌّ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ رِبْعِيٍّ عَنْ عَلِيٍّ ‏.‏ وَسَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ لَمْ يَكْذِبْ رِبْعِيُّ بْنُ حِرَاشٍ فِي الإِسْلاَمِ كِذْبَةً ‏.‏ وَأَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الأَسْوَدِ قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ مَهْدِيٍّ يَقُولُ مَنْصُورُ بْنُ الْمُعْتَمِرِ أَثْبَتُ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{3715}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rib'i bin Hirash:"At Ar-Rahbah, 'Ali narrated to us: 'On the Day of (the Pledge of) Hudaibiyah, some people from the idolaters came out to us. Among them was Suhail bin 'Amr, and some people among the heads of the idolaters. They said: "O Messenger of Allah! People among our fathers, brothers, and slaves have come to you, and they have no knowledge of the religion, rather they came fleeing from our wealth and property, so return them to us. If they do not have knowledge of the religion, then we will teach them." So the Prophet (ﷺ) said: "O people of Quraish, you will desist, or Allah will send upon you one who will chop your necks with the sword over the religion. Allah has tested their hearts regarding faith." They said: "Who is he O Messenger of Allah?" Abu Bakr said to him: "Who is he O Messenger of Allah?" 'Umar said to him: "Who is he O Messenger of Allah?" He said: "He is the one repairing the sandals." - And he had given 'Ali his sandals to repair them. - He said: "Then 'Ali turned to us and said: 'Indeed the Messenger of Allah (ﷺ) said: "Whoever lies upon me intentionally, then let him take his seat in the Fire}}
\hadithdefcmd{tirmidhi}{3716}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ إِسْرَائِيلَ، وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِعَلِيِّ بْنِ أَبِي طَالِبٍ ‏ "‏ أَنْتَ مِنِّي وَأَنَا مِنْكَ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3716}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Al-Bara bin 'Azib:that the Prophet (ﷺ) said to 'Ali bin Abi Talib: "You are from me, and I am from you." And there is a story along with this Hadith}}
\hadithdefcmd{tirmidhi}{3717}{\hadithno{3717}\hadithgrade{Ahmad Muhammad Shakir: Very Daif Isnaad; Al-Albani: Very Daif Isnaad; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{3718}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ ابْنُ بِنْتِ السُّدِّيِّ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي رَبِيعَةَ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ أَمَرَنِي بِحُبِّ أَرْبَعَةٍ وَأَخْبَرَنِي أَنَّهُ يُحِبُّهُمْ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ سَمِّهِمْ لَنَا ‏.‏ قَالَ ‏"‏ عَلِيٌّ مِنْهُمْ يَقُولُ ذَلِكَ ثَلاَثًا وَأَبُو ذَرٍّ وَالْمِقْدَادُ وَسَلْمَانُ أَمَرَنِي بِحُبِّهِمْ وَأَخْبَرَنِي أَنَّهُ يُحِبُّهُمْ ‏"‏ ‏.‏هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَرِيكٍ ‏.‏\hadithno{3718}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraidah:that the Messenger of Allah (ﷺ) said: "Indeed Allah has ordered me to love four, and He informed me that He loves them." It was said: "O Messenger of Allah! Name them for us." He said: "'Ali is among them," saying that three times, "And Abu Dharr, Al-Miqdad, and Salman. And He ordered me to love them, and He informed me that He loves them}}
\hadithdefcmd{tirmidhi}{3719}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ حُبْشِيِّ بْنِ جُنَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلِيٌّ مِنِّي وَأَنَا مِنْ عَلِيٍّ وَلاَ يُؤَدِّي عَنِّي إِلاَّ أَنَا أَوْ عَلِيٌّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3719}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Hubshi bin Junadah:that the Messenger of Allah (ﷺ) said: "'Ali is from me and I am from 'Ali. And none should represent me except myself or 'Ali}}
\hadithdefcmd{tirmidhi}{3720}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى الْقَطَّانُ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ قَادِمٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ صَالِحِ بْنِ حَىٍّ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، عَنْ جُمَيْعِ بْنِ عُمَيْرٍ التَّيْمِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ آخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَصْحَابِهِ فَجَاءَ عَلِيٌّ تَدْمَعُ عَيْنَاهُ فَقَالَ يَا رَسُولَ اللَّهِ آخَيْتَ بَيْنَ أَصْحَابِكَ وَلَمْ تُؤَاخِ بَيْنِي وَبَيْنَ أَحَدٍ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنْتَ أَخِي فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ زَيْدِ بْنِ أَبِي أَوْفَى ‏.‏\hadithno{3720}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) made bonds of brotherhood among his Companions. So 'Ali came crying saying: "O Messenger of Allah! You have made a bond of brotherhood among your Companions, but you have not made a bond of brotherhood with me and anyone." So the Messenger of Allah (ﷺ) said to him: "I am your brother, in this life and the next}}
\hadithdefcmd{tirmidhi}{3721}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ عِيسَى بْنِ عُمَرَ، عَنِ السُّدِّيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم طَيْرٌ فَقَالَ ‏ "‏ اللَّهُمَّ ائْتِنِي بِأَحَبِّ خَلْقِكَ إِلَيْكَ يَأْكُلُ مَعِي هَذَا الطَّيْرَ ‏"‏ ‏.‏ فَجَاءَ عَلِيٌّ فَأَكَلَ مَعَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ السُّدِّيِّ إِلاَّ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ ‏.‏ وَعِيسَى بْنُ عُمَرَ هُوَ كُوفِيٌّ وَالسُّدِّيُّ اسْمُهُ إِسْمَاعِيلُ بْنُ عَبْدِ الرَّحْمَنِ قَدْ أَدْرَكَ أَنَسَ بْنَ مَالِكٍ وَرَأَى الْحُسَيْنَ بْنَ عَلِيٍّ وَثَّقَهُ شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ وَزَائِدَةُ وَوَثَّقَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ ‏.‏\hadithno{3721}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas bin Malik:"There was a bird with the Prophet (ﷺ), so he said: 'O Allah, send to me the most beloved of Your creatures to eat this bird with me.' So 'Ali came and ate with him}}
\hadithdefcmd{tirmidhi}{3722}{حَدَّثَنَا خَلاَّدُ بْنُ أَسْلَمَ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ أَخْبَرَنَا عَوْفٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ هِنْدٍ الْجَمَلِيِّ، قَالَ قَالَ عَلِيٌّ كُنْتُ إِذَا سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَانِي وَإِذَا سَكَتُّ ابْتَدَأَنِي ‏.هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3722}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif}\hadithtrans{Narrated 'Ali:"When I would ask the Messenger of Allah (ﷺ), he would give me, and when I would be silent, he would initiate (speech or giving) with me}}
\hadithdefcmd{tirmidhi}{3724}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ بُكَيْرِ بْنِ مِسْمَارٍ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ أَمَّرَ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ سَعْدًا فَقَالَ مَا يَمْنَعُكَ أَنْ تَسُبَّ أَبَا تُرَابٍ قَالَ أَمَّا مَا ذَكَرْتُ ثَلاَثًا قَالَهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَنْ أَسُبَّهُ لأَنْ تَكُونَ لِي وَاحِدَةٌ مِنْهُنَّ أَحَبُّ إِلَىَّ مِنْ حُمْرِ النَّعَمِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِعَلِيٍّ وَخَلَفَهُ فِي بَعْضِ مَغَازِيهِ فَقَالَ لَهُ عَلِيٌّ يَا رَسُولَ اللَّهِ تُخَلِّفُنِي مَعَ النِّسَاءِ وَالصِّبْيَانِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا تَرْضَى أَنْ تَكُونَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى إِلاَّ أَنَّهُ لاَ نُبُوَّةَ بَعْدِي ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ يَوْمَ خَيْبَرَ ‏"‏ لأُعْطِيَنَّ الرَّايَةَ رَجُلاً يُحِبُّ اللَّهَ وَرَسُولَهُ وَيُحِبُّهُ اللَّهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ فَتَطَاوَلْنَا لَهَا فَقَالَ ‏"‏ ادْعُ لِي عَلِيًّا ‏"‏ ‏.‏ فَأَتَاهُ وَبِهِ رَمَدٌ فَبَصَقَ فِي عَيْنِهِ فَدَفَعَ الرَّايَةَ إِلَيْهِ فَفَتَحَ اللَّهُ عَلَيْهِ ‏.‏ وَأُنْزِلَتْ هَذِهِ الآيَةُ ‏:‏ ‏(‏ فَقلْ تَعَالَوْا نَدْعُ أَبْنَاءَنَا وَأَبْنَاءَكُمْ ‏)‏ الآيَةَ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيًّا وَفَاطِمَةَ وَحَسَنًا وَحُسَيْنًا فَقَالَ ‏"‏ اللَّهُمَّ هَؤُلاَءِ أَهْلِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3724}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Amir bin Sa'd bin Abi Waqqas:from his father, saying "Mu'awiyah bin Abu Sufyan ordered Sa'd, saying 'What prevented you from reviling Abu Turab?' He said: 'Three things that I remember from the Messenger of Allah (ﷺ) prevent me from reviling him. That I should have even one those things is more beloved to me than red camels. I heard the Messenger of Allah (ﷺ) speaking to 'Ali, and he had left him behind in one of his battles. So 'Ali said to him: "O Messenger of Allah! You leave me behind with women and children?" So the Messenger of Allah (ﷺ) said to him: "Are you not pleased that you should be in the position with me that Harun was with Musa? Except that there is no Prophethood after me?" And on the Day of (the battle of) Khaibar, I heard him saying: "I shall give the banner to a man who loves Allah and His Messenger, and Allah and His Messenger love him." So we all waited for that, then he said: "Call 'Ali for me." He said: 'So he came to him, and he had been suffering from Ramad (an eye condition), so he (ﷺ) put spittle in his eye and gave the banner to him, then Allah granted him victory. And when this Ayah was revealed: 'Let us call our sons and your sons, our women and your women...' (3:61) the Messenger of Allah (ﷺ) called 'Ali, Fatimah, Hasan, and Husain and said: "O Allah, these are my family}}
\hadithdefcmd{tirmidhi}{3725}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، قَالَ حَدَّثَنَا الأَحْوَصُ بْنُ جَوَّابٍ أَبُو الْجَوَّابِ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم جَيْشَيْنِ وَأَمَّرَ عَلَى أَحَدِهِمَا عَلِيَّ بْنَ أَبِي طَالِبٍ وَعَلَى الآخَرِ خَالِدَ بْنَ الْوَلِيدِ وَقَالَ ‏"‏ إِذَا كَانَ الْقِتَالُ فَعَلِيٌّ ‏"‏ ‏.‏ قَالَ فَافْتَتَحَ عَلِيٌّ حِصْنًا فَأَخَذَ مِنْهُ جَارِيَةً فَكَتَبَ مَعِي خَالِدٌ كِتَابًا إِلَى النَّبِيِّ صلى الله عليه وسلم يَشِي بِهِ ‏.‏ قَالَ فَقَدِمْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَرَأَ الْكِتَابَ فَتَغَيَّرَ لَوْنُهُ ثُمَّ قَالَ ‏"‏ مَا تَرَى فِي رَجُلٍ يُحِبُّ اللَّهَ وَرَسُولَهُ وَيُحِبُّهُ اللَّهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ قُلْتُ أَعُوذُ بِاللَّهِ مِنْ غَضَبِ اللَّهِ وَ مِنْ غَضَبِ رَسُولِهِ وَإِنَّمَا أَنَا رَسُولٌ فَسَكَتَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3725}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bara:"The Prophet (ﷺ) dispatched two armies and put 'Ali bin Abi Talib in charge of one of them, and Khalid bin Al-Walid in charge of the other. He said: "When there is fighting, then (the leader is) 'Ali." He said: "So 'Ali conquered a fortress and took a slave girl. So Khalid sent me with a letter to the Prophet (ﷺ) complaining about him. So I came to the Prophet (ﷺ) and he read the letter and his color changed, then he said: 'What is your view concerning one who loves Allah and His Messenger, and Allah and His Messenger love him.'" He said: "I said: 'I seek refuge in Allah from the wrath of Allah and the anger of His Messenger, and I am but a Messenger.' So he became silent}}
\hadithdefcmd{tirmidhi}{3726}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْدِرِ الْكُوفِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الأَجْلَحِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيًّا يَوْمَ الطَّائِفِ فَانْتَجَاهُ فَقَالَ النَّاسُ لَقَدْ طَالَ نَجْوَاهُ مَعَ ابْنِ عَمِّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا انْتَجَيْتُهُ وَلَكِنَّ اللَّهَ انْتَجَاهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الأَجْلَحِ وَقَدْ رَوَاهُ غَيْرُ ابْنِ فُضَيْلٍ أَيْضًا عَنِ الأَجْلَحِ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ وَلَكِنَّ اللَّهَ انْتَجَاهُ ‏"‏ ‏.‏ يَقُولُ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَنْتَجِيَ مَعَهُ ‏.‏\hadithno{3726}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:"The Messenger of Allah (ﷺ) called 'Ali on the Day (of the battle) of At-Ta'if, and spoke privately with him, so the people said: 'His private conversation with his cousin has grown lengthy.' So the Messenger of Allah (ﷺ) said: 'I did not speak privately with him, rather Allah spoke privately with him}}
\hadithdefcmd{tirmidhi}{3727}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ سَالِمِ بْنِ أَبِي حَفْصَةَ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَلِيٍّ ‏ "‏ يَا عَلِيُّ لاَ يَحِلُّ لأَحَدٍ أَنْ يُجْنِبَ فِي هَذَا الْمَسْجِدِ غَيْرِي وَغَيْرَكَ ‏"‏ ‏.‏ قَالَ عَلِيُّ بْنُ الْمُنْذِرِ قُلْتُ لِضِرَارِ بْنِ صُرَدَ مَا مَعْنَى هَذَا الْحَدِيثِ قَالَ لاَ يَحِلُّ لأَحَدٍ يَسْتَطْرِقُهُ جُنُبًا غَيْرِي وَغَيْرُكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَقَدْ سَمِعَ مِنِّي مُحَمَّدُ بْنُ إِسْمَاعِيلَ هَذَا الْحَدِيثَ وَاسْتَغْرَبَهُ ‏.‏\hadithno{3727}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed:that the Messenger of Allah (ﷺ) said to 'Ali: "O 'Ali! It is not permissible for anyone to be Junub in this Masjid except for you and I}}
\hadithdefcmd{tirmidhi}{3728}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَابِسٍ، عَنْ مُسْلِمٍ الْمُلاَئِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ بُعِثَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ الاِثْنَيْنِ وَصَلَّى عَلِيٌّ يَوْمَ الثُّلاَثَاءِ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُسْلِمٍ الأَعْوَرِ ‏.‏ وَمُسْلِمٌ الأَعْوَرُ لَيْسَ عِنْدَهُمْ بِذَلِكَ الْقَوِيِّ ‏.‏ وَقَدْ رُوِيَ هَذَا عَنْ مُسْلِمٍ عَنْ حَبَّةَ عَنْ عَلِيٍّ نَحْوَ هَذَا ‏\hadithno{3728}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:"The advent of the Prophet (ﷺ) was on Monday and 'Ali performed Salat on Tuesday}}
\hadithdefcmd{tirmidhi}{3729}{حَدَّثَنَا خَلَّادُ بْنُ أَسْلَمَ الْبَغْدَادِيُّ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا عَوْفٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ هِنْدٍ الْجَمَلِيِّ قَالَ: قَالَ عَلِيٌّ: كُنْتُ إِذَا سَأَلْتُ رَسُولَ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ أَعْطَانِي وَإِذَا سَكَتُّ ابْتَدَأَنِي. قَالَ أَبُو عِيسَى: هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ\hadithno{3729}\hadithgrade{Ahmad Muhammad Shakir: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali:"When I would ask the Messenger of Allah SAW he would give me, and when I would be silent, he would initiate (speech or giving) with me}}
\hadithdefcmd{tirmidhi}{3730}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِعَلِيٍّ ‏ "‏ أَنْتَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى إِلاَّ أَنَّهُ لاَ نَبِيَّ بَعْدِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ سَعْدٍ وَزَيْدِ بْنِ أَرْقَمَ وَأَبِي هُرَيْرَةَ وَأُمِّ سَلَمَةَ ‏.‏\hadithno{3730}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin 'Abdullah:that the Prophet (ﷺ) said to 'Ali: "You are to me in the position that Harun was to Musa, except that there is no Prophet after me}}
\hadithdefcmd{tirmidhi}{3731}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ عَبْدِ السَّلاَمِ بْنِ حَرْبٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِعَلِيٍّ ‏ "‏ أَنْتَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى إِلاَّ أَنَّهُ لاَ نَبِيَّ بَعْدِي ‏"‏ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ سَعْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَيُسْتَغْرَبُ هَذَا الْحَدِيثُ مِنْ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ ‏.‏\hadithno{3731}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'd bin Abi Waqqas:that the Prophet (ﷺ) said to 'Ali, "You are to me, in the position that Harun was to Musa, [except that there is no Prophet after me]}}
\hadithdefcmd{tirmidhi}{3732}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُخْتَارِ، عَنْ شُعْبَةَ، عَنْ أَبِي بَلْجٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِسَدِّ الأَبْوَابِ إِلاَّ بَابَ عَلِيٍّ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ عَنْ شُعْبَةَ بِهَذَا الإِسْنَادِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3732}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) ordered that the gates be closed, except the gate of 'Ali}}
\hadithdefcmd{tirmidhi}{3733}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ جَعْفَرِ بْنِ مُحَمَّدِ بْنِ عَلِيٍّ، قَالَ أَخْبَرَنِي أَخِي، مُوسَى بْنُ جَعْفَرِ بْنِ مُحَمَّدٍ عَنْ أَبِيهِ، جَعْفَرِ بْنِ مُحَمَّدٍ عَنْ أَبِيهِ، مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِ، عَلِيِّ بْنِ الْحُسَيْنِ عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَلِيِّ بْنِ أَبِي طَالِبٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ بِيَدِ حَسَنٍ وَحُسَيْنٍ فَقَالَ ‏ "‏ مَنْ أَحَبَّنِي وَأَحَبَّ هَذَيْنِ وَأَبَاهُمَا وَأُمَّهُمَا كَانَ مَعِي فِي دَرَجَتِي يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ جَعْفَرِ بْنِ مُحَمَّدٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3733}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali bin Husain:from his father, from his grandfather, 'Ali bin Abi Talib: "The Prophet (ﷺ) took Hasan and Husain by the hand and said: 'Whoever loves me and loves these two, and their father and mother, he shall be with me in my level on the Day of Judgement}}
\hadithdefcmd{tirmidhi}{3734}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُخْتَارِ، عَنْ شُعْبَةَ، عَنْ أَبِي بَلْجٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَوَّلُ مَنْ صَلَّى عَلِيٌّ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ مِنْ حَدِيثِ شُعْبَةَ عَنْ أَبِي بَلْجٍ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ حُمَيْدٍ ‏.‏ وَأَبُو بَلْجٍ اسْمُهُ يَحْيَى بْنُ أَبِي سُلَيْمٍ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا فَقَالَ بَعْضُهُمْ أَوَّلُ مَنْ أَسْلَمَ أَبُو بَكْرٍ الصِّدِّيقُ ‏.‏ وَقَالَ بَعْضُهُمْ أَوَّلُ مَنْ أَسْلَمَ عَلِيٌّ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ أَوَّلُ مَنْ أَسْلَمَ مِنَ الرِّجَالِ أَبُو بَكْرٍ وَأَسْلَمَ عَلِيٌّ وَهُوَ غُلاَمٌ ابْنُ ثَمَانِ سِنِينَ وَأَوَّلُ مَنْ أَسْلَمَ مِنَ النِّسَاءِ خَدِيجَةُ ‏.‏\hadithno{3734}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:"The first to perform Salat was 'Ali}}
\hadithdefcmd{tirmidhi}{3735}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي حَمْزَةَ، رَجُلٌ مِنَ الأَنْصَارِ قَالَ سَمِعْتُ زَيْدَ بْنَ أَرْقَمَ، يَقُولُ أَوَّلُ مَنْ أَسْلَمَ عَلِيٌّ ‏.‏ قَالَ عَمْرُو بْنُ مُرَّةَ فَذَكَرْتُ ذَلِكَ لإِبْرَاهِيمَ النَّخَعِيِّ فَأَنْكَرَهُ وَقَالَ أَوَّلُ مَنْ أَسْلَمَ أَبُو بَكْرٍ الصِّدِّيقُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حَمْزَةَ اسْمُهُ طَلْحَةُ بْنُ يَزِيدَ ‏.‏\hadithno{3735}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated a man from the Ansar:that Zaid bin Al-Arqam said: "The first to accept Islam was 'Ali." 'Amr bin Murrah said: "So I mentioned that to Ibrahim An-Nakha'i, so he rejected that and said: 'The first to accept Islam was Abu Bakr As-Siddiq}}
\hadithdefcmd{tirmidhi}{3736}{حَدَّثَنَا عِيسَى بْنُ عُثْمَانَ ابْنُ أَخِي، يَحْيَى بْنِ عِيسَى الرَّمْلِيُّ قَالَ حَدَّثَنَا يَحْيَى بْنُ عِيسَى الرَّمْلِيُّ، عَنِ الأَعْمَشِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ عَلِيٍّ، قَالَ لَقَدْ عَهِدَ إِلَىَّ النَّبِيُّ الأُمِّيُّ صلى الله عليه وسلم ‏ "‏ أَنَّهُ لاَ يُحِبُّكَ إِلاَّ مُؤْمِنٌ وَلاَ يَبْغَضُكَ إِلاَّ مُنَافِقٌ ‏"‏ ‏.‏ قَالَ عَدِيُّ بْنُ ثَابِتٍ أَنَا مِنَ الْقَرْنِ الَّذِينَ دَعَا لَهُمُ النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3736}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Ali:"The Prophet (ﷺ) - the Unlettered Prophet - exhorted me (saying): 'None loves you except a believer and none hates you except a hypocrite.'" 'Adi bin Thabit (a narrator) said: "I am from the generation whom the Prophet (ﷺ) supplicated for}}
\hadithdefcmd{tirmidhi}{3737}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ أَبِي الْجَرَّاحِ، قَالَ حَدَّثَنِي جَابِرُ بْنُ صُبْحٍ، قَالَ حَدَّثَتْنِي أُمُّ شَرَاحِيلَ، قَالَتْ حَدَّثَتْنِي أُمُّ عَطِيَّةَ، قَالَتْ بَعَثَ النَّبِيُّ صلى الله عليه وسلم جَيْشًا فِيهِمْ عَلِيٌّ ‏.‏ قَالَتْ فَسَمِعْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ رَافِعٌ يَدَيْهِ يَقُولُ ‏ "‏ اللَّهُمَّ لاَ تُمِتْنِي حَتَّى تُرِيَنِي عَلِيًّا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3737}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm 'Atiyyah:"The Prophet (ﷺ) sent an army in which was 'Ali." She said: "While he was raising his hands, I heard the Messenger of Allah (ﷺ) saying: 'O Allah! Do not cause me to die until You allow me to see 'Ali}}
\hadithdefcmd{tirmidhi}{3738}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَحْيَى ابْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنِ الزُّبَيْرِ، قَالَ كَانَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ دِرْعَانِ فَنَهَضَ إِلَى صَخْرَةٍ فَلَمْ يَسْتَطِعْ فَأَقْعَدَ تَحْتَهُ طَلْحَةَ فَصَعِدَ النَّبِيُّ صلى الله عليه وسلم حَتَّى اسْتَوَى عَلَى الصَّخْرَةِ فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَوْجَبَ طَلْحَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3738}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah bin Az-Zubair:that Az-Zubair said: "On the Day of (the battle of) Uhud, the Messenger of Allah (ﷺ) wore two coats of mail. He tried to get up on a boulder, but was not able to, so Talhah squatted under him, lifting the Prophet (ﷺ) upon it, such that he could sit on the boulder. So he said: 'It (Paradise) is obligatory for Talhah}}
\hadithdefcmd{tirmidhi}{3739}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا صَالِحُ بْنُ مُوسَى الطَّلْحِيُّ، مِنْ وَلَدِ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ عَنِ الصَّلْتِ بْنِ دِينَارٍ، عَنْ أَبِي نَضْرَةَ، قَالَ قَالَ جَابِرُ بْنُ عَبْدِ اللَّهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ سَرَّهُ أَنْ يَنْظُرَ إِلَى شَهِيدٍ يَمْشِي عَلَى وَجْهِ الأَرْضِ فَلْيَنْظُرْ إِلَى طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الصَّلْتِ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي الصَّلْتِ بْنِ دِينَارٍ وَفِي صَالِحِ بْنِ مُوسَى مِنْ قِبَلِ حِفْظِهِمَا ‏.‏\hadithno{3739}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin 'Abdullah:that the Messenger of Allah (ﷺ) said: "Whoever would be pleased to look at a martyr walking upon the face of the earth, then let him look at Talhah bin 'Ubaidullah}}
\hadithdefcmd{tirmidhi}{3740}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ الْعَطَّارُ الْبَصْرِيُّ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، عَنْ إِسْحَاقَ بْنِ يَحْيَى بْنِ طَلْحَةَ، عَنْ عَمِّهِ، مُوسَى بْنِ طَلْحَةَ قَالَ دَخَلْتُ عَلَى مُعَاوِيَةَ فَقَالَ أَلاَ أُبَشِّرُكَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ طَلْحَةُ مِمَّنْ قَضَى نَحْبَهُ ‏"‏ ‏.‏هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ مُعَاوِيَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3740}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Musa bin Talhah:"I entered upon Mu'awiyah and he said: 'Shall I not give you some good news?' I said: 'Of course!' He said: 'I heard the Messenger of Allah (ﷺ) saying: 'Talhah is among those who fulfilled their vow (referring to 33:)}}
\hadithdefcmd{tirmidhi}{3741}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ بْنُ مَنْصُورٍ الْعَنَزِيُّ، عَنْ عُقْبَةَ بْنِ عَلْقَمَةَ الْيَشْكُرِيِّ، قَالَ سَمِعْتُ عَلِيَّ بْنَ أَبِي طَالِبٍ، قَالَ سَمِعَتْ أُذُنِي، مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏ "‏ طَلْحَةُ وَالزُّبَيْرُ جَارَاىَ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ\hadithno{3741}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali bin abi Talib:"My ear heard from the mouth of the Messenger of Allah (ﷺ), while he was saying: 'Talhah and Az-Zubair are my neighbors in Paradise}}
\hadithdefcmd{tirmidhi}{3742}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ قَالَ حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ مُوسَى، وَعِيسَى، ابْنَىْ طَلْحَةَ عَنْ أَبِيهِمَا، طَلْحَةَ أَنَّ أَصْحَابَ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالُوا لأَعْرَابِيٍّ جَاهِلٍ سَلْهُ عَمَّنْ قَضَى نَحْبَهُ مَنْ هُوَ وَكَانُوا لاَ يَجْتَرِئُونَ عَلَى مَسْأَلَتِهِ يُوَقِّرُونَهُ وَيَهَابُونَهُ فَسَأَلَهُ الأَعْرَابِيُّ فَأَعْرَضَ عَنْهُ ثُمَّ سَأَلَهُ فَأَعْرَضَ عَنْهُ ثُمَّ سَأَلَهُ فَأَعْرَضَ عَنْهُ ثُمَّ إِنِّي اطَّلَعْتُ مِنْ بَابِ الْمَسْجِدِ وَعَلَىَّ ثِيَابٌ خُضْرٌ فَلَمَّا رَآنِي رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَيْنَ السَّائِلُ عَمَّنْ قَضَى نَحْبَهُ ‏"‏ ‏.‏ قَالَ الأَعْرَابِيُّ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ هَذَا مِمَّنْ قَضَى نَحْبَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي كُرَيْبٍ عَنْ يُونُسَ بْنِ بُكَيْرٍ ‏.‏ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ مِنْ كِبَارِ أَهْلِ الْحَدِيثِ عَنْ أَبِي كُرَيْبٍ بِهَذَا الْحَدِيثِ ‏.‏ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يُحَدِّثُ بِهَذَا عَنْ أَبِي كُرَيْبٍ وَوَضَعَهُ فِي كِتَابِ الْفَوَائِدِ ‏.‏\hadithno{3742}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Musa and 'Eisa, the sons of Talhah:from their father: "The Companions of the Prophet (ﷺ) said, to an unknowing Bedouin man: 'Ask him who it is that has fulfilled his vow.' They were not in the habit of asking him questions out of their respect and reverence for him. So the Bedouin asked him, but he turned away from him. Then he asked him again, but he turned away from him. Then again he asked him, but he turned away from him. Then I stood looking from the door of the Masjid, while I was wearing a green garment, and I saw the Prophet (ﷺ), he said: 'Where is the one who was asking about the one who fulfilled his vow?' The Bedouin said: 'Here I am O Messenger of Allah!' The Messenger of Allah (ﷺ) said: 'This is one who has fulfilled his vow}}
\hadithdefcmd{tirmidhi}{3743}{حَدَّثَنَا هَنَّادٌ، قَالَ حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنِ الزُّبَيْرِ، قَالَ جَمَعَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ يَوْمَ قُرَيْظَةَ فَقَالَ ‏ "‏ بِأَبِي وَأُمِّي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3743}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Az-Zubair:from Az-Zubair, who said: "The Messenger of Allah (ﷺ) gathered together his parents for me the Day of Quraizah, (i.e. the battle of Ahzab) and said: 'May my mother and father be ransomed for you}}
\hadithdefcmd{tirmidhi}{3744}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَلِيِّ رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِكُلِّ نَبِيٍّ حَوَارِيًّا وَإِنَّ حَوَارِيَّ الزُّبَيْرُ بْنُ الْعَوَّامِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُقَالُ الْحَوَارِيُّ هُوَ النَّاصِرُ ‏.‏ سَمِعْتُ ابْنَ أَبِي عُمَرَ يَقُولُ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ الْحَوَارِيُّ هُوَ النَّاصِرُ ‏.‏\hadithno{3744}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Ali bin Abi Talib [may Allah be pleased with him]:that the Messenger of Allah (ﷺ) said: "Indeed, every Prophet has a Hawari, and my Hawari is Az-Zubair bin Al-'Awwam}}
\hadithdefcmd{tirmidhi}{3745}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، وَأَبُو نُعَيْمٍ عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، رضى الله عنه قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ لِكُلِّ نَبِيٍّ حَوَارِيًّا وَإِنَّ حَوَارِيَّ الزُّبَيْرُ بْنُ الْعَوَّامِ ‏"‏ ‏.‏ وَزَادَ أَبُو نُعَيْمٍ فِيهِ يَوْمَ الأَحْزَابِ قَالَ ‏"‏ مَنْ يَأْتِينَا بِخَبَرِ الْقَوْمِ ‏"‏ ‏.‏ قَالَ الزُّبَيْرُ أَنَا ‏.‏ قَالَهَا ثَلاَثًا قَالَ الزُّبَيْرُ أَنَا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3745}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir [may Allah be pleased with him]:that the Messenger of Allah (ﷺ) said: "Indeed, every Prophet has a Hawari and, [indeed], my Hawari is Az-Zubair [bin Al-'Awwam]." And Abu Na'im added in it: "On the Day of Al-Ahzab, he (ﷺ) said: 'Who will bring us news about their party?' Az-Zubair said: 'I will.' He said it three times. Az-Zubair said (each time): 'I will}}
\hadithdefcmd{tirmidhi}{3746}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ صَخْرِ بْنِ جُوَيْرِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَوْصَى الزُّبَيْرُ إِلَى ابْنِهِ عَبْدِ اللَّهِ صَبِيحَةَ الْجَمَلِ فَقَالَ مَا مِنِّي عُضْوٌ إِلاَّ وَقَدْ جُرِحَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ حَتَّى انْتَهَى ذَاكَ إِلَى فَرْجِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ حَمَّادِ بْنِ زَيْدٍ ‏.‏\hadithno{3746}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hisham bin 'Urwah:"On the Day of (the battle of) Al-Jamal, Az-Zubair exhorted his son 'Abdullah, saying: 'There is not a part of me except that it has been injured while with the Messenger of Allah (ﷺ),' until that ended with his private parts}}
\hadithdefcmd{tirmidhi}{3747}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبُو بَكْرٍ فِي الْجَنَّةِ وَعُمَرُ فِي الْجَنَّةِ وَعُثْمَانُ فِي الْجَنَّةِ وَعَلِيٌّ فِي الْجَنَّةِ وَطَلْحَةُ فِي الْجَنَّةِ وَالزُّبَيْرُ فِي الْجَنَّةِ وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فِي الْجَنَّةِ وَسَعْدٌ فِي الْجَنَّةِ وَسَعِيدٌ فِي الْجَنَّةِ وَأَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ فِي الْجَنَّةِ ‏"‏ ‏.‏ أَخْبَرَنَا أَبُو مُصْعَبٍ، قِرَاءَةً عَنْ عَبْدِ الْعَزِيزِ بْنِ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ‏.‏ قَالَ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ عَنْ أَبِيهِ عَنْ سَعِيدِ بْنِ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا وَهَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏\hadithno{3747}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdur-Rahman bin 'Awf:that the Messenger of Allah (ﷺ) said: "Abu Bakr is in Paradise, 'Umar is in Paradise, 'Uthman is in Paradise, 'Ali is in Paradise, Talhah is in Paradise, Az-Zubair is in Paradise, 'Abdur-Rahman bin 'Awf is in Paradise, Sa'd bin Abi Waqqas is in Paradise, Sa'eed bin Zaid is in Paradise, and Abu 'Ubaidah bin Al-Jarrah is in Paradise}}
\hadithdefcmd{tirmidhi}{3748}{حَدَّثَنَا صَالِحُ بْنُ مِسْمَارٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ مُوسَى بْنِ يَعْقُوبَ، عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، عَنْ أَبِيهِ، أَنَّ سَعِيدَ بْنَ زَيْدٍ، حَدَّثَهُ فِي، نَفَرٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَشَرَةٌ فِي الْجَنَّةِ أَبُو بَكْرٍ فِي الْجَنَّةِ وَعُمَرُ فِي الْجَنَّةِ وَعُثْمَانُ وَعَلِيٌّ وَالزُّبَيْرُ وَطَلْحَةُ وَعَبْدُ الرَّحْمَنِ وَأَبُو عُبَيْدَةَ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ ‏"‏ ‏.‏ قَالَ فَعَدَّ هَؤُلاَءِ التِّسْعَةَ وَسَكَتَ عَنِ الْعَاشِرِ فَقَالَ الْقَوْمُ نَنْشُدُكَ اللَّهَ يَا أَبَا الأَعْوَرِ مَنِ الْعَاشِرُ قَالَ نَشَدْتُمُونِي بِاللَّهِ أَبُو الأَعْوَرِ فِي الْجَنَّةِ ‏.‏أَبُو الأَعْوَرِ هُوَ سَعِيدُ بْنُ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ هُوَ أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏\hadithno{3748}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abdur-Rahman bin Humaid:from his father, that Sa'eed bin Zaid reported to him, while in a group of people, that the Messenger of Allah (ﷺ) said: "Ten are in Paradise: Abu Bakr is in Paradise, 'Umar is in Paradise. 'Ali and 'Uthman are in Paradise. Az-Zubair and Talhah, 'Abdur-Rahman, Abu 'Ubaidah and Sa'd bin Abi Waqqas" - He said: "So he counted these nine and was silent concerning the tenth - so the people said: 'We implore you by Allah, O Abu Al-A'war, who is the tenth?' He said: 'You have implored me by Allah. Abu Al-A'war is in Paradise.'" [Abu 'Eisa] said: [Abu Al-A'war] he is Sa'eed bin Zaid bin 'Amr bin Nufail. I heard Muhammad saying: "It is more correct than the first Hadith}}
\hadithdefcmd{tirmidhi}{3749}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ صَخْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ إِنَّ أَمْرَكُنَّ مِمَّا يُهِمُّنِي بَعْدِي وَلَنْ يَصْبِرَ عَلَيْكُنَّ إِلاَّ الصَّابِرُونَ ‏"‏ ‏.‏ قَالَ ثُمَّ تَقُولُ عَائِشَةُ فَسَقَى اللَّهُ أَبَاكَ مِنْ سَلْسَبِيلِ الْجَنَّةِ ‏.‏ تُرِيدُ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ وَقَدْ كَانَ وَصَلَ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم بِمَالٍ يقالُ بِيعَتْ بِأَرْبَعِينَ أَلْفًا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3749}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Salamah:from 'Aishah that the Messenger of Allah (ﷺ) used to say: "Indeed your affair [feminine plural: referring to the wives of the Prophet (ﷺ)] is from that which concerns me after me, and none shall be able to be patient concerning you except the patient ones." He said: "Then 'Aishah said: 'So may Allah give your father drink from the Salsabil of Paradise" intending 'Abdur-Rahman bin 'Awf (Abu Salamah is the son of 'Abdur-Rahman bin 'Awf). And he had maintained ties with the wives of the Prophet (ﷺ) with property that had been sold for forty-thousand}}
\hadithdefcmd{tirmidhi}{3750}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ الْبَصْرِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبِ الْبَصْرِيُّ، قَالاَ حَدَّثَنَا قُرَيْشُ بْنُ أَنَسٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، أَوْصَى بِحَدِيقَةٍ لأُمَّهَاتِ الْمُؤْمِنِينَ بِيعَتْ بِأَرْبَعِ مِئَةِ أَلْفٍ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3750}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Salamah:that 'Abdur-Rahman bin 'Awf left a garden for the Mothers of the Believers that was sold for four-hundred thousand}}
\hadithdefcmd{tirmidhi}{3751}{حَدَّثَنَا رَجَاءُ بْنُ مُحَمَّدٍ الْعُذْرِيُّ، - بَصْرِيٌّ - قَالَ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، عَنْ إِسْمَاعِيلَ ابْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ اسْتَجِبْ لِسَعْدٍ إِذَا دَعَاكَ ‏"‏ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ إِسْمَاعِيلَ عَنْ قَيْسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ اسْتَجِبْ لِسَعْدٍ إِذَا دَعَاكَ ‏"‏ ‏.‏ وَهَذَا أَصَحُّ ‏.‏\hadithno{3751}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd:that the Messenger of Allah (ﷺ) said: "O Allah, respond to Sa'd when he supplicates to You}}
\hadithdefcmd{tirmidhi}{3752}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُجَالِدٍ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَقْبَلَ سَعْدٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَذَا خَالِي فَلْيُرِنِي امْرُؤٌ خَالَهُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُجَالِدٍ ‏.‏ وَكَانَ سَعْدُ بْنُ أَبِي وَقَّاصٍ مِنْ بَنِي زُهْرَةَ وَكَانَتْ أُمُّ النَّبِيِّ صلى الله عليه وسلم مِنْ بَنِي زُهْرَةَ فَلِذَلِكَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَذَا خَالِي ‏"‏ ‏.‏\hadithno{3752}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin 'Abdullah:"Sa'd came, so the Prophet (ﷺ) said: "This is my maternal uncle, so let a man show me his maternal uncle}}
\hadithdefcmd{tirmidhi}{3753}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، وَيَحْيَى بْنِ سَعِيدٍ، سَمِعَا سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ قَالَ عَلِيٌّ مَا جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَاهُ وَأُمَّهُ لأَحَدٍ إِلاَّ لِسَعْدٍ قَالَ لَهُ يَوْمَ أُحُدٍ ‏ "‏ ارْمِ فِدَاكَ أَبِي وَأُمِّي وَقَالَ لَهُ ارْمِ أَيُّهَا الْغُلاَمُ الْحَزَوَّرُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ سَعْدٍ ‏.‏ وَفِي الْبَابِ عَنْ سَعْدٍ\hadithno{3753}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ali:"The Messenger of Allah (ﷺ) did not mention both (his) parents for anyone except Sa'd bin Abi Waqqas. On the Day of (the battle of) Uhud he said: 'Shoot, may my father and mother be ransomed for you.' And he said to him: 'Shoot O young man}}
\hadithdefcmd{tirmidhi}{3754}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، وَعَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ جَمَعَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ يَوْمَ أُحُدٍ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادِ بْنِ الْهَادِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم\hadithno{3754}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sa'd bin Abi Waqqas:"The Messenger of Allah (ﷺ) mentioned both of his parents for me on the Day of Uhud}}
\hadithdefcmd{tirmidhi}{3755}{‏حَدَّثَنَا بِذَلِكَ، مَحْمُودُ بْنُ غَيْلاَنَ قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ مَا سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يُفَدِّي أَحَدًا بِأَبَوَيْهِ إِلاَّ لِسَعْدٍ فَإِنِّي سَمِعْتُهُ يَقُولُ يَوْمَ أُحُدٍ ‏ "‏ ارْمِ سَعْدٌ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{3755}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Ali bin Abi Talib:"I never heard the Prophet (ﷺ) mentioning both of his parents being ransomed for anyone except for Sa'd. On the Day of Uhud, I heard him saying: 'Shoot, Sa'd, may my father and mother be ransomed for you}}
\hadithdefcmd{tirmidhi}{3756}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، أَنَّ عَائِشَةَ، قَالَتْ سَهِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَقْدَمَهُ الْمَدِينَةَ لَيْلَةً قَالَ ‏"‏ لَيْتَ رَجُلاً صَالِحًا يَحْرُسُنِي اللَّيْلَةَ ‏"‏ ‏.‏ قَالَتْ فَبَيْنَا نَحْنُ كَذَلِكَ إِذْ سَمِعْنَا خَشْخَشَةَ السِّلاَحِ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَقَالَ سَعْدُ بْنُ أَبِي وَقَّاصٍ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا جَاءَ بِكَ ‏"‏ ‏.‏ فَقَالَ سَعْدٌ وَقَعَ فِي نَفْسِي خَوْفٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَجِئْتُ أَحْرُسُهُ ‏.‏ فَدَعَا لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ نَامَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3756}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:"The Messenger of Allah (ﷺ) did not sleep one night upon arriving in Al-Madinah. So he said: 'If only a righteous man would guard me tonight.'" She said: "So we were like that, when we heard the clanging of weapons. He said: 'Who is this?' So he said: 'Sa'd bin Abi Waqqas.' So the Messenger of Allah (ﷺ) said: 'What has brought you?' Sa'd said: 'Fear for the Messenger of Allah (ﷺ) came upon me, so I came to protect him.' So the Messenger of Allah (ﷺ) supplicated for him, then slept}}
\hadithdefcmd{tirmidhi}{3757}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا حُصَيْنٌ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عَبْدِ اللَّهِ بْنِ ظَالِمٍ الْمَازِنِيِّ، عَنْ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، أَنَّهُ قَالَ أَشْهَدُ عَلَى التِّسْعَةِ أَنَّهُمْ فِي الْجَنَّةِ وَلَوْ شَهِدْتُ عَلَى الْعَاشِرِ لَمْ آثَمْ ‏.‏ قِيلَ وَكَيْفَ ذَلِكَ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِحِرَاءَ فَقَالَ ‏ "‏ اثْبُتْ حِرَاءُ فَإِنَّهُ لَيْسَ عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدٌ ‏"‏ ‏.‏ قِيلَ وَمَنْ هُمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَطَلْحَةُ وَالزُّبَيْرُ وَسَعْدٌ وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ ‏.‏ قِيلَ فَمَنِ الْعَاشِرُ قَالَ أَنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ سَعِيدِ بْنِ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا الْحَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي شُعْبَةُ، عَنِ الْحُرِّ بْنِ الصَّبَّاحِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَخْنَسِ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3757}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin Zalim Al-Mazini:that Sa'eed bin Zaid bin 'Amr bin Nufail said: "I bear witness for nine people, that they are in Paradise, and if I were to bear witness for a tenth, I would not be sinful." It was said: "How is that?" He said: "We were with the Messenger of Allah (ﷺ) at (mount) Hira when he said, 'Be firm, Hira! There is not upon you any but a Prophet, or a Siddiq, or a martyr." It was said: "And who were they?" He said: "The Messenger of Allah (ﷺ), Abu Bakr, 'Umar, 'Uthman, 'Ali, Talhah, Az-Zubair, Sa'd, and 'Abdur-Rahman bin 'Awf." It was said: "And who is the tenth?" He said: "Me}}
\hadithdefcmd{tirmidhi}{3758}{\hadithno{3758}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{3759}{\hadithno{3759}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{3760}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، سَمِعْتُ الأَعْمَشَ، يُحَدِّثُ عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِعُمَرَ فِي الْعَبَّاسِ ‏ "‏ إِنَّ عَمَّ الرَّجُلِ صِنْوُ أَبِيهِ ‏"‏ ‏.‏ وَكَانَ عُمَرُ كَلَّمَهُ فِي صَدَقَتِهِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3760}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ali:that concerning Al-'Abbas, the Prophet (ﷺ) said to 'Umar: "Indeed, the uncle of a man is the Sinw of his father." And 'Umar had spoken to him concerning his charity}}
\hadithdefcmd{tirmidhi}{3761}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالَ حَدَّثَنَا شَبَابَةُ، قَالَ حَدَّثَنَا وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَبَّاسُ عَمُّ رَسُولِ اللَّهِ وَإِنَّ عَمَّ الرَّجُلِ صِنْوُ أَبِيهِ أَوْ مِنْ صِنْوِ أَبِيهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَبِي الزِّنَادِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3761}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "Al-'Abbas is the uncle of the Messenger of Allah (ﷺ), and indeed, the uncle of a man is the Sinw of his father or from the Sinw of his father}}
\hadithdefcmd{tirmidhi}{3762}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ مَكْحُولٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْعَبَّاسِ ‏"‏ إِذَا كَانَ غَدَاةُ الاِثْنَيْنِ فَأْتِنِي أَنْتَ وَوَلَدُكَ حَتَّى أَدْعُوَ لَهُمْ بِدَعْوَةٍ يَنْفَعُكَ اللَّهُ بِهَا وَوَلَدَكَ ‏"‏ ‏.‏ فَغَدَا وَغَدَوْنَا مَعَهُ وَأَلْبَسَنَا كِسَاءً ثُمَّ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِلْعَبَّاسِ وَوَلَدِهِ مَغْفِرَةً ظَاهِرَةً وَبَاطِنَةً لاَ تُغَادِرُ ذَنْبًا اللَّهُمَّ احْفَظْهُ فِي وَلَدِهِ ‏"‏ ‏.هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3762}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) said to Al-'Abbas: 'On the night of Monday, come to me, you and your offspring, so that I may supplicate for them with a supplication that Allah will benefit you and your children by.' So he went, and we went with at night, so he (ﷺ) covered us in a Kisah (shawl), then said: 'O Allah, forgive Al-'Abbas and his offspring, for what is open and what is secret, with a forgiveness that does not leave any sins. O Allah! Take care of him concerning the affair of his offspring}}
\hadithdefcmd{tirmidhi}{3763}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ جَعْفَرًا يَطِيرُ فِي الْجَنَّةِ مَعَ الْمَلاَئِكَةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي هُرَيْرَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ ‏.‏ وَقَدْ ضَعَّفَهُ يَحْيَى بْنُ مَعِينٍ وَغَيْرُهُ وَعَبْدُ اللَّهِ بْنُ جَعْفَرٍ هُوَ وَالِدُ عَلِيِّ بْنِ الْمَدِينِيِّ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{3763}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "I saw Ja'far flying in Paradise with the angels}}
\hadithdefcmd{tirmidhi}{3764}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، قَالَ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا احْتَذَى النِّعَالَ وَلاَ انْتَعَلَ وَلاَ رَكِبَ الْمَطَايَا وَلاَ رَكِبَ الْكُورَ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَفْضَلُ مِنْ جَعْفَرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏‏ وَالْكُورُ الرَّحْلُ\hadithno{3764}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:"None has put on sandals - nor worn them, nor ridden a mount, nor a Kur, after the Messenger of Allah (ﷺ) - better than Ja'far [bin Abi Talib]}}
\hadithdefcmd{tirmidhi}{3765}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِجَعْفَرِ بْنِ أَبِي طَالِبٍ ‏ "‏ أَشْبَهْتَ خَلْقِي وَخُلُقِي ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ إِسْرَائِيلَ نَحْوَهُ ‏.‏\hadithno{3765}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Al-Bara bin 'Azib:that the Prophet (ﷺ) said to Ja'far bin Abi Talib: "You share similarity with me in appearance and in character}}
\hadithdefcmd{tirmidhi}{3766}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ أَبُو يَحْيَى التَّيْمِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ أَبُو إِسْحَاقَ الْمَخْزُومِيُّ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ إِنْ كُنْتُ لأَسْأَلُ الرَّجُلَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ الآيَاتِ مِنَ الْقُرْآنِ أَنَا أَعْلَمُ بِهَا مِنْهُ مَا أَسْأَلُهُ إِلاَّ لِيُطْعِمَنِي شَيْئًا فَكُنْتُ إِذَا سَأَلْتُ جَعْفَرَ بْنَ أَبِي طَالِبٍ لَمْ يُجِبْنِي حَتَّى يَذْهَبَ بِي إِلَى مَنْزِلِهِ فَيَقُولُ لاِمْرَأَتِهِ يَا أَسْمَاءُ أَطْعِمِينَا شَيْئًا ‏.‏ فَإِذَا أَطْعَمَتْنَا أَجَابَنِي وَكَانَ جَعْفَرٌ يُحِبُّ الْمَسَاكِينَ وَيَجْلِسُ إِلَيْهِمْ وَيُحَدِّثُهُمْ وَيُحَدِّثُونَهُ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَكْنِيهِ بِأَبِي الْمَسَاكِينِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَأَبُو إِسْحَاقَ الْمَخْزُومِيُّ هُوَ إِبْرَاهِيمُ بْنُ الْفَضْلِ الْمَدَنِيُّ وَقَدْ تَكَلَّمَ فِيهِ بَعْضُ أَهْلِ الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ وَلَهُ غَرَائِبُ ‏.‏\hadithno{3766}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:"I used to ask a man from among the Companions of the Prophet (ﷺ) concerning Ayat of the Qur'an which I would be more knowledgeable about than him, so that he might inform me something (more about them). So when I would ask Ja'far bin Abi Talib, he would not answer me until he would go with me to his place and say to his wife: 'O Asma, give us some food.' Once she had given us some food, he would answer me. And Ja'far used to love the poor and sit with them, and speak with them, and they would speak with him, so the Messenger of Allah (ﷺ) used to call him Abu Al-Masakin (the Father of the Poor)}}
\hadithdefcmd{tirmidhi}{3767}{حَدَّثَنَا أَبُو أَحْمَدَ حَاتِمُ بْنُ سِيَاهٍ الْمَرْوَزِيُّ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ عَجْلاَنَ، عَنْ يَزِيدَ بْنِ قُسَيْطٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنَّا نَدْعُو جَعْفَرَ بْنَ أَبِي طَالِبٍ رضى الله عنه أَبَا الْمَسَاكِينِ فَكُنَّا إِذَا أَتَيْنَاهُ قَرَّبْنَا إِلَيْهِ مَا حَضَرَ فَأَتَيْنَاهُ يَوْمًا فَلَمْ يَجِدْ عِنْدَهُ شَيْئًا فَأَخْرَجَ جَرَّةً مِنْ عَسَلٍ فَكَسَرَهَا فَجَعَلْنَا نَلْعَقُ مِنْهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3767}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:"We used to call Ja'far bin Abi Talib the Father of the Poor, so when we used to come to him, he would draw us close to him as long as he was present. One day we came to him, and he did not find anything with him, so he brought a jar of honey and broke it, so we began to lick out of it}}
\hadithdefcmd{tirmidhi}{3768}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْحَسَنُ وَالْحُسَيْنُ سَيِّدَا شَبَابِ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا جَرِيرٌ، وَمُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ يَزِيدَ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَابْنُ أَبِي نُعْمٍ هُوَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي نُعْمٍ الْبَجَلِيُّ الْكُوفِيُّ وَيُكْنَى أَبَا الْحَكَمِ ‏.‏\hadithno{3768}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Sa'eed:that the Messenger of Allah (ﷺ) said: "Al-Hasan and Al-Husain are the chiefs of the youths of Paradise}}
\hadithdefcmd{tirmidhi}{3769}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ يَعْقُوبَ الزَّمْعِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ زَيْدِ بْنِ الْمُهَاجِرِ، قَالَ أَخْبَرَنِي مُسْلِمُ بْنُ أَبِي سَهْلٍ النَّبَّالُ، قَالَ أَخْبَرَنِي الْحَسَنُ بْنُ أُسَامَةُ بْنِ زَيْدٍ، قَالَ أَخْبَرَنِي أَبِي أُسَامَةُ بْنُ زَيْدٍ، قَالَ طَرَقْتُ النَّبِيَّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فِي بَعْضِ الْحَاجَةِ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ مُشْتَمِلٌ عَلَى شَيْءٍ لاَ أَدْرِي مَا هُوَ فَلَمَّا فَرَغْتُ مِنْ حَاجَتِي قُلْتُ مَا هَذَا الَّذِي أَنْتَ مُشْتَمِلٌ عَلَيْهِ قَالَ فَكَشَفَهُ فَإِذَا حَسَنٌ وَحُسَيْنٌ عَلَيْهِمَا السَّلاَمُ عَلَى وَرِكَيْهِ فَقَالَ ‏ "‏ هَذَانِ ابْنَاىَ وَابْنَا ابْنَتِي اللَّهُمَّ إِنِّي أُحِبُّهُمَا فَأَحِبَّهُمَا وَأَحِبَّ مَنْ يُحِبُّهُمَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3769}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Usamah bin Zaid:"I came to the Prophet (ﷺ) one night concerning some need, so the Prophet (ﷺ) came out while he was covering up something, and I did not know what it was. Once I had tended to my need, I said: 'What is this that you were covering up?' So he uncovered it, and I found it was Hasan and Husain [peace be upon them] upon his hips. So he said: 'These are my two sons, and the sons of my daughter. O Allah! Indeed, I love them, so love them, and love those who love them}}
\hadithdefcmd{tirmidhi}{3770}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْبَصْرِيُّ الْعَمِّيُّ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرِ بْنِ حَازِمٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ أَبِي يَعْقُوبَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي نُعْمٍ، أَنَّ رَجُلاً، مِنْ أَهْلِ الْعِرَاقِ سَأَلَ ابْنَ عُمَرَ عَنْ دَمِ الْبَعُوضِ يُصِيبُ الثَّوْبَ فَقَالَ ابْنُ عُمَرَ انْظُرُوا إِلَى هَذَا يَسْأَلُ عَنْ دَمِ الْبَعُوضِ وَقَدْ قَتَلُوا ابْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْحَسَنَ وَالْحُسَيْنَ هُمَا رَيْحَانَتَاىَ مِنَ الدُّنْيَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ وَمَهْدِيُّ بْنُ مَيْمُونٍ عَنْ مُحَمَّدِ بْنِ أَبِي يَعْقُوبَ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ ‏.‏\hadithno{3770}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdur-Rahman bin Abu Nu'm:that a man from the people of Al-'Iraq asked Ibn 'Umar about the blood of a gnat that gets on the clothes. Ibn 'Umar said "Look at this one, he asks about the blood of a gnat while they killed the son of the Messenger of Allah (ﷺ)! And I heard the Messenger of Allah (ﷺ) said: 'Indeed Al-Hasan and Al-Husain - they are my two sweet basils in the world}}
\hadithdefcmd{tirmidhi}{3771}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، قَالَ حَدَّثَنَا رَزِينٌ، قَالَ حَدَّثَتْنِي سَلْمَى، قَالَتْ دَخَلْتُ عَلَى أُمِّ سَلَمَةَ وَهِيَ تَبْكِي فَقُلْتُ مَا يُبْكِيكِ قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم - تَعْنِي فِي الْمَنَامِ - وَعَلَى رَأْسِهِ وَلِحْيَتِهِ التُّرَابُ فَقُلْتُ مَا لَكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏ "‏ شَهِدْتُ قَتْلَ الْحُسَيْنِ آنِفًا ‏"‏ ‏. هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{3771}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salma:"I entered upon Umm Salamah while she was crying, so I said: 'What causes you to cry?' She said: 'I saw the Messenger of Allah - that is, in a dream - and there was was dirt on his head and his beard. so I said: "What is wrong with you, O Messenger of Allah?" He said: 'I just witnessed the killing of Al-Husain}}
\hadithdefcmd{tirmidhi}{3772}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنِي يُوسُفُ بْنُ إِبْرَاهِيمَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ أَهْلِ بَيْتِكَ أَحَبُّ إِلَيْكَ قَالَ ‏"‏ الْحَسَنُ وَالْحُسَيْنُ ‏"‏ ‏.‏ وَكَانَ يَقُولُ لِفَاطِمَةَ ‏"‏ ادْعِي لِي ابْنَىَّ ‏"‏ ‏.‏ فَيَشُمُّهُمَا وَيَضُمُّهُمَا إِلَيْهِ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَنَسٍ\hadithno{3772}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:That the Messenger of Allah (ﷺ) was asked: "Which of the people of your house are most beloved to you?" He said: "Al-Hasan and Al-Husain." And he used to say to Fatimah: "Call my two sons for me so that I may smell them." And he would hug them}}
\hadithdefcmd{tirmidhi}{3773}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنَا الأَشْعَثُ، هُوَ ابْنُ عَبْدِ الْمَلِكِ عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ صَعِدَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمِنْبَرَ فَقَالَ ‏ "‏ إِنَّ ابْنِي هَذَا سَيِّدٌ يُصْلِحُ اللَّهُ عَلَى يَدَيْهِ فِئَتَيْنِ عَظِيمَتَيْنِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ يَعْنِي الْحَسَنَ بْنَ عَلِيٍّ ‏.‏\hadithno{3773}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Bakrah:that the Messenger of Allah (ﷺ) ascended the Minbar and said: "Indeed, this son of mine is a chief, Allah shall bring peace between two [tremendous] parties through his hands}}
\hadithdefcmd{tirmidhi}{3774}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ حُسَيْنِ بْنِ وَاقِدٍ، قَالَ حَدَّثَنِي أَبِي، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ سَمِعْتُ أَبِي، ‏:‏ بُرَيْدَةَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُنَا إِذْ جَاءَ الْحَسَنُ وَالْحُسَيْنُ عَلَيْهِمَا السَّلاَمُ عَلَيْهِمَا قَمِيصَانِ أَحْمَرَانِ يَمْشِيَانِ وَيَعْثُرَانِ فَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمِنْبَرِ فَحَمَلَهُمَا وَوَضَعَهُمَا بَيْنَ يَدَيْهِ ثُمَّ قَالَ ‏"‏ صَدَقَ اللَّهُ ‏:‏ ‏(‏ إنَّمَا أَمْوَالُكُمْ وَأَوْلاَدُكُمْ فِتْنَةٌ ‏)‏ نَظَرْتُ إِلَى هَذَيْنِ الصَّبِيَّيْنِ يَمْشِيَانِ وَيَعْثُرَانِ فَلَمْ أَصْبِرْ حَتَّى قَطَعْتُ حَدِيثِي وَرَفَعْتُهُمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ الْحُسَيْنِ بْنِ وَاقِدٍ ‏.‏\hadithno{3774}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraidah:"The Messenger of Allah (ﷺ) was delivering a Khutbah to us when Al-Hasan and Al-Husain [peace be upon them] came, wearing red shirts, walking and falling down. So the Messenger of Allah (ﷺ) descended from the Minbar and carried them, and placed them in front of him. Then he said: 'Allah spoke the Truth: Indeed, your wealth and your children are a trial (64:15). I looked at these two children walking and falling down, and I could not bear patiently anymore until I interrupted my talk and picked them up}}
\hadithdefcmd{tirmidhi}{3775}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ رَاشِدٍ، عَنْ يَعْلَى بْنِ مُرَّةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حُسَيْنٌ مِنِّي وَأَنَا مِنْ حُسَيْنٍ أَحَبَّ اللَّهُ مَنْ أَحَبَّ حُسَيْنًا حُسَيْنٌ سِبْطٌ مِنَ الأَسْبَاطِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَإِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ عُثْمَانَ ابْنِ خُثَيْمٍ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ ‏.‏\hadithno{3775}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ya'la bin Murrah:that the Messenger of Allah (ﷺ) said: "Husain is from me, and I am from Husain. Allah loves whoever loves Husain. Husain is a Sibt among the Asbat." [Asbat, plural of Sibt: A great tribe. Meaning, Al-Husain would have many offspring, such that they would become a great tribe. And this has indeed occurred. See Tuhfat Al-Ahwadhi]}}
\hadithdefcmd{tirmidhi}{3776}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمْ يَكُنْ أَحَدٌ مِنْهُمْ أَشْبَهَ بِرَسُولِ اللَّهِ مِنَ الْحَسَنِ بْنِ عَلِيٍّ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3776}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas bin Malik:"None of them used to resemble the Messenger of Allah (ﷺ) more than Al-Hasan bin 'Ali}}
\hadithdefcmd{tirmidhi}{3777}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَكَانَ الْحَسَنُ بْنُ عَلِيٍّ يُشْبِهُهُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَابْنِ عَبَّاسٍ وَابْنِ الزُّبَيْرِ ‏.‏\hadithno{3777}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Juhaifah:"I saw the Messenger of Allah (ﷺ), and Al-Hasan bin 'Ali used to resemble him}}
\hadithdefcmd{tirmidhi}{3778}{حَدَّثَنَا خَلاَّدُ بْنُ أَسْلَمَ أَبُو بَكْرٍ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، قَالَتْ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ كُنْتُ عِنْدَ ابْنِ زِيَادٍ فَجِيءَ بِرَأْسِ الْحُسَيْنِ فَجَعَلَ يَقُولُ بِقَضِيبٍ لَهُ فِي أَنْفِهِ وَيَقُولُ مَا رَأَيْتُ مِثْلَ هَذَا حُسْنًا لَمْ يُذْكَرْ ‏.‏ قَالَ قُلْتُ أَمَا إِنَّهُ كَانَ مِنْ أَشْبَهِهِمْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3778}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas bin Malik:"I was with Ibn Ziyad and the head of Al-Husain was brought. He began to poke it in the nose with a stick that he had, saying: 'I do not see the like of this as beautiful, why is he mentioned as such?'" He said: "I said: 'Behold, he was of the closest of them in resemblance to the Messenger of Allah (ﷺ)}}
\hadithdefcmd{tirmidhi}{3779}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ هَانِئِ بْنِ هَانِئٍ، عَنْ عَلِيٍّ، قَالَ الْحَسَنُ أَشْبَهُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم مَا بَيْنَ الصَّدْرِ إِلَى الرَّأْسِ وَالْحُسَيْنُ أَشْبَهُ بِالنَّبِيِّ صلى الله عليه وسلم مَا كَانَ أَسْفَلَ مِنْ ذَلِكَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3779}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:said: "Al-Hasan is greater in resemblance to the Messenger of Allah (ﷺ) with regards to what is between the chest and the head, and Al-Husain is greater in resemblance to the Messenger of Allah (ﷺ) with regards to what is below that}}
\hadithdefcmd{tirmidhi}{3780}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، قَالَ لَمَّا جِيءَ بِرَأْسِ عُبَيْدِ اللَّهِ بْنِ زِيَادٍ وَأَصْحَابِهِ نُضِّدَتْ فِي الْمَسْجِدِ فِي الرَّحَبَةِ فَانْتَهَيْتُ إِلَيْهِمْ وَهُمْ يَقُولُونَ قَدْ جَاءَتْ قَدْ جَاءَتْ ‏.‏ فَإِذَا حَيَّةٌ قَدْ جَاءَتْ تَخَلَّلُ الرُّءُوسَ حَتَّى دَخَلَتْ فِي مَنْخَرَىْ عُبَيْدِ اللَّهِ بْنِ زِيَادٍ فَمَكَثَتْ هُنَيْهَةً ثُمَّ خَرَجَتْ فَذَهَبَتْ حَتَّى تَغَيَّبَتْ ثُمَّ قَالُوا قَدْ جَاءَتْ قَدْ جَاءَتْ ‏.‏ فَفَعَلَتْ ذَلِكَ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3780}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Umarah bin 'Umair:"When the heads of 'Ubaidullah bin Ziyad and his companions were brought, they were stacked in the Masjid at Ar-Rahbah. So I came to them and they were saying: 'It has come, it has come." And behold, there was a snake going between the heads, until it entered the nostrils of 'Ubaidullah bin Ziyad, and it remained there momentarily, then left and went until it had disappeared. Then they said: 'It has come, it has come.' So it did that two or three times}}
\hadithdefcmd{tirmidhi}{3781}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ إِسْرَائِيلَ، عَنْ مَيْسَرَةَ بْنِ حَبِيبٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ حُذَيْفَةَ، قَالَ سَأَلَتْنِي أُمِّي مَتَى عَهْدُكَ - تَعْنِي - بِالنَّبِيِّ صلى الله عليه وسلم ‏.‏ فَقُلْتُ مَا لِي بِهِ عَهْدٌ مُنْذُ كَذَا وَكَذَا ‏.‏ فَنَالَتْ مِنِّي فَقُلْتُ لَهَا دَعِينِي آتِي النَّبِيَّ صلى الله عليه وسلم فَأُصَلِّيَ مَعَهُ الْمَغْرِبَ وَأَسْأَلُهُ أَنْ يَسْتَغْفِرَ لِي وَلَكِ ‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَصَلَّيْتُ مَعَهُ الْمَغْرِبَ فَصَلَّى حَتَّى صَلَّى الْعِشَاءَ ثُمَّ انْفَتَلَ فَتَبِعْتُهُ فَسَمِعَ صَوْتِي فَقَالَ ‏"‏ مَنْ هَذَا حُذَيْفَةُ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ مَا حَاجَتُكَ غَفَرَ اللَّهُ لَكَ وَلأُمِّكَ ‏"‏ ‏.‏ قَالَ ‏"‏ إِنَّ هَذَا مَلَكٌ لَمْ يَنْزِلِ الأَرْضَ قَطُّ قَبْلَ هَذِهِ اللَّيْلَةِ اسْتَأْذَنَ رَبَّهُ أَنْ يُسَلِّمَ عَلَىَّ وَيُبَشِّرَنِي بِأَنَّ فَاطِمَةَ سَيِّدَةُ نِسَاءِ أَهْلِ الْجَنَّةِ وَأَنَّ الْحَسَنَ وَالْحُسَيْنَ سَيِّدَا شَبَابِ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِسْرَائِيلَ ‏.‏\hadithno{3781}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hudhaifah :"My mother asked me: 'When is your planned time - meaning with the Prophet (ﷺ)?' So I said: 'I have not had a planned time to see him since such and such time.' She rebuked me, so I said to her: 'Let me go to the Prophet (ﷺ) so that I may perform Maghrib (prayer) with him, and ask him to seek forgiveness for you and I.' So I came to the Prophet (ﷺ), and I prayed Maghrib with him, then he prayed until he prayed Al-'Isha. Then he turned, and I followed him, and he heard my voice, and said: 'Who is this? Hudhaifah?' I said: 'Yes.' He said: "What is your need, may Allah forgive you and your mother?' He said: 'Indeed, this is an angel that never descended to the earth ever before tonight. He sought permission from his Lord to greet me with peace and to give me the glad tidings that Fatimah is the chief of the women of Paradise, and that Al-Hasan and Al-Husain are the chiefs of the youths of the people of Paradise}}
\hadithdefcmd{tirmidhi}{3782}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَبْصَرَ حَسَنًا وَحُسَيْنًا فَقَالَ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُمَا فَأَحِبَّهُمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3782}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Bara:that the Prophet (ﷺ) saw Hasan and Husain, so he said: "O Allah, I love them, so love them}}
\hadithdefcmd{tirmidhi}{3783}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَاضِعًا الْحَسَنَ بْنَ عَلِيٍّ عَلَى عَاتِقِهِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُ فَأَحِبَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ أَصَحُّ مِنْ حَدِيثِ الْفُضَيْلِ بْنِ مَرْزُوقٍ ‏.‏\hadithno{3783}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Bara bin 'Azib:"I saw the Prophet (ﷺ) placing Al-Hasan bin 'Ali upon his shoulder while saying: 'O Allah, I love him, so love him}}
\hadithdefcmd{tirmidhi}{3784}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنْ سَلَمَةَ بْنِ وَهْرَامَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَامِلَ الْحَسَنِ بْنِ عَلِيٍّ عَلَى عَاتِقِهِ فَقَالَ رَجُلٌ نِعْمَ الْمَرْكَبُ رَكِبْتَ يَا غُلاَمُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَنِعْمَ الرَّاكِبُ هُوَ ‏"‏ ‏. هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَزَمْعَةُ بْنُ صَالِحٍ قَدْ ضَعَّفَهُ بَعْضُ أَهْلِ الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{3784}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) was carrying Al-Hasan bin 'Ali upon his shoulder, so a man said: "What an excellent mount you are riding, O child." So the Prophet (ﷺ) said: "And what an excellent rider he is}}
\hadithdefcmd{tirmidhi}{3785}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ كَثِيرٍ النَّوَّاءِ، عَنْ أَبِي إِدْرِيسَ، عَنِ الْمُسَيَّبِ بْنِ نَجْبَةَ، قَالَ قَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ كُلَّ نَبِيٍّ أُعْطِيَ سَبْعَةَ نُجَبَاءَ أَوْ نُقَبَاءَ وَأُعْطِيتُ أَنَا أَرْبَعَةَ عَشَرَ ‏"‏ ‏.‏ قُلْنَا مَنْ هُمَ قَالَ أَنَا وَابْنَاىَ وَجَعْفَرٌ وَحَمْزَةُ وَأَبُو بَكْرٍ وَعُمَرُ وَمُصْعَبُ بْنُ عُمَيْرٍ وَبِلاَلٌ وَسَلْمَانُ وَعَمَّارٌ وَالْمِقْدَادُ وَ حُذَيْفَةُ وَعَبْدُ اللَّهِ بْنُ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَلِيٍّ مَوْقُوفًا ‏.‏\hadithno{3785}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Musayyab bin Najabah:"'Ali bin Abi Talib said: 'The Prophet SAW said: "Indeed every Prophet is given seven select attendants" - or he said: "guards" - "and I was given fourteen." We said: "Who are they?" He said: 'Myself, my two sons (Al-Hasan and Al-Husain), Ja'far, Hamzah, Abu Bakr, 'Umar, Mus'ab bin 'Umair, Bilal, Salman, 'Ammar, Al-Miqdad, Hudhaifah, Abu Dharr, and 'Abdullah bin Mas'ud}}
\hadithdefcmd{tirmidhi}{3786}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحَسَنِ، هُوَ الأَنْمَاطِيُّ عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّتِهِ يَوْمَ عَرَفَةَ وَهُوَ عَلَى نَاقَتِهِ الْقَصْوَاءِ يَخْطُبُ فَسَمِعْتُهُ يَقُولُ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنِّي قَدْ تَرَكْتُ فِيكُمْ مَا إِنْ أَخَذْتُمْ بِهِ لَنْ تَضِلُّوا كِتَابَ اللَّهِ وَعِتْرَتِي أَهْلَ بَيْتِي ‏"‏ ‏.‏وَفِي الْبَابِ عَنْ أَبِي ذَرٍّ وَأَبِي سَعِيدٍ وَزَيْدِ بْنِ أَرْقَمَ وَحُذَيْفَةَ بْنِ أَسِيدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَزَيْدُ بْنُ الْحَسَنِ قَدْ رَوَى عَنْهُ سَعِيدُ بْنُ سُلَيْمَانَ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ ‏.‏\hadithno{3786}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin 'Abdullah:"I saw the Messenger of Allah during his Hajj, on the Day of 'Arafah. He was upon his camel Al-Qaswa, giving a Khutbah, so he said: 'O people! Indeed, I have left among you, that which if you hold fast to it, you shall not go astray: The Book of Allah and my family, the people of my house}}
\hadithdefcmd{tirmidhi}{3787}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَصْبَهَانِيُّ، عَنْ يَحْيَى بْنِ عُبَيْدٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، رَبِيبِ النَّبِيِّ صلى الله عليه وسلم قَالَ نَزَلَتْ هَذِهِ الآيَةُ عَلَى النَّبِيِّ صلى الله عليه وسلمَّ ‏:‏ ‏(‏ إنمَا يُرِيدُ اللَّهُ لِيُذْهِبَ عَنْكُمُ الرِّجْسَ أَهْلَ الْبَيْتِ وَيُطَهِّرَكُمْ تَطْهِيرًا ‏)‏ فِي بَيْتِ أُمِّ سَلَمَةَ فَدَعَا النَّبِيُّ صلى الله عليه وسلم فَاطِمَةَ وَحَسَنًا وَحُسَيْنًا فَجَلَّلَهُمْ بِكِسَاءٍ وَعَلِيٌّ خَلْفَ ظَهْرِهِ فَجَلَّلَهُ بِكِسَاءٍ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ هَؤُلاَءِ أَهْلُ بَيْتِي فَأَذْهِبْ عَنْهُمُ الرِّجْسَ وَطَهِّرْهُمْ تَطْهِيرًا ‏"‏ ‏.‏ قَالَتْ أُمُّ سَلَمَةَ وَأَنَا مَعَهُمْ يَا نَبِيَّ اللَّهِ قَالَ ‏"‏ أَنْتِ عَلَى مَكَانِكِ وَأَنْتِ إِلَيَّ خَيْرٍ ‏"‏ ‏. وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ وَمَعْقِلِ بْنِ يَسَارٍ وَأَبِي الْحَمْرَاءِ وَأَنَسٍ بْنِ مَالِكٍ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3787}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Umar bin Abi Salamah - the step-son of the Prophet (ﷺ):"When these Ayat were revealed to the Prophet (ﷺ): 'Allah only wishes to remove the Rijs from you, O members of the family, and to purify you with a thorough purification...' (33:33) in the home of Umm Salamah, he called for Fatimah, Hasan, Husain, and wrapped them in a cloak, and 'Ali was behind him, so he wrapped him in the cloak, then he said: 'O Allah! These are the people of my house, so remove the Rijs from them, and purify them with a thorough purification.' So Umm Salamah said: 'And am I with them O Messenger of Allah?' He said: 'You are in your place, and you are more virtuous to me}}
\hadithdefcmd{tirmidhi}{3788}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، - الْكُوفِيٌّ - قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، وَالأَعْمَشُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، رَضِيَ اللَّهُ عَنْهُمَا قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي تَارِكٌ فِيكُمْ مَا إِنْ تَمَسَّكْتُمْ بِهِ لَنْ تَضِلُّوا بَعْدِي أَحَدُهُمَا أَعْظَمُ مِنَ الآخَرِ كِتَابُ اللَّهِ حَبْلٌ مَمْدُودٌ مِنَ السَّمَاءِ إِلَى الأَرْضِ وَعِتْرَتِي أَهْلُ بَيْتِي وَلَنْ يَتَفَرَّقَا حَتَّى يَرِدَا عَلَىَّ الْحَوْضَ فَانْظُرُوا كَيْفَ تَخْلُفُونِي فِيهِمَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3788}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zaid bin Arqam, may Allah be pleased with both of them:that the Messenger of Allah (ﷺ) said:"Indeed, I am leaving among you, that which if you hold fast to them, you shall not be misguided after me. One of them is greater than the other: The Book of Allah is a rope extended from the sky to the earth, and my family - the people of my house - and they shall not split until they meet at the Hawd, so look at how you deal with them after me}}
\hadithdefcmd{tirmidhi}{3789}{حَدَّثَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ الأَشْعَثِ قَالَ أَخْبَرَنَا يَحْيَى بْنُ مَعِينٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ عَبْدِ اللَّهِ بْنِ سُلَيْمَانَ النَّوْفَلِيِّ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحِبُّوا اللَّهَ لِمَا يَغْذُوكُمْ مِنْ نِعَمِهِ وَأَحِبُّونِي بِحُبِّ اللَّهِ وَأَحِبُّوا أَهْلَ بَيْتِي لِحُبِّي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا ��َدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3789}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "Love Allah for what He nourishes you with of His Blessings, love me due to the love of Allah, and love the people of my house due to love of me}}
\hadithdefcmd{tirmidhi}{3790}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ دَاوُدَ الْعَطَّارِ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْحَمُ أُمَّتِي بِأُمَّتِي أَبُو بَكْرٍ وَأَشَدُّهُمْ فِي أَمْرِ اللَّهِ عُمَرُ وَأَصْدَقُهُمْ حَيَاءً عُثْمَانُ وَأَعْلَمُهُمْ بِالْحَلاَلِ وَالْحَرَامِ مُعَاذُ بْنُ جَبَلٍ وَأَفْرَضُهُمْ زَيْدُ بْنُ ثَابِتٍ وَأَقْرَؤُهُمْ أُبَىُّ بْنُ كَعْبٍ وَلِكُلِّ أُمَّةٍ أَمِينٌ وَأَمِينُ هَذِهِ الأُمَّةِ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ قَتَادَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَاهُ أَبُو قِلاَبَةَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَالْمَشْهُورُ حَدِيثُ أَبِي قِلاَبَةَ ‏.‏\hadithno{3790}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "The most merciful of my nation to my nation is Abu Bakr, and the most severe of them concerning the order of Allah is 'Umar, and the most truly modest of them is 'Uthman bin 'Affan. The most knowledgeable of them concerning the lawful and unlawful is Mu'adh Bin Jabal, the most knowledgeable of them concerning (the laws of) inheritance is Zaid bin Thabit, the best reciter (of the Qur'an) among them is Ubayy bin Ka'b, and every nation has a trustworthy one, and the trustworthy one of this nation is Abu 'Ubaidah Bin Al-Jarrah}}
\hadithdefcmd{tirmidhi}{3791}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ الثَّقَفِيُّ، قَالَ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْحَمُ أُمَّتِي بِأُمَّتِي أَبُو بَكْرٍ وَأَشَدُّهُمْ فِي أَمْرِ اللَّهِ عُمَرُ وَأَصْدَقُهُمْ حَيَاءً عُثْمَانُ وَأَقْرَؤُهُمْ لِكِتَابِ اللَّهِ أُبَىُّ بْنُ كَعْبٍ وَأَفْرَضُهُمْ زَيْدُ بْنُ ثَابِتٍ وَأَعْلَمُهُمْ بِالْحَلاَلِ وَالْحَرَامِ مُعَاذُ بْنُ جَبَلٍ أَلاَ وَإِنَّ لِكُلِّ أُمَّةٍ أَمِينًا وَإِنَّ أَمِينَ هَذِهِ الأُمَّةِ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3791}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "The most merciful of my nation to my nation is Abu Bakr, and the most severe of them concerning the order of Allah is 'Umar, and the most truly modest of them is 'Uthman bin 'Affan. The best reciter (of the Qur'an) among them is Ubayy bin Ka'b, the most knowledgeable of them concerning (the laws of) inheritance is Zaid bin Thabit, the most knowledgeable of them concerning the lawful and the unlawful is Mu'adh bin Jabal. Truly, every nation has a trustworthy one, and the trustworthy one of this nation is Abu 'Ubaidah bin Al-Jarrah}}
\hadithdefcmd{tirmidhi}{3792}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأُبَىِّ بْنِ كَعْبٍ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏:‏ ‏(‏ لَمْ يَكُنِ الَّذِينَ كَفَرُوا ‏)‏ ‏"‏ ‏.‏ قَالَ وَسَمَّانِي قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَبَكَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ أُبَىِّ بْنِ كَعْبٍ قَالَ قَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{3792}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said to Ubayy bin Ka'b: "Indeed Allah ordered me to recite to you: Those who disbelieve were not going to... (98:1) He said: "And He named me?" He said: "Yes." So he wept}}
\hadithdefcmd{tirmidhi}{3793}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ عَاصِمٍ، قَالَ سَمِعْتُ زِرَّ بْنَ حُبَيْشٍ، يُحَدِّثُ عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏"‏ ‏.‏ فَقَرَأَ عَلَيْهِ‏:‏ ‏(‏ لَمْ يَكُنِ الَّذِينَ كَفَرُوا مِنْ أَهْلِ الْكِتَابِ ‏)‏ فَقَرَأَ فِيهَا ‏"‏ إِنَّ ذَاتَ الدِّينِ عِنْدَ اللَّهِ الْحَنِيفِيَّةُ الْمُسْلِمَةُ لاَ الْيَهُودِيَّةُ وَلاَ النَّصْرَانِيَّةُ مَنْ يَعْمَلْ خَيْرًا فَلَنْ يُكْفَرَهُ ‏"‏ ‏.‏ وَقَرَأَ عَلَيْهِ ‏"‏ وَلَوْ أَنَّ لاِبْنِ آدَمَ وَادِيًا مِنْ مَالٍ لاَبْتَغَى إِلَيْهِ ثَانِيًا وَلَوْ كَانَ لَهُ ثَانِيًا لاَبْتَغَى إِلَيْهِ ثَالِثًا وَلاَ يَمْلأُ جَوْفَ ابْنِ آدَمَ إِلاَّ التُّرَابُ وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ رَوَاهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أَبِيهِ عَنْ أُبَىِّ بْنِ كَعْبٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَأُبَىِّ بْنِ كَعْبٍ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ الْقُرْآنَ ‏"‏ ‏.‏ وَقَدْ رَوَى قَتَادَةُ عَنْ أَنَسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأُبَىٍّ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ الْقُرْآنَ ‏"‏ ‏.‏\hadithno{3793}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ubayy bin Ka'b:that the Messenger of Allah (ﷺ) said to him: "Indeed, Allah ordered me to recite to you, so he recited in it: "Those who disbelieve from amongst the People of the Book were not going to...'" (And he) also recited in it, "Indeed, the religion with Allah is Al-Hanafiyyah, the Muslim, not Judaism, nor Christianity, whoever does good, it shall not be rejected from him." And he recited to him: "And if the son of Adam had a valley-full of wealth, he would seek a second, and if he had a second, he would seek a third, and nothing fills the belly of the son of Adam except for dirt. And Allah pardons those who repent}}
\hadithdefcmd{tirmidhi}{3794}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَمَعَ الْقُرْآنَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْبَعَةٌ كُلُّهُمْ مِنَ الأَنْصَارِ أُبَىُّ بْنُ كَعْبٍ وَمُعَاذُ بْنُ جَبَلٍ وَزَيْدُ بْنُ ثَابِتٍ وَأَبُو زَيْدٍ ‏.‏ قُلْتُ لأَنَسٍ مَنْ أَبُو زَيْدٍ قَالَ أَحَدُ عُمُومَتِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3794}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Qatadah:that Anas bin Malik said: "Four gathered the Qur'an during the time of the Messenger of Allah (ﷺ), all of them are from the Ansar: Ubayy bin Ka'b, Mu'adh bin Jabal, Zaid bin Thabit, and Abu Zaid." I said to Anas: "Who is Abu Zaid?" He said: "One of my uncles}}
\hadithdefcmd{tirmidhi}{3795}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نِعْمَ الرَّجُلُ أَبُو بَكْرٍ نِعْمَ الرَّجُلُ عُمَرُ نِعْمَ الرَّجُلُ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ نِعْمَ الرَّجُلُ أُسَيْدُ بْنُ حُضَيْرٍ نِعْمَ الرَّجُلُ ثَابِتُ بْنُ قَيْسِ بْنِ شَمَّاسٍ نِعْمَ الرَّجُلُ مُعَاذُ بْنُ جَبَلٍ نِعْمَ الرَّجُلُ مُعَاذُ بْنُ عَمْرِو بْنِ الْجَمُوحِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ سُهَيْلٍ ‏.‏\hadithno{3795}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:narrated that the Messenger of Allah (ﷺ) said: "What an excellent man is Abu Bakr, what an excellent man is 'Umar, what an excellent man is Abu 'Ubaidah bin Al-Jarrah, what an excellent man is Usaid bin Hudair, what an excellent man is Thabit bin Qais bin Shammas, what an excellent man is Mua'dh bin Jabal, and what an excellent man is Mu'adh bin 'Amr bin Al-Jamuh}}
\hadithdefcmd{tirmidhi}{3796}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ جَاءَ الْعَاقِبُ وَالسَّيِّدُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالاَ ابْعَثْ مَعَنَا أَمِينًا ‏.‏ فَقَالَ ‏"‏ فَإِنِّي سَأَبْعَثُ مَعَكُمْ أَمِينًا حَقَّ أَمِينٍ ‏"‏ ‏.‏ فَأَشْرَفَ لَهَا النَّاسُ فَبَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ رضى الله عنه ‏.‏ قَالَ وَكَانَ أَبُو إِسْحَاقَ إِذَا حَدَّثَ بِهَذَا الْحَدِيثِ عَنْ صِلَةَ قَالَ سَمِعْتُهُ مُنْذُ سِتِّينَ سَنَةً ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏. حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ أَخْبَرَنَا سَلْمُ بْنُ قُتَيْبَةَ وَأَبُو دَاوُدَ عَنْ شُعْبَةَ عَنْ أَبِي إِسْحَاقَ قَالَ قَالَ حُذَيْفَةُ قَلْبُ صِلَةَ بْنِ زُفَرَ مِنْ ذَهَبٍ ‏ وَقَدْ رُوِيَ عَنْ عُمَرَ وَأَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لِكُلِّ أُمَّةٍ أَمِينٌ وَأَمِينُ هَذِهِ الأُمَّةِ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏"‏ ‏.‏\hadithno{3796}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Hudhaifah bin Al-Yaman:that Al-'Aqib and As-Sayyid (two of the leaders of the Christians of Najran) came to the Prophet (ﷺ) and said: "Send with us your trustworthy one." He said: "I shall send with you a trustworthy one who is truly a trustworthy one." So the people desired that, and he sent Abu 'Ubaidah, may Allah be pleased with him}}
\hadithdefcmd{tirmidhi}{3797}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا أَبِي، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ أَبِي رَبِيعَةَ الإِيَادِيِّ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْجَنَّةَ تَشْتَاقُ إِلَى ثَلاَثَةٍ عَلِيٍّ وَعَمَّارٍ وَسَلْمَانَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْحَسَنِ بْنِ صَالِحٍ ‏.‏\hadithno{3797}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: 'Indeed, Paradise longs for three: 'Ali, 'Ammar, and Salman}}
\hadithdefcmd{tirmidhi}{3798}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ هَانِىءِ بْنِ هَانِىءٍ، عَنْ عَلِيٍّ، قَالَ جَاءَ عَمَّارٌ يَسْتَأْذِنُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ ائْذَنُوا لَهُ مَرْحَبًا بِالطَّيِّبِ الْمُطَيَّبِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3798}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Ali:that 'Ammar bin Yasir came seeking permission to enter upon the Prophet (ﷺ) so he said: 'Permit him, greetings to the pure one, the purified}}
\hadithdefcmd{tirmidhi}{3799}{\hadithno{3799}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{3800}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبْشِرْ عَمَّارُ تَقْتُلُكَ الْفِئَةُ الْبَاغِيَةُ ‏"‏ ‏. وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي الْيَسَرِ وَحُذَيْفَةَ ‏. وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ ‏.‏\hadithno{3800}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Rejoice, 'Ammar, the transgressing party shall kill you}}
\hadithdefcmd{tirmidhi}{3801}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنِ الأَعْمَشِ، عَنْ عُثْمَانَ بْنِ عُمَيْرٍ، هُوَ أَبُو الْيَقْظَانِ عَنْ أَبِي حَرْبِ بْنِ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا أَظَلَّتِ الْخَضْرَاءُ وَلاَ أَقَلَّتِ الْغَبْرَاءُ أَصْدَقَ مِنْ أَبِي ذَرٍّ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي الدَّرْدَاءِ وَأَبِي ذَرٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3801}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Messenger of Allah (ﷺ) said: "There is no one more truthful, that the sky has shaded and the earth has carried, than Abu Dharr}}
\hadithdefcmd{tirmidhi}{3802}{حَدَّثَنَا الْعَبَّاسُ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنِي أَبُو زُمَيْلٍ، هُوَ سِمَاكُ بْنُ الْوَلِيدِ الْحَنَفِيُّ عَنْ مَالِكِ بْنِ مَرْثَدٍ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَظَلَّتِ الْخَضْرَاءُ وَلاَ أَقَلَّتِ الْغَبْرَاءُ مِنْ ذِي لَهْجَةٍ أَصْدَقَ وَلاَ أَوْفَى مِنْ أَبِي ذَرٍّ شِبْهِ عِيسَى ابْنِ مَرْيَمَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ كَالْحَاسِدِ يَا رَسُولَ اللَّهِ أَفَنَعْرِفُ ذَلِكَ لَهُ قَالَ ‏"‏ نَعَمْ فَاعْرِفُوهُ لَهُ ‏"‏ ‏. هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ فَقَالَ ‏"‏ أَبُو ذَرٍّ يَمْشِي فِي الأَرْضِ بِزُهْدِ عِيسَى ابْنِ مَرْيَمَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{3802}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Dharr:that the Messenger of Allah (ﷺ) said: "There is no one more truthful in speech, nor in fulfilling of promises, that sky has covered and the earth has carried, than Abu Dharr, the likeness of 'Eisa bin Mariam." So 'Umar bin Al-Khattab said, as if out of envy: "So do you acknowledge that for him, O Messenger of Allah?" He said: "Yes, so acknowledge it}}
\hadithdefcmd{tirmidhi}{3803}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ، قَالَ حَدَّثَنَا أَبُو مُحَيَّاةَ يَحْيَى بْنُ يَعْلَى بْنِ عَطَاءٍ عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنِ ابْنِ أَخِي عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ لَمَّا أُرِيدَ قَتْلُ عُثْمَانَ جَاءَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ فَقَالَ لَهُ عُثْمَانُ مَا جَاءَ بِكَ قَالَ جِئْتُ فِي نَصْرِكَ ‏.‏ قَالَ اخْرُجْ إِلَى النَّاسِ فَاطْرُدْهُمْ عَنِّي فَإِنَّكَ خَارِجًا خَيْرٌ لِي مِنْكَ دَاخِلاً ‏.‏ فَخَرَجَ عَبْدُ اللَّهِ إِلَى النَّاسِ فَقَالَ أَيُّهَا النَّاسُ إِنَّهُ كَانَ اسْمِي فِي الْجَاهِلِيَّةِ فُلاَنٌ فَسَمَّانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَبْدَ اللَّهِ وَنَزَلَتْ فِيَّ آيَاتٌ مِنْ كِتَابِ اللَّهِ فَنَزَلَتْ فِيَّ ‏:‏ ‏(‏ وشهد شَاهِدٌ مِنْ بَنِي إِسْرَائِيلَ عَلَى مِثْلِهِ فَآمَنَ وَاسْتَكْبَرْتُمْ إِنَّ اللَّهَ لاَ يَهْدِي الْقَوْمَ الظَّالِمِينَ ‏)‏ وَنَزَلَتْ فِيَّ ‏:‏ ‏(‏ قلْ كَفَى بِاللَّهِ شَهِيدًا بَيْنِي وَبَيْنَكُمْ وَمَنْ عِنْدَهُ عِلْمُ الْكِتَابِ ‏)‏ إِنَّ لِلَّهِ سَيْفًا مَغْمُودًا عَنْكُمْ وَإِنَّ الْمَلاَئِكَةَ قَدْ جَاوَرَتْكُمْ فِي بَلَدِكُمْ هَذَا الَّذِي نَزَلَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاللَّهَ اللَّهَ فِي هَذَا الرَّجُلِ أَنْ تَقْتُلُوهُ فَوَاللَّهِ لَئِنْ قَتَلْتُمُوهُ لَتَطْرُدُنَّ جِيرَانَكُمُ الْمَلاَئِكَةَ وَلَتَسُلُّنَّ سَيْفَ اللَّهِ الْمَغْمُودَ عَنْكُمْ فَلاَ يُغْمَدُ عَنْكُمْ إِلَى يَوْمِ الْقِيَامَةِ ‏.‏ قَالُوا اقْتُلُوا الْيَهُودِيَّ وَاقْتُلُوا عُثْمَانَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ ‏.‏ وَقَدْ رَوَى شُعَيْبُ بْنُ صَفْوَانَ هَذَا الْحَدِيثَ عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ فَقَالَ عَنْ عُمَرَ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ ‏.‏\hadithno{3803}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdul-Malik bin 'Umair:from the nephew of 'Abdullah bin Salam who said: "When they were about to kill 'Uthman, 'Abdullah bin Salam came and 'Uthman said to him: 'What did you come for?' He said: 'I came to assist you.' He said: 'Go to the people to repel their advances against me. For verily your going is better to me than your entering here.' So 'Abdullah went to the people and said: 'O you people! During Jahiliyyah I was named so-and-so, then the Messenger of Allah (ﷺ) named me 'Abdullah, and some Ayat from the Book of Allah were revealed about me. (The following) was revealed about me: "A witness from among the Children of Isra'il has testified to something similar and believed while you rejected. Verily, Allah does not guide the wrongdoing people. (46:10)" [And (the following) was revealed about me:] "Sufficient as a witness between me and you is Allah, and those too who have knowledge of the Scripture. (13:43)" Allah has sheathed the sword from you and the angels are your neighbors in this city of yours, the one in which the Revelation came to the Messenger of Allah (ﷺ). But by Allah! (Fear) Allah regarding this man; if you kill him, then by Allah! If you kill him, then you will cause the angels to remove your goodness from you, and to raise Allah's sheathed sword against you, such that it will never be sheathed again until the Day of Resurrection.'" He said: "They said: 'Kill the Jew and kill 'Uthman}}
\hadithdefcmd{tirmidhi}{3804}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ يَزِيدَ بْنِ عَمِيرَةَ، قَالَ لَمَّا حَضَرَ مُعَاذَ بْنَ جَبَلٍ الْمَوْتُ قِيلَ لَهُ يَا أَبَا عَبْدِ الرَّحْمَنِ أَوْصِنَا ‏.‏ قَالَ أَجْلِسُونِي ‏.‏ فَقَالَ إِنَّ الْعِلْمَ وَالإِيمَانَ مَكَانَهُمَا مَنِ ابْتَغَاهُمَا وَجَدَهُمَا يَقُولُ ذَلِكَ ثَلاَثَ مَرَّاتٍ وَالْتَمِسُوا الْعِلْمَ عِنْدَ أَرْبَعَةِ رَهْطٍ عِنْدَ عُوَيْمِرٍ أَبِي الدَّرْدَاءِ وَعِنْدَ سَلْمَانَ الْفَارِسِيِّ وَعِنْدَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَعِنْدَ عَبْدِ اللَّهِ بْنِ سَلاَمٍ الَّذِي كَانَ يَهُودِيًّا فَأَسْلَمَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّهُ عَاشِرُ عَشَرَةٍ فِي الْجَنَّةِ ‏"‏ ‏. وَفِي الْبَابِ عَنْ سَعْدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3804}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Yazid bin 'Umairah:"When death was upon Mu'adh bin Jabal, it was said to him: 'O Abu 'Abdur-Rahman, advise us.' He said: 'Sit me up.' So he said: 'Indeed, knowledge and faith are at their place, whoever desires them shall find them.' He said that three times. 'And seek knowledge from four men: 'Uwaimir Abu Ad-Darda, with Salman Al-Farisi, with 'Abdullah bin Mas'ud, and with 'Abdullah bin Salam who used to be a Jew and then accepted Islam. For indeed, I heard the Messenger of Allah (ﷺ) saying, "Indeed he is the tenth of ten in Paradise}}
\hadithdefcmd{tirmidhi}{3805}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ بْنِ يَحْيَى بْنِ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي الزَّعْرَاءِ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْتَدُوا بِاللَّذَيْنِ مِنْ بَعْدِي مِنْ أَصْحَابِي أَبِي بَكْرٍ وَعُمَرَ وَاهْتَدُوا بِهَدْىِ عَمَّارٍ وَتَمَسَّكُوا بِعَهْدِ ابْنِ مَسْعُودٍ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ابْنِ مَسْعُودٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ سَلَمَةَ بْنِ كُهَيْلٍ ‏.‏ وَيَحْيَى بْنُ سَلَمَةَ يُضَعَّفُ فِي الْحَدِيثِ وَأَبُو الزَّعْرَاءِ اسْمُهُ عَبْدُ اللَّهِ بْنُ هَانِئٍ وَأَبُو الزَّعْرَاءِ الَّذِي رَوَى عَنْهُ شُعْبَةُ وَالثَّوْرِيُّ وَابْنُ عُيَيْنَةَ اسْمُهُ عَمْرُو بْنُ عَمْرٍو وَهُوَ ابْنُ أَخِي أَبِي الأَحْوَصِ صَاحِبُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏.‏\hadithno{3805}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn Mas'ud:that the Messenger of Allah (ﷺ) said: "Take as examples the two after me from my Companions, Abu Bakr and 'Umar. And act upon the guidance of 'Ammar, and hold fast to the advice of Ibn Mas'ud}}
\hadithdefcmd{tirmidhi}{3806}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، أَنَّهُ سَمِعَ أَبَا مُوسَى، يَقُولُ لَقَدْ قَدِمْتُ أَنَا وَأَخِي، مِنَ الْيَمَنِ وَمَا نُرَى حِينًا إِلاَّ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ رَجُلٌ مِنْ أَهْلِ بَيْتِ النَّبِيِّ صلى الله عليه وسلم لِمَا نَرَى مِنْ دُخُولِهِ وَدُخُولِ أُمِّهِ عَلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ عَنْ أَبِي إِسْحَاقَ ‏.‏\hadithno{3806}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Musa:"My brother and I arrived from Yemen, and we did not see a period except that we thought 'Abdullah bin Mas'ud was a man from the people of the house of the Prophet (ﷺ), due to what we would see of him entering, and his mother's entering, upon the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{3807}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ أَتَيْنَا عَلَى حُذَيْفَةَ فَقُلْنَا حَدِّثْنَا مَنْ، بِأَقْرَبِ النَّاسِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم هَدْيًا وَدَلاًّ فَنَأْخُذَ عَنْهُ وَنَسْمَعَ مِنْهُ قَالَ كَانَ أَقْرَبَ النَّاسِ هَدْيًا وَدَلاًّ وَسَمْتًا بِرَسُولِ اللَّهِ صلى الله عليه وسلم ابْنُ مَسْعُودٍ حَتَّى يَتَوَارَى مِنَّا فِي بَيْتِهِ وَلَقَدْ عَلِمَ الْمَحْفُوظُونَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ ابْنَ أُمِّ عَبْدٍ هُوَ مِنْ أَقْرَبِهِمْ إِلَى اللَّهِ زُلْفَى ‏. هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3807}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Abdur-Rahman bin Yazid:"We came to Hudhaifah and said: 'Inform us of the closest to the Messenger of Allah (ﷺ) in guidance and conduct, so that we may take from him and hear from him.' He said: 'The closest of the people in guidance, conduct, and character used to be 'Abdullah bin Mas'ud, until he would hide from us in his house. And the guarded ones (guarded by Allah from straying in word and deed) from the Companions of Muhammad (ﷺ) know that Ibn Umm 'Abd (a nickname for 'Abdullah bin Mas'ud) is from among the most intimately close to Allah of them}}
\hadithdefcmd{tirmidhi}{3808}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنَا صَاعِدٌ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا مَنْصُورٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ مُؤَمِّرًا أَحَدًا مِنْ غَيْرِ مَشُورَةٍ مِنْهُمْ لأَمَّرْتُ عَلَيْهِمُ ابْنَ أُمِّ عَبْدٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ الْحَارِثِ عَنْ عَلِيٍّ ‏.‏\hadithno{3808}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:that the Messenger of Allah (ﷺ) said: "If I was going to appoint anyone of them as a leader without any consultation, I would appoint Ibn Umm 'Abd over them}}
\hadithdefcmd{tirmidhi}{3809}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ مُؤَمِّرًا أَحَدًا مِنْ غَيْرِ مَشُورَةٍ لأَمَّرْتُ ابْنَ أُمِّ عَبْدٍ ‏"‏ ‏.‏\hadithno{3809}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:that the Messenger of Allah (ﷺ) said: "If I was going to appoint anyone as a leader without any consultation, I would appoint Ibn Umm 'Abd}}
\hadithdefcmd{tirmidhi}{3810}{حَدَّثَنَا هَنَّادٌ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنِ ابْنِ مَسْعُودٍ وَأُبَىِّ بْنِ كَعْبٍ وَمُعَاذِ بْنِ جَبَلٍ وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ ‏"‏ ‏. هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3810}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Messenger of Allah (ﷺ) said: "Take the Qur'an from four: From Ibn Mas'ud, Ubayy bin Ka'b, Mu'adh bin Jabal, and Salim the freed slave of Abu Hudhaifah}}
\hadithdefcmd{tirmidhi}{3811}{حَدَّثَنَا الْجَرَّاحُ بْنُ مَخْلَدٍ الْبَصْرِيُّ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ خَيْثَمَةَ بْنِ أَبِي سَبْرَةَ، قَالَ أَتَيْتُ الْمَدِينَةَ فَسَأَلْتُ اللَّهَ أَنْ يُيَسِّرَ لِي جَلِيسًا صَالِحًا فَيَسَّرَ لِي أَبَا هُرَيْرَةَ فَجَلَسْتُ إِلَيْهِ فَقُلْتُ لَهُ إِنِّي سَأَلْتُ اللَّهَ أَنْ يُيَسِّرَ لِي جَلِيسًا صَالِحًا فَوُفِّقْتَ لِي ‏.‏ فَقَالَ لِي مِنْ أَيْنَ أَنْتَ قُلْتُ مِنْ أَهْلِ الْكُوفَةِ جِئْتُ أَلْتَمِسُ الْخَيْرَ وَأَطْلُبُهُ ‏.‏ قَالَ أَلَيْسَ فِيكُمْ سَعْدُ بْنُ مَالِكٍ مُجَابُ الدَّعْوَةِ وَابْنُ مَسْعُودٍ صَاحِبُ طَهُورِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَعْلَيْهِ وَحُذَيْفَةُ صَاحِبُ سِرِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَمَّارُ الَّذِي أَجَارَهُ اللَّهُ مِنَ الشَّيْطَانِ عَلَى لِسَانِ نَبِيِّهِ وَسَلْمَانُ صَاحِبُ الْكِتَابَيْنِ ‏.‏ قَالَ قَتَادَةُ وَالْكِتَابَانِ الإِنْجِيلُ وَالْقُرْآنُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَخَيْثَمَةُ هُوَ ابْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَبْرَةَ نُسِبَ إِلَى جَدِّهِ ‏.‏\hadithno{3811}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khaithamah bin Abi Sabrah:"I came to Al-Madinah, so I asked Allah to make it easy for me to sit with one who is righteous. He made Abu Hurairah accessible to me, so I sat with him and said to him: 'Indeed, I asked Allah to make it easy for me to sit with one who is righteous, and it is to you that I was guided.' So he said to me: 'From where are you?' I said: 'From the people of Al-Kufah, I came to search out good and to seek it.' So he said: 'Is there not among you Sa'd bin Malik whose supplication is answered, Ibn Mas'ud, the one who used to carry the water for purification and the sandals of the Messenger of Allah (ﷺ), and Hudhaifah, the keeper of the secrets of the Messenger of Allah (ﷺ), and 'Ammar whom Allah has guarded from Shaitan upon the tongue of His Prophet, and Salman the companion of the Two Books?}}
\hadithdefcmd{tirmidhi}{3812}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنَا إِسْحَاقُ بْنُ عِيسَى، عَنْ شَرِيكٍ، عَنْ أَبِي الْيَقْظَانِ، عَنْ زَاذَانَ، عَنْ حُذَيْفَةَ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ لَوِ اسْتَخْلَفْتَ ‏.‏ قَالَ ‏ "‏ إِنِ اسْتَخْلَفْتُ عَلَيْكُمْ فَعَصَيْتُمُوهُ عُذِّبْتُمْ وَلَكِنْ مَا حَدَّثَكُمْ حُذَيْفَةُ فَصَدِّقُوهُ وَمَا أَقْرَأَكُمْ عَبْدُ اللَّهِ فَاقْرَءُوهُ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ فَقُلْتُ لإِسْحَاقَ بْنِ عِيسَى يَقُولُونَ هَذَا عَنْ أَبِي وَائِلٍ ‏.‏ قَالَ لاَ عَنْ زَاذَانَ إِنْ شَاءَ اللَّهُ ‏. هَذَا حَدِيثٌ حَسَنٌ وَهُوَ حَدِيثُ شَرِيكٍ ‏.‏\hadithno{3812}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hudhaifah:that they said: "O Messenger of Allah, if you were to appoint someone as a successor." He said: "If I were to appoint a successor over you, and you were to disobey him, you would be punished. But whatever Hudhaifah narrates to you, then believe him, and whatever 'Abdullah teaches you to recite, then recite it}}
\hadithdefcmd{tirmidhi}{3813}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ، أَنَّهُ فَرَضَ لأُسَامَةَ بْنِ زَيْدٍ فِي ثَلاَثَةِ آلاَفٍ وَخَمْسِمِائَةٍ وَفَرَضَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ فِي ثَلاَثَةِ آلاَفٍ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لأَبِيهِ لِمَ فَضَّلْتَ أُسَامَةَ عَلَىَّ فَوَاللَّهِ مَا سَبَقَنِي إِلَى مَشْهَدٍ ‏.‏ قَالَ لأَنَّ زَيْدًا كَانَ أَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَبِيكَ وَكَانَ أُسَامَةُ أَحَبَّ إِلَى رَسُولِ اللَّهِ مِنْكَ فَآثَرْتُ حُبَّ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى حُبِّي ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3813}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Zaid bin Aslam:from his father, from 'Umar, that he ('Umar) granted a stipend of three-thousand and five-hundred to Usamah bin Zaid, and he granted three-thousand to 'Abdullah bin 'Umar. So 'Abdullah bin 'Umar said to his father: "Why have you given preference to Usamah over me? For by Allah, he has not preceded me to any battle." He said: "Because Zaid used to be more beloved to the Messenger of Allah (ﷺ) than your father, and Usamah was more beloved to the Messenger of Allah (ﷺ) than you. So I gave preference to the beloved of the Messenger of Allah (ﷺ) over my beloved}}
\hadithdefcmd{tirmidhi}{3814}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ مَا كُنَّا نَدْعُو زَيْدَ بْنَ حَارِثَةَ إِلاَّ زَيْدَ بْنَ مُحَمَّدٍ حَتَّى نَزَلَتْ ‏:‏ ‏(‏ ادعُوهُمْ لِأَبَائِهِمْ هُوَ أَقْسَطُ عِنْدَ اللَّهِ ‏)‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3814}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:"We called Zaid bin Harithah nothing but 'Zaid bin Muhammad' until the Qur'an was revealed (ordering): Call them by their fathers, that is more just according to Allah. (33:)}}
\hadithdefcmd{tirmidhi}{3815}{حَدَّثَنَا الْجَرَّاحُ بْنُ مَخْلَدٍ الْبَصْرِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ الرُّومِيِّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، قَالَ أَخْبَرَنِي جَبَلَةُ بْنُ حَارِثَةَ، أَخُو زَيْدٍ قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ ابْعَثْ مَعِي أَخِي زَيْدًا ‏.‏ قَالَ ‏"‏ هُوَ ذَا ‏"‏ ‏.‏ قَالَ ‏"‏ فَإِنِ انْطَلَقَ مَعَكَ لَمْ أَمْنَعْهُ ‏"‏ ‏.‏ قَالَ زَيْدٌ يَا رَسُولَ اللَّهِ وَاللَّهِ لاَ أَخْتَارُ عَلَيْكَ أَحَدًا ‏.‏ قَالَ فَرَأَيْتُ رَأْىَ أَخِي أَفْضَلَ مِنْ رَأْيِي ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ الرُّومِيِّ عَنْ عَلِيِّ بْنِ مُسْهِرٍ ‏.‏\hadithno{3815}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabalah bin Harithah, the brother of Zaid:"I came to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, send my brother Zaid with me.' He said: 'Here he is.' He said: "'If he goes with you, I will not prevent him.' Zaid said: 'O Messenger of Allah, by Allah, I will not choose anyone over you.'" He said: "So I considered the view of my brother to be better than my own view}}
\hadithdefcmd{tirmidhi}{3816}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ بَعْثًا وَأَمَّرَ عَلَيْهِمْ أُسَامَةَ بْنَ زَيْدٍ فَطَعَنَ النَّاسُ فِي إِمَارَتِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنْ تَطْعَنُوا فِي إِمَارَتِهِ فَقَدْ كُنْتُمْ تَطْعَنُونَ فِي إِمْرَةِ أَبِيهِ مِنْ قَبْلُ وَايْمُ اللَّهِ إِنْ كَانَ لَخَلِيقًا لِلإِمَارَةِ وَإِنْ كَانَ مِنْ أَحَبِّ النَّاسِ إِلَىَّ وَإِنَّ هَذَا مِنْ أَحَبِّ النَّاسِ إِلَىَّ بَعْدَهُ ‏"‏ ‏. هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ مَالِكِ بْنِ أَنَسٍ ‏.‏\hadithno{3816}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) sent and army and put Usamah bin Zaid in charge of them. So the people contested his leadership, so the Prophet (ﷺ) said: 'If you contest his leadership, then you did contest the leadership of his father before him. And indeed, by Allah, he was certainly fit for leadership, and he was of the most beloved of people to me, and this one is among the most beloved of people to me after him}}
\hadithdefcmd{tirmidhi}{3817}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ عُبَيْدِ بْنِ السَّبَّاقِ، عَنْ مُحَمَّدِ بْنِ أُسَامَةَ بْنِ زَيْدٍ، عَنْ أَبِيهِ، قَالَ لَمَّا ثَقُلَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَبَطْتُ وَهَبَطَ النَّاسُ الْمَدِينَةَ فَدَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أُصْمِتَ فَلَمْ يَتَكَلَّمْ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ يَدَيْهِ عَلَىَّ وَيَرْفَعُهُمَا فَأَعْرِفُ أَنَّهُ يَدْعُو لِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3817}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Muhammad bin Usamah bin Zaid:from his father, that he said: "When the Messenger of Allah (ﷺ) became weak, I marched and the people marched upon Al-Madinah. I entered upon the Messenger of Allah (ﷺ) and he was unable to speak (because of weakness), so he did not say anything. So the Messenger of Allah (ﷺ) began to place his hands upon me and then raise them up, so I knew he was supplicating for me}}
\hadithdefcmd{tirmidhi}{3818}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُنَحِّيَ مُخَاطَ أُسَامَةَ قَالَتْ عَائِشَةُ دَعْنِي دَعْنِي حَتَّى أَكُونَ أَنَا الَّذِي أَفْعَلُ ‏.‏ قَالَ ‏ "‏ يَا عَائِشَةُ أَحِبِّيهِ فَإِنِّي أُحِبُّهُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3818}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah, the Mother of the Believers:"The Prophet (ﷺ) wanted to wipe the running nose of Usamah." 'Aishah said: "Leave it to me so that I may be the one to do it." He said: "O 'Aishah, love him, for verily I love him}}
\hadithdefcmd{tirmidhi}{3819}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، قَالَ حَدَّثَنَا عُمَرُ بْنُ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، قَالَ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ جَاءَ عَلِيٌّ وَالْعَبَّاسُ يَسْتَأْذِنَانِ فَقَالاَ يَا أُسَامَةُ اسْتَأْذِنْ لَنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ عَلِيٌّ وَالْعَبَّاسُ يَسْتَأْذِنَانِ ‏.‏ فَقَالَ ‏"‏ أَتَدْرِي مَا جَاءَ بِهِمَا ‏"‏ ‏.‏ قُلْتُ لاَ أَدْرِيَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَكِنِّي أَدْرِي ‏"‏ ‏.‏ فَأَذِنَ لَهُمَا فَدَخَلاَ فَقَالاَ يَا رَسُولَ اللَّهِ جِئْنَاكَ نَسْأَلُكَ أَىُّ أَهْلِكَ أَحَبُّ إِلَيْكَ قَالَ ‏"‏ فَاطِمَةُ بِنْتُ مُحَمَّدٍ ‏"‏ ‏.‏ فَقَالاَ مَا جِئْنَاكَ نَسْأَلُكَ عَنْ أَهْلِكَ ‏.‏ قَالَ ‏"‏ أَحَبُّ أَهْلِي إِلَىَّ مَنْ قَدْ أَنْعَمَ اللَّهُ عَلَيْهِ وَأَنْعَمْتُ عَلَيْهِ أُسَامَةُ بْنُ زَيْدٍ ‏"‏ ‏.‏ قَالاَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ عَلِيُّ بْنُ أَبِي طَالِبٍ ‏"‏ ‏.‏ قَالَ الْعَبَّاسُ يَا رَسُولَ الله جَعَلْتَ عَمَّكَ آخِرَهُمْ قَالَ ‏"‏ لأَنَّ عَلِيًّا قَدْ سَبَقَكَ بِالْهِجْرَةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَكَانَ شُعْبَةُ يُضَعِّفُ عُمَرَ بْنَ أَبِي سَلَمَةَ ‏.‏\hadithno{3819}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Usamah bin Zaid:"I was sitting [with the Prophet (ﷺ)] when 'Ali and Al-'Abbas came seeking permission to enter. They said: 'O Usamah, seek permission for us from the Messenger of Allah (ﷺ).' So I said: 'O Messenger of Allah, 'Ali and Al-'Abbas seek permission to enter.' He said: 'Do you know what has brought them?' I said: 'No [I do not know].' So the Prophet (ﷺ) said: 'But I know, grant them permission.' So they entered and said: 'O Messenger of Allah, we have come to you, to ask you which of your family is most beloved to you.' He said: 'Fatimah bint Muhammad.' So they said: 'We did not come to ask you about (immediate) family.' He said: 'The most beloved of my family to me is the one whom Allah favored and I favored, Usamah bin Zaid.' They said: 'Then who?' He said: 'Then 'Ali bin Abi Talib.' Al-'Abbas said: 'O Messenger of Allah, you have made your uncle the last of them.' He said: 'Indeed, 'Ali has preceded you in emigration}}
\hadithdefcmd{tirmidhi}{3820}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو الأَزْدِيُّ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ بَيَانٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ مَا حَجَبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ وَلاَ رَآنِي إِلاَّ ضَحِكَ . هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3820}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jarir bin 'Abdullah:"The Messenger of Allah (ﷺ) never screened me since I accepted Islam, nor did he look at me except that he laughed}}
\hadithdefcmd{tirmidhi}{3821}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، قَالَ مَا حَجَبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ وَلاَ رَآنِي إِلاَّ تَبَسَّمَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3821}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jarir:"The Messenger of Allah (ﷺ) never screened me since I accepted Islam, nor did he look at me except that he smiled}}
\hadithdefcmd{tirmidhi}{3822}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو أَحْمَدَ، عَنْ سُفْيَانَ، عَنْ لَيْثٍ، عَنْ أَبِي جَهْضَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ رَأَى جِبْرِيلَ عَلَيْهِ السَّلاَمُ مَرَّتَيْنِ وَدَعَا لَهُ النَّبِيُّ صلى الله عليه وسلم مَرَّتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُرْسَلٌ ‏.‏ وَلاَ نَعْرِفُ لأَبِي جَهْضَمٍ سَمَاعًا مِنَ ابْنِ عَبَّاسٍ ‏.‏ وَقَدْ رُوِيَ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَأَبُو جَهْضَمٍ اسْمُهُ مُوسَى بْنُ سَالِمٍ ‏.‏\hadithno{3822}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Jahdam:from Ibn 'Abbas that he saw Jibra'il (AS), two times and the Prophet (ﷺ) supplicated for him two times}}
\hadithdefcmd{tirmidhi}{3823}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُكْتِبُ الْمُؤَدِّبُ، قَال حَدَّثَنَا الْقَاسِمُ بْنُ مَالِكٍ الْمُزَنِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ دَعَا لِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُؤْتِيَنِي اللَّهُ الْحِكْمَةَ مَرَّتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَطَاءٍ ‏.‏ وَقَدْ رَوَاهُ عِكْرِمَةُ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{3823}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) supplicated for me that Allah should give me Al-Hukm (knowledge, understanding, judging justly, or understanding of the Qur'an) two times}}
\hadithdefcmd{tirmidhi}{3824}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَال حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، قَال أَخْبَرَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ضَمَّنِي إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ اللَّهُمَّ عَلِّمْهُ الْحِكْمَةَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3824}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) pulled me close to him and said: 'O Allah, teach him Al-Hikmah (wisdom)}}
\hadithdefcmd{tirmidhi}{3825}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ فِي الْمَنَامِ كَأَنَّمَا بِيَدِي قِطْعَةُ إِسْتَبْرَقٍ وَلاَ أُشِيرُ بِهَا إِلَى مَوْضِعٍ مِنَ الْجَنَّةِ إِلاَّ طَارَتْ بِي إِلَيْهِ فَقَصَصْتُهَا عَلَى حَفْصَةَ فَقَصَّتْهَا حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ أَخَاكِ رَجُلٌ صَالِحٌ ‏"‏ ‏.‏ أَوْ ‏"‏ إِنَّ عَبْدَ اللَّهِ رَجُلٌ صَالِحٌ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3825}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:"I had a dream in which I saw as if there was a piece of silk in my hand, and I would not gesture to any place in Paradise except that it would fly with me, (taking me) to it. So I told the dream to Hafsah, so she told it to the Prophet (ﷺ), so he said: 'Indeed, your brother is a righteous man,' or 'Indeed, 'Abdullah is a righteous man}}
\hadithdefcmd{tirmidhi}{3826}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِسْحَاقَ الْجَوْهَرِيُّ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُؤَمَّلِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى فِي بَيْتِ الزُّبَيْرِ مِصْبَاحًا فَقَالَ ‏ "‏ يَا عَائِشَةُ مَا أُرَى أَسْمَاءَ إِلاَّ قَدْ نَفِسَتْ فَلاَ تُسَمُّوهُ حَتَّى أُسَمِّيَهُ ‏"‏ ‏.‏ فَسَمَّاهُ عَبْدَ اللَّهِ وَحَنَّكَهُ بِتَمْرَةٍ بِيَدِهِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3826}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Abi Mulaikah:from 'Aishah, that the Prophet (ﷺ) saw a lamp in the house of Az-Zubair, so he said: "O 'Aishah, I do not think except that Asma has given birth, so do not name him until I should name him." So he named him 'Abdullah, and he (performed Tahnik) with a date that was in his hand}}
\hadithdefcmd{tirmidhi}{3827}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنِ الْجَعْدِ أَبِي عُثْمَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَمِعَتْ أُمِّي أُمُّ سُلَيْمٍ صَوْتَهُ فَقَالَتْ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ أُنَيْسٌ ‏.‏ قَالَ فَدَعَا لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَ دَعَوَاتٍ قَدْ رَأَيْتُ مِنْهُنَّ اثْنَيْنِ فِي الدُّنْيَا وَأَنَا أَرْجُو الثَّالِثَةَ فِي الآخِرَةِ ‏. هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3827}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas bin Malik:"The Messenger of Allah (ﷺ) passed by, so my mother, Umm Sulaim, heard his voice and said: 'May my father and mother be ransomed for you, O Messenger of Allah. This is Unais.' So the Messenger of Allah (ﷺ) supplicated for me with three supplications, and I have seem two of them in the world, and I hope for the third in the Hereafter}}
\hadithdefcmd{tirmidhi}{3828}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ شَرِيكٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَنَسٍ، قَالَ رُبَّمَا قَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا ذَا الأُذُنَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو أُسَامَةَ يَعْنِي يُمَازِحُهُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3828}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas bin Malik:that the Prophet (ﷺ) said to him: "O possessor of two ears!" (One of the narrators) Abu Usamah said: 'He only meant it as a joke}}
\hadithdefcmd{tirmidhi}{3829}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أُمِّ سُلَيْمٍ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ أَنَسٌ خَادِمُكَ ادْعُ اللَّهَ لَهُ ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3829}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:from Umm Sulaim, that she said: "O Messenger of Allah, Anas bin Malik is your servant, supplicate to Allah for him." He said: "O Allah, increase his wealth and his children, and bless him in what You have given him}}
\hadithdefcmd{tirmidhi}{3830}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ جَابِرٍ، عَنْ أَبِي نَصْرٍ، عَنْ أَنَسٍ، رضى الله عنه قَالَ كَنَّانِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِبَقْلَةٍ كُنْتُ أَجْتَنِيهَا ‏. هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ جَابِرٍ الْجُعْفِيِّ عَنْ أَبِي نَصْرٍ ‏.‏ وَأَبُو نَصْرٍ هُوَ خَيْثَمَةُ بْنُ أَبِي خَيْثَمَةَ الْبَصْرِيُّ رَوَى عَنْ أَنَسٍ أَحَادِيثَ ‏.‏\hadithno{3830}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas [may Allah be pleased with him]:"The Messenger of Allah (ﷺ) gave me my Kunyah because of a plant that I used to care for}}
\hadithdefcmd{tirmidhi}{3831}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، قَالَ حَدَّثَنَا مَيْمُونٌ أَبُو عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ قَالَ قَالَ لِي أَنَسُ بْنُ مَالِكٍ يَا ثَابِتُ خُذْ عَنِّي فَإِنَّكَ لَمْ تَأْخُذْ عَنْ أَحَدٍ أَوْثَقَ مِنِّي إِنِّي أَخَذْتُهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ جِبْرِيلَ وَأَخَذَهُ جِبْرِيلُ عَنِ اللَّهِ تَعَالَى ‏. هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ زَيْدِ بْنِ حُبَابٍ ‏.‏\hadithno{3831}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Thabit Al-Bunani:"Anas bin Malik said to me: 'O Thabit, take from me, for indeed you shall not take from one more trustworthy than me. Verily, I took it from the Messenger of Allah (ﷺ), and the Messenger of Allah (ﷺ) took it from Jibra'il, and Jibra'il took it from Allah the Mighty and Sublime}}
\hadithdefcmd{tirmidhi}{3832}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ مَيْمُونٍ أَبِي عَبْدِ اللَّهِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، نَحْوَ حَدِيثِ إِبْرَاهِيمَ بْنِ يَعْقُوبَ وَلَمْ يَذْكُرْ فِيهِ وَأَخَذَهُ النَّبِيُّ صلى الله عليه وسلم عَنْ جِبْرِيلَ ‏.‏\hadithno{3832}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Narrated Thabit:from Anas, similar to the previous narration of Ibrahim bin Ya'qub, and he did not mention in it: "And the Prophet (ﷺ) took it from Jibra'il}}
\hadithdefcmd{tirmidhi}{3833}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ أَبِي خَلْدَةَ، قَالَ قُلْتُ لأَبِي الْعَالِيَةِ سَمِعَ أَنَسٌ، مِنَ النَّبِيِّ صلى الله عليه وسلم قَالَ خَدَمَهُ عَشْرَ سِنِينَ وَدَعَا لَهُ النَّبِيُّ صلى الله عليه وسلم وَكَانَ لَهُ بُسْتَانٌ يَحْمِلُ فِي السَّنَةِ الْفَاكِهَةَ مَرَّتَيْنِ وَكَانَ فِيهَا رَيْحَانٌ يَجِدُ مِنْهُ رِيحَ الْمِسْكِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو خَلْدَةَ اسْمُهُ خَالِدُ بْنُ دِينَارٍ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ وَقَدْ أَدْرَكَ أَنَسَ بْنَ مَالِكٍ وَرَوَى عَنْهُ ‏.‏\hadithno{3833}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Khaldah:"I said to Abu Al-'Aliyah: '(Did) Anas heard from the Prophet (ﷺ)?' He said: 'He served him for ten years, and the Prophet (ﷺ) supplicated for him, and he used to have a garden that would bear fruit twice in the year, and there used to be sweet basil in it, from which could be found the smell of musk}}
\hadithdefcmd{tirmidhi}{3834}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، عَنْ أَبِي الرَّبِيعِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَبَسَطْتُ ثَوْبِي عِنْدَهُ ثُمَّ أَخَذَهُ فَجَمَعَهُ عَلَى قَلْبِي فَمَا نَسِيتُ بَعْدَهُ حَدِيثًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3834}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:"I came to the Prophet (ﷺ) and spread out my garment next to him, then he took it and gathered it at my heart, so I did not forget after that [any Hadith]}}
\hadithdefcmd{tirmidhi}{3835}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَسْمَعُ مِنْكَ أَشْيَاءَ فَلاَ أَحْفَظُهَا ‏.‏ قَالَ ‏ "‏ ابْسُطْ رِدَاءَكَ ‏"‏ ‏.‏ فَبَسَطْتُ فَحَدَّثَ حَدِيثًا كَثِيرًا فَمَا نَسِيتُ شَيْئًا حَدَّثَنِي بِهِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3835}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah:"I said: 'O Messenger of Allah, I hear from you things that I do not remember.' He said: 'Spread your cloak.' So I spread it, then he narrated many Ahadith, and I did not forget a thing that he reported to me}}
\hadithdefcmd{tirmidhi}{3836}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا يَعْلَى بْنُ عَطَاءٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَالَ لأَبِي هُرَيْرَةَ يَا أَبَا هُرَيْرَةَ أَنْتَ كُنْتَ أَلْزَمَنَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَأَحْفَظَنَا لِحَدِيثِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3836}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Walid bin 'Abdur-Rahman:that Ibn 'Umar said to Abu Hurairah: "You used to stick to the Messenger of Allah (ﷺ) most out of all of us, and you used to best memorize his Ahadith out of us}}
\hadithdefcmd{tirmidhi}{3837}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَخْبَرَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ الْحَرَّانِيُّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ مَالِكِ بْنِ أَبِي عَامِرٍ، قَالَ جَاءَ رَجُلٌ إِلَى طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ فَقَالَ يَا أَبَا مُحَمَّدٍ أَرَأَيْتَ هَذَا الْيَمَانِيَ يَعْنِي أَبَا هُرَيْرَةَ هُوَ أَعْلَمُ بِحَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْكُمْ نَسْمَعُ مِنْهُ مَا لاَ نَسْمَعُ مِنْكُمْ أَوْ يَقُولُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ يَقُلْ ‏.‏ قَالَ أَمَّا أَنْ يَكُونَ سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ نَسْمَعْ فَلاَ أَشُكُّ إِلاَّ أَنَّهُ سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ نَسْمَعْ وَذَاكَ أَنَّهُ كَانَ مِسْكِينًا لاَ شَىْءَ لَهُ ضَيْفًا لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَدُهُ مَعَ يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكُنَّا نَحْنُ أَهْلَ بُيُوتَاتٍ وَغِنًى وَكُنَّا نَأْتِي رَسُولَ اللَّهِ صلى الله عليه وسلم طَرَفَىِ النَّهَارِ فَلاَ نَشُكُّ إِلاَّ أَنَّهُ سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ نَسْمَعْ وَلاَ نَجِدُ أَحَدًا فِيهِ خَيْرٌ يَقُولُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ يَقُلْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ إِسْحَاقَ ‏.‏ وَقَدْ رَوَاهُ يُونُسُ بْنُ بُكَيْرٍ وَغَيْرُهُ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ ‏.‏\hadithno{3837}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Malik bin Abi 'Amir:"A man came to Talhah bin 'Ubaidullah and said: 'O Abu Muhammad, do you see this Yemeni - meaning: Abu Hurairah - is he more knowledgeable of the Ahadith of the Messenger of Allah (ﷺ) than you? We hear from him what we do not hear from you, or does he attribute to the Messenger of Allah (ﷺ) what he did not say?' He said: 'As for his having heard from the Messenger of Allah (ﷺ) what we did not hear from him, then that is because he was poor, having nothing, a guest of the Messenger of Allah (ﷺ), his hand was in the hand of the Messenger of Allah (ﷺ). And we used to be people of houses and wealth, and we used to come to the Messenger of Allah (ﷺ) at the two ends of the day. I do not doubt that he heard from the Messenger of Allah (ﷺ) what we did not hear, and you will not find anyone in whom there is good attributing to the Messenger of Allah (ﷺ) what he did not say}}
\hadithdefcmd{tirmidhi}{3838}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ ابْنُ بِنْتِ أَزْهَرَ السَّمَّانِ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا أَبُو خَلْدَةَ، قَالَ حَدَّثَنَا أَبُو الْعَالِيَةِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مِمَّنْ أَنْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ مِنْ دَوْسٍ ‏.‏ قَالَ ‏"‏ مَا كُنْتُ أُرَى أَنَّ فِي دَوْسٍ أَحَدًا فِيهِ خَيْرٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَأَبُو خَلْدَةَ اسْمُهُ خَالِدُ بْنُ دِينَارٍ وَأَبُو الْعَالِيَةِ اسْمُهُ رُفَيْعٌ ‏.‏\hadithno{3838}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:"The Prophet (ﷺ) said to me: 'Who are you from?' I said: 'From Daws.' He said: 'I did not used think there was anyone from Daws in whom there was good}}
\hadithdefcmd{tirmidhi}{3839}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى الْقَزَّازُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ حَدَّثَنَا الْمُهَاجِرُ، عَنْ أَبِي الْعَالِيَةِ الرِّيَاحِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِتَمَرَاتٍ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ فِيهِنَّ بِالْبَرَكَةِ ‏.‏ فَضَمَّهُنَّ ثُمَّ دَعَا لِي فِيهِنَّ بِالْبَرَكَةِ فَقَالَ لِي ‏ "‏ خُذْهُنَّ وَاجْعَلْهُنَّ فِي مِزْوَدِكَ هَذَا أَوْ فِي هَذَا الْمِزْوَدِ كُلَّمَا أَرَدْتَ أَنْ تَأْخُذَ مِنْهُ شَيْئًا فَأَدْخِلْ فِيهِ يَدَكَ فَخُذْهُ وَلاَ تَنْثُرْهُ نَثْرًا ‏"‏ ‏.‏ فَقَدْ حَمَلْتُ مِنْ ذَلِكَ التَّمْرِ كَذَا وَكَذَا مِنْ وَسْقٍ فِي سَبِيلِ اللَّهِ فَكُنَّا نَأْكُلُ مِنْهُ وَنُطْعِمُ وَكَانَ لاَ يُفَارِقُ حَقْوِي حَتَّى كَانَ يَوْمُ قَتْلِ عُثْمَانَ فَإِنَّهُ انْقَطَعَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3839}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:"I came to the Prophet (ﷺ) with some dates and said: 'O Messenger of Allah, supplicate to Allah to bless them.' So he took them and supplicated for me for blessing in them, and then said to me: 'Take them and put them in this bag of yours - or this bag - and whenever you intend to take any from it, then put your hand in it and take it, and do not scatter them all about.' So I carried such and such Wasq of those dates in the cause of Allah. We used to eat from it, and give others to eat, and it (the bag) would not part from my waist until the day 'Uthman was killed, for they had run out}}
\hadithdefcmd{tirmidhi}{3840}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْمُرَابِطِيُّ، قَالَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، قَالَ حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، قَالَ قُلْتُ لأَبِي هُرَيْرَةَ لِمَ كُنِّيتَ أَبَا هُرَيْرَةَ قَالَ أَمَا تَفْرَقُ مِنِّي قُلْتُ بَلَى وَاللَّهِ إِنِّي لأَهَابُكَ ‏.‏ قَالَ كُنْتُ أَرْعَى غَنَمَ أَهْلِي فَكَانَتْ لِي هُرَيْرَةٌ صَغِيرَةٌ فَكُنْتُ أَضَعُهَا بِاللَّيْلِ فِي شَجَرَةٍ فَإِذَا كَانَ النَّهَارُ ذَهَبْتُ بِهَا مَعِي فَلَعِبْتُ بِهَا فَكَنَّوْنِي أَبَا هُرَيْرَةَ ‏. هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3840}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah bin Rafi':"I said to Abu Hurairah: 'Why were you given the Kunyah Abu Hurairah?' He said: 'Do you not fear me?'" He said: "Indeed, I am in awe of you.' He said: 'I used to tend the sheep of my people, and I had a small kitten; so I used to place it in a tree at night, and during the day I would take it with me and play with it. So they named me Abu Hurairah}}
\hadithdefcmd{tirmidhi}{3841}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ أَخِيهِ، هَمَّامِ بْنِ مُنَبِّهٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ لَيْسَ أَحَدٌ أَكْثَرَ حَدِيثًا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنِّي إِلاَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو فَإِنَّهُ كَانَ يَكْتُبُ وَكُنْتُ لاَ أَكْتُبُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3841}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah [may Allah be pleased with him] :"There is none with more Ahadith from the Messenger of Allah (ﷺ) than I, except for 'Abdullah bin 'Amr, for he used to write, (the Ahadith) and I did not used to write}}
\hadithdefcmd{tirmidhi}{3842}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا أَبُو مُسْهِرٍ عَبْدُ الأَعْلَى بْنُ مُسْهِرٍ، عَنْ سَعِيدِ بْنِ عَبْدِ الْعَزِيزِ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمِيرَةَ، وَكَانَ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ لِمُعَاوِيَةَ ‏ "‏ اللَّهُمَّ اجْعَلْهُ هَادِيًا مَهْدِيًّا وَاهْدِ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3842}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdur-Rahman bin Abu 'Umairah - and he was one of the Companions of the Messenger of Allah (ﷺ):from the Prophet (ﷺ), that he said to Mu'awiyah: "O Allah, make him a guiding one, and guide (others) by him}}
\hadithdefcmd{tirmidhi}{3843}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، قَالَ حَدَّثَنَا عَمْرُو بْنُ وَاقِدٍ، عَنْ يُونُسَ بْنِ حَلْبَسٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، قَالَ لَمَّا عَزَلَ عُمَرُ بْنُ الْخَطَّابِ عُمَيْرَ بْنَ سَعِيدٍ عَنْ حِمْصَ، وَلَّى مُعَاوِيَةَ فَقَالَ النَّاسُ عَزَلَ عُمَيْرًا وَوَلَّى مُعَاوِيَةَ ‏.‏ فَقَالَ عُمَيْرٌ لاَ تَذْكُرُوا مُعَاوِيَةَ إِلاَّ بِخَيْرٍ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ اهْدِ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏, وَعَمْرُو بْنُ وَاقِدٍ يُضَعَّفُ ‏.‏\hadithno{3843}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Idris Al-Khawlani:"When 'Umar bin Al-Khattab removed 'Umair bin Sa'd as governor of Hims, he appointed Mu'awiyah. The people said: 'He has removed 'Umair and appointed Mu'awiyah.' So 'Umair said: 'Do not mention Mu'awiyah except with good, for indeed, I heard the Messenger of Allah (ﷺ) saying: "O Allah guide (others) by him}}
\hadithdefcmd{tirmidhi}{3844}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ مِشْرَحِ بْنِ هَاعَانَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَسْلَمَ النَّاسُ وَآمَنَ عَمْرُو بْنُ الْعَاصِي ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ عَنْ مِشْرَحِ بْنِ هَاعَانَ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏\hadithno{3844}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Uqbah bin 'Amir:that the Messenger of Allah (ﷺ) said: "The people submitted while 'Amr bin Al-'As believed}}
\hadithdefcmd{tirmidhi}{3845}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَخْبَرَنَا أَبُو أُسَامَةَ، عَنْ نَافِعِ بْنِ عُمَرَ الْجُمَحِيِّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ قَالَ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ عَمْرَو بْنَ الْعَاصِي مِنْ صَالِحِي قُرَيْشٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ نَافِعِ بْنِ عُمَرَ الْجُمَحِيِّ ‏.‏ وَنَافِعٌ ثِقَةٌ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ وَابْنُ أَبِي مُلَيْكَةَ لَمْ يُدْرِكْ طَلْحَةَ ‏.‏\hadithno{3845}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Talhah bin 'Ubaidullah:"I heard the Messenger of Allah (ﷺ) saying: 'Indeed, 'Amr bin Al-'As is from among the righteous of the Quraish}}
\hadithdefcmd{tirmidhi}{3846}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَزَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَنْزِلاً فَجَعَلَ النَّاسُ يَمُرُّونَ فَيَقُولُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذَا يَا أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ فَأَقُولُ فُلاَنٌ ‏.‏ فَيَقُولُ ‏"‏ نِعْمَ عَبْدُ اللَّهِ هَذَا ‏"‏ ‏.‏ وَيَقُولُ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَأَقُولُ فُلاَنٌ ‏.‏ فَيَقُولُ ‏"‏ بِئْسَ عَبْدُ اللَّهِ هَذَا ‏"‏ ‏.‏ حَتَّى مَرَّ خَالِدُ بْنُ الْوَلِيدِ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَقُلْتُ هَذَا خَالِدُ بْنُ الْوَلِيدِ ‏.‏ فَقَالَ ‏"‏ نِعْمَ عَبْدُ اللَّهِ خَالِدُ بْنُ الْوَلِيدِ سَيْفٌ مِنْ سُيُوفِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَلاَ نَعْرِفُ لِزَيْدِ بْنِ أَسْلَمَ سَمَاعًا مِنْ أَبِي هُرَيْرَةَ وَهُوَ عِنْدِي حَدِيثٌ مُرْسَلٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ ‏.‏\hadithno{3846}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:"We camped with the Messenger of Allah (ﷺ) at a place, and the people began passing by. The Messenger of Allah (ﷺ) would say: 'Who is this, O Abu Hurairah?' So I would say: 'So-and-so.' So he would say: 'What an excellent slave of Allah this is.' And he would say: 'Who is this?' So I would say: 'So-and-so.' So he would say: 'What a bad slave of Allah this is.' Until Khalid bin Al-Walid passed, so he said: 'Who is this?' So I said: 'This is Khalid bin Al-Walid.' He said: 'What an excellent slave of Allah is Khalid bin Al-Walid, a sword from among the swords of Allah}}
\hadithdefcmd{tirmidhi}{3847}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ أُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ثَوْبٌ حَرِيرٌ فَجَعَلُوا يَعْجَبُونَ مِنْ لِينِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعْجَبُونَ مِنْ هَذَا لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ أَحْسَنُ مِنْ هَذَا ‏"‏ ‏. وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3847}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Bara:"A garment of silk was gifted to the Messenger of Allah (ﷺ) so they began to marvel at its softness, so the Messenger of Allah (ﷺ) said: 'Do you marvel at this? Indeed, the handkerchiefs of Sa'd bin Mu'adh in Paradise are better than this}}
\hadithdefcmd{tirmidhi}{3848}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَجَنَازَةُ سَعْدِ بْنِ مُعَاذٍ بَيْنَ أَيْدِيهِمْ ‏ "‏ اهْتَزَّ لَهُ عَرْشُ الرَّحْمَنِ ‏"‏ ‏. وَفِي الْبَابِ عَنْ أُسَيْدِ بْنِ حُضَيْرٍ وَأَبِي سَعِيدٍ وَرُمَيْثَةَ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3848}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin 'Abdullah:"I heard the Messenger of Allah (ﷺ), saying while the funeral of Sa'd bin Mu'adh was in front of them: 'The Throne of Ar-Rahman shook due to it}}
\hadithdefcmd{tirmidhi}{3849}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا حُمِلَتْ جَنَازَةُ سَعْدِ بْنِ مُعَاذٍ قَالَ الْمُنَافِقُونَ مَا أَخَفَّ جَنَازَتَهُ ‏.‏ وَذَلِكَ لِحُكْمِهِ فِي بَنِي قُرَيْظَةَ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ كَانَتْ تَحْمِلُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3849}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik:"When the funeral of Sa'd bin Mu'adh was carried, the hypocrites said: 'How light his funeral is.' And this was due to his judgment concerning Banu Quraizah. So this reached the Prophet (ﷺ), and he said: 'Indeed, the angels were carrying him}}
\hadithdefcmd{tirmidhi}{3850}{حَدَّثَنَا مُحَمَّدُ بْنُ مَرْزُوقٍ الْبَصْرِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسٍ، قَالَ كَانَ قَيْسُ بْنُ سَعْدٍ مِنَ النَّبِيِّ صلى الله عليه وسلم بِمَنْزِلَةِ صَاحِبِ الشُّرَطِ مِنَ الأَمِيرِ ‏.‏ قَالَ الأَنْصَارِيُّ يَعْنِي مِمَّا يَلِي مِنْ أُمُورِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الأَنْصَارِيِّ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ قَوْلَ الأَنْصَارِيِّ ‏.‏\hadithno{3850}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas:"Qais bin Sa'd used to be, to the Prophet (ﷺ), in the position of the head of police for a ruler." (One of the narrators) Al-Ansari said: "That is: Due to his affairs that he takes charge of}}
\hadithdefcmd{tirmidhi}{3851}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْسَ بِرَاكِبِ بَغْلٍ وَلاَ بِرْذَوْنَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3851}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir bin 'Abdullah:"The Messenger of Allah (ﷺ) came to me, not riding a mule nor a Birdhawn (a type of Turkish horse)}}
\hadithdefcmd{tirmidhi}{3852}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ اسْتَغْفَرَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْبَعِيرِ خَمْسًا وَعِشْرِينَ مَرَّةً ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَمَعْنَى قَوْلِهِ لَيْلَةَ الْبَعِيرِ مَا رُوِيَ عَنْ جَابِرٍ مِنْ غَيْرِ وَجْهٍ أَنَّهُ كَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَبَاعَ بَعِيرَهُ مِنَ النَّبِيِّ صلى الله عليه وسلم وَاشْتَرَطَ ظَهْرَهُ إِلَى الْمَدِينَةِ يَقُولُ جَابِرٌ لَيْلَةَ بِعْتُ مِنَ النَّبِيِّ صلى الله عليه وسلم الْبَعِيرَ اسْتَغْفَرَ لِي خَمْسًا وَعِشْرِينَ مَرَّةً وَكَانَ جَابِرٌ قَدْ قُتِلَ أَبُوهُ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ حَرَامٍ يَوْمَ أُحُدٍ وَتَرَكَ بَنَاتٍ فَكَانَ جَابِرٌ يَعُولُهُنَّ وَيُنْفِقُ عَلَيْهِنَّ وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَبَرُّ جَابِرًا وَيَرْحَمُهُ لِسَبَبِ ذَلِكَ هَكَذَا رُوِيَ فِي حَدِيثٍ عَنْ جَابِرٍ نَحْوُ هَذَا ‏.‏\hadithno{3852}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:"The Messenger of Allah (ﷺ) supplicated for forgiveness for me on the Night of the Camel, twenty-five times}}
\hadithdefcmd{tirmidhi}{3853}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ خَبَّابٍ، قَالَ هَاجَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَبْتَغِي وَجْهَ اللَّهِ فَوَقَعَ أَجْرُنَا عَلَى اللَّهِ فَمِنَّا مَنْ مَاتَ وَلَمْ يَأْكُلْ مِنْ أَجْرِهِ شَيْئًا وَمِنَّا مَنْ أَيْنَعَتْ لَهُ ثَمَرَتُهُ فَهُوَ يَهْدُبُهَا وَإِنَّ مُصْعَبَ بْنَ عُمَيْرٍ مَاتَ وَلَمْ يَتْرُكْ إِلاَّ ثَوْبًا كَانُوا إِذَا غَطَّوْا بِهِ رَأْسَهُ خَرَجَتْ رِجْلاَهُ وَإِذَا غُطِّيَ بِهَا رِجْلاَهُ خَرَجَ رَأْسُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَطُّوا رَأْسَهُ وَاجْعَلُوا عَلَى رِجْلَيْهِ الإِذْخِرَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا هَنَّادٌ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، شَقِيقِ بْنِ سَلَمَةَ عَنْ خَبَّابِ بْنِ الأَرَتِّ، نَحْوَهُ ‏.‏\hadithno{3853}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Khabbab:"We emigrated with the Messenger of Allah (ﷺ), seeking the Face of Allah. So our reward is with Allah. Among us were those who died and did not consume any of the rewards (in this life), and among us were those who lived to see its fruits and tend to them. Verily, Musab bin 'Umair died without leaving anything behind but a garment. When they covered his head with it, his feet would become exposed, and when they covered his feet with it, his head will become exposed. So the Messenger of Allah (ﷺ) said: 'Cover his head and place Al-Idhkir over his feet}}
\hadithdefcmd{tirmidhi}{3854}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، قَالَ حَدَّثَنَا سَيَّارٌ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ثَابِتٌ، وَعَلِيُّ بْنُ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَمْ مِنْ أَشْعَثَ أَغْبَرَ ذِي طِمْرَيْنِ لاَ يُؤْبَهُ لَهُ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ مِنْهُمُ الْبَرَاءُ بْنُ مَالِكٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3854}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "How many are there with dishevelled hair, covered with dust, possessing two cloths, whom no one pays any mind to - if he swears by Allah then He shall fulfill it. Among them is Al-Bara bin Malik}}
\hadithdefcmd{tirmidhi}{3855}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ، قَالَ حَدَّثَنَا أَبُو يَحْيَى الْحِمَّانِيُّ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَا أَبَا مُوسَى لَقَدْ أُعْطِيتَ مِزْمَارًا مِنْ مَزَامِيرِ آلِ دَاوُدَ ‏"‏ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَأَبِي هُرَيْرَةَ وَأَنَسٍ ‏.‏\hadithno{3855}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Musa:that the Prophet (ﷺ) said: "O Abu Musa! You have been given a Mizmar among the Mazamir of the family of Dawud}}
\hadithdefcmd{tirmidhi}{3856}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَحْفِرُ الْخَنْدَقَ وَنَحْنُ نَنْقُلُ التُّرَابَ فَيَمُرُّ بِنَا فَقَالَ ‏ "‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَةِ فَاغْفِرْ لِلأَنْصَارِ وَالْمُهَاجِرَةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو حَازِمٍ اسْمُهُ سَلَمَةُ بْنُ دِينَارٍ الأَعْرَجُ الزَّاهِدُ ‏.‏وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ ‏.‏\hadithno{3856}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Sahl bin Sa'd:"We were with the Messenger of Allah (ﷺ) while he was excavating the trench, and we were transporting the soil. He passed by us and said: 'O Allah! There is no life but the life of the Hereafter! So forgive the Ansar and the Emigrants}}
\hadithdefcmd{tirmidhi}{3857}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَةِ فَأَكْرِمِ الأَنْصَارَ وَالْمُهَاجِرَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ رضى الله عنه ‏.‏\hadithno{3857}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) would say: "O Allah! There is no life but the life of the Hereafter! So honor the Ansar and the Emigrants}}
\hadithdefcmd{tirmidhi}{3858}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا مُوسَى بْنُ إِبْرَاهِيمَ بْنِ كَثِيرٍ الأَنْصَارِيُّ، قَالَ سَمِعْتُ طَلْحَةَ بْنَ خِرَاشٍ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَمَسُّ النَّارُ مُسْلِمًا رَآنِي أَوْ رَأَى مَنْ رَآنِي ‏"‏ ‏.‏ قَالَ طَلْحَةُ فَقَدْ رَأَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ‏.‏ وَقَالَ مُوسَى وَقَدْ رَأَيْتُ طَلْحَةَ ‏.‏ قَالَ يَحْيَى وَقَالَ لِي مُوسَى وَقَدْ رَأَيْتَنِي وَنَحْنُ نَرْجُو اللَّهَ ‏. هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُوسَى بْنِ إِبْرَاهِيمَ الأَنْصَارِيِّ ‏.‏ وَرَوَى عَلِيُّ بْنُ الْمَدِينِيِّ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْحَدِيثِ عَنْ مُوسَى هَذَا الْحَدِيثَ ‏.‏\hadithno{3858}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Talhah bin Khirash:"I heard Jabir bin 'Abdullah saying: 'I heard the Prophet (ﷺ) saying: "The Fire shall not touch the Muslim who saw me, or saw one who saw me}}
\hadithdefcmd{tirmidhi}{3859}{حَدَّثَنِي هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، هُوَ السَّلْمَانِيُّ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ النَّاسِ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَأْتِي قَوْمٌ مِنْ بَعْدِ ذَلِكَ تَسْبِقُ أَيْمَانُهُمْ شَهَادَاتِهِمْ أَوْ شَهَادَاتُهُمْ أَيْمَانَهُمْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عُمَرَ وَعِمْرَانَ بْنِ حُصَيْنٍ وَبُرَيْدَةَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3859}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Mas'ud:that the Messenger of Allah (ﷺ) said: "The best generation is my generation, then those who follow them, then those who follow them. Then comes a people after that whose swearing precedes their testimony, or whose testimony precedes their swearing}}
\hadithdefcmd{tirmidhi}{3860}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ النَّارَ أَحَدٌ مِمَّنْ بَايَعَ تَحْتَ الشَّجَرَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3860}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir:that the Messenger of Allah (ﷺ) said: "None of those who gave the pledge under the tree shall enter the Fire}}
\hadithdefcmd{tirmidhi}{3861}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ ذَكْوَانَ أَبَا صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَسُبُّوا أَصْحَابِي فَوَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنَّ أَحَدَكُمْ أَنْفَقَ مِثْلَ أُحُدٍ ذَهَبًا مَا أَدْرَكَ مُدَّ أَحَدِهِمْ وَلاَ نَصِيفَهُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ نَصِيفَهُ ‏"‏ يَعْنِي نِصْفَ الْمُدِّ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، - وَكَانَ حَافِظًا - قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3861}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:that the Messenger of Allah (ﷺ) said: "Do not abuse my Companions, for by the One in Whose Hand is my soul! If one of you were to spend gold the like of Uhud, it would not equal a Mudd - nor half of it - of one of them}}
\hadithdefcmd{tirmidhi}{3862}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا عَبِيدَةُ ابْنُ أَبِي رَائِطَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهَ اللَّهَ فِي أَصْحَابِي اللَّهَ اللَّهَ فِي أَصْحَابِي لاَ تَتَّخِذُوهُمْ غَرَضًا بَعْدِي فَمَنْ أَحَبَّهُمْ فَبِحُبِّي أَحَبَّهُمْ وَمَنْ أَبْغَضَهُمْ فَبِبُغْضِي أَبْغَضَهُمْ وَمَنْ آذَاهُمْ فَقَدْ آذَانِي وَمَنْ آذَانِي فَقَدْ آذَى اللَّهَ وَمَنْ آذَى اللَّهَ فَيُوشِكُ أَنْ يَأْخُذَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3862}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Mughaffal:that the Messenger of Allah (ﷺ) said: "(Fear) Allah! (Fear) Allah regarding my Companions! Do not make them objects of insults after me. Whoever loves them, it is out of love of me that he loves them. And whoever hates them, it is out of hatred for me that he hates them. And whoever harms them, he has harmed me, and whoever harms me, he has offended Allah, and whoever offends Allah, [then] he shall soon be punished}}
\hadithdefcmd{tirmidhi}{3863}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَزْهَرُ السَّمَّانُ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ خِدَاشٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَدْخُلَنَّ الْجَنَّةَ مَنْ بَايَعَ تَحْتَ الشَّجَرَةِ إِلاَّ صَاحِبَ الْجَمَلِ الأَحْمَرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3863}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Az-Zubair:from Jabir, that the Prophet (ﷺ) said: "Those who gave the pledge under the tree shall enter Paradise, except for the owner of the red camel}}
\hadithdefcmd{tirmidhi}{3864}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ عَبْدًا، لِحَاطِبِ بْنِ أَبِي بَلْتَعَةَ جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَشْكُو حَاطِبًا فَقَالَ يَا رَسُولَ اللَّهِ لَيَدْخُلَنَّ حَاطِبٌ النَّارَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَذَبْتَ لاَ يَدْخُلُهَا فَإِنَّهُ قَدْ شَهِدَ بَدْرًا وَالْحُدَيْبِيَةَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3864}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Az-Zubair:from Jabir, that a slave of Hatib [bin Abi Balt'ah] came to the Messenger of Allah (ﷺ) complaining about Hatib. So he said: 'O Messenger of Allah (ﷺ)! Hatib is going to enter the Fire!' So the Messenger of Allah (ﷺ) said: 'You have lied! No one who participated in (the battle of) Badr and (the treaty of) Al-Hudaybiyah shall enter it}}
\hadithdefcmd{tirmidhi}{3865}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ نَاجِيَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ أَبِي طَيْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ أَحَدٍ مِنْ أَصْحَابِي يَمُوتُ بِأَرْضٍ إِلاَّ بُعِثَ قَائِدًا وَنُورًا لَهُمْ يَوْمَ الْقِيَامَةِ ‏"‏ ‏. هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَرُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ أَبِي طَيْبَةَ عَنِ ابْنِ بُرَيْدَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَهُوَ أَصَحُّ ‏.‏\hadithno{3865}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Buraidah:from his father, that the Messenger of Allah (ﷺ) said: "There is no one among my Companions who dies in a land except that he shall be resurrected as a guide and light for them (people of that land) on the Day of Resurrection}}
\hadithdefcmd{tirmidhi}{3866}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ نَافِعٍ قَالَ حَدَّثَنَا النَّضْرُ بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا سَيْفُ ابْنُ عُمَرَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الَّذِينَ يَسُبُّونَ أَصْحَابِي فَقُولُوا لَعْنَةُ اللَّهِ عَلَى شَرِّكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُنْكَرٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ عُمَرَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالنَّضْرُ مَجْهُولٌ وَسَيْفٌ مَجْهُولٌ ‏.‏\hadithno{3866}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "If you see those who abuse my Companions, then say: 'May Allah's curse be upon the worst of you}}
\hadithdefcmd{tirmidhi}{3867}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ وَهُوَ عَلَى الْمِنْبَرِ ‏ "‏ إِنَّ بَنِي هِشَامِ بْنِ الْمُغِيرَةِ اسْتَأْذَنُونِي فِي أَنْ يُنْكِحُوا ابْنَتَهُمْ عَلِيَّ بْنَ أَبِي طَالِبٍ فَلاَ آذَنُ ثُمَّ لاَ آذَنُ ثُمَّ لاَ آذَنُ إِلاَّ أَنْ يُرِيدَ ابْنُ أَبِي طَالِبٍ أَنْ يُطَلِّقَ ابْنَتِي وَيَنْكِحَ ابْنَتَهُمْ فَإِنَّهَا بَضْعَةٌ مِنِّي يَرِيبُنِي مَا رَابَهَا وَيُؤْذِينِي مَا آذَاهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ عَمْرُو بْنُ دِينَارٍ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ نَحْوَ حَدِيث اللَّيْث ‏.‏\hadithno{3867}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Miswar bin Makhramah:"While he was on the Minbar, I heard the Prophet (ﷺ) saying: 'Indeed Banu Hisham bin Al-Mughirah asked me if they could marry their daughter to 'Ali bin Abi Talib. But I do not allow it, I do not allow it, I do not allow it - unless 'Ali bin Abi Talib wishes to divorce my daughter and marry their daughter, because she is a part of me. I am displeased by what displeases her, and I am harmed by what harms her}}
\hadithdefcmd{tirmidhi}{3868}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، عَنْ جَعْفَرٍ الأَحْمَرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ أَحَبَّ النِّسَاءِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاطِمَةُ وَمِنَ الرِّجَالِ عَلِيٌّ ‏.‏ قَالَ إِبْرَاهِيمُ بْنُ سَعِيدٍ يَعْنِي مِنْ أَهْلِ بَيْتِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3868}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraidah:"The most beloved of women to the Messenger of Allah (ﷺ) was Fatimah and from the men was 'Ali}}
\hadithdefcmd{tirmidhi}{3869}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ عَلِيًّا، ذَكَرَ بِنْتَ أَبِي جَهْلٍ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّمَا فَاطِمَةُ بَضْعَةٌ مِنِّي يُؤْذِينِي مَا آذَاهَا وَيُنْصِبُنِي مَا أَنْصَبَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ هَكَذَا قَالَ أَيُّوبُ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنِ ابْنِ الزُّبَيْرِ وَقَالَ غَيْرُ وَاحِدٍ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ وَيُحْتَمَلُ أَنْ يَكُونَ ابْنُ أَبِي مُلَيْكَةَ رَوَى عَنْهُمَا جَمِيعًا ‏.‏\hadithno{3869}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin Az-Zubair:that 'Ali mentioned the daughter of Abu Jahl (for marriage), and that reached the Prophet (ﷺ) so he said: "Indeed Fatimah is but a part of me, I am harmed by what harms her and I am uncomfortable by what makes her uncomfortable}}
\hadithdefcmd{tirmidhi}{3870}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الْجَبَّارِ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ قَادِمٍ، قَالَ حَدَّثَنَا أَسْبَاطُ بْنُ نَصْرٍ الْهَمْدَانِيُّ، عَنِ السُّدِّيِّ، عَنْ صُبَيْحٍ، مَوْلَى أُمِّ سَلَمَةَ عَنْ زَيْدِ بْنِ أَرْقَمَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِعَلِيٍّ وَفَاطِمَةَ وَالْحَسَنِ وَالْحُسَيْنِ ‏ "‏ أَنَا حَرْبٌ لِمَنْ حَارَبْتُمْ وَسَلْمٌ لِمَنْ سَالَمْتُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ ‏.‏ وَصُبَيْحٌ مَوْلَى أُمِّ سَلَمَةَ لَيْسَ بِمَعْرُوفٍ ‏.‏\hadithno{3870}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zaid bin Arqam:that the Messenger of Allah (ﷺ) said to 'Ali, Fatimah, Al-Hasan and Al-Husain: "I am at war with whoever makes war with you, and peace for whoever makes peace with you}}
\hadithdefcmd{tirmidhi}{3871}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زُبَيْدٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَلَّلَ عَلَى الْحَسَنِ وَالْحُسَيْنِ وَعَلِيٍّ وَفَاطِمَةَ كِسَاءً ثُمَّ قَالَ ‏"‏ اللَّهُمَّ هَؤُلاَءِ أَهْلُ بَيْتِي وَخَاصَّتِي أَذْهِبْ عَنْهُمُ الرِّجْسَ وَطَهِّرْهُمْ تَطْهِيرًا ‏"‏ ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ وَأَنَا مَعَهُمْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنَّكَ عَلَى خَيْرٍ ‏"‏ ‏. هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ أَحْسَنُ شَيْءٍ رُوِيَ فِي هَذَا الْبَابِ ‏.‏ وَفِي الْبَابِ عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ وَأَنَسِ بْنِ مَالِكٍ وَأَبِي الْحَمْرَاءِ وَمَعْقِلِ بْنِ يَسَارٍ وَعَائِشَةَ ‏.‏\hadithno{3871}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah:"The Prophet (ﷺ) put a garment over Al-Hasan, Al-Hussain, 'Ali and Fatimah, then he said: 'O Allah, these are the people of my house and the close ones, so remove the Rijs from them and purify them thoroughly." So Umm Salamah said: 'And am I with them, O Messenger of Allah?' He said: "You are upon good}}
\hadithdefcmd{tirmidhi}{3872}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ أَخْبَرَنَا إِسْرَائِيلُ، عَنْ مَيْسَرَةَ ابْنِ حَبِيبٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ مَا رَأَيْتُ أَحَدًا أَشْبَهَ سَمْتًا وَدَلاًّ وَهَدْيًا بِرَسُولِ اللَّهِ فِي قِيَامِهَا وَقُعُودِهَا مِنْ فَاطِمَةَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ وَكَانَتْ إِذَا دَخَلَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم قَامَ إِلَيْهَا فَقَبَّلَهَا وَأَجْلَسَهَا فِي مَجْلِسِهِ وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ عَلَيْهَا قَامَتْ مِنْ مَجْلِسِهَا فَقَبَّلَتْهُ وَأَجْلَسَتْهُ فِي مَجْلِسِهَا فَلَمَّا مَرِضَ النَّبِيُّ صلى الله عليه وسلم دَخَلَتْ فَاطِمَةُ فَأَكَبَّتْ عَلَيْهِ فَقَبَّلَتْهُ ثُمَّ رَفَعَتْ رَأْسَهَا فَبَكَتْ ثُمَّ أَكَبَّتْ عَلَيْهِ ثُمَّ رَفَعَتْ رَأْسَهَا فَضَحِكَتْ فَقُلْتُ إِنْ كُنْتُ لأَظُنُّ أَنَّ هَذِهِ مِنْ أَعْقَلِ نِسَائِنَا فَإِذَا هِيَ مِنَ النِّسَاءِ فَلَمَّا تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم قُلْتُ لَهَا أَرَأَيْتِ حِيْنَ أَكْبَبْتِ عَلَى النَّبِيِّ صلى الله عليه وسلم فَرَفَعْتِ رَأْسَكِ فَبَكَيْتِ ثُمَّ أَكْبَبْتِ عَلَيْهِ فَرَفَعْتِ رَأْسَكِ فَضَحِكْتِ مَا حَمَلَكِ عَلَى ذَلِكَ قَالَتْ إِنِّي إِذًا لَبَذِرَةٌ أَخْبَرَنِي أَنَّهُ مَيِّتٌ مِنْ وَجَعِهِ هَذَا فَبَكَيْتُ ثُمَّ أَخْبَرَنِي أَنِّي أَسْرَعُ أَهْلِهِ لُحُوقًا بِهِ فَذَاكَ حِينَ ضَحِكْتُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ عَائِشَةَ ‏.‏\hadithno{3872}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:"I have not seen anyone closer in conduct, way, and manners to that of the Messenger of Allah in regards to standing and sitting, than Fatimah the daughter of the Messenger of Allah (ﷺ)." She said "Whenever she would enter upon the Prophet (ﷺ) he would stand to her and kiss her, and he would sit her in his sitting place. Whenever the Prophet (ﷺ) entered upon her she would stand from her seat, and kiss him and sit him in her sitting place. So when the Prophet (ﷺ) fell sick and Fatimah entered, she bent over and kissed him. Then she lifted her head and cried, then she bent over him and she lifted her head and laughed. So I said: 'I used to think that this one was from the most intelligent of our women, but she is really just one of the women.' So when the Prophet (ﷺ) died, I said to her: 'Do you remember when you bent over the Prophet (ﷺ) and you lifted your head and cried, then you bent over him, then you lifted your head and laughed. What caused you to do that?' She said: 'Then, I would be the one who spreads the secrets. He (ﷺ) told me that he was to die from his illness, so I cried. Then he told me that I would be the quickest of his family to meet up with him. So that is when I laughed}}
\hadithdefcmd{tirmidhi}{3873}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ عَثْمَةَ، قَالَ حَدَّثَنِي مُوسَى بْنُ يَعْقُوبَ الزَّمْعِيُّ، عَنْ هَاشِمِ بْنِ هَاشِمٍ، أَنَّ عَبْدَ اللَّهِ بْنَ وَهْبٍ، أَخْبَرَهُ أَنَّ أُمَّ سَلَمَةَ أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَعَا فَاطِمَةَ يَوْمَ الْفَتْحِ فَنَاجَاهَا فَبَكَتْ ثُمَّ حَدَّثَهَا فَضَحِكَتْ ‏.‏ قَالَتْ فَلَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَأَلْتُهَا عَنْ بُكَائِهَا وَضَحِكِهَا قَالَتْ أَخْبَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّهُ يَمُوتُ فَبَكَيْتُ ثُمَّ أَخْبَرَنِي أَنِّي سَيِّدَةُ نِسَاءِ أَهْلِ الْجَنَّةِ إِلاَّ مَرْيَمَ ابْنَتَ عِمْرَانَ فَضَحِكْتُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3873}\hadithgrade{Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah:that the Messenger of Allah (ﷺ) called Fatimah on the Day of the Conquest (of Makkah) and he spoke to her, so she cried. Then he spoke to her and she laughed. She said: "So when the Messenger of Allah (ﷺ) died, I asked her about her crying and laughing. She said: "The Messenger of Allah (ﷺ) told me that he will die, so I cried, then he told me that I was the master over all the women of the inhabitants of Paradise, except for Mariam the daughter of 'Imran, so I laughed}}
\hadithdefcmd{tirmidhi}{3874}{حَدَّثَنَا حُسَيْنُ بْنُ يَزِيدَ الْكُوفِيُّ، قَالَ حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ أَبِي الْجَحَّافِ، عَنْ جُمَيْعِ بْنِ عُمَيْرٍ التَّيْمِيِّ، قَالَ دَخَلْتُ مَعَ عَمَّتِي عَلَى عَائِشَةَ فَسُئِلَتْ أَىُّ النَّاسِ كَانَ أَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ فَاطِمَةُ ‏.‏ فَقِيلَ مِنَ الرِّجَالِ قَالَتْ زَوْجُهَا إِنْ كَانَ مَا عَلِمْتُ صَوَّامًا قَوَّامًا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو الْجَحَّافِ اسْمُهُ دَاوُدُ بْنُ أَبِي عَوْفٍ وَيُرْوَى عَنْ سُفْيَانَ الثَّوْرِيِّ قَالَ حَدَّثَنَا أَبُو الْجَحَّافِ وَكَانَ مَرْضِيًّا ‏.‏\hadithno{3874}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jumai' bin 'Umair At-Taimi:"I entered along with my uncle upon 'Aishah and she was asked: 'Who among people was the most beloved to the Messenger of Allah (ﷺ)?' She said: 'Fatimah.' So it was said: 'From the men?' She said: 'Her husband, as I knew him to fast much and stand in prayer much}}
\hadithdefcmd{tirmidhi}{3875}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، قَالَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا غِرْتُ عَلَى أَحَدٍ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم مَا غِرْتُ عَلَى خَدِيجَةَ وَمَا بِي أَنْ أَكُونَ أَدْرَكْتُهَا وَمَا ذَاكَ إِلاَّ لِكَثْرَةِ ذِكْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَهَا وَإِنْ كَانَ لَيَذْبَحُ الشَّاةَ فَيَتَتَبَّعُ بِهَا صَدَائِقَ خَدِيجَةَ فَيُهْدِيهَا لَهُنَّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3875}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{Narrated 'Aishah:"I was not jealous of any wife of the Prophet (ﷺ) as I was jealous of Khadijah, and it was not because I did not see her. It was only because the Messenger of Allah (ﷺ) mentioned her so much, and because whenever he would slaughter a sheep, he would look for Khadijah's friends to gift them some of it}}
\hadithdefcmd{tirmidhi}{3876}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا حَسَدْتُ أَحَدًا مَا حَسَدْتُ خَدِيجَةَ وَمَا تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ بَعْدَ مَا مَاتَتْ وَذَلِكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَشَّرَهَا بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ مِنْ قَصَبٍ قَالَ إِنَّمَا يَعْنِي بِهِ قَصَبَ اللُّؤْلُؤِ ‏.‏\hadithno{3876}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah:"I did not envy any woman as I envied Khadijah - and the Messenger of Allah (ﷺ) did not marry me except after she had died - that was because the Messenger of Allah (ﷺ) gave her glad tidings of a house in Paradise made of Qasab, without clamoring nor discomforts in it}}
\hadithdefcmd{tirmidhi}{3877}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، قَالَ حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ سَمِعْتُ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ نِسَائِهَا خَدِيجَةُ بِنْتُ خُوَيْلِدٍ وَخَيْرُ نِسَائِهَا مَرْيَمُ بِنْتُ عِمْرَانَ ‏"‏ ‏. وَفِي الْبَابِ عَنْ أَنَسٍ وَابْنِ عَبَّاسٍ وَعَائِشَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3877}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Ali bin Abi Talib:that the Messenger of Allah (ﷺ) said: "The best of its women is Khadijah bint Khuwailid, and the best of its women is Mariam bint 'Imran}}
\hadithdefcmd{tirmidhi}{3878}{حَدَّثَنَا أَبُو بَكْرِ بْنُ زَنْجُويَهْ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ حَسْبُكَ مِنْ نِسَاءِ الْعَالَمِينَ مَرْيَمُ ابْنَةُ عِمْرَانَ وَخَدِيجَةُ بِنْتُ خُوَيْلِدٍ وَفَاطِمَةُ بِنْتُ مُحَمَّدٍ وَآسِيَةُ امْرَأَةُ فِرْعَوْنَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{3878}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas [may Allah be pleased with him]:that the Prophet (ﷺ) said: "Sufficient for you among the women of mankind are Mariam bint 'Imran, Khadijah bint Khuwailid, Fatimah bint Muhammad and Asiyah the wife of Fir'awn}}
\hadithdefcmd{tirmidhi}{3879}{حَدَّثَنَا يَحْيَى بْنُ دُرُسْتَ، - الْمِصْرِيُّ - قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّاسُ يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ قَالَتْ فَاجْتَمَعَ صَوَاحِبَاتِي إِلَى أُمِّ سَلَمَةَ فَقُلْنَ يَا أُمَّ سَلَمَةَ إِنَّ النَّاسَ يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ وَإِنَّا نُرِيدُ الْخَيْرَ كَمَا تُرِيدُ عَائِشَةُ فَقُولِي لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَأْمُرِ النَّاسَ يُهْدُونَ إِلَيْهِ أَيْنَمَا كَانَ فَذَكَرَتْ ذَلِكَ أُمُّ سَلَمَةَ فَأَعْرَضَ عَنْهَا ثُمَّ عَادَ إِلَيْهَا فَأَعَادَتِ الْكَلاَمَ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ صَوَاحِبَاتِي قَدْ ذَكَرْنَ أَنَّ النَّاسَ يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ فَأْمُرِ النَّاسَ يُهْدُونَ أَيْنَمَا كُنْتَ ‏.‏ فَلَمَّا كَانَتِ الثَّالِثَةُ قَالَتْ ذَلِكَ قَالَ ‏ "‏ يَا أُمَّ سَلَمَةَ لاَ تُؤْذِينِي فِي عَائِشَةَ فَإِنَّهُ مَا أُنْزِلَ عَلَىَّ الْوَحْىُ وَأَنَا فِي لِحَافِ امْرَأَةٍ مِنْكُنَّ غَيْرَهَا ‏"‏ ‏‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ حَمَّادِ بْنِ زَيْدٍ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏. هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏ وَقَدْ رُوِيَ عَنْ هِشَامِ بْنِ عُرْوَةَ هَذَا الْحَدِيثُ عَنْ عَوْفِ بْنِ الْحَارِثِ عَنْ رُمَيْثَةَ عَنْ أُمِّ سَلَمَةَ شَيْئًا مِنْ هَذَا ‏.وَ‏هَذَا حَدِيثٌ قَدْ رُوِيَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَلَى رِوَايَاتٍ مُخْتَلِفَةٍ ‏.‏ وَقَدْ رَوَى سُلَيْمَانُ بْنُ بِلاَلٍ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَائِشَةَ نَحْوَ حَدِيثِ حَمَّادِ بْنِ زَيْدٍ ‏.‏\hadithno{3879}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:"The people used to give their gifts [to the Prophet (ﷺ)] on 'Aishah's day." She said: "So my companions gathered with Umm Salamah and they said 'O Umm Salamah! The people give their gifts on 'Aishah's day, and we desire good as 'Aishah desires, so tell the Messenger of Allah (ﷺ) to order the people to give (their gifts to) him no matter where he is.' So Umm Salamah said that, and he turned away from her. Then he turned back to her and she repeated the words saying: 'O Messenger of Allah! My companions have mentioned that the people give their gifts on 'Aishah's day, so order the people to give them no matter where you are.' So upon the third time she said that, he said: 'O Umm Salamah! Do not bother me about 'Aishah! For Revelation has not been sent down upon me while I was under the blankets of a woman among you other than her}}
\hadithdefcmd{tirmidhi}{3880}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ الْمَكِّيِّ، عَنِ ابْنِ أَبِي حُسَيْنٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، أَنَّ جِبْرِيلَ، جَاءَ بِصُورَتِهَا فِي خِرْقَةِ حَرِيرٍ خَضْرَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ هَذِهِ زَوْجَتُكَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ ‏.‏ وَقَدْ رَوَى عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ بِهَذَا الإِسْنَادِ مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ عَنْ عَائِشَةَ وَقَدْ رَوَى أَبُو أُسَامَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْئًا مِنْ هَذَا ‏.‏\hadithno{3880}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah:that Jibril came to the Prophet (ﷺ) with her image upon a piece of green silk cloth, and he said: "This is your wife in the world, and in the Hereafter}}
\hadithdefcmd{tirmidhi}{3881}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ هَذَا جِبْرِيلُ وَهُوَ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ تَرَى مَا لاَ نَرَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3881}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah [may Allah be pleased with her]:that the Messenger of Allah (ﷺ) said: "O 'Aishah! Here is Jibril and he is giving Salam to you." She said: "I said: 'And upon him be peace and the mercy of Allah, and His blessings. You see that which we do not}}
\hadithdefcmd{tirmidhi}{3882}{حَدَّثَنَا سُوَيْدٌ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَخْبَرَنَا زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ جِبْرِيلَ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏ ‏.‏ فَقُلْتُ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3882}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:"The Messenger of Allah (ﷺ) said to me: 'Indeed Jibril gives his Salam to you.' So I said: 'And upon him be peace and Allah's Mercy [and His blessings]}}
\hadithdefcmd{tirmidhi}{3883}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا زِيَادُ بْنُ الرَّبِيعِ، قَالَ حَدَّثَنَا خَالِدُ بْنُ سَلَمَةَ الْمَخْزُومِيُّ، عَنِ ابْنِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ مَا أَشْكَلَ عَلَيْنَا أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثٌ قَطُّ فَسَأَلْنَا عَائِشَةَ إِلاَّ وَجَدْنَا عِنْدَهَا مِنْهُ عِلْمًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3883}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Musa:"Never was a Hadith unclear to us - the Companions of the Messenger of Allah - and we asked 'Aishah, except that we found some knowledge concerning it with her}}
\hadithdefcmd{tirmidhi}{3884}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، قَالَ مَا رَأَيْتُ أَحَدًا أَفْصَحَ مِنْ عَائِشَةَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3884}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Musa bin Talhah:"I have not seen anyone clearer (in speech) than 'Aishah}}
\hadithdefcmd{tirmidhi}{3885}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، وَاللَّفْظُ، لاِبْنِ يَعْقُوبَ قَالاَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، قَالَ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَهُ عَلَى جَيْشِ ذَاتِ السَّلاَسِلِ ‏.‏ قَالَ فَأَتَيْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ أَحَبُّ إِلَيْكَ قَالَ ‏"‏ عَائِشَةُ ‏"‏ ‏.‏ قُلْتُ مِنَ الرِّجَالِ قَالَ ‏"‏ أَبُوهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3885}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Amr bin Al-'As:that the Messenger of Allah (ﷺ) appointed him as a leader of the army of Dhatis-Salasil. He said: "So I went to him and said: 'O Messenger of Allah! Who is the most beloved to you among the people?' He said: ''Aishah.' I said: 'From the men?' He said: 'Her father}}
\hadithdefcmd{tirmidhi}{3886}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الأُمَوِيُّ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ مَنْ أَحَبُّ النَّاسِ إِلَيْكَ قَالَ ‏"‏ عَائِشَةُ ‏"‏ ‏.‏ قَالَ مِنَ الرِّجَالِ قَالَ ‏"‏ أَبُوهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ إِسْمَاعِيلَ عَنْ قَيْسٍ ‏.‏\hadithno{3886}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Amr bin Al-'As:that he said to the Messenger of Allah (ﷺ): "Who is the most beloved of the people to you?" He said: "'Aishah." He said: "From the men?" He said: "Her farther}}
\hadithdefcmd{tirmidhi}{3887}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ الأَنْصَارِيِّ، عَنْ أَنَسِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏ ‏. وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي مُوسَى ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ هُوَ أَبُو طُوَالَةَ الأَنْصَارِيُّ الْمَدَنِيُّ ثِقَةٌ وَقَدْ رَوَى عَنْهُ مَالِكُ بْنُ أَنَسٍ ‏.‏\hadithno{3887}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "The virtue of 'Aishah over women is like the virtue of Tharid over all other foods}}
\hadithdefcmd{tirmidhi}{3888}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ غَالِبٍ، أَنَّ رَجُلاً، نَالَ مِنْ عَائِشَةَ عِنْدَ عَمَّارِ بْنِ يَاسِرٍ فَقَالَ اغْرُبْ مَقْبُوحًا مَنْبُوحًا أَتُؤْذِي حَبِيبَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3888}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Amr bin Ghalib:that a man spoke negatively of 'Aishah before 'Ammar bin Yasir so he said: "Be gone as one despicable and rejected! Do you insult the beloved of the Messenger of Allah (ﷺ)?}}
\hadithdefcmd{tirmidhi}{3889}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حُصَيْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ زِيَادٍ الأَسَدِيِّ، قَالَ سَمِعْتُ عَمَّارَ بْنَ يَاسِرٍ، يَقُولُ هِيَ زَوْجَتُهُ فِي الدُّنْيَا وَالآخِرَةِ ‏.‏ يَعْنِي عَائِشَةَ رضى الله عنها ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيِّ ‏.‏\hadithno{3889}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ammar bin Yasir:"She is his wife in the world and in the Hereafter." - meaning: 'Aishah [may Allah be pleased with her]}}
\hadithdefcmd{tirmidhi}{3890}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ قَالَ قِيلَ يَا رَسُولَ اللَّهِ مَنْ أَحَبُّ النَّاسِ إِلَيْكَ قَالَ ‏"‏ عَائِشَةُ ‏"‏ ‏.‏ قِيلَ مِنَ الرِّجَالِ قَالَ ‏"‏ أَبُوهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَنَسٍ ‏.‏\hadithno{3890}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas [May Allah be pleased with him]:"It was said: 'O Messenger of Allah! Who is the most beloved of the people to you?' He said: ''Aishah.' It was said: 'From the men?' He said: 'Her father}}
\hadithdefcmd{tirmidhi}{3891}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ الْعَنْبَرِيُّ أَبُو غَسَّانَ، قَالَ حَدَّثَنَا سَلْمُ ابْنُ جَعْفَرٍ وَكَانَ ثِقَةً عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، قَالَ قِيلَ لاِبْنِ عَبَّاسٍ بَعْدَ صَلاَةِ الصُّبْحِ مَاتَتْ فُلاَنَةُ لِبَعْضِ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فَسَجَدَ فَقِيلَ لَهُ أَتَسْجُدُ هَذِهِ السَّاعَةَ فَقَالَ أَلَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمْ آيَةً فَاسْجُدُوا ‏"‏ ‏.‏ فَأَىُّ آيَةٍ أَعْظَمُ مِنْ ذَهَابِ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3891}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Ikrimah:"After Salat As-Subh, it was said to Ibn 'Abbas that so-and-so - one of the wives of the Prophet (ﷺ) - has died, so he prostrated. So it was said to him: 'Do you prostrate at this hour?' So he said: 'Has not the Messenger of Allah (ﷺ) [already] said: 'If you see a sign then prostrate?' Then which sign is grater than the passing of (one of) the wives of the Prophet (ﷺ)?}}
\hadithdefcmd{tirmidhi}{3892}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا هَاشِمٌ، هُوَ ابْنُ سَعِيدٍ الْكُوفِيُّ قَالَ حَدَّثَنَا كِنَانَةُ، قَالَ حَدَّثَتْنَا صَفِيَّةُ بِنْتُ حُيَىٍّ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ بَلَغَنِي عَنْ حَفْصَةَ وَعَائِشَةَ كَلاَمٌ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ أَلاَ قُلْتِ فَكَيْفَ تَكُونَانِ خَيْرًا مِنِّي وَزَوْجِي مُحَمَّدٌ وَأَبِي هَارُونُ وَعَمِّي مُوسَى ‏"‏ ‏.‏ وَكَانَ الَّذِي بَلَغَهَا أَنَّهُمْ قَالُوا نَحْنُ أَكْرَمُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْهَا ‏.‏ وَقَالُوا نَحْنُ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم وَبَنَاتُ عَمِّهِ ‏.‏ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ صَفِيَّةَ إِلاَّ مِنْ حَدِيثِ هَاشِمٍ الْكُوفِيُّ وَلَيْسَ إِسْنَادُهُ بِذَلِكَ الْقَوِيِّ ‏.‏\hadithno{3892}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Safiyyah bint Huyai:"The Messenger of Allah (ﷺ) entered upon me and some words had reached me from Hafsah and 'Aishah. So I mentioned it to him. So he said: 'Why did you not say: "And how are you two better than me, while my husband is Muhammad and my father is Harun, and my uncle is Musa?" That which had reached her, was that they had said: "We are more honored to the Messenger of Allah (ﷺ) than her," and that they said: "We are the wives of the Prophet (ﷺ) and his cousins}}
\hadithdefcmd{tirmidhi}{3893}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ عَثْمَةَ، قَالَ حَدَّثَنِي مُوسَى بْنُ يَعْقُوبَ الزَّمْعِيُّ، عَنْ هَاشِمِ بْنِ هَاشِمٍ، أَنَّ عَبْدَ اللَّهِ بْنَ وَهْبِ بْنِ زَمْعَةَ أَخْبَرَهُ أَنَّ أُمَّ سَلَمَةَ أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى ا��له عليه وسلم دَعَا فَاطِمَةَ عَامَ الْفَتْحِ فَنَاجَاهَا فَبَكَتْ ثُمَّ حَدَّثَهَا فَضَحِكَتْ قَالَتْ فَلَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَأَلْتُهَا عَنْ بُكَائِهَا وَضَحِكِهَا ‏.‏ قَالَتْ أَخْبَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّهُ يَمُوتُ فَبَكَيْتُ ثُمَّ أَخْبَرَنِي أَنِّي سَيِّدَةُ نِسَاءِ أَهْلِ الْجَنَّةِ إِلاَّ مَرْيَمَ بِنْتَ عِمْرَانَ فَضَحِكْتُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3893}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah:that the Messenger of Allah (ﷺ) called for Fatimah in the Year of the Conquest to speak to her, and she cried. Then he spoke to her and she laughed. She said: "When the Messenger of Allah (ﷺ) died I asked her about her crying and her laughing. She said: 'The Messenger of Allah (ﷺ) informed me that he would (soon) die, so I cried. Then, he informed me that I was the master over all of the women among the inhabitants of Paradise, except for Mariam bint 'Imran, so I laughed}}
\hadithdefcmd{tirmidhi}{3894}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ بَلَغَ صَفِيَّةَ أَنَّ حَفْصَةَ، قَالَتْ بِنْتُ يَهُودِيٍّ ‏.‏ فَبَكَتْ فَدَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم وَهِيَ تَبْكِي فَقَالَ ‏"‏ مَا يُبْكِيكِ ‏"‏ ‏.‏ فَقَالَتْ قَالَتْ لِي حَفْصَةُ إِنِّي بِنْتُ يَهُودِيٍّ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّكِ لاَبْنَةُ نَبِيٍّ وَإِنَّ عَمَّكِ لَنَبِيٌّ وَإِنَّكِ لَتَحْتَ نَبِيٍّ فَفِيمَ تَفْخَرُ عَلَيْكِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اتَّقِي اللَّهَ يَا حَفْصَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3894}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas:said: "It reached Safiyyah that Hafsah said: 'The daughter of a Jew' so she wept. Then the Prophet (ﷺ) entered upon her while she was crying, so he said: 'What makes you cry?' She said: 'Hafsah said to me that I am the daughter of a Jew.' So the Prophet (ﷺ) said: 'And you are the daughter of a Prophet, and your uncle is a Prophet, and you are married to a Prophet, so what is she boasting to you about?' Then he said: 'Fear Allah, O Hafsah}}
\hadithdefcmd{tirmidhi}{3895}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُكُمْ خَيْرُكُمْ لأَهْلِهِ وَأَنَا خَيْرُكُمْ لأَهْلِي وَإِذَا مَاتَ صَاحِبُكُمْ فَدَعُوهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ مِنْ حَدِيثِ الثَّوْرِيِّ مَا أَقَلَّ مَنْ رَوَاهُ عَنِ الثَّوْرِيِّ ‏.‏ وَرُوِيَ هَذَا عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ ‏.‏\hadithno{3895}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Aishah:that the Messenger of Allah (ﷺ) said: "The best of you is the best to his wives, and I am the best of you to my wives, and when your companion dies, leave him alone}}
\hadithdefcmd{tirmidhi}{3896}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ إِسْرَائِيلَ، عَنِ الْوَلِيدِ، عَنْ زَيْدِ بْنِ زَائِدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يُبَلِّغُنِي أَحَدٌ عَنْ أَحَدٍ مِنْ أَصْحَابِي شَيْئًا فَإِنِّي أُحِبُّ أَنْ أَخْرُجَ إِلَيْهِمْ وَأَنَا سَلِيمُ الصَّدْرِ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَالٍ فَقَسَمَهُ فَانْتَهَيْتُ إِلَى رَجُلَيْنِ جَالِسَيْنِ وَهُمَا يَقُولاَنِ وَاللَّهِ مَا أَرَادَ مُحَمَّدٌ بِقِسْمَتِهِ الَّتِي قَسَمَهَا وَجْهَ اللَّهِ وَلاَ الدَّارَ الآخِرَةَ ‏.‏ فَتَثَبَّتُّ حِينَ سَمِعْتُهُمَا فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَخْبَرْتُهُ فَاحْمَرَّ وَجْهُهُ وَقَالَ ‏"‏ دَعْنِي عَنْكَ فَقَدْ أُوذِيَ مُوسَى بِأَكْثَرَ مِنْ هَذَا فَصَبَرَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ زِيدَ فِي هَذَا الإِسْنَادِ رَجُلٌ ‏.‏\hadithno{3896}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Mas'ud:that the Messenger of Allah (ﷺ) said: "No one should convey to me anything regarding any of my Companions, for I love that I should go out to them while my breast is at peace." 'Abdullah said: "The Messenger of Allah (ﷺ) was brought some wealth, so the Prophet (ﷺ) distributed it. Then I came across two men that were sitting saying: 'By Allah! Muhammad (ﷺ) did not intend the Face of Allah in his distribution, nor the abode of the Hereafter.' So I spread this when I heard them, and I went to the Messenger of Allah (ﷺ) and I informed him. So his face became red and he said: 'Do not bother me with this, for indeed Musa was afflicted by more than this and he was patient}}
\hadithdefcmd{tirmidhi}{3897}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، وَالْحُسَيْنُ بْنُ مُحَمَّدٍ، عَنْ إِسْرَائِيلَ، عَنِ السُّدِّيِّ، عَنِ الْوَلِيدِ بْنِ أَبِي هِشَامٍ، عَنْ زَيْدِ بْنِ زَائِدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، رَضِيَ اللَّهُ عَنْهُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُبَلِّغُنِي أَحَدٌ عَنْ أَحَدٍ شَيْئًا ‏"‏ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْئًا مِنْ هَذَا مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{3897}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Mas'ud:that the Prophet (ﷺ) said: "No one should convey to me anything regarding anyone}}
\hadithdefcmd{tirmidhi}{3898}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ عَاصِمٍ، قَالَ سَمِعْتُ زِرَّ بْنَ حُبَيْشٍ، يُحَدِّثُ عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ الْقُرْآنَ ‏"‏ ‏.‏ فَقَرَأَ عَلَيْهِ ‏:‏ ‏(‏ لمْ يَكُنِ الَّذِينَ كَفَرُوا ‏)‏ وَفِيهَا ‏"‏ إِنَّ ذَاتَ الدِّينِ عِنْدَ اللَّهِ الْحَنِيفِيَّةُ الْمُسْلِمَةُ لاَ الْيَهُودِيَّةُ وَلاَ النَّصْرَانِيَّةُ وَلاَ الْمَجُوسِيَّةُ مَنْ يَعْمَلْ خَيْرًا فَلَنْ يُكْفَرَهُ ‏"‏ ‏.‏ وَقَرَأَ عَلَيْهِ ‏"‏ لَوْ أَنَّ لاِبْنِ آدَمَ وَادِيًا مِنْ مَالٍ لاَبْتَغَى إِلَيْهِ ثَانِيًا وَلَوْ كَانَ لَهُ ثَانِيًا لاَبْتَغَى إِلَيْهِ ثَالِثًا وَلاَ يَمْلأُ جَوْفَ ابْنِ آدَمَ إِلاَّ التُّرَابُ وَيَتُوبُ اللهُ عَلَى مَنْ تَابَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ رَوَاهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أَبِيهِ عَنْ أُبَىِّ بْنِ كَعْبٍ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ الْقُرْآنَ ‏"‏ ‏.‏ وَقَدْ رَوَاهُ قَتَادَةُ عَنْ أَنَسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأُبَىِّ بْنِ كَعْبٍ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ الْقُرْآنَ ‏"‏ ‏.‏\hadithno{3898}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ubayy bin Ka'b:that the Messenger of Allah (ﷺ) said to him: "Indeed Allah has ordered me to recite the Qur'an to you." So he recited to him: "Those who disbelieved were not going to... (98:1) and he recited in it: "Indeed the religion with Allah is that which is Hanafiyyah, Muslim, not Judaism, nor Christianity, nor Zoroastrian, whoever does good then it shall not be rejected from him." And he recited to him: "If the son of Adam had a valley of wealth he would seek a second, and if he had a second he would seek a third, and nothing fills the belly of the son of Adam except dirt. And Allah pardons those who repent}}
\hadithdefcmd{tirmidhi}{3899}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ، عَنْ زُهَيْرِ بْنِ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ ابْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنِ الطُّفَيْلِ بْنِ أُبَىِّ بْنِ كَعْبٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْلاَ الْهِجْرَةُ لَكُنْتُ امْرَأً مِنَ الأَنْصَارِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَوْ سَلَكَ النَّاسُ وَادِيًا أَوْ شِعْبًا لَكُنْتُ مَعَ الأَنْصَارِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3899}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ubayy bin Ka'b:that the Messenger of Allah (ﷺ) said: "If it were not for the Hijrah, I would be a man from the Ansar}}
\hadithdefcmd{tirmidhi}{3900}{حَدَّثَنَا بُنْدَارٌ قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم أَوْ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم فِي الأَنْصَارِ ‏ "‏ لاَ يُحِبُّهُمْ إِلاَّ مُؤْمِنٌ وَلاَ يَبْغَضُهُمْ إِلاَّ مُنَافِقٌ مَنْ أَحَبَّهُمْ فَأَحَبَّهُ اللَّهُ وَمَنْ أَبْغَضَهُمْ فَأَبْغَضَهُ اللَّهُ ‏"‏ ‏.‏ فَقُلْتُ لَهُ أَأَنْتَ سَمِعْتَهُ مِنَ الْبَرَاءِ فَقَالَ إِيَّاىَ حَدَّثَ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{3900}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Shu'bah:from 'Adi bin Thabit, from Al-Bara bin 'Azib, that he heard the Prophet (ﷺ), or - he said: "The Prophet (ﷺ) said, about the Ansar: 'No one loves them except a believer, and no one hates them except a hypocrite. Whoever loves them, then Allah loves him, and whoever hates them then Allah hates him.'" So we said to him: "Did you hear this from Al-Bara?" He said: "He narrated it to me}}
\hadithdefcmd{tirmidhi}{3901}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ،قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسٍ، رَضِيَ اللَّهُ عَنْهُ قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاسًا مِنَ الأَنْصَارِ فَقَالَ ‏"‏ هَلُمَّ هَلْ فِيكُمْ أَحَدٌ مِنْ غَيْرِكُمْ ‏"‏ ‏.‏ قَالُوا لاَ إِلاَّ ابْنَ أُخْتٍ لَنَا ‏.‏ فَقَالَ صلى الله عليه وسلم ‏"‏ إِنَّ ابْنَ أُخْتِ الْقَوْمِ مِنْهُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ قُرَيْشًا حَدِيثٌ عَهْدُهُمْ بِجَاهِلِيَّةٍ وَمُصِيبَةٍ وَإِنِّي أَرَدْتُ أَنْ أَجْبُرَهُمْ وَأَتَأَلَّفَهُمْ أَمَا تَرْضَوْنَ أَنْ يَرْجِعَ النَّاسُ بِالدُّنْيَا وَتَرْجِعُونَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى بُيُوتِكُمْ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ سَلَكَ النَّاسُ وَادِيًا أَوْ شِعْبًا وَسَلَكَتِ الأَنْصَارُ وَادِيًا أَوْ شِعْبًا لَسَلَكْتُ وَادِيَ الأَنْصَارِ أَوْ شِعْبَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3901}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas:that the Messenger of Allah (ﷺ) gathered a group of people from the Ansar and said: "Come, is there anyone among you who is from other than you?" They said: "No, except the son of a sister of ours." So he said: "The son of the sister of a people is from them." Then he said: "Indeed the Quraish is not far from their time of ignorance and affliction, and I wished that I subdue them and coax them. Are you not happy that the people return with this world and you return to your homes with the Messenger of Allah (ﷺ)?" They said: "Of course we are." So the Messenger of Allah (ﷺ) said: "If the people were to pass through a valley or a path, and the Ansar passed through a valley or a path then I would pass through the valley or path of the Ansar}}
\hadithdefcmd{tirmidhi}{3902}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، أَنَّهُ كَتَبَ إِلَى أَنَسِ بْنِ مَالِكٍ يُعَزِّيهِ فِيمَنْ أُصِيبَ مِنْ أَهْلِهِ وَبَنِي عَمِّهِ يَوْمَ الْحَرَّةِ فَكَتَبَ إِلَيْهِ إِنِّي أُبَشِّرُكَ بِبُشْرَى مِنَ اللَّهِ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِلأَنْصَارِ وَلِذَرَارِيِّ الأَنْصَارِ وَلِذَرَارِيِّ ذَرَارِيِّهِمْ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏‏ وَقَدْ رَوَاهُ قَتَادَةُ عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، ‏.‏\hadithno{3902}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Zaid bin Arqam wrote to Anas bin Malik, comforting him over those of his family and children of his paternal uncle who suffered on the day of Al-Harrah. So he wrote to him:"I give you glad tidings of good news from Allah. I heard the Messenger of Allah (ﷺ) say: 'O Allah forgive the Ansar and the children of the Ansar, and the children of their children}}
\hadithdefcmd{tirmidhi}{3903}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، وَعَبْدُ الصَّمَدِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ ثَابِتٍ الْبُنَانِيُّ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي طَلْحَةَ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْرَأْ قَوْمَكَ السَّلاَمَ فَإِنَّهُمْ مَا عَلِمْتُ أَعِفَّةٌ صُبُرٌ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3903}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Talhah:"The Messenger of Allah (ﷺ) said to me: 'Convey my Salam to your people, because I know them to be modest and patient}}
\hadithdefcmd{tirmidhi}{3904}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنِي الْفَضْلُ بْنُ مُوسَى، عَنْ زَكَرِيَّا ابْنِ أَبِي زَائِدَةَ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ إِنَّ عَيْبَتِي الَّتِي آوِي إِلَيْهَا أَهْلُ بَيْتِي وَإِنَّ كَرِشِي الأَنْصَارُ فَاعْفُوا عَنْ مُسِيئِهِمْ وَاقْبَلُوا مِنْ مُحْسِنِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏. وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏\hadithno{3904}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:that the Prophet (ﷺ) said: "Indeed my elite, those whom I lean towards, are the people of my house and my close ones are the Ansar, so forgive those who do wrong from them and accept from those who do good from them}}
\hadithdefcmd{tirmidhi}{3905}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْهَاشِمِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ ابْنُ سَعْدٍ، قَالَ حَدَّثَنِي صَالِحُ بْنُ كَيْسَانَ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ أَبِي سُفْيَانَ، عَنْ يُوسُفَ بْنِ الْحَكَمِ، عَنْ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يُرِدْ هَوَانَ قُرَيْشٍ أَهَانَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ أَخْبَرَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3905}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'd:that the Messenger of Allah (ﷺ) said: "Whoever wishes to humiliate the Quraish then Allah will humiliate him}}
\hadithdefcmd{tirmidhi}{3906}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، وَالْمُؤَمَّلُ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبْغَضُ الأَنْصَارَ أَحَدٌ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3906}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) said to me: 'A man who believes in Allah and the Last Day does not hate the Ansar}}
\hadithdefcmd{tirmidhi}{3907}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَنْصَارُ كَرِشِي وَعَيْبَتِي وَإِنَّ النَّاسَ سَيَكْثُرُونَ وَيَقِلُّونَ فَاقْبَلُوا مِنْ مُحْسِنِهِمْ وَتَجَاوَزُوا عَنْ مُسِيئِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3907}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "The Ansar are my close ones and my elite. Indeed the people shall increase and they shall dwindle, so accept from those who do good among them, and overlook those who do bad among them}}
\hadithdefcmd{tirmidhi}{3908}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا أَبُو يَحْيَى الْحِمَّانِيُّ، عَنِ الأَعْمَشِ، عَنْ طَارِقِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ أَذَقْتَ أَوَّلَ قُرَيْشٍ نَكَالاً فَأَذِقْ آخِرَهُمْ نَوَالاً ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ حَدَّثَنَا عَبْدُ الْوَهَّابِ الْوَرَّاقُ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الأُمَوِيُّ، عَنِ الأَعْمَشِ، نَحْوَهُ ‏.‏\hadithno{3908}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "O Allah! You made the first of the Quraish taste punishment, so let the last of them taste blessings}}
\hadithdefcmd{tirmidhi}{3909}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ جَعْفَرٍ الأَحْمَرِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ اغْفِرْ لِلأَنْصَارِ وَلأَبْنَاءِ الأَنْصَارِ وَلأَبْنَاءِ أَبْنَاءِ الأَنْصَارِ وَلِنِسَاءِ الأَنْصَارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3909}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas:that the Messenger of Allah (ﷺ) said: "O Allah forgive the Ansar and the children of the Ansar, and the children of the children of the Ansar, and the women of the Ansar}}
\hadithdefcmd{tirmidhi}{3910}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ دُورِ الأَنْصَارِ أَوْ بِخَيْرِ الأَنْصَارِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ بَنُو النَّجَّارِ ثُمَّ الَّذِينَ يَلُونَهُمْ بَنُو عَبْدِ الأَشْهَلِ ثُمَّ الَّذِينَ يَلُونَهُمْ بَنُو الْحَارِثِ بْنِ الْخَزْرَجِ ثُمَّ الَّذِينَ يَلُونَهُمْ بَنُو سَاعِدَةَ ‏"‏ ‏.‏ ثُمَّ قَالَ بِيَدِهِ فَقَبَضَ أَصَابِعَهُ ثُمَّ بَسَطَهُنَّ كَالرَّامِي بِيَدَيْهِ قَالَ ‏"‏ وَفِي دُورِ الأَنْصَارِ كُلِّهَا خَيْرٌ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا أَيْضًا عَنْ أَنَسٍ عَنْ أَبِي أُسَيْدٍ السَّاعِدِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3910}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "Shall I inform you of the best houses of the Ansar, or of the best of the Ansar?" They said: "Of course, O Messenger of Allah!" He said: "Banu An-Najjar. Then those who come after them are Banu 'Abdul-Ashhal. Then those who come after them are Banu Al-Harith bin Al-Khazraj. Then those who come after them are Banu Sa'idah." Then he motioned with his hands, clenching his fingers, then opening them, like an archer does with his hands. He said: "And in all of the houses of the Ansar there is good}}
\hadithdefcmd{tirmidhi}{3911}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي أُسَيْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ دُورِ الأَنْصَارِ دُورُ بَنِي النَّجَّارِ ثُمَّ دُورُ بَنِي عَبْدِ الأَشْهَلِ ثُمَّ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ ثُمَّ بَنِي سَاعِدَةَ وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏ ‏.‏ فَقَالَ سَعْدٌ مَا أَرَى رَسُولَ اللَّهِ صلى الله عليه وسلم إِلاَّ قَدْ فَضَّلَ عَلَيْنَا ‏.‏ فَقِيلَ قَدْ فَضَّلَكُمْ عَلَى كَثِيرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو أُسَيْدٍ السَّاعِدِيُّ اسْمُهُ مَالِكُ بْنُ رَبِيعَةَ ‏.‏ وَقَدْ رُوِيَ نَحْوَ هَذَا عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ وَعُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3911}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Usaid As-Sa'idi:that the Messenger of Allah (ﷺ) said: "The Best houses of the Ansar are the houses of Banu An-Najjar, then the house of Banu 'Abdul-Ashhal, then Banu Al-Harith bin Al-Khazraj, then Banu Sa'idah. And in all of the houses of the Ansar there is good." So Sa'd said: "I do not see except that the Prophet (ﷺ) has preferred everyone over us." So it was said: "He preferred you over many}}
\hadithdefcmd{tirmidhi}{3912}{حَدَّثَنَا أَبُو السَّائِبِ سَلْمُ بْنُ جُنَادَةَ قَالَ حَدَّثَنَا أَحْمَدُ بْنُ بَشِيرٍ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ دِيَارِ الأَنْصَارِ بَنُو النَّجَّارِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3912}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir bin 'Abdullah:that the Messenger of Allah (ﷺ) said: "The best house of the Ansar is Banu An-Najjar}}
\hadithdefcmd{tirmidhi}{3913}{حَدَّثَنَا أَبُو السَّائِبِ، سَلْمُ بْنُ جُنَادَةَ قَالَ حَدَّثَنَا أَحْمَدُ بْنُ بَشِيرٍ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ الأَنْصَارِ بَنُو عَبْدِ الأَشْهَلِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3913}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir [bin 'Abdullah]:that the Messenger of Allah (ﷺ) said: "The best of the Ansar are Banu 'Abdul-Ashhal}}
\hadithdefcmd{tirmidhi}{3914}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعْدٍ‏ قَالَ حَدَّثَنَا اللَّيْثُ عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ عَاصِمِ بْنِ عُمَرَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كُنَّا بِحَرَّةِ السُّقْيَا الَّتِي كَانَتْ لِسَعْدِ بْنِ أَبِي وَقَّاصٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ائْتُونِي بِوَضُوءٍ ‏"‏ ‏.‏ فَتَوَضَّأَ ثُمَّ قَامَ فَاسْتَقْبَلَ الْقِبْلَةَ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ إِنَّ إِبْرَاهِيمَ كَانَ عَبْدَكَ وَخَلِيلَكَ وَدَعَا لأَهْلِ مَكَّةَ بِالْبَرَكَةِ وَأَنَا عَبْدُكَ وَرَسُولُكَ أَدْعُوكَ لأَهْلِ الْمَدِينَةِ أَنْ تُبَارِكَ لَهُمْ فِي مُدِّهِمْ وَصَاعِهِمْ مِثْلَىْ مَا بَارَكْتَ لأَهْلِ مَكَّةَ مَعَ الْبَرَكَةِ بَرَكَتَيْنِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعَبْدِ اللَّهِ بْنِ زَيْدٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{3914}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Ali bin Abi Talib:"We departed with the Messenger of Allah (ﷺ) until he was at Harrah As-Suqya which belonged to Sa'd bin Abi Waqqas. So the Messenger of Allah (ﷺ) said: 'Bring me water for Wudu.' So he performed Wudu, then he faced the Qiblah and said: 'O Allah! Indeed Ibrahim was Your servant and Your Khalil, and he supplicated for blessings for the people of Makkah. And I am Your servant and Messenger, and I supplicate for the people of Al-Madinah; that You bless them in their Mudd and their Sa' like You blessed the people of Makkah, for each blessing let there be two blessings}}
\hadithdefcmd{tirmidhi}{3915}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ،‏ قَالَ حَدَّثَنَا أَبُو نُبَاتَةَ، يُونُسُ بْنُ يَحْيَى بْنِ نُبَاتَةَ‏ قَالَ حَدَّثَنَا سَلَمَةُ بْنُ وَرْدَانَ، عَنْ أَبِي سَعِيدِ بْنِ أَبِي الْمُعَلَّى، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، وَأَبِي هُرَيْرَةَ قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَلِيٍّ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3915}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Ali bin Abi Talib and Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whatever is between my house and my Minbar is a garden from the gardens of Paradise}}
\hadithdefcmd{tirmidhi}{3916}{حَدَّثَنَا مُحَمَّدُ بْنُ كَامِلٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ الزَّاهِدُ، عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنِ الْوَلِيدِ بْنِ رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ صَلاَةٌ فِي مَسْجِدِي هَذَا خَيْرٌ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ مِنَ الْمَسَاجِدِ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{3916}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "What is between my house and my Minbar is a garden from the gardens of Paradise." And with this chain, from the Prophet (ﷺ), that he said: "One Salat in this Masjid of mine is better than one thousand prayers in any other Masjid, except for Al-Masjid Al-Haram}}
\hadithdefcmd{tirmidhi}{3917}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مَعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَطَاعَ أَنْ يَمُوتَ بِالْمَدِينَةِ فَلْيَمُتْ بِهَا فَإِنِّي أَشْفَعُ لِمَنْ يَمُوتُ بِهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ سُبَيْعَةَ بِنْتِ الْحَارِثِ الأَسْلَمِيَّةِ ‏. هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَيُّوبَ السَّخْتِيَانِيِّ ‏.‏\hadithno{3917}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Umar:that the Prophet (ﷺ) said: "Whoever is able to die in Al-Madinah, then let him die there, for I will intercede for those who die there}}
\hadithdefcmd{tirmidhi}{3918}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ ابْنَ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّ مَوْلاَةً، لَهُ أَتَتْهُ فَقَالَتِ اشْتَدَّ عَلَىَّ الزَّمَانُ وَإِنِّي أُرِيدُ أَنْ أَخْرُجَ إِلَى الْعِرَاقِ ‏.‏ قَالَ فَهَلاَّ إِلَى الشَّأْمِ أَرْضِ الْمَنْشَرِ اصْبِرِي لَكَاعِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَبَرَ عَلَى شِدَّتِهَا وَلأْوَائِهَا كُنْتُ لَهُ شَهِيدًا أَوْ شَفِيعًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَسُفْيَانَ بْنِ أَبِي زُهَيْرٍ وَسُبَيْعَةَ الأَسْلَمِيَّةِ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ ‏.‏\hadithno{3918}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Umar:that a freed a slave girl of his came to him, and said: "Times have become hard on me and I want to go to Al-'Iraq." He said: "Why not to Ash-Sham the land of the resurrection? Have patience you foolish lady; I heard the Messenger of Allah (ﷺ) say: 'Whoever endures its hardships and difficulties (Al-Madinah) then I will be a witness, or an intercessor for him on the Day of Judgement." [He said:] There are narrations on this topic from Abu Sa'eed, Sufyan bin Abi Zuhair, and Subai'ah Al-Aslamiyyah}}
\hadithdefcmd{tirmidhi}{3919}{حَدَّثَنَا أَبُو السَّائِبِ، سَلْمُ بْنُ جُنَادَةَ قَالَ أَخْبَرَنَا أَبِي جُنَادَةُ بْنُ سَلْمٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ آخِرُ قَرْيَةٍ مِنْ قُرَى الإِسْلاَمِ خَرَابًا الْمَدِينَةُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ جُنَادَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ ‏.‏ قَالَ تَعَجَّبَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ مِنْ حَدِيثِ أَبِي هُرَيْرَةَ هَذَا ‏.‏\hadithno{3919}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "The last of the cities of Islam to be destroyed is Al-Madinah}}
\hadithdefcmd{tirmidhi}{3920}{حَدَّثَنَا الأَنْصَارِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، أَنَّ أَعْرَابِيًّا، بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الإِسْلاَمِ فَأَصَابَهُ وَعَكٌ بِالْمَدِينَةِ فَجَاءَ الأَعْرَابِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَرَجَ الأَعْرَابِيُّ ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى فَخَرَجَ الأَعْرَابِيُّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْمَدِينَةُ كَالْكِيرِ تَنْفِي خَبَثَهَا وَتُنَصِّعُ طَيِّبَهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3920}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir:that a Bedouin gave the pledge to the Messenger of Allah (ﷺ) for Islam, then he was afflicted by the sickness in Al-Madinah. So the Bedouin went to the Messenger of Allah (ﷺ) and said: "Take back my pledge." But the Messenger of Allah (ﷺ) refused. Then the Bedouin left and came back and said: "Take back my pledge," and he refused. Then the Messenger of Allah (ﷺ) said: "Al-Madinah is but like bellows, it expels its filth and purifies its good}}
\hadithdefcmd{tirmidhi}{3921}{حَدَّثَنَا الأَنْصَارِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيِّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ لَوْ رَأَيْتُ الظِّبَاءَ تَرْتَعُ بِالْمَدِينَةِ مَا ذَعَرْتُهَا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ لاَبَتَيْهَا حَرَامٌ ‏"‏ ‏. وَفِي الْبَابِ عَنْ سَعْدٍ وَعَبْدِ اللَّهِ بْنِ زَيْدٍ وَأَنَسٍ وَأَبِي أَيُّوبَ وَزَيْدِ بْنِ ثَابِتٍ وَرَافِعِ بْنِ خَدِيجٍ وَسَهْلِ بْنِ حُنَيْفٍ وَجَابِرٍ ‏.‏ حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3921}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sa'eed bin Al-Musayyab:that Abu Hurairah used to say: "If I saw hyenas roaming in Al-Madinah, I would not advance upon them. Indeed the Messenger of Allah (ﷺ) said: 'Whatever is between its two lava tracts is sacred}}
\hadithdefcmd{tirmidhi}{3922}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، وَحَدَّثَنَا الأَنْصَارِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَلَعَ لَهُ أُحُدٌ فَقَالَ ‏ "‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ اللَّهُمَّ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ وَإِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3922}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:that (mount) Uhud appeared to the Messenger of Allah (ﷺ) so he said: "This mountain loves us and we love it. O Allah! Indeed Ibrahim made Makkah sacred, and I make sacred whatever is between its (i.e. Al-Madinah) two lava tracts}}
\hadithdefcmd{tirmidhi}{3923}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عِيسَى بْنِ عُبَيْدٍ، عَنْ غَيْلاَنَ بْنِ عَبْدِ اللَّهِ الْعَامِرِيِّ، عَنْ أَبِي زُرَعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ أَوْحَى إِلَىَّ أَىَّ هَؤُلاَءِ الثَّلاَثَةِ نَزَلْتَ فَهِيَ دَارُ هِجْرَتِكَ الْمَدِينَةَ أَوِ الْبَحْرَيْنِ أَوْ قِنَّسْرِينَ ‏"‏ ‏. هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْفَضْلِ بْنِ مُوسَى تَفَرَّدَ بِهِ أَبُو عَامِرٍ ‏.‏\hadithno{3923}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jarir bin 'Abdullah:that the Prophet (ﷺ) said: "Indeed Allah has revealed to me that: Whichever of these three places you go to will be the place of your emigration: Al-Madinah, Bahrain, or Qinnasrin}}
\hadithdefcmd{tirmidhi}{3924}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ صَالِحِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَصْبِرُ عَلَى لأْوَاءِ الْمَدِينَةِ وَشِدَّتِهَا أَحَدٌ إِلاَّ كُنْتُ لَهُ شَفِيعًا أَوْ شَهِيدًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَسُفْيَانَ بْنِ أَبِي زُهَيْرٍ وَسُبَيْعَةَ الأَسْلَمِيَّةِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏. وَصَالِحُ بْنُ أَبِي صَالِحٍ أَخُو سُهَيْلِ بْنِ أَبِي صَالِحٍ ‏.‏\hadithno{3924}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "No one is patient with the difficulties and hardships of Al-Madinah, except that I am an intercessor, or a witness for him on the Day of Judgement}}
\hadithdefcmd{tirmidhi}{3925}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَدِيِّ بْنِ حَمْرَاءَ الزُّهْرِيِّ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَاقِفًا عَلَى الْحَزْوَرَةِ فَقَالَ ‏ "‏ وَاللَّهِ إِنَّكِ لَخَيْرُ أَرْضِ اللَّهِ وَأَحَبُّ أَرْضِ اللَّهِ إِلَى اللَّهِ وَلَوْلاَ أَنِّي أُخْرِجْتُ مِنْكِ مَا خَرَجْتُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ يُونُسُ عَنِ الزُّهْرِيِّ نَحْوَهُ ‏.‏ وَرَوَاهُ مُحَمَّدُ بْنُ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَدِيِّ بْنِ حَمْرَاءَ عِنْدِي أَصَحُّ ‏.‏\hadithno{3925}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abdullah bin 'Adi bin Hamra [Az-Zuhri]:"I saw the Messenger of Allah (ﷺ) standing at Al-Hazwarah, and he said: "By Allah! You are the best of Allah's earth, and the most beloved of Allah's earth to Allah, and if it were not that I was expelled from you I would not have left}}
\hadithdefcmd{tirmidhi}{3926}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْبَصْرِيُّ، قَالَ حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ جُبَيْرٍ، وَأَبُو الطُّفَيْلِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَكَّةَ ‏ "‏ مَا أَطْيَبَكِ مِنْ بَلَدٍ وَأَحَبَّكِ إِلَىَّ وَلَوْلاَ أَنَّ قَوْمِي أَخْرَجُونِي مِنْكِ مَا سَكَنْتُ غَيْرَكِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3926}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said about Makkah: "How sweet of a land you are and how dear you are to me, and if it were not that my people expelled me from you, I would not have lived in other than you}}
\hadithdefcmd{tirmidhi}{3927}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ، وَأَحْمَدُ بْنُ مَنِيعٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو بَدْرٍ، شُجَاعُ ابْنُ الْوَلِيدِ عَنْ قَابُوسِ بْنِ أَبِي ظَبْيَانَ، عَنْ أَبِيهِ، عَنْ سَلْمَانَ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا سَلْمَانُ لاَ تُبْغِضْنِي فَتُفَارِقَ دِينَكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أُبْغِضُكَ وَبِكَ هَدَانَا اللَّهُ قَالَ ‏"‏ تُبْغِضُ الْعَرَبَ فَتُبْغِضُنِي ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي بَدْرٍ شُجَاعِ بْنِ الْوَلِيدِ ‏.‏ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ أَبُو ظَبْيَانَ لَمْ يُدْرِكْ سَلْمَانَ مَاتَ سَلْمَانُ قَبْلَ عَلِيٍّ ‏.‏\hadithno{3927}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salman:"The Messenger of Allah (ﷺ) said to me: 'O Salman! Do not detest me and thereby leave your religion.' I said: 'O Messenger of Allah! How could I detest you while Allah guided us by you.' He said: 'You will detest the Arabs and thereby detest me}}
\hadithdefcmd{tirmidhi}{3928}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ الأَسْوَدِ، عَنْ حُصَيْنِ بْنِ عُمَرَ الأَحْمَسِيِّ، عَنْ مُخَارِقِ بْنِ عَبْدِ اللَّهِ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ عُثْمَانَ ابْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ غَشَّ الْعَرَبَ لَمْ يَدْخُلْ فِي شَفَاعَتِي وَلَمْ تَنَلْهُ مَوَدَّتِي ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حُصَيْنِ بْنِ عُمَرَ الأَحْمَسِيِّ عَنْ مُخَارِقٍ ‏.‏ وَلَيْسَ حُصَيْنٌ عِنْدَ أَهْلِ الْحَدِيثِ بِذَاكَ الْقَوِيِّ ‏.‏\hadithno{3928}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Uthman bin 'Affan:that the Messenger of Allah (ﷺ) said: "Whoever cheats the Arabs, he will not be included in my intercession, and my love shall not reach him}}
\hadithdefcmd{tirmidhi}{3929}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي رَزِينٍ، عَنْ أُمِّهِ، قَالَتْ كَانَتْ أُمُّ الْحَرِيرِ إِذَا مَاتَ أَحَدٌ مِنَ الْعَرَبِ اشْتَدَّ عَلَيْهَا فَقِيلَ لَهَا إِنَّا نَرَاكِ إِذَا مَاتَ رَجُلٌ مِنَ الْعَرَبِ اشْتَدَّ عَلَيْكِ ‏.‏ قَالَتْ سَمِعْتُ مَوْلاَىَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِنَ اقْتِرَابِ السَّاعَةِ هَلاَكُ الْعَرَبِ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ أَبِي رَزِينٍ وَمَوْلاَهَا طَلْحَةُ بْنُ مَالِكٍ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لَا نَعْرِفُهُ إِلَّا مِنْ حَدِيثِ سُلَيْمَانَ بْنِ حَرْبٍ ‏.‏\hadithno{3929}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muhammad bin Abi Razin:that his mother said: "If someone died from the Arabs it would be hard upon Umm Al-Harir so it was said to her: 'We see that if a man from the Arabs dies it is hard upon you.' She said: 'I heard my Mawla say that the Messenger of Allah (ﷺ) said: "From the (signs of) coming of the Hour is the destruction of the Arabs." Muhammad bin Abi Razin said: "And her Mawla was Talhah bin Malik}}
\hadithdefcmd{tirmidhi}{3930}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ حَدَّثَتْنِي أُمُّ شَرِيكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيَفِرَّنَّ النَّاسُ مِنَ الدَّجَّالِ حَتَّى يَلْحَقُوا بِالْجِبَالِ ‏"‏ ‏.‏ قَالَتْ أُمُّ شَرِيكٍ يَا رَسُولَ اللَّهِ فَأَيْنَ الْعَرَبُ يَوْمَئِذٍ قَالَ ‏"‏ هُمْ قَلِيلٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3930}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Umm Sharik:that the Messenger of Allah (ﷺ) said: "The people will flee from the Dajjal such that they will go to the mountains." Umm Sharik said: "O Messenger of Allah! Where will the Arabs be that day?" He said: "They will be few}}
\hadithdefcmd{tirmidhi}{3931}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الْعَقَدِيُّ، - بَصْرِيٌّ - قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سَامٌ أَبُو الْعَرَبِ وَيَافِثُ أَبُو الرُّومِ وَحَامٌ أَبُو الْحَبَشِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَيُقَالُ يَافِثُ وَيَافِتُ وَيَفتُ ‏.‏\hadithno{3931}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah bin Jundab:that the Messenger of Allah (ﷺ) said: "Sam was the father of Arabs, Yafith was the father of Romans, and Ham was the father of Ethiopians}}
\hadithdefcmd{tirmidhi}{3932}{أَخْبَرَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، قَالَ حَدَّثَنَا صَالِحُ بْنُ أَبِي صَالِحٍ، مَوْلَى عَمْرِو بْنِ حُرَيْثٍ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ ذُكِرَتِ الأَعَاجِمُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لأَنَا بِهِمْ أَوْ بِبَعْضِهِمْ أَوْثَقُ مِنِّي بِكُمْ أَوْ بِبَعْضِكُمْ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي بَكْرِ بْنِ عَيَّاشٍ ‏.‏ وَصَالِحُ بْنُ أَبِي صَالِحٍ هَذَا يُقَالُ لَهُ صَالِحُ بْنُ مِهْرَانَ مَوْلَى عَمْرِو بْنِ حُرَيْثٍ ‏.‏\hadithno{3932}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:"Al-'Ajam (non-Arabs) were mentioned before the Messenger of Allah (ﷺ) so the Prophet (ﷺ) said: 'I am supported more by them, or, by some of them, than I am by you, or some of you}}
\hadithdefcmd{tirmidhi}{3933}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي ثَوْرُ بْنُ زَيْدٍ الدِّيلِيُّ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ أُنْزِلَتْ سُورَةُ الْجُمُعَةِ فَتَلاَهَا فَلَمَّا بَلَغَ ‏:‏ ‏(‏ وآخَرِينَ مِنْهُمْ لَمَّا يَلْحَقُوا بِهِمْ ‏)‏ قَالَ لَهُ رَجُلٌ يَا رَسُولَ اللَّهِ مَنْ هَؤُلاَءِ الَّذِينَ لَمْ يَلْحَقُوا بِنَا فَلَمْ يُكَلِّمْهُ ‏.‏ قَالَ وَسَلْمَانُ الْفَارِسِيُّ فِينَا ‏.‏ قَالَ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ عَلَى سَلْمَانَ فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ كَانَ الإِيمَانُ بِالثُّرَيَّا لَتَنَاوَلَهُ رِجَالٌ مِنْ هَؤُلاَءِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَبُو الْغَيْثِ اسْمُهُ سَالِمٌ مَوْلَى عَبْدِ اللَّهِ بْنِ مُطِيعٍ مَدَنِيٌّ ‏.‏\hadithno{3933}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:"We were with the Messenger of Allah (ﷺ) when Surat Al-Jumu'ah was revealed, so he recited it until he reached: 'And others among them who have not yet joined them (62:3).' A man said to him: 'O Messenger of Allah! Who are these people who have not yet joined us?' But he did not say anything to him." He said: "Salman Al-Farisi was among us." He said: "So the Messenger of Allah (ﷺ) placed his hand upon Salman and said: 'By the One Whose Hand is my soul! If faith were on Pleiades then men among these people would reach it}}
\hadithdefcmd{tirmidhi}{3934}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ الْقَطَوَانِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، قَالَ حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَظَرَ قِبَلَ الْيَمَنِ فَقَالَ ‏ "‏ اللَّهُمَّ أَقْبِلْ بِقُلُوبِهِمْ وَبَارِكْ لَنَا فِي صَاعِنَا وَمُدِّنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ زَيْدِ بْنِ ثَابِتٍ إِلاَّ مِنْ حَدِيثِ عِمْرَانَ الْقَطَّانِ ‏.‏\hadithno{3934}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Zaid bin Thabit [may Allah be pleased with him]:that the Prophet (ﷺ) looked towards Yemen and said: "O Allah direct their hearts and bless us in our Sa' and our Mudd}}
\hadithdefcmd{tirmidhi}{3935}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَاكُمْ أَهْلُ الْيَمَنِ هُمْ أَضْعَفُ قُلُوبًا وَأَرَقُّ أَفْئِدَةً الإِيمَانُ يَمَانٍ وَالْحِكْمَةُ يَمَانِيَةٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي مَسْعُودٍ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3935}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "The people of Yemen have come to you. They are weaker in heart and softer in understanding, faith is Yemeni and wisdom is Yemeni}}
\hadithdefcmd{tirmidhi}{3936}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، قَالَ حَدَّثَنَا أَبُو مَرْيَمَ الأَنْصَارِيُّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُلْكُ فِي قُرَيْشٍ وَالْقَضَاءُ فِي الأَنْصَارِ وَالأَذَانُ فِي الْحَبَشَةِ وَالأَمَانَةُ فِي الأَزْدِ ‏"‏ ‏.‏ يَعْنِي الْيَمَنَ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ أَبِي مَرْيَمَ الأَنْصَارِيِّ، عَنْ أَبِي هُرَيْرَةَ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ زَيْدِ بْنِ حُبَابٍ ‏.‏\hadithno{3936}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Leadership is among the Quraish, and reasoning and judgment is among the Ansar, and the Adhan is among the Ethiopians, and the trust is among the Al-Azd." meaning Yemen}}
\hadithdefcmd{tirmidhi}{3937}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ الْعَطَّارُ، قَالَ حَدَّثَنِي عَمِّي، صَالِحُ بْنُ عَبْدِ الْكَبِيرِ بْنِ شُعَيْبٍ بْنِ الْحَبْحَابِ قَالَ حَدَّثَنِي عَمِّي عَبْدُ السَّلاَمِ بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ أَنَسٍ، رَضِيَ اللَّهُ عَنْهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَزْدُ أُسْدُ اللَّهِ فِي الأَرْضِ يُرِيدُ النَّاسُ أَنْ يَضَعُوهُمْ وَيَأْبَى اللَّهُ إِلاَّ أَنْ يَرْفَعَهُمْ وَلَيَأْتِيَنَّ عَلَى النَّاسِ زَمَانٌ يَقُولُ الرَّجُلُ يَا لَيْتَ أَبِي كَانَ أَزْدِيًّا يَا لَيْتَ أُمِّي كَانَتْ أَزْدِيَّةً ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرُوِيَ هَذَا الْحَدِيثُ عَنْ أَنَسٍ بِهَذَا الإِسْنَادِ مَوْقُوفًا وَهُوَ عِنْدَنَا أَصَحُّ ‏.‏\hadithno{3937}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas:that the Messenger of Allah (ﷺ) said: "Al-Azd is Allah's lion upon the earth, the people wish to lower them but Allah refuses except to raise them. A time will come upon the people where a man will say: "I wish my father was Azadi, I wish my mother was Azadi}}
\hadithdefcmd{tirmidhi}{3938}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ الْعَطَّارُ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ الْعَبْدِيُّ الْبَصْرِيُّ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنِي غَيْلاَنُ بْنُ جَرِيرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنْ لَمْ نَكُنْ مِنَ الأَزْدِ فَلَسْنَا مِنَ النَّاسِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3938}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas:"If we are not from Al-Azd then we are not from the people}}
\hadithdefcmd{tirmidhi}{3939}{حَدَّثَنَا أَبُو بَكْرِ بْنُ زَنْجُويَهْ، - بَغْدَادِيٌّ - قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنِي أَبِي، عَنْ مِينَاءَ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَ رَجُلٌ أَحْسِبُهُ مِنْ قَيْسٍ فَقَالَ يَا رَسُولَ اللَّهِ الْعَنْ حِمْيَرًا ‏.‏ فَأَعْرَضَ عَنْهُ ثُمَّ جَاءَهُ مِنَ الشَّقِّ الآخَرِ فَأَعْرَضَ عَنْهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رَحِمَ اللَّهُ حِمْيَرًا أَفْوَاهُهُمْ سَلاَمٌ وَأَيْدِيهِمْ طَعَامٌ وَهُمْ أَهْلُ أَمْنٍ وَإِيمَانٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَبْدِ الرَّزَّاقِ ‏.‏ وَيُرْوَى عَنْ مِينَاءَ هَذَا أَحَادِيثُ مَنَاكِيرُ ‏.‏\hadithno{3939}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mina, the freed slave of 'Abdur-Rahman bin 'Awf that Abu Hurairah said:"We were with the Prophet (ﷺ) and a man came to him who I think was from Qais. So he said: 'O Messenger of Allah! Curse Himyar.' So he turned away from him, then he went to his other side, and he turned away from him. Then he went to his other side, and he turned away from him. Then he went to his other side, and he turned away from him. So the Prophet (ﷺ) said: 'May Allah have mercy upon Himyar! Their mouths are (full of) peace, their hands are (generous with) food, and they are the people of trust and faith}}
\hadithdefcmd{tirmidhi}{3940}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا أَبُو مَالِكٍ الأَشْجَعِيُّ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَنْصَارُ وَمُزَيْنَةُ وَجُهَيْنَةُ وَغِفَارُ وَأَشْجَعُ وَمَنْ كَانَ مِنْ بَنِي عَبْدِ الدَّارِ مَوَالِيَّ لَيْسَ لَهُمْ مَوْلًى دُونَ اللَّهِ وَاللَّهُ وَرَسُولُهُ مَوْلاَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3940}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Ayyub Al-Ansari:that the Messenger of Allah (ﷺ) said: "The Ansar, Muzainah, and Juhainah, Ashja', Ghifar, and whoever is from Banu 'Abdid-Dar are Mawali. They do not have a Mawla other than Allah, and Allah and His Messenger are their Mawla}}
\hadithdefcmd{tirmidhi}{3941}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْلَمُ سَالَمَهَا اللَّهُ وَغِفَارُ غَفَرَ اللَّهُ لَهَا وَعُصَيَّةُ عَصَتِ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3941}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "Aslam, may Allah make them safe: Ghifar, may Allah forgive them, and 'Usayyah has disobeyed Allah and His Messenger}}
\hadithdefcmd{tirmidhi}{3942}{حَدَّثَنَا أَبُو سَلَمَةَ يَحْيَى بْنُ خَلَفٍ قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ أَخْرَقَتْنَا نِبَالُ ثَقِيفٍ فَادْعُ اللَّهَ عَلَيْهِمْ ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ اهْدِ ثَقِيفًا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3942}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:"They said: 'O Messenger of Allah! Thaqif are razing us with their arrows, so supplicate to Allah against them!' So he said: 'O Allah! Guide Thaqif}}
\hadithdefcmd{tirmidhi}{3943}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْقَاهِرِ بْنُ شُعَيْبٍ، قَالَ حَدَّثَنَا هِشَامٌ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ مَاتَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ يَكْرَهُ ثَلاَثَةَ أَحْيَاءٍ ثَقِيفًا وَبَنِي حَنِيفَةَ وَبَنِي أُمَيَّةَ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3943}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Imran bin Husain:"The Prophet (ﷺ) died while he was having trouble with three tribes: Thaqif, Banu Hanifah, and Banu Umayyah}}
\hadithdefcmd{tirmidhi}{3944}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ شَرِيكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُصْمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِي ثَقِيفٍ كَذَّابٌ وَمُبِيرٌ ‏"‏ ‏.‏ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ وَاقِدٍ أَبُو مُسْلِمٍ، قَالَ حَدَّثَنَا شَرِيكٌ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَعَبْدُ اللَّهِ بْنُ عُصْمٍ يُكْنَى أَبَا عُلْوَانَ وَهُوَ كُوفِيٌّ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَرِيكٍ ‏.‏ وَشَرِيكٌ يَقُولُ عَبْدُ اللَّهِ بْنُ عُصْمٍ وَإِسْرَائِيلُ يَرْوِي عَنْ هَذَا الشَّيْخِ وَيَقُولُ عَبْدُ اللَّهِ بْنُ عُصْمَةَ ‏.‏ وَفِي الْبَابِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ‏.‏\hadithno{3944}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "In Thaqif there is a liar and a destroyer}}
\hadithdefcmd{tirmidhi}{3945}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَخْبَرَنِي أَيُّوبُ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ أَعْرَابِيًّا، أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم بَكْرَةً فَعَوَّضَهُ مِنْهَا سِتَّ بَكَرَاتٍ فَتَسَخَّطَهَا فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّ فُلاَنًا أَهْدَى إِلَىَّ نَاقَةً فَعَوَّضْتُهُ مِنْهَا سِتَّ بَكَرَاتٍ فَظَلَّ سَاخِطًا وَلَقَدْ هَمَمْتُ أَنْ لاَ أَقْبَلَ هَدِيَّةً إِلاَّ مِنْ قُرَشِيٍّ أَوْ أَنْصَارِيٍّ أَوْ ثَقَفِيٍّ أَوْ دَوْسِيٍّ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ كَلاَمٌ أَكْثَرُ مِنْ هَذَا ‏.‏ هَذَا حَدِيثٌ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ وَيَزِيدُ بْنُ هَارُونَ يَرْوِي عَنْ أَيُّوبَ أَبِي الْعَلاَءِ وَهُوَ أَيُّوبُ بْنُ مِسْكِينٍ وَيُقَالُ ابْنُ أَبِي مِسْكِينٍ وَلَعَلَّ هَذَا الْحَدِيثَ الَّذِي رُوِيَ عَنْ أَيُّوبَ عَنْ سَعِيدٍ الْمَقْبُرِيِّ هُوَ أَيُّوبُ أَبُو الْعَلاَءِ ‏.‏\hadithno{3945}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that a Bedouin gave a young female camel as a gift to the Messenger of Allah (ﷺ), so he in turn for that, gave him six young female camels. But he was not satisfied with that, so when that news reached the Prophet (ﷺ), he praised Allah, and expressed gratitude to Him, then said: 'Indeed so-and-so gave a camel to me as a gift, so I reciprocated for that with six young she-camels, yet he became upset. So I decided that I would not accept a gift except from a Quraishi, or Ansari, or Dawsi}}
\hadithdefcmd{tirmidhi}{3946}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ الْحِمْصِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ ابْنُ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَهْدَى رَجُلٌ مِنْ بَنِي فَزَارَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم نَاقَةً مِنْ إِبِلِهِ الَّتِي كَانُوا أَصَابُوا بِالْغَابَةِ فَعَوَّضَهُ مِنْهَا بَعْضَ الْعِوَضِ فَتَسَخَّطَهُ فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى هَذَا الْمِنْبَرِ يَقُولُ ‏ "‏ إِنَّ رِجَالاً مِنَ الْعَرَبِ يُهْدِي أَحَدُهُمُ الْهَدِيَّةَ فَأُعَوِّضُهُ مِنْهَا بِقَدْرِ مَا عِنْدِي ثُمَّ يَتَسَخَّطُهُ فَيَظَلُّ يَتَسَخَّطُ فِيهِ عَلَىَّ وَايْمُ اللَّهِ لاَ أَقْبَلُ بَعْدَ مَقَامِي هَذَا مِنْ رَجُلٍ مِنَ الْعَرَبِ هَدِيَّةً إِلاَّ مِنْ قُرَشِيٍّ أَوْ أَنْصَارِيٍّ أَوْ ثَقَفِيٍّ أَوْ دَوْسِيٍّ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ وَهُوَ أَصَحُّ مِنْ حَدِيثِ يَزِيدَ بْنِ هَارُونَ عَنْ أَيُّوبَ ‏.‏\hadithno{3946}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:"A man from Banu Fazarah gave a gift to the Prophet (ﷺ) of she-camel from his camels which they had taken at Al-Ghabah. So he reciprocated for it with something in return, but he was upset with it. So I heard the Messenger of Allah (ﷺ), upon [this] Minbar saying: 'Indeed one of the men from the Bedouins gave me a gift so I reciprocated for it to the extent of what I had. Then he became very upset with me. By Allah! After my experience with this Bedouin man, I shall not accept a gift from anyone except from a Quraishi, Ansari, Thaqafi, or Dawsi}}
\hadithdefcmd{tirmidhi}{3947}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَلاَذٍ، يُحَدِّثُ عَنْ نُمَيْرِ بْنِ أَوْسٍ، عَنْ مَالِكِ بْنِ مَسْرُوحٍ، عَنْ عَامِرِ بْنِ أَبِي عَامِرٍ الأَشْعَرِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نِعْمَ الْحَىُّ الأَسْدُ وَالأَشْعَرُونَ لاَ يَفِرُّونَ فِي الْقِتَالِ وَلاَ يَغُلُّونَ هُمْ مِنِّي وَأَنَا مِنْهُمْ ‏"‏ ‏.‏ قَالَ فَحَدَّثْتُ بِذَلِكَ مُعَاوِيَةَ فَقَالَ لَيْسَ هَكَذَا قَالَ رَسُولُ اللَّهِ قَالَ ‏"‏ هُمْ مِنِّي وَإِلَىَّ ‏"‏ ‏.‏ فَقُلْتُ لَيْسَ هَكَذَا حَدَّثَنِي أَبِي وَلَكِنَّهُ حَدَّثَنِي قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ هُمْ مِنِّي وَأَنَا مِنْهُمْ ‏"‏ ‏.‏ قَالَ فَأَنْتَ أَعْلَمُ بِحَدِيثِ أَبِيكَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ وَهْبِ بْنِ جَرِيرٍ ‏.‏ وَيُقَالُ الأَسْدُ هُمُ الأَزْدُ ‏.‏\hadithno{3947}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amir bin Abi 'Amir Al-Ash'ari:from his father who said: "The Messenger of Allah (ﷺ) said: 'Blessed are the tribes of Al-Asad and Al-Ash'arun, they flee not from fighting nor do they pilfer the spoils of war. They are from me and I am from them.'" He ('Amir) said: "So I narrated that to Mu'awiyah, and he said: "This is not how the Messenger of Allah (ﷺ) said it, he said: 'They are from me, and for me.' I said, this is not how my father narrated it to me, rather he narrated to me, saying: 'I heard the Messenger of Allah (ﷺ) saying: "They are from me and I am from them.'" So he said: 'Then you are more knowledgeable of your father's Hadith}}
\hadithdefcmd{tirmidhi}{3948}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْلَمُ سَالَمَهَا اللَّهُ وَغِفَارُ غَفَرَ اللَّهُ لَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي ذَرٍّ وَأَبِي بَرْزَةَ الأَسْلَمِيِّ وَبُرَيْدَةَ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{3948}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Umar:that the Prophet (ﷺ) said: "Aslam, may Allah make them safe, and Ghifar, may Allah forgive them}}
\hadithdefcmd{tirmidhi}{3949}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُؤَمَّلٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، نَحْوَ حَدِيثِ شُعْبَةَ وَزَادَ فِيهِ ‏ "‏ وَعُصَيَّةُ عَصَتِ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3949}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{Narrated 'Abdullah bin Dinar:similar to Shu'bah (\#3948) and he added: "And 'Usayyah has disobeyed Allah and His Messenger}}
\hadithdefcmd{tirmidhi}{3950}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَغِفَارُ وَأَسْلَمُ وَمُزَيْنَةُ وَمَنْ كَانَ مِنْ جُهَيْنَةَ أَوْ قَالَ جُهَيْنَةُ وَمَنْ كَانَ مِنْ مُزَيْنَةَ خَيْرٌ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ مِنْ أَسَدٍ وَطَيِّءٍ وَغَطَفَانَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3950}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "By the One in Whose Hand is Muhammad's soul! Ghifar, Aslam, Muzainah, and whoever is from Juhainah," or he said: "Juhainah, and whoever is from Muzainah, they are better with Allah on the Day of Judgment than Asad, Tayyi' and Ghatafan}}
\hadithdefcmd{tirmidhi}{3951}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ جَاءَ نَفَرٌ مِنْ بَنِي تَمِيمٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبْشِرُوا يَا بَنِي تَمِيمٍ ‏"‏ ‏.‏ قَالُوا بَشَّرْتَنَا فَأَعْطِنَا ‏.‏ قَالَ فَتَغَيَّرَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَجَاءَ نَفَرٌ مِنْ أَهْلِ الْيَمَنِ فَقَالَ ‏"‏ أقْبَلُوا الْبُشْرَى فَلَمْ يَقْبَلْهَا بَنُو تَمِيمٍ ‏"‏ ‏.‏ قَالُوا قَدْ قَبِلْنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3951}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Imran bin Husain:that a group from Banu Tamim came to the Messenger of Allah (ﷺ) so he said: "Have glad tidings O Banu Tamim." They said: "You have given us glad tidings, so then give something to us." He said: "So the face of the Messenger of Allah (ﷺ) changed. Then a group from the people of Yemen came so he said: 'Accept the glad tidings, for Banu Tamim did not accept them.' They said: 'We accept}}
\hadithdefcmd{tirmidhi}{3952}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ ابْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَسْلَمُ وَغِفَارُ وَمُزَيْنَةُ خَيْرٌ مِنْ تَمِيمٍ وَأَسَدٍ وَغَطَفَانَ وَبَنِي عَامِرِ بْنِ صَعْصَعَةَ ‏"‏ ‏.‏ يَمُدُّ بِهَا صَوْتَهُ فَقَالَ الْقَوْمُ قَدْ خَابُوا وَخَسِرُوا ‏.‏ قَالَ ‏"‏ فَهُمْ خَيْرٌ مِنْهُمْ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3952}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Bakrah:that the Messenger of Allah (ﷺ) said: "Aslam, Ghifar, and Muzainah are better than Tamim, Asad, Ghatafan, and Banu 'Amir bin Sa'sa'ah," prolonging his voice when saying it. So the people said: "They have been treacherous and have lost." He said: "So these are better than them}}
\hadithdefcmd{tirmidhi}{3953}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ ابْنُ بِنْتِ أَزْهَرَ السَّمَّانِ، قَالَ حَدَّثَنِي جَدِّي، أَزْهَرُ السَّمَّانُ عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ بَارِكْ لَنَا فِي شَامِنَا اللَّهُمَّ بَارِكْ لَنَا فِي يَمَنِنَا ‏"‏ ‏.‏ قَالُوا وَفِي نَجْدِنَا ‏.‏ فَقَالَ ‏"‏ اللَّهُمَّ بَارِكْ لَنَا فِي شَامِنَا وَبَارِكْ لَنَا فِي يَمَنِنَا ‏"‏ ‏.‏ قَالُوا وَفِي نَجْدِنَا ‏.‏ قَالَ ‏"‏ هُنَالِكَ الزَّلاَزِلُ وَالْفِتَنُ وَبِهَا أَوْ قَالَ مِنْهَا يَخْرُجُ قَرْنُ الشَّيْطَانِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ابْنِ عَوْنٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ أَيْضًا عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3953}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "O Allah bless us in our Sham! O Allah bless us in our Yemen." They said: "And in our Najd" He said: "O Allah bless us in our Sham and bless us in our Yemen." They said: "And in our Najd" He said: "Earthquakes are there, and tribulations are there." Or he said: "The horn of Shaitan comes from there}}
\hadithdefcmd{tirmidhi}{3954}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ يَحْيَى بْنَ أَيُّوبَ، يُحَدِّثُ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُمَاسَةَ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم نُؤَلِّفُ الْقُرْآنَ مِنَ الرِّقَاعِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ طُوبَى لِلشَّأْمِ ‏"‏ ‏.‏ فَقُلْنَا لأَىٍّ ذَلِكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لأَنَّ مَلاَئِكَةَ الرَّحْمَنِ بَاسِطَةٌ أَجْنِحَتَهَا عَلَيْهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ يَحْيَى بْنِ أَيُّوبَ ‏.‏\hadithno{3954}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zaid bin Thabit:"We were with the Messenger of Allah (ﷺ) collecting the Qur'an on pieces of cloth, so the Messenger of Allah (ﷺ) said: 'Tuba is for Ash-Sham.' So we said: 'Why is that O Messenger of Allah?' He said: 'Because the angels of Ar-Rahman spread their wings over it}}
\hadithdefcmd{tirmidhi}{3955}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ يَفْتَخِرُونَ بِآبَائِهِمُ الَّذِينَ مَاتُوا إِنَّمَا هُمْ فَحْمُ جَهَنَّمَ أَوْ لَيَكُونَنَّ أَهْوَنَ عَلَى اللَّهِ مِنَ الْجُعَلِ الَّذِي يُدَهْدِهُ الْخِرَاءَ بِأَنْفِهِ إِنَّ اللَّهَ قَدْ أَذْهَبَ عَنْكُمْ عُبِّيَّةَ الْجَاهِلِيَّةِ إِنَّمَا هُوَ مُؤْمِنٌ تَقِيٌّ وَفَاجِرٌ شَقِيٌّ النَّاسُ كُلُّهُمْ بَنُو آدَمَ وَآدَمُ خُلِقَ مِنْ تُرَابٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3955}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "People should stop boasting about their fathers who have died, while they are but coals of Hell, or they will be more humiliated with Allah than the dung beetle who rolls dung with his nose. Indeed Allah has removed the pride of Jahiliyyah from you, and its boasting about lineage. [Indeed a person is either] a pious believer, or a miserable sinner. And people are all the children of Adam, and Adam was [created] from dust}}
\hadithdefcmd{tirmidhi}{3956}{حَدَّثَنَا هَارُونُ بْنُ مُوسَى بْنِ أَبِي عَلْقَمَةَ الْفَرْوِيُّ الْمَدَنِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَدْ أَذْهَبَ اللَّهُ عَنْكُمْ عُبِّيَّةَ الْجَاهِلِيَّةِ وَفَخْرَهَا بِالآبَاءِ مُؤْمِنٌ تَقِيٌّ وَفَاجِرٌ شَقِيٌّ وَالنَّاسُ بَنُو آدَمَ وَآدَمُ مِنْ تُرَابٍ ‏"‏ ‏. هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏‏ وَهَذَا أَصَحُّ عِنْدَنَا مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏ وَسَعِيدٌ الْمَقْبُرِيُّ قَدْ سَمِعَ مِنْ أَبِي هُرَيْرَةَ وَيَرْوِي عَنْ أَبِيهِ أَشْيَاءَ كَثِيرَةً عَنْ أَبِي هُرَيْرَةَ رضى الله عنه ‏.‏ وَقَدْ رَوَى سُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ هِشَامِ ابْنِ سَعْدٍ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ أَبِي عَامِرٍ عَنْ هِشَامِ بْنِ سَعْدٍ ‏.‏\hadithno{3956}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{Narrated Abu Hurairah [may Allah be pleased with him]:that the Messenger of Allah (ﷺ) said: "Allah has removed the pride of Jahiliyyah from you and boasting about lineage. (A person is either) a pious believer or a miserable sinner, and the people are the children of Adam, and Adam is from dirt}}
