% Auto-generated chapter 25 for bukhari
% Hadiths in this chapter: 247

\hadithdefcmd{bukhari}{1513}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ الْفَضْلُ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَتِ امْرَأَةٌ مِنْ خَثْعَمَ، فَجَعَلَ الْفَضْلُ يَنْظُرُ إِلَيْهَا وَتَنْظُرُ إِلَيْهِ، وَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَصْرِفُ وَجْهَ الْفَضْلِ إِلَى الشِّقِّ الآخَرِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَلَى عِبَادِهِ فِي الْحَجِّ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا، لاَ يَثْبُتُ عَلَى الرَّاحِلَةِ، أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ‏.‏\hadithno{1513}\hadithtrans{Narrated `Abdullah bin `Abbas:Al-Fadl (his brother) was riding behind Allah's Messenger (ﷺ) and a woman from the tribe of Khath'am came and Al-Fadl started looking at her and she started looking at him. The Prophet (ﷺ) turned Al-Fadl's face to the other side. The woman said, "O Allah's Messenger (ﷺ)! The obligation of Hajj enjoined by Allah on His devotees has become due on my father and he is old and weak, and he cannot sit firm on the Mount; may I perform Hajj on his behalf?" The Prophet (ﷺ) replied, "Yes, you may." That happened during the Hajj-al-Wida (of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{1514}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْكَبُ رَاحِلَتَهُ بِذِي الْحُلَيْفَةِ ثُمَّ يُهِلُّ حَتَّى تَسْتَوِيَ بِهِ قَائِمَةً‏.‏\hadithno{1514}\hadithtrans{Narrated Ibn `Umar:I saw that Allah's Messenger (ﷺ) used to ride on his Mount at Dhul Hulaifa and used to start saying, "Labbaik" when the Mount stood upright}}
\hadithdefcmd{bukhari}{1515}{حَدَّثَنَا إِبْرَاهِيمُ، أَخْبَرَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، سَمِعَ عَطَاءً، يُحَدِّثُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ إِهْلاَلَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ ذِي الْحُلَيْفَةِ حِينَ اسْتَوَتْ بِهِ رَاحِلَتُهُ‏.‏ رَوَاهُ أَنَسٌ وَابْنُ عَبَّاسٍ رضى الله عنهم‏.‏\hadithno{1515}\hadithtrans{Narrated Jabir bin `Abdullah:that Allah's Messenger (ﷺ) started saying, "Labbaik" from Dhul-Hulaifa when his Mount stood upright carrying him}}
\hadithdefcmd{bukhari}{1516}{وَقَالَ أَبَانُ حَدَّثَنَا مَالِكُ بْنُ دِينَارٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مَعَهَا أَخَاهَا عَبْدَ الرَّحْمَنِ، فَأَعْمَرَهَا مِنَ التَّنْعِيمِ، وَحَمَلَهَا عَلَى قَتَبٍ‏.‏ وَقَالَ عُمَرُ ـ رضى الله عنه ـ شُدُّوا الرِّحَالَ فِي الْحَجِّ، فَإِنَّهُ أَحَدُ الْجِهَادَيْنِ‏.‏\hadithno{1516}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) sent my brother, 'Abdur Rahman with me to Tan'im for the 'Umra, and he made me ride on the packsaddle (of a camel). 'Umar said, "Be ready to travel for Hajj as it (Hajj) is one of the two kind of Jihad}}
\hadithdefcmd{bukhari}{1517}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسٍ، قَالَ حَجَّ أَنَسٌ عَلَى رَحْلٍ، وَلَمْ يَكُنْ شَحِيحًا، وَحَدَّثَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَجَّ عَلَى رَحْلٍ وَكَانَتْ زَامِلَتَهُ‏.‏\hadithno{1517}\hadithtrans{Narrated Thumama bin `Abdullah bin Anas:Anas performed the Hajj on a packsaddle and he was not a miser. Anas said, "Allah's Messenger (ﷺ) performed Hajj on a packsaddle and the same Mount was carrying his baggage too}}
\hadithdefcmd{bukhari}{1518}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا أَيْمَنُ بْنُ نَابِلٍ، حَدَّثَنَا الْقَاسِمُ بْنُ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ، اعْتَمَرْتُمْ وَلَمْ أَعْتَمِرْ‏.‏ فَقَالَ ‏ "‏ يَا عَبْدَ الرَّحْمَنِ اذْهَبْ بِأُخْتِكَ فَأَعْمِرْهَا مِنَ التَّنْعِيمِ ‏"‏‏.‏ فَأَحْقَبَهَا عَلَى نَاقَةٍ فَاعْتَمَرَتْ‏.‏\hadithno{1518}\hadithtrans{Narrated Al-Qasim bin Muhammad:`Aisha said, "O Allah's Messenger (ﷺ)! You performed `Umra but I did not." He said, "O `Abdur-Rahman! Go along with your sister and let her perform `Umra from Tan`im." `Abdur-Rahman made her ride over the packsaddle of a she-camel and she performed `Umra}}
\hadithdefcmd{bukhari}{1519}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏"‏ إِيمَانٌ بِاللَّهِ وَرَسُولِهِ ‏"‏‏.‏ قِيلَ ثُمَّ مَاذَا قَالَ ‏"‏ جِهَادٌ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ قِيلَ ثُمَّ مَاذَا قَالَ ‏"‏ حَجٌّ مَبْرُورٌ ‏"‏‏.‏\hadithno{1519}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) was asked, "Which is the best deed?" He said, "To believe in Allah and His Apostle." He was then asked, "Which is the next (in goodness)?" He said, "To participate in Jihad in Allah's Cause." He was then asked, "Which is the next?" He said, "To perform Hajj-Mabrur}}
\hadithdefcmd{bukhari}{1520}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنَا خَالِدٌ، أَخْبَرَنَا حَبِيبُ بْنُ أَبِي عَمْرَةَ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ، نَرَى الْجِهَادَ أَفْضَلَ الْعَمَلِ، أَفَلاَ نُجَاهِدُ قَالَ ‏ "‏ لاَ، لَكِنَّ أَفْضَلَ الْجِهَادِ حَجٌّ مَبْرُورٌ ‏"‏‏.‏\hadithno{1520}\hadithtrans{Narrated `Aisha:(the mother of the faithful believers) I said, "O Allah's Messenger (ﷺ)! We consider Jihad as the best deed." The Prophet (ﷺ) said, "The best Jihad (for women) is Hajj Mabrur}}
\hadithdefcmd{bukhari}{1521}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سَيَّارٌ أَبُو الْحَكَمِ، قَالَ سَمِعْتُ أَبَا حَازِمٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ حَجَّ لِلَّهِ فَلَمْ يَرْفُثْ وَلَمْ يَفْسُقْ رَجَعَ كَيَوْمِ وَلَدَتْهُ أُمُّهُ ‏"‏‏.‏\hadithno{1521}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever performs Hajj for Allah's pleasure and does not have sexual relations with his wife, and does not do evil or sins then he will return (after Hajj free from all sins) as if he were born anew}}
\hadithdefcmd{bukhari}{1522}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنِي زَيْدُ بْنُ جُبَيْرٍ، أَنَّهُ أَتَى عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ فِي مَنْزِلِهِ وَلَهُ فُسْطَاطٌ وَسُرَادِقٌ، فَسَأَلْتُهُ مِنْ أَيْنَ يَجُوزُ أَنْ أَعْتَمِرَ قَالَ فَرَضَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ نَجْدٍ قَرْنًا، وَلأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ، وَلأَهْلِ الشَّأْمِ الْجُحْفَةَ‏.‏\hadithno{1522}\hadithtrans{Narrated Zaid bin Jubair:I went to visit `Abdullah bin `Umar at his house which contained many tents made of cotton cloth and these were encircled with Suradik (part of the tent). I asked him from where, should one assume Ihram for Umra. He said, "Allah's Messenger (ﷺ) had fixed as Miqat (singular of Mawaqit) Qarn for the people of Najd, Dhul-Hulaifa for the people of Medina, and Al-Juhfa for the people of Sham}}
\hadithdefcmd{bukhari}{1523}{حَدَّثَنَا يَحْيَى بْنُ بِشْرٍ، حَدَّثَنَا شَبَابَةُ، عَنْ وَرْقَاءَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ أَهْلُ الْيَمَنِ يَحُجُّونَ وَلاَ يَتَزَوَّدُونَ وَيَقُولُونَ نَحْنُ الْمُتَوَكِّلُونَ، فَإِذَا قَدِمُوا مَكَّةَ سَأَلُوا النَّاسَ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏وَتَزَوَّدُوا فَإِنَّ خَيْرَ الزَّادِ التَّقْوَى‏\}‏‏.‏ رَوَاهُ ابْنُ عُيَيْنَةَ عَنْ عَمْرٍو عَنْ عِكْرِمَةَ مُرْسَلاً‏.‏\hadithno{1523}\hadithtrans{Narrated Ibn `Abbas:The people of Yemen used to come for Hajj and used not to bring enough provisions with them and used to say that they depend on Allah. On their arrival in Medina they used to beg the people, and so Allah revealed, "And take a provision (with you) for the journey, but the best provision is the fear of Allah}}
\hadithdefcmd{bukhari}{1524}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ، وَلأَهْلِ الشَّأْمِ الْجُحْفَةَ، وَلأَهْلِ نَجْدٍ قَرْنَ الْمَنَازِلِ، وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ، هُنَّ لَهُنَّ وَلِمَنْ أَتَى عَلَيْهِنَّ مِنْ غَيْرِهِنَّ، مِمَّنْ أَرَادَ الْحَجَّ وَالْعُمْرَةَ، وَمَنْ كَانَ دُونَ ذَلِكَ فَمِنْ حَيْثُ أَنْشَأَ، حَتَّى أَهْلُ مَكَّةَ مِنْ مَكَّةَ‏.‏\hadithno{1524}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) made Dhul-Hulaifa as the Miqat for the people of Medina; Al-Juhfa for the people of Sham; Qarn-al-Manazil for the people of Najd; and Yalamlam for the people of Yemen; and these Mawaqit are for the people at those very places, and besides them for those who come through those places with the intention of performing Hajj and `Umra; and whoever is living within these boundaries can assume Ihram from the place he starts, and the people of Mecca can assume Ihram from Mecca}}
\hadithdefcmd{bukhari}{1525}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ، وَأَهْلُ الشَّأْمِ مِنَ الْجُحْفَةِ، وَأَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ وَبَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏‏.‏\hadithno{1525}\hadithtrans{Narrated Nafi`:`Abdullah bin `Umar said, "Allah's Messenger (ﷺ) said, 'The people of Medina should assume Ihram from Dhul-Hulaifa; the people of Sham from Al-Juhfa; and the people of Najd from Qarn." And `Abdullah added, "I was informed that Allah's Messenger (ﷺ) had said, 'The people of Yemen should assume Ihram from Yalamlam}}
\hadithdefcmd{bukhari}{1526}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ، وَلأَهْلِ الشَّأْمِ الْجُحْفَةَ، وَلأَهْلِ نَجْدٍ قَرْنَ الْمَنَازِلِ، وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ، فَهُنَّ لَهُنَّ وَلِمَنْ أَتَى عَلَيْهِنَّ مِنْ غَيْرِ أَهْلِهِنَّ، لِمَنْ كَانَ يُرِيدُ الْحَجَّ وَالْعُمْرَةَ، فَمَنْ كَانَ دُونَهُنَّ فَمُهَلُّهُ مِنْ أَهْلِهِ، وَكَذَاكَ حَتَّى أَهْلُ مَكَّةَ يُهِلُّونَ مِنْهَا‏.‏\hadithno{1526}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) had fixed Dhul Hulaifa as the Miqat for the people of Medina; Al-Juhfa for the people of Sham; and Qarn Ul-Manazil for the people of Najd; and Yalamlam for the people of Yemen. So, these (above mentioned) are the Mawaqit for all those living at those places, and besides them for those who come through those places with the intention of performing Hajj and `Umra and whoever lives within these places should assume Ihram from his dwelling place, and similarly the people of Mecca can assume Ihram from Mecca}}
\hadithdefcmd{bukhari}{1527}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، حَفِظْنَاهُ مِنَ الزُّهْرِيِّ عَنْ سَالِمٍ، عَنْ أَبِيهِ، وَقَّتَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{1527}\hadithtrans{Narrated Salim from his father who said:"The Prophet (ﷺ) had fixed the Mawaqit as follows: (No)}}
\hadithdefcmd{bukhari}{1528}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ ـ رضى الله عنه ـ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مُهَلُّ أَهْلِ الْمَدِينَةِ ذُو الْحُلَيْفَةِ، وَمُهَلُّ أَهْلِ الشَّأْمِ مَهْيَعَةُ وَهِيَ الْجُحْفَةُ، وَأَهْلِ نَجْدٍ قَرْنٌ ‏"‏‏.‏ قَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ زَعَمُوا أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ وَلَمْ أَسْمَعْهُ ‏"‏ وَمُهَلُّ أَهْلِ الْيَمَنِ يَلَمْلَمُ ‏"‏‏.‏\hadithno{1528}\hadithtrans{Narrated Salim bin `Abdullah from his father:I heard Allah's Messenger (ﷺ) saying, "The Miqat for the people of Medina is Dhul-Hulaifa; for the people of Sham is Mahita; (i.e. Al-Juhfa); and for the people of Najd is Qarn. And said Ibn `Umar, "They claim, but I did not hear personally, that the Prophet (ﷺ) said, "The Miqat for the people of Yemen is Yalamlam}}
\hadithdefcmd{bukhari}{1529}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ، وَلأَهْلِ الشَّأْمِ الْجُحْفَةَ، وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ، وَلأَهْلِ نَجْدٍ قَرْنًا، فَهُنَّ لَهُنَّ وَلِمَنْ أَتَى عَلَيْهِنَّ مِنْ غَيْرِ أَهْلِهِنَّ، مِمَّنْ كَانَ يُرِيدُ الْحَجَّ وَالْعُمْرَةَ فَمَنْ كَانَ دُونَهُنَّ فَمِنْ أَهْلِهِ حَتَّى إِنَّ أَهْلَ مَكَّةَ يُهِلُّونَ مِنْهَا‏.‏\hadithno{1529}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) fixed Dhul-Hulaifa as the Miqat for the people of Medina, Al-Juhfa, for the people of Sham, Yalamlam for the people of Yemen, and Qarn for the people of Najd. And these Mawaqit are for those living at those very places, and besides them for those who come through those places with the intention of performing Hajj and Umra; and whoever is living inside these places can assume Ihram from his own dwelling place, and the people of Mecca can assume Ihram from Mecca}}
\hadithdefcmd{bukhari}{1530}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ، وَلأَهْلِ الشَّأْمِ الْجُحْفَةَ، وَلأَهْلِ نَجْدٍ قَرْنَ الْمَنَازِلِ، وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ، هُنَّ لأَهْلِهِنَّ وَلِكُلِّ آتٍ أَتَى عَلَيْهِنَّ مِنْ غَيْرِهِمْ مِمَّنْ أَرَادَ الْحَجَّ وَالْعُمْرَةَ فَمَنْ كَانَ دُونَ ذَلِكَ، فَمِنْ حَيْثُ أَنْشَأَ حَتَّى أَهْلُ مَكَّةَ مِنْ مَكَّةَ‏.‏\hadithno{1530}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) fixed Dhul-Hulaifa as the Miqat for the people of Medina, Al-Juhfa for the people of Sham, Qarn-al-Manazil for the people of Najd, and Yalamlam for the people of Yemen; and these Mawaqit are for those living at those very places, and besides them for those whom come through them with the intention of performing Hajj and Umra; and whoever is living within these Mawaqit should assume Ihram from where he starts, and the people of Mecca can assume Ihram from Mecca}}
\hadithdefcmd{bukhari}{1531}{حَدَّثَنِي عَلِيُّ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ لَمَّا فُتِحَ هَذَانِ الْمِصْرَانِ أَتَوْا عُمَرَ فَقَالُوا يَا أَمِيرَ الْمُؤْمِنِينَ، إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَدَّ لأَهْلِ نَجْدٍ قَرْنًا، وَهُوَ جَوْرٌ عَنْ طَرِيقِنَا، وَإِنَّا إِنْ أَرَدْنَا قَرْنًا شَقَّ عَلَيْنَا‏.‏ قَالَ فَانْظُرُوا حَذْوَهَا مِنْ طَرِيقِكُمْ‏.‏ فَحَدَّ لَهُمْ ذَاتَ عِرْقٍ‏.‏\hadithno{1531}\hadithtrans{Narrated Ibn `Umar:When these two towns (Basra and Kufa) were captured, the people went to `Umar and said, "O the Chief of the faithful believers! The Prophet (ﷺ) fixed Qarn as the Miqat for the people of Najd, it is beyond our way and it is difficult for us to pass through it." He said, "Take as your Miqat a place situated opposite to Qarn on your usual way. So, he fixed Dhatu-Irq (as their Miqat)}}
\hadithdefcmd{bukhari}{1532}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَاخَ بِالْبَطْحَاءِ بِذِي الْحُلَيْفَةِ فَصَلَّى بِهَا‏.‏ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ يَفْعَلُ ذَلِكَ‏.‏\hadithno{1532}\hadithtrans{Narrated Nafi`:`Abdullah bin `Umar' said, "Allah's Messenger (ﷺ) made his camel sit (i.e. he dismounted) at Al-Batha' in Dhul-Hulaifa and offered the prayer." `Abdullah bin `Umar used to do the same}}
\hadithdefcmd{bukhari}{1533}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْرُجُ مِنْ طَرِيقِ الشَّجَرَةِ، وَيَدْخُلُ مِنْ طَرِيقِ الْمُعَرَّسِ، وَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ إِلَى مَكَّةَ يُصَلِّي فِي مَسْجِدِ الشَّجَرَةِ، وَإِذَا رَجَعَ صَلَّى بِذِي الْحُلَيْفَةِ بِبَطْنِ الْوَادِي، وَبَاتَ حَتَّى يُصْبِحَ‏.‏\hadithno{1533}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) used to go (for Hajj) via Ash-Shajara way and return via Muarras way; and no doubt, whenever Allah's Messenger (ﷺ) went to Mecca, he used to offer the prayer in the Mosque of Ash-Shajara; and on his return, he used to offer the prayer at Dhul-Hulaifa in the middle of the valley, and pass the night there till morning}}
\hadithdefcmd{bukhari}{1534}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا الْوَلِيدُ، وَبِشْرُ بْنُ بَكْرٍ التِّنِّيسِيُّ، قَالاَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، قَالَ حَدَّثَنِي عِكْرِمَةُ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ إِنَّهُ سَمِعَ عُمَرَ ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم بِوَادِي الْعَقِيقِ يَقُولُ ‏ "‏ أَتَانِي اللَّيْلَةَ آتٍ مِنْ رَبِّي فَقَالَ صَلِّ فِي هَذَا الْوَادِي الْمُبَارَكِ وَقُلْ عُمْرَةً فِي حَجَّةٍ ‏"‏‏.‏\hadithno{1534}\hadithtrans{Narrated `Umar:In the valley of Al-`Aqiq I heard Allah's Messenger (ﷺ) saying, "To night a messenger came to me from my Lord and asked me to pray in this blessed valley and to assume Ihram for Hajj and `Umra together}}
\hadithdefcmd{bukhari}{1535}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ رُئِيَ وَهُوَ فِي مُعَرَّسٍ بِذِي الْحُلَيْفَةِ بِبَطْنِ الْوَادِي قِيلَ لَهُ إِنَّكَ بِبَطْحَاءَ مُبَارَكَةٍ‏.‏ وَقَدْ أَنَاخَ بِنَا سَالِمٌ، يَتَوَخَّى بِالْمُنَاخِ الَّذِي كَانَ عَبْدُ اللَّهِ يُنِيخُ، يَتَحَرَّى مُعَرَّسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ أَسْفَلُ مِنَ الْمَسْجِدِ الَّذِي بِبَطْنِ الْوَادِي، بَيْنَهُمْ وَبَيْنَ الطَّرِيقِ وَسَطٌ مِنْ ذَلِكَ‏.‏\hadithno{1535}\hadithtrans{Narrated Musa bin `Uqba:Salim bin `Abdullah's father said, "The Prophet (ﷺ) said that while resting in the bottom of the valley at Muarras in Dhul-Hulaifa, he had been addressed in a dream: 'You are verily in a blessed valley.' " Salim made us to dismount from our camels at the place where `Abdullah used to dismount, aiming at the place where Allah's Messenger (ﷺ) had rested and it was below the Mosque situated in the middle of the valley in between them (the residence) and the road}}
\hadithdefcmd{bukhari}{1536}{قَالَ أَبُو عَاصِمٍ أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَنَّ صَفْوَانَ بْنَ يَعْلَى، أَخْبَرَهُ أَنَّ يَعْلَى قَالَ لِعُمَرَ ـ رضى الله عنه ـ أَرِنِي النَّبِيَّ صلى الله عليه وسلم حِينَ يُوحَى إِلَيْهِ قَالَ فَبَيْنَمَا النَّبِيُّ صلى الله عليه وسلم بِالْجِعْرَانَةِ، وَمَعَهُ نَفَرٌ مِنْ أَصْحَابِهِ، جَاءَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي رَجُلٍ أَحْرَمَ بِعُمْرَةٍ، وَهْوَ مُتَضَمِّخٌ بِطِيبٍ فَسَكَتَ النَّبِيُّ صلى الله عليه وسلم سَاعَةً فَجَاءَهُ الْوَحْىُ، فَأَشَارَ عُمَرُ ـ رضى الله عنه ـ إِلَى يَعْلَى، فَجَاءَ يَعْلَى، وَعَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَوْبٌ قَدْ أُظِلَّ بِهِ فَأَدْخَلَ رَأْسَهُ، فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُحْمَرُّ الْوَجْهِ، وَهُوَ يَغِطُّ ثُمَّ سُرِّيَ عَنْهُ فَقَالَ ‏"‏ أَيْنَ الَّذِي سَأَلَ عَنِ الْعُمْرَةِ ‏"‏ فَأُتِيَ بِرَجُلٍ فَقَالَ ‏"‏ اغْسِلِ الطِّيبَ الَّذِي بِكَ ثَلاَثَ مَرَّاتٍ، وَانْزِعْ عَنْكَ الْجُبَّةَ، وَاصْنَعْ فِي عُمْرَتِكَ كَمَا تَصْنَعُ فِي حَجَّتِكَ ‏"‏‏.‏ قُلْتُ لِعَطَاءٍ أَرَادَ الإِنْقَاءَ حِينَ أَمَرَهُ أَنْ يَغْسِلَ ثَلاَثَ مَرَّاتٍ قَالَ نَعَمْ‏.‏\hadithno{1536}\hadithtrans{Narrated Safwan bin Ya'la:Ya'la said to 'Umar, "Show me the Prophet (ﷺ) when he is being inspired Divinely." While the Prophet (ﷺ) was at Ji'rana (in the company of some of his Companions) a person came and asked, "O Allah's Messenger! What is your verdict regarding that person who assumes Ihram for 'Umra and is scented with perfume ?" The Prophet (ﷺ) kept quiet for a while and he was Divinely inspired (then). 'Umar beckoned Ya'la. So he came, and the Allah's Messenger (ﷺ) was shaded with sheet. Ya'la put his head in and saw that the face of Allah's Messenger was red and he was snoring. When the state of the Prophet (ﷺ) was over, he (ﷺ) asked, "Where is the person who asked about 'Umra?" Then that person was brought and the Prophet (ﷺ) said, "Wash the perfume off your body thrice and take off the cloak and do the same in 'Umra as you do in Hajj}}
\hadithdefcmd{bukhari}{1538}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَدَّهِنُ بِالزَّيْتِ‏.‏ فَذَكَرْتُهُ لإِبْرَاهِيمَ قَالَ مَا تَصْنَعُ بِقَوْلِهِ حَدَّثَنِي الأَسْوَدُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ‏.‏\hadithno{1538}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Umar used to oil his hair. I told that to Ibrahim who said, "What do you think about this statement: Narrated Aswad from `Aisha: As if I were now observing the glitter of the scent in the parting of the hair of the Prophet (ﷺ) while he was Muhrim?}}
\hadithdefcmd{bukhari}{1539}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم لإِحْرَامِهِ حِينَ يُحْرِمُ، وَلِحِلِّهِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ‏.‏\hadithno{1539}\hadithtrans{Narrated `Aisha:(the wife of the Prophet (ﷺ) I used to scent Allah's Messenger (ﷺ) when he wanted to assume Ihram and also on finishing Ihram before the Tawaf round the Ka`ba (Tawaf-al-ifada)}}
\hadithdefcmd{bukhari}{1540}{حَدَّثَنَا أَصْبَغُ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ مُلَبِّدًا‏.‏\hadithno{1540}\hadithtrans{Narrated Salim from his father:I heard that Allah's Messenger (ﷺ) assumed Ihram with his hair matted together}}
\hadithdefcmd{bukhari}{1541}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ‏.‏ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَاهُ، يَقُولُ مَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ مِنْ عِنْدِ الْمَسْجِدِ يَعْنِي مَسْجِدَ ذِي الْحُلَيْفَةِ‏.‏\hadithno{1541}\hadithtrans{Narrated Salim bin `Abdullah:I heard my father saying, "Never did Allah's Messenger (ﷺ) assume Ihram except at the Mosque, that is, at the Mosque of Dhul-Hulaifa}}
\hadithdefcmd{bukhari}{1542}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَلْبَسُ الْقُمُصَ وَلاَ الْعَمَائِمَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ، إِلاَّ أَحَدٌ لاَ يَجِدُ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ، وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ، وَلاَ تَلْبَسُوا مِنَ الثِّيَابِ شَيْئًا مَسَّهُ الزَّعْفَرَانُ أَوْ وَرْسٌ ‏"‏‏.‏\hadithno{1542}\hadithtrans{Narrated `Abdullah bin `Umar:A man asked, "O Allah's Messenger (ﷺ)! What kind of clothes should a Muhrim wear?" Allah's Messenger (ﷺ) replied, "He should not wear a shirt, a turban, trousers, a headcloak or leather socks except if he can find no slippers, he then may wear leather socks after cutting off what might cover the ankles. And he should not wear clothes which are scented with saffron or Wars (kinds of Perfumes)}}
\hadithdefcmd{bukhari}{1544}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ يُونُسَ الأَيْلِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ أُسَامَةَ ـ رضى الله عنه ـ كَانَ رِدْفَ النَّبِيِّ صلى الله عليه وسلم مِنْ عَرَفَةَ إِلَى الْمُزْدَلِفَةِ، ثُمَّ أَرْدَفَ الْفَضْلَ مِنَ الْمُزْدَلِفَةِ إِلَى مِنًى‏.‏ قَالَ فَكِلاَهُمَا قَالَ لَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم يُلَبِّي، حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ‏.‏\hadithno{1544}\hadithtrans{Narrated 'Ubaidullah bin `Abdullah:Ibn `Abbas' said, "Usama rode behind Allah's Messenger (ﷺ) from `Arafat to Al-Muzdalifa; and then Al-Fadl rode behind Allah's Messenger (ﷺ) from Al-Muzdalifa to Mina." Ibn `Abbas added, "Both of them said, 'The Prophet kept on reciting Talbiya till he did the Rami of Jamrat-Al-`Aqaba}}
\hadithdefcmd{bukhari}{1545}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي مُوسَى بْنُ عُقْبَةَ، قَالَ أَخْبَرَنِي كُرَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ انْطَلَقَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْمَدِينَةِ، بَعْدَ مَا تَرَجَّلَ وَادَّهَنَ وَلَبِسَ إِزَارَهُ وَرِدَاءَهُ، هُوَ وَأَصْحَابُهُ، فَلَمْ يَنْهَ عَنْ شَىْءٍ مِنَ الأَرْدِيَةِ وَالأُزْرِ تُلْبَسُ إِلاَّ الْمُزَعْفَرَةَ الَّتِي تَرْدَعُ عَلَى الْجِلْدِ، فَأَصْبَحَ بِذِي الْحُلَيْفَةِ، رَكِبَ رَاحِلَتَهُ حَتَّى اسْتَوَى عَلَى الْبَيْدَاءِ، أَهَلَّ هُوَ وَأَصْحَابُهُ وَقَلَّدَ بَدَنَتَهُ، وَذَلِكَ لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ، فَقَدِمَ مَكَّةَ لأَرْبَعِ لَيَالٍ خَلَوْنَ مِنْ ذِي الْحَجَّةِ، فَطَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ، وَلَمْ يَحِلَّ مِنْ أَجْلِ بُدْنِهِ لأَنَّهُ قَلَّدَهَا، ثُمَّ نَزَلَ بِأَعْلَى مَكَّةَ عِنْدَ الْحَجُونِ، وَهْوَ مُهِلٌّ بِالْحَجِّ، وَلَمْ يَقْرَبِ الْكَعْبَةَ بَعْدَ طَوَافِهِ بِهَا حَتَّى رَجَعَ مِنْ عَرَفَةَ، وَأَمَرَ أَصْحَابَهُ أَنْ يَطَّوَّفُوا بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ، ثُمَّ يُقَصِّرُوا مِنْ رُءُوسِهِمْ ثُمَّ يَحِلُّوا، وَذَلِكَ لِمَنْ لَمْ يَكُنْ مَعَهُ بَدَنَةٌ قَلَّدَهَا، وَمَنْ كَانَتْ مَعَهُ امْرَأَتُهُ فَهِيَ لَهُ حَلاَلٌ، وَالطِّيبُ وَالثِّيَابُ‏.‏\hadithno{1545}\hadithtrans{Narrated `Abdullah bin `Abbas:The Prophet (ﷺ) with his companions started from Medina after combing and oiling his hair and putting on two sheets of Ihram (upper body cover and waist cover). He did not forbid anyone to wear any kind of sheets except the ones colored with saffron because they may leave the scent on the skin. And so in the early morning, the Prophet (ﷺ) mounted his Mount while in Dhul-Hulaifa and set out till they reached Baida', where he and his companions recited Talbiya, and then they did the ceremony of Taqlid (which means to put the colored garlands around the necks of the Budn (camels for sacrifice). And all that happened on the 25th of Dhul-Qa'da. And when he reached Mecca on the 4th of Dhul-Hijja he performed the Tawaf round the Ka`ba and performed the Tawaf between Safa and Marwa. And as he had a Badana and had garlanded it, he did not finish his Ihram. He proceeded towards the highest places of Mecca near Al-Hajun and he was assuming the Ihram for Hajj and did not go near the Ka`ba after he performed Tawaf (round it) till he returned from `Arafat. Then he ordered his companions to perform the Tawaf round the Ka`ba and then the Tawaf of Safa and Marwa, and to cut short the hair of their heads and to finish their Ihram. And that was only for those people who had not garlanded Budn. Those who had their wives with them were permitted to contact them (have sexual intercourse), and similarly perfume and (ordinary) clothes were permissible for them}}
\hadithdefcmd{bukhari}{1546}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم بِالْمَدِينَةِ أَرْبَعًا، وَبِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ، ثُمَّ بَاتَ حَتَّى أَصْبَحَ بِذِي الْحُلَيْفَةِ، فَلَمَّا رَكِبَ رَاحِلَتَهُ وَاسْتَوَتْ بِهِ أَهَلَّ‏.‏\hadithno{1546}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) offered four rak`at in Medina and then two rak`at at Dhul Hulaifa and then passed the night at Dhul-Hulaifa till it was morning and when he mounted his Mount and it stood up, he started to recite Talbiya}}
\hadithdefcmd{bukhari}{1547}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا، وَصَلَّى الْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ، قَالَ وَأَحْسِبُهُ بَاتَ بِهَا حَتَّى أَصْبَحَ‏.‏\hadithno{1547}\hadithtrans{Narrated Abu Qilaba:Anas bin Malik said, "The Prophet (ﷺ) offered four rak`at of the Zuhr prayer in Medina and two rak`at of `Asr prayer at Dhul-Hulaifa." I think that the Prophet (ﷺ) passed the night there till morning}}
\hadithdefcmd{bukhari}{1548}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم بِالْمَدِينَةِ الظُّهْرَ أَرْبَعًا، وَالْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ، وَسَمِعْتُهُمْ يَصْرُخُونَ بِهِمَا جَمِيعًا‏.‏\hadithno{1548}\hadithtrans{Narrated Anas:The Prophet (ﷺ) offered four rak`at of the Zuhr prayer in Medina and two rak`at of the `Asr prayer in Dhul-Hulaifa and I heard them (the companions of the Prophet) reciting Talbiya together loudly to the extent of shouting}}
\hadithdefcmd{bukhari}{1549}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ تَلْبِيَةَ، رَسُولِ اللَّهِ صلى الله عليه وسلم لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ، لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ، إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ، لاَ شَرِيكَ لَكَ‏.‏\hadithno{1549}\hadithtrans{Narrated `Abdullah bin `Umar:The Talbiya of Allah's Messenger (ﷺ) was : 'Labbaika Allahumma labbaik, Labbaika la sharika Laka labbaik, Inna-l-hamda wan-ni'mata Laka walmulk, La sharika Laka' (I respond to Your call O Allah, I respond to Your call, and I am obedient to Your orders, You have no partner, I respond to Your call All the praises and blessings are for You, All the sovereignty is for You, And You have no partners with You)}}
\hadithdefcmd{bukhari}{1550}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ أَبِي عَطِيَّةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ إِنِّي لأَعْلَمُ كَيْفَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُلَبِّي لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ، لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ، إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ‏.‏ تَابَعَهُ أَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ‏.‏ وَقَالَ شُعْبَةُ أَخْبَرَنَا سُلَيْمَانُ، سَمِعْتُ خَيْثَمَةَ، عَنْ أَبِي عَطِيَّةَ، سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ‏.‏\hadithno{1550}\hadithtrans{Narrated `Aisha:I know how the Prophet (ﷺ) used to say (Talbiya) and it was: 'Labbaika Allahumma Labbaik, Labbaika la sharika Laka labbaik, Inna-l-hamda wan-ni'mata Laka walmu Lk, La sharika Laka}}
\hadithdefcmd{bukhari}{1551}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ مَعَهُ بِالْمَدِينَةِ الظُّهْرَ أَرْبَعًا، وَالْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ، ثُمَّ بَاتَ بِهَا حَتَّى أَصْبَحَ، ثُمَّ رَكِبَ حَتَّى اسْتَوَتْ بِهِ عَلَى الْبَيْدَاءِ، حَمِدَ اللَّهَ وَسَبَّحَ وَكَبَّرَ، ثُمَّ أَهَلَّ بِحَجٍّ وَعُمْرَةٍ، وَأَهَلَّ النَّاسُ بِهِمَا، فَلَمَّا قَدِمْنَا أَمَرَ النَّاسَ فَحَلُّوا، حَتَّى كَانَ يَوْمُ التَّرْوِيَةِ أَهَلُّوا بِالْحَجِّ قَالَ وَنَحَرَ النَّبِيُّ صلى الله عليه وسلم بَدَنَاتٍ بِيَدِهِ قِيَامًا، وَذَبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ كَبْشَيْنِ أَمْلَحَيْنِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ بَعْضُهُمْ هَذَا عَنْ أَيُّوبَ عَنْ رَجُلٍ عَنْ أَنَسٍ‏.‏\hadithno{1551}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) offered four rak`at of Zuhr prayer at Medina and we were in his company, and two rak`at of the `Asr prayer at Dhul-Hulaifa and then passed the night there till it was dawn; then he rode, and when he reached Al-Baida', he praised and glorified Allah and said Takbir (i.e. Al hamdu-li l-lah and Subhanallah(1) and Allahu-Akbar). Then he and the people along with him recited Talbiya with the intention of performing Hajj and Umra. When we reached (Mecca) he ordered us to finish the Ihram (after performing the Umra) (only those who had no Hadi (animal for sacrifice) with them were asked to do so) till the day of Tarwiya that is 8th Dhul-Hijja when they assumed Ihram for Hajj. The Prophet sacrificed many camels (slaughtering them) with his own hands while standing. While Allah's Apostle was in Medina he sacrificed two horned rams black and white in color in the Name of Allah}}
\hadithdefcmd{bukhari}{1552}{حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي صَالِحُ بْنُ كَيْسَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أَهَلَّ النَّبِيُّ صلى الله عليه وسلم حِينَ اسْتَوَتْ بِهِ رَاحِلَتُهُ قَائِمَةً‏.‏\hadithno{1552}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) recited Talbiya when he had mounted his Mount and was ready to set out}}
\hadithdefcmd{bukhari}{1553}{وَقَالَ أَبُو مَعْمَرٍ حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ إِذَا صَلَّى بِالْغَدَاةِ بِذِي الْحُلَيْفَةِ أَمَرَ بِرَاحِلَتِهِ فَرُحِلَتْ ثُمَّ رَكِبَ، فَإِذَا اسْتَوَتْ بِهِ اسْتَقْبَلَ الْقِبْلَةَ قَائِمًا، ثُمَّ يُلَبِّي حَتَّى يَبْلُغَ الْمَحْرَمَ، ثُمَّ يُمْسِكُ حَتَّى إِذَا جَاءَ ذَا طُوًى بَاتَ بِهِ حَتَّى يُصْبِحَ، فَإِذَا صَلَّى الْغَدَاةَ اغْتَسَلَ، وَزَعَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ ذَلِكَ‏.‏ تَابَعَهُ إِسْمَاعِيلُ عَنْ أَيُّوبَ فِي الْغَسْلِ‏.‏\hadithno{1553}\hadithtrans{Narrated Nafi', 'Whenever Ibn 'Umar finished his morning Salat at Dhul-Hulaifa he would get his Rahila (mount) prepared. Then, he would ride on it, and after it had stood up straight (ready to set out), he would face Al-Qiblah (the Ka'bah at Makkah) while sitting (on his mount) and recite Talbiya. When he had reached the boundaries of the Haram (or Makkah), he would stop recitation of Talbiya till he reached Dhi-Tuwa (near Makkah) where he would pass the night till it was dawn. After offering the morning Salat, he would take a bath. He claimed that Allah's Messenger (ﷺ) had done the same}}
\hadithdefcmd{bukhari}{1554}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ أَبُو الرَّبِيعِ، حَدَّثَنَا فُلَيْحٌ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ إِذَا أَرَادَ الْخُرُوجَ إِلَى مَكَّةَ ادَّهَنَ بِدُهْنٍ لَيْسَ لَهُ رَائِحَةٌ طَيِّبَةٌ، ثُمَّ يَأْتِي مَسْجِدَ الْحُلَيْفَةِ فَيُصَلِّي ثُمَّ يَرْكَبُ، وَإِذَا اسْتَوَتْ بِهِ رَاحِلَتُهُ قَائِمَةً أَحْرَمَ، ثُمَّ قَالَ هَكَذَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَفْعَلُ‏.‏\hadithno{1554}\hadithtrans{Narrated Nafi`:Whenever Ibn `Umar intended to go to Mecca he used to oil himself with a sort of oil that had no pleasant smell, then he would go to the Mosque of Al-Hulaifa and offer the prayer, and then ride. When he mounted well on his Mount and the Mount stood up straight, he would proclaim the intention of assuming Ihram, and he used to say that he had seen the Prophet (ﷺ) doing the same}}
\hadithdefcmd{bukhari}{1555}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُجَاهِدٍ، قَالَ كُنَّا عِنْدَ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ فَذَكَرُوا الدَّجَّالَ أَنَّهُ قَالَ ‏"‏ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ ‏"‏‏.‏ فَقَالَ ابْنُ عَبَّاسٍ لَمْ أَسْمَعْهُ وَلَكِنَّهُ قَالَ ‏"‏ أَمَّا مُوسَى كَأَنِّي أَنْظُرُ إِلَيْهِ إِذِ انْحَدَرَ فِي الْوَادِي يُلَبِّي ‏"‏‏.‏\hadithno{1555}\hadithtrans{Narrated Mujahid:I was in the company of Ibn `Abbas and the people talked about Ad-Dajjal and said, "Ad-Dajjal will come with the word Kafir (non-believer) written in between his eyes." On that Ibn `Abbas said, "I have not heard this from the Prophet (ﷺ) but I heard him saying, 'As if I saw Moses just now entering the valley reciting Talbyia}}
\hadithdefcmd{bukhari}{1556}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ، فَأَهْلَلْنَا بِعُمْرَةٍ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهِلَّ بِالْحَجِّ مَعَ الْعُمْرَةِ، ثُمَّ لاَ يَحِلَّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ فَقَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ، وَلَمْ أَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ، فَشَكَوْتُ ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ انْقُضِي رَأْسَكِ وَامْتَشِطِي، وَأَهِلِّي بِالْحَجِّ، وَدَعِي الْعُمْرَةَ ‏"‏‏.‏ فَفَعَلْتُ فَلَمَّا قَضَيْنَا الْحَجَّ أَرْسَلَنِي النَّبِيُّ صلى الله عليه وسلم مَعَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ إِلَى التَّنْعِيمِ فَاعْتَمَرْتُ فَقَالَ ‏"‏ هَذِهِ مَكَانَ عُمْرَتِكِ ‏"‏‏.‏ قَالَتْ فَطَافَ الَّذِينَ كَانُوا أَهَلُّوا بِالْعُمْرَةِ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ، ثُمَّ حَلُّوا، ثُمَّ طَافُوا طَوَافًا وَاحِدًا بَعْدَ أَنْ رَجَعُوا مِنْ مِنًى، وَأَمَّا الَّذِينَ جَمَعُوا الْحَجَّ وَالْعُمْرَةَ فَإِنَّمَا طَافُوا طَوَافًا وَاحِدًا‏.‏\hadithno{1556}\hadithtrans{Narrated Aisha:(the wife of the Prophet (ﷺ) We set out with the Prophet (ﷺ) in his last Hajj and we assumed Ihram for Umra. The Prophet (ﷺ) then said, "Whoever has the Hadi with him should assume Ihram for Hajj along with `Umra and should not finish the Ihram till he finishes both." I was menstruating when I reached Mecca, and so I neither did Tawaf round the Ka`ba nor Tawaf between Safa and Marwa. I complained about that to the Prophet (ﷺ) on which he replied, "Undo and comb your head hair, and assume Ihram for Hajj (only) and leave the Umra." So, I did so. When we had performed the Hajj, the Prophet sent me with my brother `Abdur-Rahman bin Abu Bakr to Tan`im. So I performed the `Umra. The Prophet (ﷺ) said to me, "This `Umra is instead of your missed one." Those who had assumed Ihram for `Umra (Hajj-at-Tamattu) performed Tawaf round the Ka`ba and between Safa and Marwa and then finished their Ihram. After returning from Mina, they performed another Tawaf (between Safa and Marwa). Those who had assumed Ihram for Hajj and `Umra together (Hajj-al-Qiran) performed only one Tawaf (between Safa and Marwa)}}
\hadithdefcmd{bukhari}{1557}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ جُرَيْجٍ، قَالَ عَطَاءٌ قَالَ جَابِرٌ ـ رضى الله عنه ـ أَمَرَ النَّبِيُّ صلى الله عليه وسلم عَلِيًّا ـ رضى الله عنه ـ أَنْ يُقِيمَ عَلَى إِحْرَامِهِ، وَذَكَرَ قَوْلَ سُرَاقَةَ‏.‏\hadithno{1557}\hadithtrans{Narrated Ata:Jabir said, "The Prophet (ﷺ) ordered `Ali to keep on assuming his Ihram." The narrator then informed about the narration of Suraqa}}
\hadithdefcmd{bukhari}{1558}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ الْهُذَلِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، قَالَ سَمِعْتُ مَرْوَانَ الأَصْفَرَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَدِمَ عَلِيٌّ ـ رضى الله عنه ـ عَلَى النَّبِيِّ صلى الله عليه وسلم مِنَ الْيَمَنِ فَقَالَ ‏"‏ بِمَا أَهْلَلْتَ ‏"‏‏.‏ قَالَ بِمَا أَهَلَّ بِهِ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَقَالَ ‏"‏ لَوْلاَ أَنَّ مَعِي الْهَدْىَ لأَحْلَلْتُ ‏"‏‏.‏ وَزَادَ مُحَمَّدُ بْنُ بَكْرٍ عَنِ ابْنِ جُرَيْجٍ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِمَا أَهْلَلْتَ يَا عَلِيُّ ‏"‏‏.‏ قَالَ بِمَا أَهَلَّ بِهِ النَّبِيُّ صلى الله عليه وسلم قَالَ ‏"‏ فَأَهْدِ وَامْكُثْ حَرَامًا كَمَا أَنْتَ ‏"‏‏.‏\hadithno{1558}\hadithtrans{Narrated Anas bin Malik:`Ali came to the Prophet (ﷺ) from Yemen (to Mecca). The Prophet (ﷺ) asked `Ali, "With what intention have you assumed Ihram?" `Ali replied, "I have assumed Ihram with the same intention as that of the Prophet." The Prophet (ﷺ) said, "If I had not the Hadi with me I would have finished the Ihram." Muhammad bin Bakr narrated extra from Ibn Juraij, "The Prophet (ﷺ) said to `Ali, "With what intention have you assumed the Ihram, O `Ali?" He replied, "With the same (intention) as that of the Prophet." The Prophet (ﷺ) said, "Have a Hadi and keep your Ihram as it is}}
\hadithdefcmd{bukhari}{1559}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم إِلَى قَوْمٍ بِالْيَمَنِ فَجِئْتُ وَهْوَ بِالْبَطْحَاءِ فَقَالَ ‏"‏ بِمَا أَهْلَلْتَ ‏"‏‏.‏ قُلْتُ أَهْلَلْتُ كَإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ هَلْ مَعَكَ مِنْ هَدْىٍ ‏"‏‏.‏ قُلْتُ لاَ‏.‏ فَأَمَرَنِي فَطُفْتُ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ أَمَرَنِي فَأَحْلَلْتُ فَأَتَيْتُ امْرَأَةً مِنْ قَوْمِي فَمَشَطَتْنِي، أَوْ غَسَلَتْ رَأْسِي، فَقَدِمَ عُمَرُ ـ رضى الله عنه ـ فَقَالَ إِنْ نَأْخُذْ بِكِتَابِ اللَّهِ فَإِنَّهُ يَأْمُرُنَا بِالتَّمَامِ قَالَ اللَّهُ ‏\{‏وَأَتِمُّوا الْحَجَّ وَالْعُمْرَةَ‏\}‏ وَإِنْ نَأْخُذْ بِسُنَّةِ النَّبِيِّ صلى الله عليه وسلم فَإِنَّهُ لَمْ يَحِلَّ حَتَّى نَحَرَ الْهَدْىَ‏.‏\hadithno{1559}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) sent me to some people in Yemen and when I returned, I found him at Al-Batha. He asked me, "With what intention have you assumed Ihram (i.e. for Hajj or for Umra or for both?") I replied, "I have assumed Ihram with an intention like that of the Prophet." He asked, "Have you a Hadi with you?" I replied in the negative. He ordered me to perform Tawaf round the Ka`ba and between Safa and Marwa and then to finish my Ihram. I did so and went to a woman from my tribe who combed my hair or washed my head. Then, when `Umar came (i.e. became Caliph) he said, "If we follow Allah's Book, it orders us to complete Hajj and Umra; as Allah says: "Perform the Hajj and Umra for Allah." (2.196). And if we follow the tradition of the Prophet (ﷺ) who did not finish his Ihram till he sacrificed his Hadi}}
\hadithdefcmd{bukhari}{1560}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنِي أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا أَفْلَحُ بْنُ حُمَيْدٍ، سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي أَشْهُرِ الْحَجِّ، وَلَيَالِي الْحَجِّ وَحُرُمِ الْحَجِّ، فَنَزَلْنَا بِسَرِفَ قَالَتْ فَخَرَجَ إِلَى أَصْحَابِهِ فَقَالَ ‏"‏ مَنْ لَمْ يَكُنْ مِنْكُمْ مَعَهُ هَدْىٌ فَأَحَبَّ أَنْ يَجْعَلَهَا عُمْرَةً فَلْيَفْعَلْ، وَمَنْ كَانَ مَعَهُ الْهَدْىُ فَلاَ ‏"‏‏.‏ قَالَتْ فَالآخِذُ بِهَا وَالتَّارِكُ لَهَا مِنْ أَصْحَابِهِ قَالَتْ فَأَمَّا رَسُولُ اللَّهِ صلى الله عليه وسلم وَرِجَالٌ مِنْ أَصْحَابِهِ فَكَانُوا أَهْلَ قُوَّةٍ، وَكَانَ مَعَهُمُ الْهَدْىُ، فَلَمْ يَقْدِرُوا عَلَى الْعُمْرَةِ قَالَتْ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا يُبْكِيكِ يَا هَنْتَاهْ ‏"‏‏.‏ قُلْتُ سَمِعْتُ قَوْلَكَ لأَصْحَابِكَ فَمُنِعْتُ الْعُمْرَةَ‏.‏ قَالَ ‏"‏ وَمَا شَأْنُكِ ‏"‏‏.‏ قُلْتُ لاَ أُصَلِّي‏.‏ قَالَ ‏"‏ فَلاَ يَضِيرُكِ، إِنَّمَا أَنْتِ امْرَأَةٌ مِنْ بَنَاتِ آدَمَ كَتَبَ اللَّهُ عَلَيْكِ مَا كَتَبَ عَلَيْهِنَّ، فَكُونِي فِي حَجَّتِكِ، فَعَسَى اللَّهُ أَنْ يَرْزُقَكِيهَا ‏"‏‏.‏ قَالَتْ فَخَرَجْنَا فِي حَجَّتِهِ حَتَّى قَدِمْنَا مِنًى فَطَهَرْتُ، ثُمَّ خَرَجْتُ مِنْ مِنًى فَأَفَضْتُ بِالْبَيْتِ قَالَتْ ثُمَّ خَرَجَتْ مَعَهُ فِي النَّفْرِ الآخِرِ حَتَّى نَزَلَ الْمُحَصَّبَ، وَنَزَلْنَا مَعَهُ فَدَعَا عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ فَقَالَ ‏"‏ اخْرُجْ بِأُخْتِكَ مِنَ الْحَرَمِ، فَلْتُهِلَّ بِعُمْرَةٍ ثُمَّ افْرُغَا، ثُمَّ ائْتِيَا هَا هُنَا، فَإِنِّي أَنْظُرُكُمَا حَتَّى تَأْتِيَانِي ‏"‏‏.‏ ـ قَالَتْ ـ فَخَرَجْنَا حَتَّى إِذَا فَرَغْتُ، وَفَرَغْتُ مِنَ الطَّوَافِ ثُمَّ جِئْتُهُ بِسَحَرَ فَقَالَ ‏"‏ هَلْ فَرَغْتُمْ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَآذَنَ بِالرَّحِيلِ فِي أَصْحَابِهِ، فَارْتَحَلَ النَّاسُ فَمَرَّ مُتَوَجِّهًا إِلَى الْمَدِينَةِ‏.‏ ضَيْرُ مِنْ ضَارَ يَضِيرُ ضَيْرًا، وَيُقَالُ ضَارَ يَضُورُ ضَوْرًا وَضَرَّ يَضُرُّ ضَرًّا‏.‏\hadithno{1560}\hadithtrans{Narrated Al-Qasim bin Muhammad:' Aisha said, "We set out with Allah's Messenger (ﷺ) in the months of Hajj, and (in) the nights of Hajj, and at the time and places of Hajj and in a state of Hajj. We dismounted at Sarif (a village six miles from Mecca). The Prophet (ﷺ) then addressed his companions and said, "Anyone who has not got the Hadi and likes to do Umra instead of Hajj may do so (i.e. Hajj-al-Tamattu`) and anyone who has got the Hadi should not finish the Ihram after performing ' `Umra). (i.e. Hajj-al-Qiran). Aisha added, "The companions of the Prophet (ﷺ) obeyed the above (order) and some of them (i.e. who did not have Hadi) finished their Ihram after Umra." Allah's Messenger (ﷺ) and some of his companions were resourceful and had the Hadi with them, they could not perform Umra (alone) (but had to perform both Hajj and Umra with one Ihram). Aisha added, "Allah's Messenger (ﷺ) came to me and saw me weeping and said, "What makes you weep, O Hantah?" I replied, "I have heard your conversation with your companions and I cannot perform the Umra." He asked, "What is wrong with you?' I replied, ' I do not offer the prayers (i.e. I have my menses).' He said, ' It will not harm you for you are one of the daughters of Adam, and Allah has written for you (this state) as He has written it for them. Keep on with your intentions for Hajj and Allah may reward you that." Aisha further added, "Then we proceeded for Hajj till we reached Mina and I became clean from my menses. Then I went out from Mina and performed Tawaf round the Ka`ba." Aisha added, "I went along with the Prophet (ﷺ) in his final departure (from Hajj) till he dismounted at Al-Muhassab (a valley outside Mecca), and we too, dismounted with him." He called ' `Abdur-Rahman bin Abu Bakr and said to him, ' Take your sister outside the sanctuary of Mecca and let her assume Ihram for ' `Umra, and when you have finished `Umra, return to this place and I will wait for you both till you both return to me.' " ' Aisha added, " So we went out of the sanctuary of Mecca and after finishing from the ' `Umra and the Tawaf we returned to the Prophet (ﷺ) at dawn. He said, 'Have you performed the ' `Umra?' We replied in the affirmative. So he announced the departure amongst his companions and the people set out for the journey, and the Prophet: too left for Medina}}
\hadithdefcmd{bukhari}{1561}{حَدَّثَنَا عُثْمَانُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم وَلاَ نُرَى إِلاَّ أَنَّهُ الْحَجُّ، فَلَمَّا قَدِمْنَا تَطَوَّفْنَا بِالْبَيْتِ، فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ أَنْ يَحِلَّ، فَحَلَّ مَنْ لَمْ يَكُنْ سَاقَ الْهَدْىَ، وَنِسَاؤُهُ لَمْ يَسُقْنَ فَأَحْلَلْنَ، قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ فَحِضْتُ فَلَمْ أَطُفْ بِالْبَيْتِ، فَلَمَّا كَانَتْ لَيْلَةُ الْحَصْبَةِ قَالَتْ يَا رَسُولَ اللَّهِ، يَرْجِعُ النَّاسُ بِعُمْرَةٍ وَحَجَّةٍ وَأَرْجِعُ أَنَا بِحَجَّةٍ قَالَ ‏"‏ وَمَا طُفْتِ لَيَالِيَ قَدِمْنَا مَكَّةَ ‏"‏‏.‏ قُلْتُ لاَ‏.‏ قَالَ ‏"‏ فَاذْهَبِي مَعَ أَخِيكِ إِلَى التَّنْعِيمِ، فَأَهِلِّي بِعُمْرَةٍ ثُمَّ مَوْعِدُكِ كَذَا وَكَذَا ‏"‏‏.‏ قَالَتْ صَفِيَّةُ مَا أُرَانِي إِلاَّ حَابِسَتَهُمْ‏.‏ قَالَ ‏"‏ عَقْرَى حَلْقَى، أَوَمَا طُفْتِ يَوْمَ النَّحْرِ ‏"‏‏.‏ قَالَتْ قُلْتُ بَلَى‏.‏ قَالَ ‏"‏ لاَ بَأْسَ، انْفِرِي ‏"‏‏.‏ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ فَلَقِيَنِي النَّبِيُّ صلى الله عليه وسلم وَهُوَ مُصْعِدٌ مِنْ مَكَّةَ، وَأَنَا مُنْهَبِطَةٌ عَلَيْهَا، أَوْ أَنَا مُصْعِدَةٌ وَهْوَ مُنْهَبِطٌ مِنْهَا‏.‏\hadithno{1561}\hadithtrans{Narrated Al-Aswad:' Aisha said, We went out with the Prophet (from Medina) with the intention of performing Hajj only and when we reached Mecca we performed Tawaf round the Ka`ba and then the Prophet (ﷺ) ordered those who had not driven the Hadi along with them to finish their Ihram. So the people who had not driven the Hadi along with them finished their Ihram. The Prophet's wives, too, had not driven the Hadi with them, so they too, finished their Ihram." `Aisha added, "I got my menses and could not perform Tawaf round the Ka`ba." So when it was the night of Hasba (i.e. when we stopped at Al-Muhassab), I said, 'O Allah's Messenger (ﷺ)! Everyone is returning after performing Hajj and `Umra but I am returning after performing Hajj only.' He said, 'Didn't you perform Tawaf round the Ka`ba the night we reached Mecca?' I replied in the negative. He said, 'Go with your brother to Tan`im and assume the Ihram for `Umra, (and after performing it) come back to such and such a place.' On that Safiya said, 'I feel that I will detain you all.' The Prophet (ﷺ) said, 'O 'Aqra Halqa! Didn't you perform Tawaf of the Ka`ba on the day of sacrifice? (i.e. Tawaf-al-ifada) Safiya replied in the affirmative. He said, (to Safiya). 'There is no harm for you to proceed on with us.' " `Aisha added, "(after returning from `Umra), the Prophet (ﷺ) met me while he was ascending (from Mecca) and I was descending to it, or I was ascending and he was descending}}
\hadithdefcmd{bukhari}{1562}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ، فَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ، وَمِنَّا مَنْ أَهَلَّ بِحَجَّةٍ وَعُمْرَةٍ، وَمِنَّا مَنْ أَهَلَّ بِالْحَجِّ وَأَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ، فَأَمَّا مَنْ أَهَلَّ بِالْحَجِّ أَوْ جَمَعَ الْحَجَّ وَالْعُمْرَةَ لَمْ يَحِلُّوا حَتَّى كَانَ يَوْمُ النَّحْرِ‏.‏\hadithno{1562}\hadithtrans{Narrated `Aisha:We set out with Allah's Messenger (ﷺ) (to Mecca) in the year of the Prophet's Last Hajj. Some of us had assumed Ihram for `Umra only, some for both Hajj and `Umra, and others for Hajj only. Allah's Apostle assumed Ihram for Hajj. So whoever had assumed Ihram for Hajj or for both Hajj and `Umra did not finish the Ihram till the day of sacrifice. (See Hadith No. 631, 636, and)}}
\hadithdefcmd{bukhari}{1563}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ مَرْوَانَ بْنِ الْحَكَمِ، قَالَ شَهِدْتُ عُثْمَانَ وَعَلِيًّا ـ رضى الله عنهما ـ وَعُثْمَانُ يَنْهَى عَنِ الْمُتْعَةِ وَأَنْ يُجْمَعَ بَيْنَهُمَا‏.‏ فَلَمَّا رَأَى عَلِيٌّ، أَهَلَّ بِهِمَا لَبَّيْكَ بِعُمْرَةٍ وَحَجَّةٍ قَالَ مَا كُنْتُ لأَدَعَ سُنَّةَ النَّبِيِّ صلى الله عليه وسلم لِقَوْلِ أَحَدٍ‏.‏\hadithno{1563}\hadithtrans{Narrated Marwan bin Al-Hakam:I saw `Uthman and `Ali. `Uthman used to forbid people to perform Hajj-at-Tamattu` and Hajj-al-Qiran (Hajj and `Umra together), and when `Ali saw (this act of `Uthman), he assumed Ihram for Hajj and `Umra together saying, "Labbaik for `Umra and Hajj," and said, "I will not leave the tradition of the Prophet (ﷺ) on the saying of somebody}}
\hadithdefcmd{bukhari}{1564}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانُوا يَرَوْنَ أَنَّ الْعُمْرَةَ فِي أَشْهُرِ الْحَجِّ مِنْ أَفْجَرِ الْفُجُورِ فِي الأَرْضِ، وَيَجْعَلُونَ الْمُحَرَّمَ صَفَرًا وَيَقُولُونَ إِذَا بَرَأَ الدَّبَرْ، وَعَفَا الأَثَرْ، وَانْسَلَخَ صَفَرْ، حَلَّتِ الْعُمْرَةُ لِمَنِ اعْتَمَرْ‏.‏ قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ صَبِيحَةَ رَابِعَةٍ مُهِلِّينَ بِالْحَجِّ، فَأَمَرَهُمْ أَنْ يَجْعَلُوهَا عُمْرَةً فَتَعَاظَمَ ذَلِكَ عِنْدَهُمْ فَقَالُوا يَا رَسُولَ اللَّهِ أَىُّ الْحِلِّ قَالَ ‏ "‏ حِلٌّ كُلُّهُ ‏"‏‏.‏\hadithno{1564}\hadithtrans{Narrated Ibn `Abbas:The people (of the Pre-Islamic Period) used to think that to perform `Umra during the months of Hajj was one of the major sins on earth. And also used to consider the month of Safar as a forbidden (i.e. sacred) month and they used to say, "When the wounds of the camel's back heal up (after they return from Hajj) and the signs of those wounds vanish and the month of Safar passes away then (at that time) `Umra is permissible for the one who wishes to perform it." In the morning of the 4th of Dhul- Hijja, the Prophet (ﷺ) and his companions reached Mecca, assuming Ihram for Hajj and he ordered his companions to make their intentions of the Ihram for `Umra only (instead of Hajj) so they considered his order as something great and were puzzled, and said, "O Allah's Messenger (ﷺ)! What kind (of finishing) of Ihram is allowed?" The Prophet (ﷺ) replied, "Finish the Ihram completely like a non-Muhrim (you are allowed everything)}}
\hadithdefcmd{bukhari}{1565}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ قَدِمْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم‏.‏ فَأَمَرَهُ بِالْحِلِّ‏.‏\hadithno{1565}\hadithtrans{Narrated Abu Musa: I came to the Prophet (from Yemen and was assuming Ihram for Hajj) and he ordered me to finish the Ihram (after performing the `Umra)}}
\hadithdefcmd{bukhari}{1566}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ،‏.‏ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ ـ رضى الله عنهم ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ، مَا شَأْنُ النَّاسِ حَلُّوا بِعُمْرَةٍ وَلَمْ تَحْلِلْ أَنْتَ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي، وَقَلَّدْتُ هَدْيِي فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏‏.‏\hadithno{1566}\hadithtrans{Narrated Ibn `Umar:Hafsa the wife of the Prophet (ﷺ) said, "O Allah's Messenger (ﷺ)! Why have the people finished their Ihram after performing `Umra but you have not finished your Ihram after performing `Umra?" He replied, "I have matted my hair and garlanded my Hadi. So I will not finish my Ihram till I have slaughtered (my Hadi)}}
\hadithdefcmd{bukhari}{1567}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا أَبُو جَمْرَةَ، نَصْرُ بْنُ عِمْرَانَ الضُّبَعِيُّ قَالَ تَمَتَّعْتُ فَنَهَانِي نَاسٌ، فَسَأَلْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ فَأَمَرَنِي، فَرَأَيْتُ فِي الْمَنَامِ كَأَنَّ رَجُلاً يَقُولُ لِي حَجٌّ مَبْرُورٌ وَعُمْرَةٌ مُتَقَبَّلَةٌ، فَأَخْبَرْتُ ابْنَ عَبَّاسٍ فَقَالَ سُنَّةَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِي أَقِمْ عِنْدِي، فَأَجْعَلَ لَكَ سَهْمًا مِنْ مَالِي‏.‏ قَالَ شُعْبَةُ فَقُلْتُ لِمَ فَقَالَ لِلرُّؤْيَا الَّتِي رَأَيْتُ‏.‏\hadithno{1567}\hadithtrans{Narrated Shu`ba:Abu Jamra Nasr bin `Imran Ad-Duba'i said, "I intended to perform Hajj-at-Tamattu` and the people advised me not to do so. I asked Ibn `Abbas regarding it and he ordered me to perform Hajj-at- Tammatu'. Later I saw in a dream someone saying to me, 'Hajj-Mabrur (Hajj performed in accordance with the Prophet's tradition without committing sins and accepted by Allah) and an accepted `Umra.' So I told that dream to Ibn `Abbas. He said, 'This is the tradition of Abul-Qasim.' Then he said to me, 'Stay with me and I shall give you a portion of my property.' " I (Shu`ba) asked, "Why (did he invite you)?" He (Abu Jamra) said, "Because of the dream which I had seen}}
\hadithdefcmd{bukhari}{1568}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَبُو شِهَابٍ، قَالَ قَدِمْتُ مُتَمَتِّعًا مَكَّةَ بِعُمْرَةٍ فَدَخَلْنَا قَبْلَ التَّرْوِيَةِ بِثَلاَثَةِ أَيَّامٍ، فَقَالَ لِي أُنَاسٌ مِنْ أَهْلِ مَكَّةَ تَصِيرُ الآنَ حَجَّتُكَ مَكِّيَّةً‏.‏ فَدَخَلْتُ عَلَى عَطَاءٍ أَسْتَفْتِيهِ فَقَالَ حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّهُ حَجَّ مَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَ سَاقَ الْبُدْنَ مَعَهُ، وَقَدْ أَهَلُّوا بِالْحَجِّ مُفْرَدًا، فَقَالَ لَهُمْ ‏"‏ أَحِلُّوا مِنْ إِحْرَامِكُمْ بِطَوَافِ الْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ، وَقَصِّرُوا ثُمَّ أَقِيمُوا حَلاَلاً، حَتَّى إِذَا كَانَ يَوْمُ التَّرْوِيَةِ فَأَهِلُّوا بِالْحَجِّ، وَاجْعَلُوا الَّتِي قَدِمْتُمْ بِهَا مُتْعَةً ‏"‏‏.‏ فَقَالُوا كَيْفَ نَجْعَلُهَا مُتْعَةً وَقَدْ سَمَّيْنَا الْحَجَّ فَقَالَ ‏"‏ افْعَلُوا مَا أَمَرْتُكُمْ، فَلَوْلاَ أَنِّي سُقْتُ الْهَدْىَ لَفَعَلْتُ مِثْلَ الَّذِي أَمَرْتُكُمْ، وَلَكِنْ لاَ يَحِلُّ مِنِّي حَرَامٌ حَتَّى يَبْلُغَ الْهَدْىُ مَحِلَّهُ ‏"‏‏.‏ فَفَعَلُوا‏.‏ قَالَ أَبُو عَبْد اللَّهِ أَبُو شِهَابٍ لَيْسَ لَهُ مُسْنَدٌ إِلَّا هَذَا\hadithno{1568}\hadithtrans{Narrated Abu Shihab:I left for Mecca for Hajj-at-Tamattu` assuming Ihram for `Umra. I reached Mecca three days before the day of Tarwiya (8th Dhul-Hijja). Some people of Mecca said to me, "Your Hajj will be like the Hajj performed by the people of Mecca (i.e. you will lose the superiority of assuming Ihram from the Miqat). So I went to `Ata' asking him his view about it. He said, "Jabir bin `Abdullah narrated to me, 'I performed Hajj with Allah's Messenger (ﷺ) on the day when he drove camels with him. The people had assumed Ihram for Hajj-al-Ifrad. The Prophet (ﷺ) ordered them to finish their Ihram after Tawaf round the Ka`ba, and between Safa and Marwa and to cut short their hair and then to stay there (in Mecca) as non-Muhrims till the day of Tarwiya (i.e. 8th of Dhul-Hijja) when they would assume Ihram for Hajj and they were ordered to make the Ihram with which they had come as for `Umra only. They asked, 'How can we make it `Umra (Tamattu`) as we have intended to perform Hajj?' The Prophet (ﷺ) said, 'Do what I have ordered you. Had I not brought the Hadi with me, I would have done the same, but I cannot finish my Ihram till the Hadi reaches its destination (i.e. is slaughtered).' So, they did (what he ordered them to do)}}
\hadithdefcmd{bukhari}{1569}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ الأَعْوَرُ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ اخْتَلَفَ عَلِيٌّ وَعُثْمَانُ ـ رضى الله عنهما ـ وَهُمَا بِعُسْفَانَ فِي الْمُتْعَةِ، فَقَالَ عَلِيٌّ مَا تُرِيدُ إِلاَّ أَنْ تَنْهَى عَنْ أَمْرٍ فَعَلَهُ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَلَمَّا رَأَى ذَلِكَ عَلِيٌّ أَهَلَّ بِهِمَا جَمِيعًا‏.‏\hadithno{1569}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:`Ali and `Uthman differed regarding Hajj-at-Tamattu` while they were at 'Usfan (a familiar place near Mecca). `Ali said, "I see you want to forbid people to do a thing that the Prophet (ﷺ) did?" When `Ali saw that, he assumed Ihram for both Hajj and `Umra}}
\hadithdefcmd{bukhari}{1570}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ حَدَّثَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَدِمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَقُولُ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ بِالْحَجِّ‏.‏ فَأَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلْنَاهَا عُمْرَةً‏.‏\hadithno{1570}\hadithtrans{Narrated Jabir bin `Abdullah:We came with Allah's Messenger (ﷺ) (to Mecca) and we were saying: 'Labbaika Allahumma Labbaik' for Hajj. Allah's Messenger (ﷺ) ordered us to perform `Umra with that Ihram (instead of Hajj)}}
\hadithdefcmd{bukhari}{1571}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ حَدَّثَنِي مُطَرِّفٌ، عَنْ عِمْرَانَ ـ رضى الله عنه ـ قَالَ تَمَتَّعْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَزَلَ الْقُرْآنُ قَالَ رَجُلٌ بِرَأْيِهِ مَا شَاءَ‏.‏\hadithno{1571}\hadithtrans{Narrated `Imran:We performed Hajj-at-Tamattu` in the lifetime of Allah's Messenger (ﷺ) and then the Qur'an was revealed (regarding Hajj-at-Tamattu`) and somebody said what he wished (regarding Hajj-at-Tamattu`) according his own opinion}}
\hadithdefcmd{bukhari}{1572}{وَقَالَ أَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ الْبَصْرِيُّ حَدَّثَنَا أَبُو مَعْشَرٍ، حَدَّثَنَا عُثْمَانُ بْنُ غِيَاثٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ سُئِلَ عَنْ مُتْعَةِ الْحَجِّ، فَقَالَ أَهَلَّ الْمُهَاجِرُونَ وَالأَنْصَارُ وَأَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَأَهْلَلْنَا، فَلَمَّا قَدِمْنَا مَكَّةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْعَلُوا إِهْلاَلَكُمْ بِالْحَجِّ عُمْرَةً إِلاَّ مَنْ قَلَّدَ الْهَدْىَ ‏"‏‏.‏ فَطُفْنَا بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ وَأَتَيْنَا النِّسَاءَ، وَلَبِسْنَا الثِّيَابَ وَقَالَ ‏"‏ مَنْ قَلَّدَ الْهَدْىَ فَإِنَّهُ لاَ يَحِلُّ لَهُ حَتَّى يَبْلُغَ الْهَدْىُ مَحِلَّهُ ‏"‏‏.‏ ثُمَّ أَمَرَنَا عَشِيَّةَ التَّرْوِيَةِ أَنْ نُهِلَّ بِالْحَجِّ، فَإِذَا فَرَغْنَا مِنَ الْمَنَاسِكِ جِئْنَا فَطُفْنَا بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ فَقَدْ تَمَّ حَجُّنَا، وَعَلَيْنَا الْهَدْىُ كَمَا قَالَ اللَّهُ تَعَالَى ‏\{‏فَمَا اسْتَيْسَرَ مِنَ الْهَدْىِ فَمَنْ لَمْ يَجِدْ فَصِيَامُ ثَلاَثَةِ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةٍ إِذَا رَجَعْتُمْ‏\}‏ إِلَى أَمْصَارِكُمْ‏.‏ الشَّاةُ تَجْزِي، فَجَمَعُوا نُسُكَيْنِ فِي عَامٍ بَيْنَ الْحَجِّ وَالْعُمْرَةِ، فَإِنَّ اللَّهَ تَعَالَى أَنْزَلَهُ فِي كِتَابِهِ وَسَنَّهُ نَبِيُّهُ صلى الله عليه وسلم وَأَبَاحَهُ لِلنَّاسِ غَيْرَ أَهْلِ مَكَّةَ، قَالَ اللَّهُ ‏\{‏ذَلِكَ لِمَنْ لَمْ يَكُنْ أَهْلُهُ حَاضِرِي الْمَسْجِدِ الْحَرَامِ‏\}‏ وَأَشْهُرُ الْحَجِّ الَّتِي ذَكَرَ اللَّهُ تَعَالَى شَوَّالٌ وَذُو الْقَعْدَةِ وَذُو الْحَجَّةِ، فَمَنْ تَمَتَّعَ فِي هَذِهِ الأَشْهُرِ فَعَلَيْهِ دَمٌ أَوْ صَوْمٌ، وَالرَّفَثُ الْجِمَاعُ، وَالْفُسُوقُ الْمَعَاصِي، وَالْجِدَالُ الْمِرَاءُ‏.‏\hadithno{1572}\hadithtrans{Ibn 'Abbas said that he has been asked regarding Hajj-at-Tamattu' on which he said:"The Muhajirin and the Ansar and the wives of the Prophet (ﷺ) and we did the same. When we reached Makkah, Allah's Messenger (ﷺ) said, "Give up your intention of doing the Hajj (at this moment) and perform 'Umra, except the one who had garlanded the Hady." So, we performed Tawaf round the Ka'bah and [Sa'y] between As-safa and Al-MArwa, slept with our wives and wore ordinary (stitched) clothes. The Prophet (ﷺ) added, "Whoever has garlanded his Hady is not allowed to finish the Ihram till the Hady has reached its destination (has been sacrificed)". Then on the night of Tarwiya (8th Dhul Hijjah, in the afternoon) he ordered us to assume Ihram for Hajj and when we had performed all the ceremonies of Hajj, we came and performed Tawaf round the Ka'bah and (Sa'y) between As-Safa and Al-Marwa, and then our Hajj was complete, and we had to sacrifice a Hady according to the statement of Allah: "... He must slaughter a Hady such as he can afford, but if he cannot afford it, he should observe Saum (fasts) three days during the Hajj and seven days after his return (to his home)…." (V. 2:196). And the sacrifice of the sheep is sufficient. So, the Prophet (ﷺ) and his Companions joined the two religious deeds, (i.e. Hajj and 'Umra) in one year, for Allah revealed (the permissibility) of such practice in His book and in the Sunna (legal ways) of His Prophet (ﷺ) and rendered it permissible for all the people except those living in Makkah. Allah says: "This is for him whose family is not present at the Al-Masjid-Al-Haram, (i.e. non resident of Makkah)." The months of Hajj which Allah mentioned in His book are: Shawwal, Dhul-Qa'da and Dhul-Hijjah. Whoever performed Hajj-at-Tamattu' in those months, then slaughtering or fasting is compulsory for him. The words: 1. Ar-Rafatha means sexual intercourse. 2. Al-Fasuq means all kinds of sin, and 3. Al-Jidal means to dispute}}
\hadithdefcmd{bukhari}{1573}{حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، أَخْبَرَنَا أَيُّوبُ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ إِذَا دَخَلَ أَدْنَى الْحَرَمِ أَمْسَكَ عَنِ التَّلْبِيَةِ، ثُمَّ يَبِيتُ بِذِي طُوًى، ثُمَّ يُصَلِّي بِهِ الصُّبْحَ وَيَغْتَسِلُ، وَيُحَدِّثُ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُ ذَلِكَ‏.‏\hadithno{1573}\hadithtrans{Narrated Nafi`:On reaching the sanctuary of Mecca, Ibn `Umar used to stop, reciting Talbiya and then he would pass the night at Dhi-Tuwa and then offer the Fajr prayer and take a bath. He used to say that the Prophet (ﷺ) used to do the same}}
\hadithdefcmd{bukhari}{1574}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ بَاتَ النَّبِيُّ صلى الله عليه وسلم بِذِي طُوًى حَتَّى أَصْبَحَ ثُمَّ دَخَلَ مَكَّةَ‏.‏ وَكَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَفْعَلُهُ‏.‏\hadithno{1574}\hadithtrans{Narrated Nafi`:' Ibn `Umar said, "The Prophet (ﷺ) passed the night at Dhi-Tuwa till it was dawn and then he entered Mecca." Ibn `Umar used to do the same}}
\hadithdefcmd{bukhari}{1575}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنِي مَعْنٌ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ مِنَ الثَّنِيَّةِ الْعُلْيَا، وَيَخْرُجُ مِنَ الثَّنِيَّةِ السُّفْلَى‏.‏\hadithno{1575}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) used to enter Mecca from the high Thaniya and used to leave Mecca from the low Thaniya}}
\hadithdefcmd{bukhari}{1576}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ الْبَصْرِيُّ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ مَكَّةَ مِنْ كَدَاءٍ مِنَ الثَّنِيَّةِ الْعُلْيَا الَّتِي بِالْبَطْحَاءِ، وَيَخْرُجُ مِنَ الثَّنِيَّةِ السُّفْلَى‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ كَانَ يُقَالُ هُوَ مُسَدَّدٌ كَاسْمِهِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ سَمِعْتُ يَحْيَى بْنَ مَعِينٍ يَقُولُ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ يَقُولُ لَوْ أَنَّ مُسَدَّدًا أَتَيْتُهُ فِي بَيْتِهِ فَحَدَّثْتُهُ لاَسْتَحَقَّ ذَلِكَ، وَمَا أُبَالِي كُتُبِي كَانَتْ عِنْدِي أَوْ عِنْدَ مُسَدَّدٍ‏.‏\hadithno{1576}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) entered Mecca from Kada' from the highest Thaniya which is at Al-Batha' and used to leave Mecca from the low Thaniya}}
\hadithdefcmd{bukhari}{1577}{حَدَّثَنَا الْحُمَيْدِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا جَاءَ إِلَى مَكَّةَ دَخَلَ مِنْ أَعْلاَهَا وَخَرَجَ مِنْ أَسْفَلِهَا‏.‏\hadithno{1577}\hadithtrans{Narrated `Aisha:When the Prophet (ﷺ) came to Mecca he entered from its higher side and left from its lower side}}
\hadithdefcmd{bukhari}{1578}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ الْمَرْوَزِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَامَ الْفَتْحِ مِنْ كَدَاءٍ، وَخَرَجَ مِنْ كُدًا مِنْ أَعْلَى مَكَّةَ‏.‏\hadithno{1578}\hadithtrans{Narrated `Aisha':In the year of the conquest of Mecca, the Prophet (ﷺ) entered Mecca from Kada' and left Mecca from Kuda, from the higher part of Mecca}}
\hadithdefcmd{bukhari}{1579}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَامَ الْفَتْحِ مِنْ كَدَاءٍ أَعْلَى مَكَّةَ‏.‏ قَالَ هِشَامٌ وَكَانَ عُرْوَةُ يَدْخُلُ عَلَى كِلْتَيْهِمَا مِنْ كَدَاءٍ وَكُدًا، وَأَكْثَرُ مَا يَدْخُلُ مِنْ كَدَاءٍ، وَكَانَتْ أَقْرَبَهُمَا إِلَى مَنْزِلِهِ‏.‏\hadithno{1579}\hadithtrans{Narrated `Aisha:In the year of the conquest of Mecca, the Prophet (ﷺ) entered Mecca from Kada' at the higher place of Mecca. (Hisham, a sub-narrator said, " `Urwa used to enter (Mecca) from both Kada' and Kuda and he often entered through Kada' which was nearer to his dwelling place}}
\hadithdefcmd{bukhari}{1580}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا حَاتِمٌ، عَنْ هِشَامٍ، عَنْ عُرْوَةَ، دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَامَ الْفَتْحِ مِنْ كَدَاءٍ مِنْ أَعْلَى مَكَّةَ‏.‏ وَكَانَ عُرْوَةُ أَكْثَرَ مَا يَدْخُلُ مِنْ كَدَاءٍ وَكَانَ أَقْرَبَهُمَا إِلَى مَنْزِلِهِ‏.‏\hadithno{1580}\hadithtrans{Narrated Hisham:`Urwa said, "The Prophet (ﷺ) entered Mecca in the year of the conquest of Mecca from the side of Kada' which is at the higher part of Mecca." `Urwa often entered from Kada' which was nearer of the two to his dwelling place}}
\hadithdefcmd{bukhari}{1581}{حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَامَ الْفَتْحِ مِنْ كَدَاءٍ‏.‏ وَكَانَ عُرْوَةُ يَدْخُلُ مِنْهُمَا كِلَيْهِمَا وَأَكْثَرُ مَا يَدْخُلُ مِنْ كَدَاءٍ أَقْرَبِهِمَا إِلَى مَنْزِلِهِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ كَدَاءٌ وَكُدًا مَوْضِعَانِ‏.‏\hadithno{1581}\hadithtrans{Narrated Hisham from his father:In the year of the conquest of Mecca, the Prophet (ﷺ) entered Mecca from the side of Kada. `Urwa used to enter through both places and he often entered through Kada' which was nearer of the two to his dwelling place}}
\hadithdefcmd{bukhari}{1582}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ لَمَّا بُنِيَتِ الْكَعْبَةُ ذَهَبَ النَّبِيُّ صلى الله عليه وسلم وَعَبَّاسٌ يَنْقُلاَنِ الْحِجَارَةَ فَقَالَ الْعَبَّاسُ لِلنَّبِيِّ صلى الله عليه وسلم اجْعَلْ إِزَارَكَ عَلَى رَقَبَتِكَ‏.‏ فَخَرَّ إِلَى الأَرْضِ، وَطَمَحَتْ عَيْنَاهُ إِلَى السَّمَاءِ فَقَالَ ‏ "‏ أَرِنِي إِزَارِي ‏"‏‏.‏ فَشَدَّهُ عَلَيْهِ‏.‏\hadithno{1582}\hadithtrans{Narrated Jabir bin `Abdullah:When the Ka`ba was built, the Prophet (ﷺ) and `Abbas went to bring stones (for its construction). Al `Abbas said to the Prophet, "Take off your waist sheet and put it on your neck." (When the Prophet (ﷺ) took it off) he fell on the ground with his eyes open towards the sky and said, "Give me my waist sheet." And he covered himself with it}}
\hadithdefcmd{bukhari}{1583}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، أَخْبَرَ عَبْدَ اللَّهِ بْنَ عُمَرَ، عَنْ عَائِشَةَ ـ رضى الله عنهم ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهَا ‏"‏ أَلَمْ تَرَىْ أَنَّ قَوْمَكِ لَمَّا بَنَوُا الْكَعْبَةَ اقْتَصَرُوا عَنْ قَوَاعِدِ إِبْرَاهِيمَ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَلاَ تَرُدُّهَا عَلَى قَوَاعِدِ إِبْرَاهِيمَ‏.‏ قَالَ ‏"‏ لَوْلاَ حِدْثَانُ قَوْمِكِ بِالْكُفْرِ لَفَعَلْتُ ‏"‏‏.‏ فَقَالَ عَبْدُ اللَّهِ ـ رضى الله عنه ـ لَئِنْ كَانَتْ عَائِشَةُ ـ رضى الله عنها ـ سَمِعَتْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أُرَى رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ اسْتِلاَمَ الرُّكْنَيْنِ اللَّذَيْنِ يَلِيَانِ الْحِجْرَ، إِلاَّ أَنَّ الْبَيْتَ لَمْ يُتَمَّمْ عَلَى قَوَاعِدِ إِبْرَاهِيمَ‏.‏\hadithno{1583}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) that Allah's Messenger (ﷺ) said to her, "Do you know that when your people (Quraish) rebuilt the Ka`ba, they decreased it from its original foundation laid by Abraham?" I said, "O Allah's Messenger (ﷺ)! Why don't you rebuild it on its original foundation laid by Abraham?" He replied, "Were it not for the fact that your people are close to the Pre-Islamic Period of ignorance (i.e. they have recently become Muslims) I would have done so." The sub-narrator, `Abdullah (bin `Umar ) stated: `Aisha 'must have heard this from Allah's Messenger (ﷺ) for in my opinion Allah's Messenger (ﷺ) had not placed his hand over the two corners of the Ka`ba opposite Al-Hijr only because the Ka`ba was not rebuilt on its original foundations laid by Abraham}}
\hadithdefcmd{bukhari}{1584}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَشْعَثُ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ الْجَدْرِ أَمِنَ الْبَيْتِ هُوَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قُلْتُ فَمَا لَهُمْ لَمْ يُدْخِلُوهُ فِي الْبَيْتِ قَالَ ‏"‏ إِنَّ قَوْمَكِ قَصَّرَتْ بِهِمُ النَّفَقَةُ ‏"‏‏.‏ قُلْتُ فَمَا شَأْنُ بَابِهِ مُرْتَفِعًا قَالَ ‏"‏ فَعَلَ ذَلِكِ قَوْمُكِ لِيُدْخِلُوا مَنْ شَاءُوا وَيَمْنَعُوا مَنْ شَاءُوا، وَلَوْلاَ أَنَّ قَوْمَكِ حَدِيثٌ عَهْدُهُمْ بِالْجَاهِلِيَّةِ فَأَخَافُ أَنْ تُنْكِرَ قُلُوبُهُمْ أَنْ أُدْخِلَ الْجَدْرَ فِي الْبَيْتِ وَأَنْ أُلْصِقَ بَابَهُ بِالأَرْضِ ‏"‏‏.‏\hadithno{1584}\hadithtrans{Narrated `Aisha:I asked the Prophet (ﷺ) whether the round wall (near Ka`ba) was part of the Ka`ba. The Prophet (ﷺ) replied in the affirmative. I further said, "What is wrong with them, why have they not included it in the building of the Ka`ba?" He said, "Don't you see that your people (Quraish) ran short of money (so they could not include it inside the building of Ka`ba)?" I asked, "What about its gate? Why is it so high?" He replied, "Your people did this so as to admit into it whomever they liked and prevent whomever they liked. Were your people not close to the Pre-Islamic Period of ignorance (i.e. they have recently embraced Islam) and were I not afraid that they would dislike it, surely I would have included the (area of the) wall inside the building of the Ka`ba and I would have lowered its gate to the level of the ground}}
\hadithdefcmd{bukhari}{1585}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ حَدَاثَةُ قَوْمِكِ بِالْكُفْرِ لَنَقَضْتُ الْبَيْتَ ثُمَّ لَبَنَيْتُهُ عَلَى أَسَاسِ إِبْرَاهِيمَ ـ عَلَيْهِ السَّلاَمُ ـ فَإِنَّ قُرَيْشًا اسْتَقْصَرَتْ بِنَاءَهُ ـ وَجَعَلْتُ لَهُ خَلْفًا ‏"‏‏.‏ قَالَ أَبُو مُعَاوِيَةَ حَدَّثَنَا هِشَامٌ خَلْفًا يَعْنِي بَابًا‏.‏\hadithno{1585}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said to me, "Were your people not close to the Pre-Islamic period of ignorance, I would have demolished the Ka`ba and would have rebuilt it on its original foundations laid by Abraham (for Quraish had curtailed its building), and I would have built a back door (too)}}
\hadithdefcmd{bukhari}{1586}{حَدَّثَنَا بَيَانُ بْنُ عَمْرٍو، حَدَّثَنَا يَزِيدُ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا يَزِيدُ بْنُ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ يَا عَائِشَةُ لَوْلاَ أَنَّ قَوْمَكِ حَدِيثُ عَهْدٍ بِجَاهِلِيَّةٍ لأَمَرْتُ بِالْبَيْتِ فَهُدِمَ، فَأَدْخَلْتُ فِيهِ مَا أُخْرِجَ مِنْهُ وَأَلْزَقْتُهُ بِالأَرْضِ، وَجَعَلْتُ لَهُ بَابَيْنِ بَابًا شَرْقِيًّا وَبَابًا غَرْبِيًّا، فَبَلَغْتُ بِهِ أَسَاسَ إِبْرَاهِيمَ ‏"‏‏.‏ فَذَلِكَ الَّذِي حَمَلَ ابْنَ الزُّبَيْرِ ـ رضى الله عنهما ـ عَلَى هَدْمِهِ‏.‏ قَالَ يَزِيدُ وَشَهِدْتُ ابْنَ الزُّبَيْرِ حِينَ هَدَمَهُ وَبَنَاهُ وَأَدْخَلَ فِيهِ مِنَ الْحِجْرِ، وَقَدْ رَأَيْتُ أَسَاسَ إِبْرَاهِيمَ حِجَارَةً كَأَسْنِمَةِ الإِبِلِ‏.‏ قَالَ جَرِيرٌ فَقُلْتُ لَهُ أَيْنَ مَوْضِعُهُ قَالَ أُرِيكَهُ الآنَ‏.‏ فَدَخَلْتُ مَعَهُ الْحِجْرَ فَأَشَارَ إِلَى مَكَانٍ فَقَالَ هَا هُنَا‏.‏ قَالَ جَرِيرٌ فَحَزَرْتُ مِنَ الْحِجْرِ سِتَّةَ أَذْرُعٍ أَوْ نَحْوَهَا‏.‏\hadithno{1586}\hadithtrans{Narrated Yazid bin Ruman from `Urwa:`Aisha said that the Prophet (ﷺ) said to her, "O Aisha! Were your nation not close to the Pre-Islamic Period of Ignorance, I would have had the Ka`ba demolished and would have included in it the portion which had been left, and would have made it at a level with the ground and would have made two doors for it, one towards the east and the other towards the west, and then by doing this it would have been built on the foundations laid by Abraham." That was what urged Ibn-Az-Zubair to demolish the Ka`ba. Yazid said, "I saw Ibn-Az-Zubair when he demolished and rebuilt the Ka`ba and included in it a portion of Al-Hijr (the unroofed portion of Ka`ba which is at present in the form of a compound towards the northwest of the Ka`ba). I saw the original foundations of Abraham which were of stones resembling the humps of camels." So Jarir asked Yazid, "Where was the place of those stones?" Yazid said, "I will just now show it to you." So Jarir accompanied Yazid and entered Al-Hijr, and Yazid pointed to a place and said, "Here it is." Jarir said, "It appeared to me about six cubits from Al-Hijr or so}}
\hadithdefcmd{bukhari}{1587}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ ‏ "‏ إِنَّ هَذَا الْبَلَدَ حَرَّمَهُ اللَّهُ، لاَ يُعْضَدُ شَوْكُهُ، وَلاَ يُنَفَّرُ صَيْدُهُ، وَلاَ يَلْتَقِطُ لُقَطَتَهُ إِلاَّ مَنْ عَرَّفَهَا ‏"‏‏.‏\hadithno{1587}\hadithtrans{Narrated Ibn `Abbas:On the Day of the Conquest of Mecca, Allah's Messenger (ﷺ) said, "Allah has made this town a sanctuary. Its thorny bushes should not be cut, its game should not be chased, and its fallen things should not be picked up except by one who would announce it publicly}}
\hadithdefcmd{bukhari}{1588}{حَدَّثَنَا أَصْبَغُ، قَالَ أَخْبَرَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ، أَيْنَ تَنْزِلُ فِي دَارِكَ بِمَكَّةَ‏.‏ فَقَالَ ‏"‏ وَهَلْ تَرَكَ عَقِيلٌ مِنْ رِبَاعٍ أَوْ دُورٍ ‏"‏‏.‏ وَكَانَ عَقِيلٌ وَرِثَ أَبَا طَالِبٍ هُوَ وَطَالِبٌ وَلَمْ يَرِثْهُ جَعْفَرٌ وَلاَ عَلِيٌّ ـ رضى الله عنهما ـ شَيْئًا لأَنَّهُمَا كَانَا مُسْلِمَيْنِ، وَكَانَ عَقِيلٌ وَطَالِبٌ كَافِرَيْنِ، فَكَانَ عُمَرُ بْنُ الْخَطَّابِ ـ رضى الله عنه ـ يَقُولُ لاَ يَرِثُ الْمُؤْمِنُ الْكَافِرَ‏.‏ قَالَ ابْنُ شِهَابٍ وَكَانُوا يَتَأَوَّلُونَ قَوْلَ اللَّهِ تَعَالَى ‏\{‏إِنَّ الَّذِينَ آمَنُوا وَهَاجَرُوا وَجَاهَدُوا بِأَمْوَالِهِمْ وَأَنْفُسِهِمْ فِي سَبِيلِ اللَّهِ وَالَّذِينَ آوَوْا وَنَصَرُوا أُولَئِكَ بَعْضُهُمْ أَوْلِيَاءُ بَعْضٍ‏\}‏ الآيَةَ‏.‏\hadithno{1588}\hadithtrans{Narrated 'Usama bin Zaid:I asked, "O Allah's Messenger (ﷺ)! Where will you stay in Mecca? Will you stay in your house in Mecca?" He replied, "Has `Aqil left any property or house?" `Aqil along with Talib had inherited the property of Abu Talib. Jafar and `Ali did not inherit anything as they were Muslims and the other two were non-believers. `Umar bin Al-Khattab used to say, "A believer cannot inherit (anything from an) infidel." Ibn Shihab, (a sub-narrator) said, "They (`Umar and others) derived the above verdict from Allah's Statement: "Verily! those who believed and Emigrated and strove with their life And property in Allah's Cause, And those who helped (the emigrants) And gave them their places to live in, These are (all) allies to one another}}
\hadithdefcmd{bukhari}{1589}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَرَادَ قُدُومَ مَكَّةَ ‏ "‏ مَنْزِلُنَا غَدًا إِنْ شَاءَ اللَّهُ بِخَيْفِ بَنِي كِنَانَةَ حَيْثُ تَقَاسَمُوا عَلَى الْكُفْرِ ‏"‏‏.‏\hadithno{1589}\hadithtrans{Narrated Abu Huraira:When Allah's Messenger (ﷺ) intended to enter Mecca he said, "Our destination tomorrow, if Allah wished, will be Khaif Bani Kinana where (the pagans) had taken the oath of Kufr." (Against the Prophet (ﷺ) i.e. to be loyal to heathenism by boycotting Bani Hashim, the Prophet's folk) (See Hadith)}}
\hadithdefcmd{bukhari}{1590}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْغَدِ يَوْمَ النَّحْرِ وَهُوَ بِمِنًى ‏ "‏ نَحْنُ نَازِلُونَ غَدًا بِخَيْفِ بَنِي كِنَانَةَ حَيْثُ تَقَاسَمُوا عَلَى الْكُفْرِ ‏"‏‏.‏ يَعْنِي ذَلِكَ الْمُحَصَّبَ، وَذَلِكَ أَنَّ قُرَيْشًا وَكِنَانَةَ تَحَالَفَتْ عَلَى بَنِي هَاشِمٍ وَبَنِي عَبْدِ الْمُطَّلِبِ، أَوْ بَنِي الْمُطَّلِبِ أَنْ لاَ يُنَاكِحُوهُمْ، وَلاَ يُبَايِعُوهُمْ حَتَّى يُسْلِمُوا إِلَيْهِمُ النَّبِيَّ صلى الله عليه وسلم‏.‏ وَقَالَ سَلاَمَةُ عَنْ عُقَيْلٍ وَيَحْيَى بْنُ الضَّحَّاكِ عَنِ الأَوْزَاعِيِّ أَخْبَرَنِي ابْنُ شِهَابٍ وَقَالاَ بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ بَنِي الْمُطَّلِبِ أَشْبَهُ‏.‏\hadithno{1590}\hadithtrans{Narrated Abu Huraira:On the Day of Nahr at Mina, the Prophet (ﷺ) said, "Tomorrow we shall stay at Khaif Bani Kinana where the pagans had taken the oath of Kufr (heathenism)." He meant (by that place) Al-Muhassab where the Quraish tribe and Bani Kinana concluded a contract against Bani Hashim and Bani `Abdul-Muttalib or Bani Al-Muttalib that they would not intermarry with them or deal with them in business until they handed over the Prophet (ﷺ) to them}}
\hadithdefcmd{bukhari}{1591}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا زِيَادُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُخَرِّبُ الْكَعْبَةَ ذُو السُّوَيْقَتَيْنِ مِنَ الْحَبَشَةِ ‏"‏‏.‏\hadithno{1591}\hadithtrans{Narrated Abu Huraira:The Prophet;; said, "Dhus-Suwaiqa-tain (literally: One with two lean legs) from Ethiopia will demolish the Ka`ba}}
\hadithdefcmd{bukhari}{1592}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ ـ هُوَ ابْنُ الْمُبَارَكِ ـ قَالَ أَخْبَرَنَا مُحَمَّدُ بْنُ أَبِي حَفْصَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانُوا يَصُومُونَ عَاشُورَاءَ قَبْلَ أَنْ يُفْرَضَ رَمَضَانُ، وَكَانَ يَوْمًا تُسْتَرُ فِيهِ الْكَعْبَةُ، فَلَمَّا فَرَضَ اللَّهُ رَمَضَانَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَاءَ أَنْ يَصُومَهُ فَلْيَصُمْهُ، وَمَنْ شَاءَ أَنْ يَتْرُكَهُ فَلْيَتْرُكْهُ ‏"‏‏.‏\hadithno{1592}\hadithtrans{Narrated `Aisha:The people used to fast on 'Ashura (the tenth day of the month of Muharram) before the fasting of Ramadan was made obligatory. And on that day the Ka`ba used to be covered with a cover. When Allah made the fasting of the month of Ramadan compulsory, Allah's Messenger (ﷺ) said, "Whoever wishes to fast (on the day of 'Ashura') may do so; and whoever wishes to leave it can do so}}
\hadithdefcmd{bukhari}{1593}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِبْرَاهِيمُ، عَنِ الْحَجَّاجِ بْنِ حَجَّاجٍ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي عُتْبَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَيُحَجَّنَّ الْبَيْتُ وَلَيُعْتَمَرَنَّ بَعْدَ خُرُوجِ يَأْجُوجَ وَمَأْجُوجَ ‏"‏‏.‏ تَابَعَهُ أَبَانُ وَعِمْرَانُ عَنْ قَتَادَةَ‏.‏ وَقَالَ عَبْدُ الرَّحْمَنِ عَنْ شُعْبَةَ قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى لاَ يُحَجَّ الْبَيْتُ ‏"‏‏.‏ وَالأَوَّلُ أَكْثَرُ، سَمِعَ قَتَادَةُ عَبْدَ اللَّهِ وَعَبْدُ اللَّهِ أَبَا سَعِيدٍ‏.‏\hadithno{1593}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said "The people will continue performing the Hajj and `Umra to the Ka`ba even after the appearance of Gog and Magog." Narrated Shu`ba extra: The Hour (Day of Judgment) will not be established till the Hajj (to the Ka`ba) is abandoned}}
\hadithdefcmd{bukhari}{1594}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا وَاصِلٌ الأَحْدَبُ، عَنْ أَبِي وَائِلٍ، قَالَ جِئْتُ إِلَى شَيْبَةَ‏.‏ وَحَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ وَاصِلٍ، عَنْ أَبِي وَائِلٍ، قَالَ جَلَسْتُ مَعَ شَيْبَةَ عَلَى الْكُرْسِيِّ فِي الْكَعْبَةِ فَقَالَ لَقَدْ جَلَسَ هَذَا الْمَجْلِسَ عُمَرُ ـ رضى الله عنه ـ فَقَالَ لَقَدْ هَمَمْتُ أَنْ لاَ أَدَعَ فِيهَا صَفْرَاءَ وَلاَ بَيْضَاءَ إِلاَّ قَسَمْتُهُ‏.‏ قُلْتُ إِنَّ صَاحِبَيْكَ لَمْ يَفْعَلاَ‏.‏ قَالَ هُمَا الْمَرْآنِ أَقْتَدِي بِهِمَا‏.‏\hadithno{1594}\hadithtrans{Narrated Abu Wail:(One day) I sat along with Shaiba on the chair inside the Ka`ba. He (Shaiba) said, "No doubt, `Umar sat at this place and said, 'I intended not to leave any yellow (i.e. gold) or white (i.e. silver) (inside the Ka`ba) undistributed.' I said (to `Umar), 'But your two companions (i.e. The Prophet (ﷺ) and Abu Bakr) did not do so.' `Umar said, They are the two persons whom I always follow}}
\hadithdefcmd{bukhari}{1595}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الأَخْنَسِ، حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَأَنِّي بِهِ أَسْوَدَ أَفْحَجَ، يَقْلَعُهَا حَجَرًا حَجَرًا ‏"‏‏.‏\hadithno{1595}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "As if I were looking at him, a black person with thin legs plucking the stones of the Ka`ba one after another}}
\hadithdefcmd{bukhari}{1596}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُخَرِّبُ الْكَعْبَةَ ذُو السُّوَيْقَتَيْنِ مِنَ الْحَبَشَةِ ‏"‏‏.‏\hadithno{1596}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Dhus-Suwaiqatain (the thin legged man) from Ethiopia will demolish the Ka`ba}}
\hadithdefcmd{bukhari}{1597}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَابِسِ بْنِ رَبِيعَةَ، عَنْ عُمَرَ ـ رضى الله عنه ـ أَنَّهُ جَاءَ إِلَى الْحَجَرِ الأَسْوَدِ فَقَبَّلَهُ، فَقَالَ إِنِّي أَعْلَمُ أَنَّكَ حَجَرٌ لاَ تَضُرُّ وَلاَ تَنْفَعُ، وَلَوْلاَ أَنِّي رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُقَبِّلُكَ مَا قَبَّلْتُكَ‏.‏\hadithno{1597}\hadithtrans{Narrated `Abis bin Rabi`a:`Umar came near the Black Stone and kissed it and said "No doubt, I know that you are a stone and can neither benefit anyone nor harm anyone. Had I not seen Allah's Messenger (ﷺ) kissing you I would not have kissed you}}
\hadithdefcmd{bukhari}{1598}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ هُوَ وَأُسَامَةُ بْنُ زَيْدٍ، وَبِلاَلٌ، وَعُثْمَانُ بْنُ طَلْحَةَ، فَأَغْلَقُوا عَلَيْهِمْ فَلَمَّا فَتَحُوا، كُنْتُ أَوَّلَ مَنْ وَلَجَ، فَلَقِيتُ بِلاَلاً فَسَأَلْتُهُ هَلْ صَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ، بَيْنَ الْعَمُودَيْنِ الْيَمَانِيَيْنِ‏.‏\hadithno{1598}\hadithtrans{Narrated Salim that his father said:"Allah's Messenger (ﷺ), Usama bin Zaid, Bilal, and `Uthman bin abu Talha entered the Ka`ba and then closed its door. When they opened the door I was the first person to enter (the Ka`ba). I met Bilal and asked him, "Did Allah's Messenger (ﷺ) offer a prayer inside (the Ka`ba)?" Bilal replied in the affirmative and said, "(The Prophet (ﷺ) offered the prayer) in between the two right pillars}}
\hadithdefcmd{bukhari}{1599}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ كَانَ إِذَا دَخَلَ الْكَعْبَةَ مَشَى قِبَلَ الْوَجْهِ حِينَ يَدْخُلُ، وَيَجْعَلُ الْبَابَ قِبَلَ الظَّهْرِ، يَمْشِي حَتَّى يَكُونَ بَيْنَهُ وَبَيْنَ الْجِدَارِ الَّذِي قِبَلَ وَجْهِهِ قَرِيبًا مِنْ ثَلاَثِ أَذْرُعٍ، فَيُصَلِّي يَتَوَخَّى الْمَكَانَ الَّذِي أَخْبَرَهُ بِلاَلٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِيهِ، وَلَيْسَ عَلَى أَحَدٍ بَأْسٌ أَنْ يُصَلِّيَ فِي أَىِّ نَوَاحِي الْبَيْتِ شَاءَ‏.‏\hadithno{1599}\hadithtrans{Narrated Nafi`:Whenever Ibn `Umar entered the Ka`ba he used to walk straight keeping the door at his back on entering, and used to proceed on till about three cubits from the wall in front of him, and then he would offer the prayer there aiming at the place where Allah's Messenger (ﷺ) prayed, as Bilal had told him. There is no harm for any person to offer the prayer at any place inside the Ka`ba}}
\hadithdefcmd{bukhari}{1600}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، وَمَعَهُ مَنْ يَسْتُرُهُ مِنَ النَّاسِ فَقَالَ لَهُ رَجُلٌ أَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْكَعْبَةَ قَالَ لاَ‏.‏\hadithno{1600}\hadithtrans{Narrated Isma'il bin Abu Khalid:`Abdullah bin Abu `Aufa said, "Allah's Messenger (ﷺ) performed the `Umra. He performed Tawaf of the Ka`ba and offered two rak`at behind the Maqam (Abraham's place) and was accompanied by those who were screening him from the people." Somebody asked `Abdullah, "Did Allah's Messenger (ﷺ) enter the Ka`ba?" `Abdullah replied in the negative}}
\hadithdefcmd{bukhari}{1601}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا قَدِمَ أَبَى أَنْ يَدْخُلَ الْبَيْتَ وَفِيهِ الآلِهَةُ فَأَمَرَ بِهَا فَأُخْرِجَتْ فَأَخْرَجُوا صُورَةَ إِبْرَاهِيمَ وَإِسْمَاعِيلَ فِي أَيْدِيهِمَا الأَزْلاَمُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَاتَلَهُمُ اللَّهُ أَمَا وَاللَّهِ قَدْ عَلِمُوا أَنَّهُمَا لَمْ يَسْتَقْسِمَا بِهَا قَطُّ ‏"‏‏.‏ فَدَخَلَ الْبَيْتَ، فَكَبَّرَ فِي نَوَاحِيهِ، وَلَمْ يُصَلِّ فِيهِ‏.‏\hadithno{1601}\hadithtrans{Narrated Ibn `Abbas:When Allah's Messenger (ﷺ) came to Mecca, he refused to enter the Ka`ba with idols in it. He ordered (idols to be taken out). So they were taken out. The people took out the pictures of Abraham and Ishmael holding Azlams in their hands. Allah's Messenger (ﷺ) said, "May Allah curse these people. By Allah, both Abraham and Ishmael never did the game of chance with Azlams." Then he entered the Ka`ba and said Takbir at its corners but did not offer the prayer in it}}
\hadithdefcmd{bukhari}{1602}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ ـ هُوَ ابْنُ زَيْدٍ ـ عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ فَقَالَ الْمُشْرِكُونَ إِنَّهُ يَقْدَمُ عَلَيْكُمْ، وَقَدْ وَهَنَهُمْ حُمَّى يَثْرِبَ‏.‏ فَأَمَرَهُمُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَرْمُلُوا الأَشْوَاطَ الثَّلاَثَةَ، وَأَنْ يَمْشُوا مَا بَيْنَ الرُّكْنَيْنِ، وَلَمْ يَمْنَعْهُ أَنْ يَأْمُرَهُمْ أَنْ يَرْمُلُوا الأَشْوَاطَ كُلَّهَا إِلاَّ الإِبْقَاءُ عَلَيْهِمْ‏.‏\hadithno{1602}\hadithtrans{Narrated Ibn `Abbas:When Allah's Messenger (ﷺ) and his companions came to Mecca, the pagans circulated the news that a group of people were coming to them and they had been weakened by the Fever of Yathrib (Medina). So the Prophet ordered his companions to do Ramal in the first three rounds of Tawaf of the Ka`ba and to walk between the two corners (The Black Stone and Yemenite corner). The Prophet (ﷺ) did not order them to do Ramal in all the rounds of Tawaf out of pity for them}}
\hadithdefcmd{bukhari}{1603}{حَدَّثَنَا أَصْبَغُ بْنُ الْفَرَجِ، أَخْبَرَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ يَقْدَمُ مَكَّةَ، إِذَا اسْتَلَمَ الرُّكْنَ الأَسْوَدَ أَوَّلَ مَا يَطُوفُ يَخُبُّ ثَلاَثَةَ أَطْوَافٍ مِنَ السَّبْعِ‏.‏\hadithno{1603}\hadithtrans{Narrated Salim that his father said:I saw Allah's Messenger (ﷺ) arriving at Mecca; he kissed the Black Stone Corner first while doing Tawaf and did ramal in the first three rounds of the seven rounds (of Tawaf)}}
\hadithdefcmd{bukhari}{1604}{حَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا سُرَيْجُ بْنُ النُّعْمَانِ، حَدَّثَنَا فُلَيْحٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَعَى النَّبِيُّ صلى الله عليه وسلم ثَلاَثَةَ أَشْوَاطٍ وَمَشَى أَرْبَعَةً فِي الْحَجِّ وَالْعُمْرَةِ‏.‏ تَابَعَهُ اللَّيْثُ قَالَ حَدَّثَنِي كَثِيرُ بْنُ فَرْقَدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1604}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) did Ramal in (first) three rounds (of Tawaf), and walked in the remaining four, in Hajj and Umra}}
\hadithdefcmd{bukhari}{1605}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ قَالَ لِلرُّكْنِ أَمَا وَاللَّهِ إِنِّي لأَعْلَمُ أَنَّكَ حَجَرٌ لاَ تَضُرُّ وَلاَ تَنْفَعُ، وَلَوْلاَ أَنِّي رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم اسْتَلَمَكَ مَا اسْتَلَمْتُكَ‏.‏ فَاسْتَلَمَهُ، ثُمَّ قَالَ فَمَا لَنَا وَلِلرَّمَلِ إِنَّمَا كُنَّا رَاءَيْنَا بِهِ الْمُشْرِكِينَ، وَقَدْ أَهْلَكَهُمُ اللَّهُ‏.‏ ثُمَّ قَالَ شَىْءٌ صَنَعَهُ النَّبِيُّ صلى الله عليه وسلم فَلاَ نُحِبُّ أَنْ نَتْرُكَهُ‏.‏\hadithno{1605}\hadithtrans{Narrated Zaid bin Aslam from his father who said:"`Umar bin Al-Khattab addressed the Corner (Black Stone) saying, 'By Allah! I know that you are a stone and can neither benefit nor harm. Had I not seen the Prophet (ﷺ) touching (and kissing) you, I would never have touched (and kissed) you.' Then he kissed it and said, 'There is no reason for us to do Ramal (in Tawaf) except that we wanted to show off before the pagans, and now Allah has destroyed them.' `Umar added, '(Nevertheless), the Prophet (ﷺ) did that and we do not want to leave it (i.e. Ramal)}}
\hadithdefcmd{bukhari}{1606}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ مَا تَرَكْتُ اسْتِلاَمَ هَذَيْنِ الرُّكْنَيْنِ فِي شِدَّةٍ وَلاَ رَخَاءٍ، مُنْذُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتَلِمُهُمَا‏.‏ قُلْتُ لِنَافِعٍ أَكَانَ ابْنُ عُمَرَ يَمْشِي بَيْنَ الرُّكْنَيْنِ قَالَ إِنَّمَا كَانَ يَمْشِي لِيَكُونَ أَيْسَرَ لاِسْتِلاَمِهِ‏.‏\hadithno{1606}\hadithtrans{Narrated Nafi`:Ibn `Umar. said, "I have never missed the touching of these two stones of Ka`ba (the Black Stone and the Yemenite Corner) both in the presence and the absence of crowds, since I saw the Prophet (ﷺ) touching them." I asked Nafi`: "Did Ibn `Umar use to walk between the two Corners?" Nafi` replied, "He used to walk in order that it might be easy for him to touch it (the Corner Stone)}}
\hadithdefcmd{bukhari}{1607}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَيَحْيَى بْنُ سُلَيْمَانَ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ طَافَ النَّبِيُّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ عَلَى بَعِيرٍ، يَسْتَلِمُ الرُّكْنَ بِمِحْجَنٍ‏.‏ تَابَعَهُ الدَّرَاوَرْدِيُّ عَنِ ابْنِ أَخِي الزُّهْرِيِّ عَنْ عَمِّهِ‏.‏\hadithno{1607}\hadithtrans{Narrated Ibn `Abbas.:In his Last Hajj the Prophet (ﷺ) performed Tawaf of the Ka`ba riding a camel and pointed a bent-headed stick towards the Corner (Black Stone)}}
\hadithdefcmd{bukhari}{1608}{وَقَالَ مُحَمَّدُ بْنُ بَكْرٍ أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، أَنَّهُ قَالَ وَمَنْ يَتَّقِي شَيْئًا مِنَ الْبَيْتِ، وَكَانَ مُعَاوِيَةُ يَسْتَلِمُ الأَرْكَانَ، فَقَالَ لَهُ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ إِنَّهُ لاَ يُسْتَلَمُ هَذَانِ الرُّكْنَانِ‏.‏ فَقَالَ لَيْسَ شَىْءٌ مِنَ الْبَيْتِ مَهْجُورًا، وَكَانَ ابْنُ الزُّبَيْرِ ـ رضى الله عنهما ـ يَسْتَلِمُهُنَّ كُلَّهُنَّ‏.‏\hadithno{1608}\hadithtrans{Abu Ash-Sha'tha said, "Who keeps away from some portion of the Ka'bah?" Mu'awiya used to touch the four corners of the Ka'bah, Ibn 'Abbas said to him, "These two corners (the one facing the Hijr) are not to be touched." Mu'awiya said, "Nothing is untouchable in the Ka'bah." And Ibn Az-Zubair used to touch all the corners of the Ka'bah}}
\hadithdefcmd{bukhari}{1609}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ ـ رضى الله عنهما ـ قَالَ لَمْ أَرَ النَّبِيَّ صلى الله عليه وسلم يَسْتَلِمُ مِنَ الْبَيْتِ إِلاَّ الرُّكْنَيْنِ الْيَمَانِيَيْنِ‏.‏\hadithno{1609}\hadithtrans{Narrated Salim bin `Abdullah that his father said:"I have not seen the Prophet (ﷺ) touching except the two Yemenite Corners (i.e. the ones facing Yemen)}}
\hadithdefcmd{bukhari}{1610}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا وَرْقَاءُ، أَخْبَرَنَا زَيْدُ بْنُ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ قَبَّلَ الْحَجَرَ وَقَالَ لَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبَّلَكَ مَا قَبَّلْتُكَ‏.‏\hadithno{1610}\hadithtrans{Narrated Zaid bin Aslam that his father said:"I saw `Umar bin Al-Khattab kissing the Black Stone and he then said, (to it) 'Had I not seen Allah's Apostle kissing you, (stone) I would not have kissed you}}
\hadithdefcmd{bukhari}{1611}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنِ الزُّبَيْرِ بْنِ عَرَبِيٍّ، قَالَ سَأَلَ رَجُلٌ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ اسْتِلاَمِ الْحَجَرِ،‏.‏ فَقَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُهُ وَيُقَبِّلُهُ‏.‏ قَالَ قُلْتُ أَرَأَيْتَ إِنْ زُحِمْتُ أَرَأَيْتَ إِنْ غُلِبْتُ قَالَ اجْعَلْ أَرَأَيْتَ بِالْيَمَنِ، رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَلِمُهُ وَيُقَبِّلُهُ‏.‏\hadithno{1611}\hadithtrans{Narrated Az-Zubair bin 'Arabi:A man asked Ibn `Umar about the touching of the Black Stone. Ibn `Umar said, "I saw Allah's Messenger (ﷺ) touching and kissing it." The questioner said, "But if there were a throng (much rush) round the Ka`ba and the people overpowered me, (what would I do?)" He replied angrily, "Stay in Yemen (as that man was from Yemen). I saw Allah's Messenger (ﷺ) touching and kissing it}}
\hadithdefcmd{bukhari}{1612}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ طَافَ النَّبِيُّ صلى الله عليه وسلم بِالْبَيْتِ عَلَى بَعِيرٍ، كُلَّمَا أَتَى عَلَى الرُّكْنِ أَشَارَ إِلَيْهِ‏.‏\hadithno{1612}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) performed Tawaf of the Ka`ba while riding a camel, and whenever he came in front of the Corner, he pointed towards it (with something)}}
\hadithdefcmd{bukhari}{1613}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ طَافَ النَّبِيُّ صلى الله عليه وسلم بِالْبَيْتِ عَلَى بَعِيرٍ، كُلَّمَا أَتَى الرُّكْنَ أَشَارَ إِلَيْهِ بِشَىْءٍ كَانَ عِنْدَهُ وَكَبَّرَ‏.‏ تَابَعَهُ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ خَالِدٍ الْحَذَّاءِ‏.‏\hadithno{1613}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) performed Tawaf of the Ka`ba riding a camel, and every time he came in front of the Corner (having the Black Stone), he pointed towards it with something he had with him and said Takbir}}
\hadithdefcmd{bukhari}{1615}{حَدَّثَنَا أَصْبَغُ، عَنِ ابْنِ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ،، ذَكَرْتُ لِعُرْوَةَ، قَالَ فَأَخْبَرَتْنِي عَائِشَةُ ـ رضى الله عنها ـ أَنَّ أَوَّلَ، شَىْءٍ بَدَأَ بِهِ حِينَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم أَنَّهُ تَوَضَّأَ، ثُمَّ طَافَ، ثُمَّ لَمْ تَكُنْ عُمْرَةً، ثُمَّ حَجَّ أَبُو بَكْرٍ وَعُمَرُ ـ رضى الله عنهما ـ مِثْلَهُ، ثُمَّ حَجَجْتُ مَعَ أَبِي الزُّبَيْرِ ـ رضى الله عنه ـ فَأَوَّلُ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ، ثُمَّ رَأَيْتُ الْمُهَاجِرِينَ وَالأَنْصَارَ يَفْعَلُونَهُ، وَقَدْ أَخْبَرَتْنِي أُمِّي أَنَّهَا أَهَلَّتْ هِيَ وَأُخْتُهَا وَالزُّبَيْرُ وَفُلاَنٌ وَفُلاَنٌ بِعُمْرَةٍ، فَلَمَّا مَسَحُوا الرُّكْنَ حَلُّوا‏.‏\hadithno{1615}\hadithtrans{Narrated `Urwa:`Aisha said, "The first thing the Prophet (ﷺ) did on reaching Mecca, was the ablution and then he performed Tawaf of the Ka`ba and that was not `Umra (alone), (but Hajj-al-Qiran). `Urwa added: Later Abu Bakr and `Umar did the same in their Hajj." And I performed the Hajj with my father Az-Zubair, and the first thing he did was Tawaf of the Ka`ba. Later I saw the Muhajirin (Emigrants) and the Ansar doing the same. My mother (Asma') told me that she, her sister (`Aisha), Az-Zubair and such and such persons assumed Ihram for `Umra, and after they passed their hands over the Black Stone Corner (of the Ka`ba) they finished the Ihram. (i.e. After doing Tawaf of the Ka`ba and Sa`i between Safa-Marwa)}}
\hadithdefcmd{bukhari}{1616}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، أَنَسٌ حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا طَافَ فِي الْحَجِّ أَوِ الْعُمْرَةِ أَوَّلَ مَا يَقْدَمُ سَعَى ثَلاَثَةَ أَطْوَافٍ، وَمَشَى أَرْبَعَةً، ثُمَّ سَجَدَ سَجْدَتَيْنِ، ثُمَّ يَطُوفُ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1616}\hadithtrans{Narrated `Abdullah bin `Umar:When Allah's Messenger (ﷺ) performed Tawaf of the Ka`ba for Hajj or `Umra, he used to do Ramal during the first three rounds, and in the last four rounds he used to walk; then after the Tawaf he used to offer two rak`at and then performed Tawaf between Safa and Marwa}}
\hadithdefcmd{bukhari}{1617}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا طَافَ بِالْبَيْتِ الطَّوَافَ الأَوَّلَ يَخُبُّ ثَلاَثَةَ أَطْوَافٍ، وَيَمْشِي أَرْبَعَةً، وَأَنَّهُ كَانَ يَسْعَى بَطْنَ الْمَسِيلِ إِذَا طَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1617}\hadithtrans{Narrated Ibn `Umar:When the Prophet (ﷺ) performed the Tawaf of the Ka`ba, he did Ramal during the first three rounds and in the last four rounds he used to walk and while doing Tawaf between Safa and Marwa, he used to run in the midst of the rain water passage}}
\hadithdefcmd{bukhari}{1618}{وَقَالَ لِي عَمْرُو بْنُ عَلِيٍّ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنَا قَالَ أَخْبَرَنِي عَطَاءٌ، إِذْ مَنَعَ ابْنُ هِشَامٍ النِّسَاءَ الطَّوَافَ مَعَ الرِّجَالِ قَالَ كَيْفَ يَمْنَعُهُنَّ، وَقَدْ طَافَ نِسَاءُ النَّبِيِّ صلى الله عليه وسلم مَعَ الرِّجَالِ قُلْتُ أَبَعْدَ الْحِجَابِ أَوْ قَبْلُ قَالَ إِي لَعَمْرِي لَقَدْ أَدْرَكْتُهُ بَعْدَ الْحِجَابِ‏.‏ قُلْتُ كَيْفَ يُخَالِطْنَ الرِّجَالَ قَالَ لَمْ يَكُنَّ يُخَالِطْنَ كَانَتْ عَائِشَةُ ـ رضى الله عنها ـ تَطُوفُ حَجْرَةً مِنَ الرِّجَالِ لاَ تُخَالِطُهُمْ، فَقَالَتِ امْرَأَةٌ انْطَلِقِي نَسْتَلِمْ يَا أُمَّ الْمُؤْمِنِينَ‏.‏ قَالَتْ ‏\{‏انْطَلِقِي‏\}‏ عَنْكِ‏.‏ وَأَبَتْ‏.‏ ‏\{‏وَكُنَّ‏\}‏ يَخْرُجْنَ مُتَنَكِّرَاتٍ بِاللَّيْلِ، فَيَطُفْنَ مَعَ الرِّجَالِ، وَلَكِنَّهُنَّ كُنَّ إِذَا دَخَلْنَ الْبَيْتَ قُمْنَ حَتَّى يَدْخُلْنَ وَأُخْرِجَ الرِّجَالُ، وَكُنْتُ آتِي عَائِشَةَ أَنَا وَعُبَيْدُ بْنُ عُمَيْرٍ وَهِيَ مُجَاوِرَةٌ فِي جَوْفِ ثَبِيرٍ‏.‏ قُلْتُ وَمَا حِجَابُهَا قَالَ هِيَ فِي قُبَّةٍ تُرْكِيَّةٍ لَهَا غِشَاءٌ، وَمَا بَيْنَنَا وَبَيْنَهَا غَيْرُ ذَلِكَ، وَرَأَيْتُ عَلَيْهَا دِرْعًا مُوَرَّدًا‏.‏\hadithno{1618}\hadithtrans{Ibn Juraij said, " `Ata informed us that when Ibn Hisham forbade women to perform Tawaf with men he said to him, 'How do you forbid them while the wives of the Prophet (ﷺ) used to perform Tawaf with the men?' I said, 'Was this before decreeing of the use of the veil or after it? `Ata took an oath and said, 'I saw it after the order of veil.' I said, 'How did they mix with the men?' `Ata said, 'The women never mixed with the men, and `A'ishah used to perform Tawaf separately and never mixed with men. Once it happened that `A'ishah was performing the Tawaf, and a woman said to her, 'O Mother of believers! Let us touch the Black stone.' `A'ishah said to her, 'Go yourself,' and she herself refused to do so. The wives of the Prophet (ﷺ) used to come out in night, in disguise and used to perform Tawaf with men. But whenever they intended to enter the Ka`bah, they would stay outside till the men had gone out. I and `Ubaid bin `Umair used to visit `A'ishah while she was residing at Jauf Thabir." I asked, "What was her veil?" `Ata said, "She was wearing an old Turkish veil, and that was the only thing (veil) which was screen between us and her. I saw a pink cover on her}}
\hadithdefcmd{bukhari}{1619}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي أَشْتَكِي‏.‏ فَقَالَ ‏"‏ طُوفِي مِنْ وَرَاءِ النَّاسِ، وَأَنْتِ رَاكِبَةٌ ‏"‏‏.‏ فَطُفْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حِينَئِذٍ يُصَلِّي إِلَى جَنْبِ الْبَيْتِ، وَهْوَ يَقْرَأُ ‏\{‏وَالطُّورِ * وَكِتَابٍ مَسْطُورٍ‏\}‏\hadithno{1619}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) I informed Allah's Messenger (ﷺ) that I was ill. So he said, "Perform the Tawaf while riding behind the people." I did so, and at that time the Prophet (ﷺ) was praying beside the Ka`ba and reciting Surat-at-Tur}}
\hadithdefcmd{bukhari}{1620}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي سُلَيْمَانُ الأَحْوَلُ، أَنَّ طَاوُسًا، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ وَهُوَ يَطُوفُ بِالْكَعْبَةِ بِإِنْسَانٍ رَبَطَ يَدَهُ إِلَى إِنْسَانٍ بِسَيْرٍ، أَوْ بِخَيْطٍ، أَوْ بِشَىْءٍ غَيْرِ ذَلِكَ، فَقَطَعَهُ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ، ثُمَّ قَالَ ‏ "‏ قُدْهُ بِيَدِهِ ‏"‏‏.‏\hadithno{1620}\hadithtrans{Narrated Ibn `Abbas:While the Prophet (ﷺ) was performing Tawaf of the Ka`ba, he passed by a person who had tied his hands to another person with a rope or string or something like that. The Prophet (ﷺ) cut it with his own hands and said, "Lead him by the hand}}
\hadithdefcmd{bukhari}{1621}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً يَطُوفُ بِالْكَعْبَةِ بِزِمَامٍ أَوْ غَيْرِهِ فَقَطَعَهُ‏.‏\hadithno{1621}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) saw a man performing Tawaf of the Ka`ba tied with a string or something else. So the Prophet cut that string}}
\hadithdefcmd{bukhari}{1622}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، قَالَ يُونُسُ قَالَ ابْنُ شِهَابٍ حَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ ـ رضى الله عنه ـ بَعَثَهُ فِي الْحَجَّةِ الَّتِي أَمَّرَهُ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ حَجَّةِ الْوَدَاعِ يَوْمَ النَّحْرِ فِي رَهْطٍ يُؤَذِّنُ فِي النَّاسِ ‏ "‏ أَلاَ لاَ يَحُجُّ بَعْدَ الْعَامِ مُشْرِكٌ، وَلاَ يَطُوفُ بِالْبَيْتِ عُرْيَانٌ ‏"‏‏.‏\hadithno{1622}\hadithtrans{Narrated Abu Huraira:In the year prior to the last Hajj of the Prophet (ﷺ) when Allah's Messenger (ﷺ) made Abu Bakr the leader of the pilgrims, the latter (Abu Bakr) sent me in the company of a group of people to make a public announcement: 'No pagan is allowed to perform Hajj after this year, and no naked person is allowed to perform Tawaf of the Ka`ba.' (See Hadith No. 365 Vol)}}
\hadithdefcmd{bukhari}{1624}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَأَلْنَا ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَيَقَعُ الرَّجُلُ عَلَى امْرَأَتِهِ فِي الْعُمْرَةِ قَبْلَ أَنْ يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا، ثُمَّ صَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، وَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ، وَقَالَ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏ قَالَ وَسَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ فَقَالَ لاَ يَقْرَبِ امْرَأَتَهُ حَتَّى يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1624}\hadithtrans{Narrated `Amr:We asked Ibn `Umar: "May a man have sexual relations with his wife during the Umra before performing Tawaf between Safa and Marwa?" He said, "Allah's Messenger (ﷺ) arrived (in Mecca) and circumambulated the Ka`ba seven times, then offered two rak`at behind Maqam Ibrahim (the station of Abraham), then performed Tawaf between Safa and Marwa." Ibn `Umar added, "Verily! In Allah's Apostle you have a good example." And I asked Jabir bin `Abdullah (the same question), and he replied, "You should not go near your wives (have sexual relations) till you have finished Tawaf between Safa and Marwa}}
\hadithdefcmd{bukhari}{1625}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا فُضَيْلٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي كُرَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ، فَطَافَ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ، وَلَمْ يَقْرَبِ الْكَعْبَةَ بَعْدَ طَوَافِهِ بِهَا حَتَّى رَجَعَ مِنْ عَرَفَةَ‏.‏\hadithno{1625}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) arrived at Mecca and performed Tawaf of the Ka`ba and Sa`i between Safa and Marwa, but he did not go near the Ka`ba after his Tawaf till he returned from `Arafat}}
\hadithdefcmd{bukhari}{1626}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ حَرْبٍ حَدَّثَنَا أَبُو مَرْوَانَ يَحْيَى بْنُ أَبِي زَكَرِيَّاءَ الْغَسَّانِيُّ عَنْ هِشَامٍ عَنْ عُرْوَةَ عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهْوَ بِمَكَّةَ، وَأَرَادَ الْخُرُوجَ، وَلَمْ تَكُنْ أُمُّ سَلَمَةَ طَافَتْ بِالْبَيْتِ وَأَرَادَتِ الْخُرُوجَ، فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتْ صَلاَةُ الصُّبْحِ فَطُوفِي عَلَى بَعِيرِكِ، وَالنَّاسُ يُصَلُّونَ ‏"‏‏.‏ فَفَعَلَتْ ذَلِكَ، فَلَمْ تُصَلِّ حَتَّى خَرَجَتْ‏.‏\hadithno{1626}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) I informed Allah's Messenger (ﷺ) (about my illness). (Through other sub-narrators, Um Salama narrated that when Allah's Messenger (ﷺ) was at Mecca and had just decided to leave (Mecca) while she had not yet done Tawaf of the Ka`ba (and after listening to her). The Prophet (ﷺ) said, "When the morning prayer is established, perform the Tawaf on your camel while the people are in prayer." So she did the same and did not offer the two rak`at of Tawaf until she came out of the Mosque}}
\hadithdefcmd{bukhari}{1627}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَدِمَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، ثُمَّ خَرَجَ إِلَى الصَّفَا، وَقَدْ قَالَ اللَّهُ تَعَالَى ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏\hadithno{1627}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) reached Mecca, circumambulated the Ka`ba seven times and then offered a two rak`at prayer behind Maqam Ibrahim. Then he went towards the Safa. Allah has said, "Verily, in Allah's Apostle you have a good example}}
\hadithdefcmd{bukhari}{1628}{حَدَّثَنَا الْحَسَنُ بْنُ عُمَرَ الْبَصْرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حَبِيبٍ، عَنْ عَطَاءٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ نَاسًا، طَافُوا بِالْبَيْتِ بَعْدَ صَلاَةِ الصُّبْحِ، ثُمَّ قَعَدُوا إِلَى الْمُذَكِّرِ، حَتَّى إِذَا طَلَعَتِ الشَّمْسُ قَامُوا يُصَلُّونَ فَقَالَتْ عَائِشَةُ ـ رضى الله عنها ـ قَعَدُوا حَتَّى إِذَا كَانَتِ السَّاعَةُ الَّتِي تُكْرَهُ فِيهَا الصَّلاَةُ قَامُوا يُصَلُّونَ‏.‏\hadithno{1628}\hadithtrans{Narrated `Urwa from Aisha:Some people performed Tawaf (of the Ka`ba) after the morning prayer and then sat to listen to a preacher till sunrise, and then they stood up for the prayer. Then Aisha commented, "Those people kept on sitting till it was the time in which the prayer is disliked and after that they stood up for the prayer}}
\hadithdefcmd{bukhari}{1629}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَنْهَى عَنِ الصَّلاَةِ عِنْدَ طُلُوعِ الشَّمْسِ وَعِنْدَ غُرُوبِهَا‏.‏\hadithno{1629}\hadithtrans{Narrated `Abdullah:I heard the Prophet (ﷺ) forbidding the offering of prayers at the time of sunrise and sunset}}
\hadithdefcmd{bukhari}{1631}{حَدَّثَنِي الْحَسَنُ بْنُ مُحَمَّدٍ ـ هُوَ الزَّعْفَرَانِيُّ ـ حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ، قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ ـ رضى الله عنهما ـ يَطُوفُ بَعْدَ الْفَجْرِ، وَيُصَلِّي رَكْعَتَيْنِ‏.‏ قَالَ عَبْدُ الْعَزِيزِ وَرَأَيْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ يُصَلِّي رَكْعَتَيْنِ بَعْدَ الْعَصْرِ، وَيُخْبِرُ أَنَّ عَائِشَةَ ـ رضى الله عنها ـ حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَدْخُلْ بَيْتَهَا إِلاَّ صَلاَّهُمَا‏.‏\hadithno{1631}\hadithtrans{Narrated Abida bin Humaid:`Abdul, `Aziz bin Rufa`i said, "I saw `Abdullah bin Az-Zubair performing Tawaf of the Ka`ba after the morning prayer then offering the two rak`at prayer." `Abdul `Aziz added, "I saw `Abdullah bin Az-Zubair offering a two rak`at prayer after the `Asr prayer." He informed me that Aisha told him that the Prophet (ﷺ) used to offer those two rak`at whenever he entered her house}}
\hadithdefcmd{bukhari}{1632}{حَدَّثَنِي إِسْحَاقُ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ بِالْبَيْتِ، وَهْوَ عَلَى بَعِيرٍ، كُلَّمَا أَتَى عَلَى الرُّكْنِ أَشَارَ إِلَيْهِ بِشَىْءٍ فِي يَدِهِ وَكَبَّرَ‏.‏\hadithno{1632}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) performed Tawaf (of the Ka`ba) riding a camel (at that time the Prophet (ﷺ) had a foot injury). Whenever he came to the Corner (having the Black Stone) he would point out towards it with a thing in his hand and say, "Allahu-Akbar}}
\hadithdefcmd{bukhari}{1633}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ قَالَتْ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي أَشْتَكِي‏.‏ فَقَالَ ‏ "‏ طُوفِي مِنْ وَرَاءِ النَّاسِ وَأَنْتِ رَاكِبَةٌ ‏"‏‏.‏ فَطُفْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي إِلَى جَنْبِ الْبَيْتِ، وَهْوَ يَقْرَأُ بِالطُّورِ وَكِتَابٍ مَسْطُورٍ‏.‏\hadithno{1633}\hadithtrans{Narrated Um Salama:I informed Allah's Messenger (ﷺ) that I was sick. He said, "Perform Tawaf (of the Ka`ba) while riding behind the people." So, I performed the Tawaf while Allah's Messenger (ﷺ) was offering the prayer beside the Ka`ba and was reciting Surat-at-Tur}}
\hadithdefcmd{bukhari}{1634}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ اسْتَأْذَنَ الْعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ ـ رضى الله عنه ـ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيتَ بِمَكَّةَ لَيَالِيَ مِنًى مِنْ أَجْلِ سِقَايَتِهِ، فَأَذِنَ لَهُ‏.‏\hadithno{1634}\hadithtrans{Narrated Ibn `Umar:Al `Abbas bin `Abdul-Muttalib asked the permission of Allah's Messenger (ﷺ) to let him stay in Mecca during the nights of Mina in order to provide the pilgrims with water to drink, so the Prophet (ﷺ) permitted him}}
\hadithdefcmd{bukhari}{1635}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا خَالِدٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَ إِلَى السِّقَايَةِ، فَاسْتَسْقَى، فَقَالَ الْعَبَّاسُ يَا فَضْلُ اذْهَبْ إِلَى أُمِّكَ، فَأْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم بِشَرَابٍ مِنْ عِنْدِهَا‏.‏ فَقَالَ ‏"‏ اسْقِنِي ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّهُمْ يَجْعَلُونَ أَيْدِيَهُمْ فِيهِ‏.‏ قَالَ ‏"‏ اسْقِنِي ‏"‏‏.‏ فَشَرِبَ مِنْهُ، ثُمَّ أَتَى زَمْزَمَ، وَهُمْ يَسْقُونَ وَيَعْمَلُونَ فِيهَا، فَقَالَ ‏"‏ اعْمَلُوا، فَإِنَّكُمْ عَلَى عَمَلٍ صَالِحٍ ـ ثُمَّ قَالَ ـ لَوْلاَ أَنْ تُغْلَبُوا لَنَزَلْتُ حَتَّى أَضَعَ الْحَبْلَ عَلَى هَذِهِ ‏"‏‏.‏ ـ يَعْنِي عَاتِقَهُ ـ وَأَشَارَ إِلَى عَاتِقِهِ‏.‏\hadithno{1635}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) came to the drinking place and asked for water. Al-Abbas said, "O Fadl! Go to your mother and bring water from her for Allah's Messenger (ﷺ) ." Allah's Messenger (ﷺ) said, "Give me water to drink." Al-Abbas said, "O Allah's Messenger (ﷺ)! The people put their hands in it." Allah's Messenger (ﷺ) again said, 'Give me water to drink. So, he drank from that water and then went to the Zamzam (well) and there the people were offering water to the others and working at it (drawing water from the well). The Prophet (ﷺ) then said to them, "Carry on! You are doing a good deed." Then he said, "Were I not afraid that other people would compete with you (in drawing water from Zamzam), I would certainly take the rope and put it over this (i.e. his shoulder) (to draw water)." On saying that the Prophet (ﷺ) pointed to his shoulder}}
\hadithdefcmd{bukhari}{1636}{وَقَالَ عَبْدَانُ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَنَسُ بْنُ مَالِكٍ كَانَ أَبُو ذَرٍّ ـ رضى الله عنه ـ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فُرِجَ سَقْفِي وَأَنَا بِمَكَّةَ، فَنَزَلَ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ فَفَرَجَ صَدْرِي، ثُمَّ غَسَلَهُ بِمَاءِ زَمْزَمَ، ثُمَّ جَاءَ بِطَسْتٍ مِنْ ذَهَبٍ مُمْتَلِئٍ حِكْمَةً وَإِيمَانًا، فَأَفْرَغَهَا فِي صَدْرِي، ثُمَّ أَطْبَقَهُ، ثُمَّ أَخَذَ بِيَدِي فَعَرَجَ إِلَى السَّمَاءِ الدُّنْيَا‏.‏ قَالَ جِبْرِيلُ لِخَازِنِ السَّمَاءِ الدُّنْيَا افْتَحْ‏.‏ قَالَ مَنْ هَذَا قَالَ جِبْرِيلُ ‏"‏‏.‏\hadithno{1636}\hadithtrans{Narrated Anas bin Malik that Abu Dhar said:Allah's Messenger (ﷺ) said, "The roof of my house was made open while I was at Makkah (on the night of Mi'raj) and Jibril descended. He opened up my chest and washed it with the water of Zamzam. Then he brought the golden tray full of Wisdom and Belief and poured it in my chest and then closed it. Then he took hold of my hand and ascended to the nearest heaven. Jibril told the gatekeeper of the nearest heaven to open the gate. The gatekeeper asked, "Who is it?" Jibril replied, "I am Jibril." (See Hadith No. 349 Vol)}}
\hadithdefcmd{bukhari}{1637}{حَدَّثَنَا مُحَمَّدٌ ـ هُوَ ابْنُ سَلاَمٍ ـ أَخْبَرَنَا الْفَزَارِيُّ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ حَدَّثَهُ قَالَ سَقَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ زَمْزَمَ فَشَرِبَ وَهُوَ قَائِمٌ‏.‏ قَالَ عَاصِمٌ فَحَلَفَ عِكْرِمَةُ مَا كَانَ يَوْمَئِذٍ إِلاَّ عَلَى بَعِيرٍ‏.‏\hadithno{1637}\hadithtrans{Narrated Ibn `Abbas:I gave Zamzam water to Allah's Messenger (ﷺ) and he drank it while standing. `Asim (a sub-narrator) said that `Ikrima took the oath that on that day the Prophet (ﷺ) had not been standing but riding a camel}}
\hadithdefcmd{bukhari}{1638}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ، فَأَهْلَلْنَا بِعُمْرَةٍ، ثُمَّ قَالَ ‏"‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهِلَّ بِالْحَجِّ وَالْعُمْرَةِ ثُمَّ لاَ يَحِلُّ حَتَّى يَحِلَّ مِنْهُمَا ‏"‏‏.‏ فَقَدِمْتُ مَكَّةَ، وَأَنَا حَائِضٌ، فَلَمَّا قَضَيْنَا حَجَّنَا أَرْسَلَنِي مَعَ عَبْدِ الرَّحْمَنِ إِلَى التَّنْعِيمِ، فَاعْتَمَرْتُ، فَقَالَ صلى الله عليه وسلم ‏"‏ هَذِهِ مَكَانَ عُمْرَتِكِ ‏"‏‏.‏ فَطَافَ الَّذِينَ أَهَلُّوا بِالْعُمْرَةِ، ثُمَّ حَلُّوا، ثُمَّ طَافُوا طَوَافًا آخَرَ، بَعْدَ أَنْ رَجَعُوا مِنْ مِنًى، وَأَمَّا الَّذِينَ جَمَعُوا بَيْنَ الْحَجِّ وَالْعُمْرَةِ طَافُوا طَوَافًا وَاحِدًا‏.‏\hadithno{1638}\hadithtrans{Narrated `Aisha:We set out with Allah's Messenger (ﷺ) in the year of his Last Hajj and we intended (the Ihram) for `Umra. Then the Prophet (ﷺ) said, "Whoever has a Hadi with him should assume Ihram for both Hajj and `Umra, and should not finish it till he performs both of them (Hajj and `Umra)." When we reached Mecca, I had my menses. When we had performed our Hajj, the Prophet (ﷺ) sent me with `Abdur-Rahman to Tan`im and I performed the `Umra. The Prophet (ﷺ) said, "This is in lieu of your missed `Umra." Those who had assumed Ihram for `Umra performed Tawaf (between Safa and Marwa) and then finished their Ihram. And then they performed another Tawaf (between Safa and Marwa) after returning from Mina. And those who had assumed Ihram for Hajj and `Umra together ( Hajj-Qiran ) performed only one Tawaf (between Safa and Marwa)}}
\hadithdefcmd{bukhari}{1639}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ دَخَلَ ابْنُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، وَظَهْرُهُ فِي الدَّارِ، فَقَالَ إِنِّي لاَ آمَنُ أَنْ يَكُونَ الْعَامَ بَيْنَ النَّاسِ قِتَالٌ، فَيَصُدُّوكَ عَنِ الْبَيْتِ، فَلَوْ أَقَمْتَ‏.‏ فَقَالَ قَدْ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَحَالَ كُفَّارُ قُرَيْشٍ بَيْنَهُ وَبَيْنَ الْبَيْتِ، فَإِنْ حِيلَ بَيْنِي وَبَيْنَهُ أَفْعَلُ كَمَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏ ثُمَّ قَالَ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ مَعَ عُمْرَتِي حَجًّا‏.‏ قَالَ ثُمَّ قَدِمَ فَطَافَ لَهُمَا طَوَافًا وَاحِدًا‏.‏\hadithno{1639}\hadithtrans{Narrated Nafi`:`Abdullah bin `Abdullah bin `Umar and his riding animal entered the house of Ibn `Umar. He (the son of Ibn `Umar) said, "I fear that this year a battle might take place between the people and you might be prevented from going to the Ka`ba. I suggest that you should stay here." Ibn `Umar said, "Once Allah's Messenger (ﷺ) set out for the pilgrimage, and the pagans of Quraish intervened between him and the Ka`ba. So, if the people intervened between me and the Ka`ba, I would do the same as Allah's Messenger (ﷺ) had done . . . "Verily, in Allah's Messenger (ﷺ) you have a good example." Then he added, "I make you a witness that I have intended to perform Hajj along with `Umra." After arriving at Mecca, Ibn `Umar performed one Tawaf only (between Safa and Marwa)}}
\hadithdefcmd{bukhari}{1640}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَرَادَ الْحَجَّ عَامَ نَزَلَ الْحَجَّاجُ بِابْنِ الزُّبَيْرِ‏.‏ فَقِيلَ لَهُ إِنَّ النَّاسَ كَائِنٌ بَيْنَهُمْ قِتَالٌ، وَإِنَّا نَخَافُ أَنْ يَصُدُّوكَ‏.‏ فَقَالَ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏ إِذًا أَصْنَعَ كَمَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم، إِنِّي أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ عُمْرَةً‏.‏ ثُمَّ خَرَجَ حَتَّى إِذَا كَانَ بِظَاهِرِ الْبَيْدَاءِ قَالَ مَا شَأْنُ الْحَجِّ وَالْعُمْرَةِ إِلاَّ وَاحِدٌ، أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ حَجًّا مَعَ عُمْرَتِي‏.‏ وَأَهْدَى هَدْيًا اشْتَرَاهُ بِقُدَيْدٍ وَلَمْ يَزِدْ عَلَى ذَلِكَ، فَلَمْ يَنْحَرْ، وَلَمْ يَحِلَّ مِنْ شَىْءٍ حَرُمَ مِنْهُ، وَلَمْ يَحْلِقْ وَلَمْ يُقَصِّرْ حَتَّى كَانَ يَوْمُ النَّحْرِ، فَنَحَرَ وَحَلَقَ، وَرَأَى أَنْ قَدْ قَضَى طَوَافَ الْحَجِّ، وَالْعُمْرَةِ بِطَوَافِهِ الأَوَّلِ‏.‏ وَقَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ كَذَلِكَ فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1640}\hadithtrans{Narrated Nafi`:Ibn `Umar intended to perform Hajj in the year when Al-Hajjaj attacked Ibn Az-Zubair. Somebody said to Ibn `Umar, "There is a danger of an impending war between them." Ibn `Umar said, "Verily, in Allah's Messenger (ﷺ) you have a good example. (And if it happened as you say) then I would do the same as Allah's Messenger (ﷺ) had done. I make you witness that I have decided to perform `Umra." Then he set out and when he reached Al-Baida', he said, "The ceremonies of both Hajj and `Umra are similar. I make you witness that I have made Hajj compulsory for me along with `Umra." He drove (to Mecca) a Hadi which he had bought from (a place called) Qudaid and did not do more than that. He did not slaughter the Hadi or finish his Ihram, or shave or cut short his hair till the day of slaughtering the sacrifices (10th Dhul-Hijja). Then he slaughtered his Hadi and shaved his head and considered the first Tawaf (of Safa and Marwa) as sufficient for Hajj and `Umra. Ibn `Umar said, "Allah's Messenger (ﷺ) did the same}}
\hadithdefcmd{bukhari}{1642}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ الْقُرَشِيِّ، أَنَّهُ سَأَلَ عُرْوَةَ بْنَ الزُّبَيْرِ فَقَالَ قَدْ حَجَّ النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَتْنِي عَائِشَةُ ـ رضى الله عنها ـ أَنَّهُ أَوَّلُ شَىْءٍ بَدَأَ بِهِ حِينَ قَدِمَ أَنَّهُ تَوَضَّأَ ثُمَّ طَافَ بِالْبَيْتِ ثُمَّ لَمْ تَكُنْ عُمْرَةً، ثُمَّ حَجَّ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَكَانَ أَوَّلَ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ ثُمَّ لَمْ تَكُنْ عُمْرَةً‏.‏ ثُمَّ عُمَرُ ـ رضى الله عنه ـ مِثْلُ ذَلِكَ‏.‏ ثُمَّ حَجَّ عُثْمَانُ ـ رضى الله عنه ـ فَرَأَيْتُهُ أَوَّلُ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ ثُمَّ لَمْ تَكُنْ عُمْرَةٌ، ثُمَّ مُعَاوِيَةُ وَعَبْدُ اللَّهِ بْنُ عُمَرَ، ثُمَّ حَجَجْتُ مَعَ أَبِي الزُّبَيْرِ بْنِ الْعَوَّامِ، فَكَانَ أَوَّلَ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ، ثُمَّ لَمْ تَكُنْ عُمْرَةٌ، ثُمَّ رَأَيْتُ الْمُهَاجِرِينَ وَالأَنْصَارَ يَفْعَلُونَ ذَلِكَ، ثُمَّ لَمْ تَكُنْ عُمْرَةٌ، ثُمَّ آخِرُ مَنْ رَأَيْتُ فَعَلَ ذَلِكَ ابْنُ عُمَرَ ثُمَّ لَمْ يَنْقُضْهَا عُمْرَةً، وَهَذَا ابْنُ عُمَرَ عِنْدَهُمْ فَلاَ يَسْأَلُونَهُ، وَلاَ أَحَدٌ مِمَّنْ مَضَى، مَا كَانُوا يَبْدَءُونَ بِشَىْءٍ حَتَّى يَضَعُوا أَقْدَامَهُمْ مِنَ الطَّوَافِ بِالْبَيْتِ، ثُمَّ لاَ يَحِلُّونَ، وَقَدْ رَأَيْتُ أُمِّي وَخَالَتِي، حِينَ تَقْدَمَانِ لاَ تَبْتَدِئَانِ بِشَىْءٍ أَوَّلَ مِنَ الْبَيْتِ، تَطُوفَانِ بِهِ، ثُمَّ لاَ تَحِلاَّنِ‏.‏ وَقَدْ أَخْبَرَتْنِي أُمِّي، أَنَّهَا أَهَلَّتْ هِيَ وَأُخْتُهَا وَالزُّبَيْرُ وَفُلاَنٌ وَفُلاَنٌ بِعُمْرَةٍ، فَلَمَّا مَسَحُوا الرُّكْنَ حَلُّوا‏.‏\hadithno{1642}\hadithtrans{Narrated Muhammad bin `Abdur-Rahman bin Nawfal Al-Qurashi:I asked `Urwa bin Az-Zubair (regarding the Hajj of the Prophet (ﷺ) ). `Urwa replied, "Aisha narrated, 'When the Prophet (ﷺ) reached Mecca, the first thing he started with was the ablution, then he performed Tawaf of the Ka`ba and his intention was not `Umra alone (but Hajj and `Umra together).' " Later Abu Bakr performed the Hajj and the first thing he started with was Tawaf of the Ka`ba and it was not `Umra alone (but Hajj and `Umra together). And then `Umar did the same. Then `Uthman performed the Hajj and the first thing he started with was Tawaf of the Ka`ba and it was not `Umra alone. And then Muawiya and `Abdullah bin `Umar did the same. I performed Hajj with Ibn Az-Zubair and the first thing he started with was Tawaf of the Ka`ba and it was not `Umra alone, (but Hajj and `Umra together). Then I saw the Muhajirin (Emigrants) and Ansar doing the same and it was not `Umra alone. And the last person I saw doing the same was Ibn `Umar, and he did not do another `Umra after finishing the first. Now here is Ibn `Umar present amongst the people! They neither ask him nor anyone of the previous ones. And all these people, on entering Mecca, would not start with anything unless they had performed Tawaf of the Ka`ba, and would not finish their Ihram. And no doubt, I saw my mother and my aunt, on entering Mecca doing nothing before performing Tawaf of the Ka`ba, and they would not finish their Ihram. And my mother informed me that she, her sister, Az-Zubair and such and such persons had assumed Ihram for `Umra and after passing their hands over the Corner (the Black Stone) (i.e. finishing their Umra) they finished their Ihram}}
\hadithdefcmd{bukhari}{1643}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ عُرْوَةُ سَأَلْتُ عَائِشَةَ ـ رضى الله عنها ـ فَقُلْتُ لَهَا أَرَأَيْتِ قَوْلَ اللَّهِ تَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏ فَوَاللَّهِ مَا عَلَى أَحَدٍ جُنَاحٌ أَنْ لاَ يَطُوفَ بِالصَّفَا وَالْمَرْوَةِ‏.‏ قَالَتْ بِئْسَ مَا قُلْتَ يَا ابْنَ أُخْتِي إِنَّ هَذِهِ لَوْ كَانَتْ كَمَا أَوَّلْتَهَا عَلَيْهِ كَانَتْ لاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَتَطَوَّفَ بِهِمَا، وَلَكِنَّهَا أُنْزِلَتْ فِي الأَنْصَارِ، كَانُوا قَبْلَ أَنْ يُسْلِمُوا يُهِلُّونَ لِمَنَاةَ الطَّاغِيَةِ الَّتِي كَانُوا يَعْبُدُونَهَا عِنْدَ الْمُشَلَّلِ، فَكَانَ مَنْ أَهَلَّ يَتَحَرَّجُ أَنْ يَطُوفَ بِالصَّفَا وَالْمَرْوَةِ، فَلَمَّا أَسْلَمُوا سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ قَالُوا يَا رَسُولَ اللَّهِ، إِنَّا كُنَّا نَتَحَرَّجُ أَنْ نَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ الآيَةَ‏.‏ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ وَقَدْ سَنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم الطَّوَافَ بَيْنَهُمَا، فَلَيْسَ لأَحَدٍ أَنْ يَتْرُكَ الطَّوَافَ بَيْنَهُمَا‏.‏ ثُمَّ أَخْبَرْتُ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، فَقَالَ إِنَّ هَذَا لَعِلْمٌ مَا كُنْتُ سَمِعْتُهُ، وَلَقَدْ سَمِعْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ، يَذْكُرُونَ أَنَّ النَّاسَ إِلاَّ مَنْ ذَكَرَتْ عَائِشَةُ مِمَّنْ كَانَ يُهِلُّ بِمَنَاةَ، كَانُوا يَطُوفُونَ كُلُّهُمْ بِالصَّفَا وَالْمَرْوَةِ، فَلَمَّا ذَكَرَ اللَّهُ تَعَالَى الطَّوَافَ بِالْبَيْتِ، وَلَمْ يَذْكُرِ الصَّفَا وَالْمَرْوَةَ فِي الْقُرْآنِ قَالُوا يَا رَسُولَ اللَّهِ كُنَّا نَطُوفُ بِالصَّفَا وَالْمَرْوَةِ، وَإِنَّ اللَّهَ أَنْزَلَ الطَّوَافَ بِالْبَيْتِ، فَلَمْ يَذْكُرِ الصَّفَا فَهَلْ عَلَيْنَا مِنْ حَرَجٍ أَنْ نَطَّوَّفَ بِالصَّفَا وَالْمَرْوَةِ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ‏\}‏ الآيَةَ‏.‏ قَالَ أَبُو بَكْرٍ فَأَسْمَعُ هَذِهِ الآيَةَ نَزَلَتْ فِي الْفَرِيقَيْنِ كِلَيْهِمَا فِي الَّذِينَ كَانُوا يَتَحَرَّجُونَ أَنْ يَطُوفُوا بِالْجَاهِلِيَّةِ بِالصَّفَا وَالْمَرْوَةِ، وَالَّذِينَ يَطُوفُونَ ثُمَّ تَحَرَّجُوا أَنْ يَطُوفُوا بِهِمَا فِي الإِسْلاَمِ مِنْ أَجْلِ أَنَّ اللَّهَ تَعَالَى أَمَرَ بِالطَّوَافِ بِالْبَيْتِ، وَلَمْ يَذْكُرِ الصَّفَا حَتَّى ذَكَرَ ذَلِكَ بَعْدَ مَا ذَكَرَ الطَّوَافَ بِالْبَيْتِ‏.‏\hadithno{1643}\hadithtrans{Narrated `Urwa:I asked `Aisha : "How do you interpret the statement of Allah,. : Verily! (the mountains) As-Safa and Al-Marwa are among the symbols of Allah, and whoever performs the Hajj to the Ka`ba or performs `Umra, it is not harmful for him to perform Tawaf between them (Safa and Marwa.) (2.158). By Allah! (it is evident from this revelation) there is no harm if one does not perform Tawaf between Safa and Marwa." `Aisha said, "O, my nephew! Your interpretation is not true. Had this interpretation of yours been correct, the statement of Allah should have been, 'It is not harmful for him if he does not perform Tawaf between them.' But in fact, this divine inspiration was revealed concerning the Ansar who used to assume Ihram for worshipping an idol called "Manat" which they used to worship at a place called Al-Mushallal before they embraced Islam, and whoever assumed Ihram (for the idol), would consider it not right to perform Tawaf between Safa and Marwa. When they embraced Islam, they asked Allah's Messenger (ﷺ) regarding it, saying, "O Allah's Apostle! We used to refrain from Tawaf between Safa and Marwa." So Allah revealed: 'Verily; (the mountains) As-Safa and Al-Marwa are among the symbols of Allah.' " Aisha added, "Surely, Allah's Apostle set the tradition of Tawaf between Safa and Marwa, so nobody is allowed to omit the Tawaf between them." Later on I (`Urwa) told Abu Bakr bin `Abdur-Rahman (of `Aisha's narration) and he said, 'I have not heard of such information, but I heard learned men saying that all the people, except those whom `Aisha mentioned and who used to assume Ihram for the sake of Manat, used to perform Tawaf between Safa and Marwa. When Allah referred to the Tawaf of the Ka`ba and did not mention Safa and Marwa in the Qur'an, the people asked, 'O Allah's Messenger (ﷺ)! We used to perform Tawaf between Safa and Marwa and Allah has revealed (the verses concerning) Tawaf of the Ka`ba and has not mentioned Safa and Marwa. Is there any harm if we perform Tawaf between Safa and Marwa?' So Allah revealed: "Verily As-Safa and Al- Marwa are among the symbols of Allah." Abu Bakr said, "It seems that this verse was revealed concerning the two groups, those who used to refrain from Tawaf between Safa and Marwa in the Pre- Islamic Period of ignorance and those who used to perform the Tawaf then, and after embracing Islam they refrained from the Tawaf between them as Allah had enjoined Tawaf of the Ka`ba and did not mention Tawaf (of Safa and Marwa) till later after mentioning the Tawaf of the Ka`ba}}
\hadithdefcmd{bukhari}{1644}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا طَافَ الطَّوَافَ الأَوَّلَ خَبَّ ثَلاَثًا وَمَشَى أَرْبَعًا، وَكَانَ يَسْعَى بَطْنَ الْمَسِيلِ إِذَا طَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏ فَقُلْتُ لِنَافِعٍ أَكَانَ عَبْدُ اللَّهِ يَمْشِي إِذَا بَلَغَ الرُّكْنَ الْيَمَانِيَ قَالَ لاَ‏.‏ إِلاَّ أَنْ يُزَاحَمَ عَلَى الرُّكْنِ فَإِنَّهُ كَانَ لاَ يَدَعُهُ حَتَّى يَسْتَلِمَهُ‏.‏\hadithno{1644}\hadithtrans{Narrated Nafi`:Ibn `Umar said, "When Allah's Messenger (ﷺ) performed the first Tawaf he did Ramal in the first three rounds and then walked in the remaining four rounds (of Tawaf of the Ka`ba), where as in performing Tawaf between Safa and Marwa he used to run in the midst of the rainwater passage," I asked Nafi`, "Did `Abdullah (bin `Umar) use to walk steadily on reaching the Yemenite Corner?" He replied, "No, unless people were crowded at the Corner; otherwise he would not leave it without touching it}}
\hadithdefcmd{bukhari}{1646}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَأَلْنَا ابْنَ عُمَرَ ـ رضى الله عنه ـ عَنْ رَجُلٍ، طَافَ بِالْبَيْتِ فِي عُمْرَةٍ، وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ أَيَأْتِي امْرَأَتَهُ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا، وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، فَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ سَبْعًا ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏ وَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ فَقَالَ لاَ يَقْرَبَنَّهَا حَتَّى يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1646}\hadithtrans{Narrated `Amr bin Dinar:We asked Ibn `Umar whether a man who, while performing `Umra, had performed Tawaf of the Ka`ba; and had not yet performed Tawaf between Safa and Marwa, could have sexual relation with his wife, Ibn `Umar replied "The Prophet (ﷺ) reached Mecca and performed the seven rounds (of Tawaf) of the Ka`ba and then offered a two-rak`at prayer behind Maqam Ibrahim and then performed the seven rounds (of Tawaf) between Safa and Marwa." He added, "Verily! In Allah's Messenger (ﷺ) you have a good example." We asked Jabir bin `Abdullah (the same question) and he said, "He (that man) should not come near (his wife) till he has completed Tawaf between Safa and Marwa}}
\hadithdefcmd{bukhari}{1647}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ، فَطَافَ بِالْبَيْتِ، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ سَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ، ثُمَّ تَلاَ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏\hadithno{1647}\hadithtrans{Narrated `Amr bin Dinar:I heard Ibn `Umar saying, "The Prophet (ﷺ) arrived at Mecca and performed Tawaf of the Ka`ba and then offered a two-rak`at prayer and then performed Tawaf between Safa and Marwa." Ibn `Umar then recited (the verse): "Verily! In Allah's Messenger (ﷺ) you have a good example}}
\hadithdefcmd{bukhari}{1648}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عَاصِمٌ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَكُنْتُمْ تَكْرَهُونَ السَّعْىَ بَيْنَ الصَّفَا وَالْمَرْوَةِ قَالَ نَعَمْ‏.‏ لأَنَّهَا كَانَتْ مِنْ شَعَائِرِ الْجَاهِلِيَّةِ، حَتَّى أَنْزَلَ اللَّهُ ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏‏.‏\hadithno{1648}\hadithtrans{Narrated `Asim:I asked Anas bin Malik: "Did you use to dislike to perform Tawaf between Safa and Marwa?" He said, "Yes, as it was of the ceremonies of the days of the Pre-Islamic period of ignorance, till Allah revealed: 'Verily! (The two mountains) As-Safa and Al-Marwa are among the symbols of Allah. It is therefore no sin for him who performs the pilgrimage to the Ka`ba, or performs `Umra, to perform Tawaf between them}}
\hadithdefcmd{bukhari}{1649}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ إِنَّمَا سَعَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ لِيُرِيَ الْمُشْرِكِينَ قُوَّتَهُ‏.‏ زَادَ الْحُمَيْدِيُّ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، سَمِعْتُ عَطَاءً، عَنِ ابْنِ عَبَّاسٍ، مِثْلَهُ‏.‏\hadithno{1649}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) performed Tawaf of the Ka`ba and the Sa`i of Safa and Marwa so as to show his strength to the pagans}}
\hadithdefcmd{bukhari}{1650}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ قَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ، وَلَمْ أَطُفْ بِالْبَيْتِ، وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ، قَالَتْ فَشَكَوْتُ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ افْعَلِي كَمَا يَفْعَلُ الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ حَتَّى تَطْهُرِي ‏"‏‏.‏\hadithno{1650}\hadithtrans{Narrated `Aisha:I was menstruating when I reached Mecca. So, I neither performed Tawaf of the Ka`ba, nor the Tawaf between Safa and Marwa. Then I informed Allah's Messenger (ﷺ) about it. He replied, "Perform all the ceremonies of Hajj like the other pilgrims, but do not perform Tawaf of the Ka`ba till you get clean (from your menses)}}
\hadithdefcmd{bukhari}{1651}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ،‏.‏ قَالَ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ أَهَلَّ النَّبِيُّ صلى الله عليه وسلم هُوَ وَأَصْحَابُهُ بِالْحَجِّ، وَلَيْسَ مَعَ أَحَدٍ مِنْهُمْ هَدْىٌ، غَيْرَ النَّبِيِّ صلى الله عليه وسلم وَطَلْحَةَ، وَقَدِمَ عَلِيٌّ مِنَ الْيَمَنِ، وَمَعَهُ هَدْىٌ فَقَالَ أَهْلَلْتُ بِمَا أَهَلَّ بِهِ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَصْحَابَهُ أَنْ يَجْعَلُوهَا عُمْرَةً، وَيَطُوفُوا، ثُمَّ يُقَصِّرُوا وَيَحِلُّوا، إِلاَّ مَنْ كَانَ مَعَهُ الْهَدْىُ، فَقَالُوا نَنْطَلِقُ إِلَى مِنًى، وَذَكَرُ أَحَدِنَا يَقْطُرُ، فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ، وَلَوْلاَ أَنَّ مَعِي الْهَدْىَ لأَحْلَلْتُ ‏"‏‏.‏ وَحَاضَتْ عَائِشَةُ ـ رضى الله عنها ـ فَنَسَكَتِ الْمَنَاسِكَ كُلَّهَا، غَيْرَ أَنَّهَا لَمْ تَطُفْ بِالْبَيْتِ، فَلَمَّا طَهُرَتْ طَافَتْ بِالْبَيْتِ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ تَنْطَلِقُونَ بِحَجَّةٍ وَعُمْرَةٍ، وَأَنْطَلِقُ بِحَجٍّ فَأَمَرَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ أَنْ يَخْرُجَ مَعَهَا إِلَى التَّنْعِيمِ، فَاعْتَمَرَتْ بَعْدَ الْحَجِّ‏.‏\hadithno{1651}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) and his companions assumed Ihram for Hajj and none except the Prophet (ﷺ) and Talha had the Hadi (sacrifice) with them. `Ali arrived from Yemen and had a Hadi with him. `Ali said, "I have assumed Ihram for what the Prophet (ﷺ) has done." The Prophet (ﷺ) ordered his companions to perform the `Umra with the Ihram which they had assumed, and after finishing Tawaf (of Ka`ba, Safa and Marwa) to cut short their hair, and to finish their Ihram except those who had Hadi with them. They (the people) said, "How can we proceed to Mina (for Hajj) after having sexual relations with our wives?" When that news reached the Prophet (ﷺ) he said, "If I had formerly known what I came to know lately, I would not have brought the Hadi with me. Had there been no Hadi with me, I would have finished the state of Ihram." `Aisha got her menses, so she performed all the ceremonies of Hajj except Tawaf of the Ka`ba, and when she got clean (from her menses), she performed Tawaf of the Ka`ba. She said, "O Allah's Messenger (ﷺ)! (All of you) are returning with the Hajj and `Umra, but I am returning after performing Hajj only." So the Prophet (ﷺ) ordered `Abdur-Rahman bin Abu Bakr to accompany her to Tan`im and thus she performed the `Umra after the Hajj}}
\hadithdefcmd{bukhari}{1652}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، قَالَتْ كُنَّا نَمْنَعُ عَوَاتِقَنَا أَنْ يَخْرُجْنَ، فَقَدِمَتِ امْرَأَةٌ فَنَزَلَتْ قَصْرَ بَنِي خَلَفٍ، فَحَدَّثَتْ أَنْ أُخْتَهَا كَانَتْ تَحْتَ رَجُلٍ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَدْ غَزَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثِنْتَىْ عَشْرَةَ غَزْوَةً، وَكَانَتْ أُخْتِي مَعَهُ فِي سِتِّ غَزَوَاتٍ، قَالَتْ كُنَّا نُدَاوِي الْكَلْمَى وَنَقُومُ عَلَى الْمَرْضَى‏.‏ فَسَأَلَتْ أُخْتِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ هَلْ عَلَى إِحْدَانَا بَأْسٌ إِنْ لَمْ يَكُنْ لَهَا جِلْبَابٌ أَنْ لاَ تَخْرُجَ قَالَ ‏"‏ لِتُلْبِسْهَا صَاحِبَتُهَا مِنْ جِلْبَابِهَا، وَلْتَشْهَدِ الْخَيْرَ، وَدَعْوَةَ الْمُؤْمِنِينَ ‏"‏‏.‏ فَلَمَّا قَدِمَتْ أُمُّ عَطِيَّةَ ـ رضى الله عنها ـ سَأَلْنَهَا ـ أَوْ قَالَتْ سَأَلْنَاهَا ـ فَقَالَتْ وَكَانَتْ لاَ تَذْكُرُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِلاَّ قَالَتْ بِأَبِي‏.‏ فَقُلْنَا أَسَمِعْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ كَذَا وَكَذَا قَالَتْ نَعَمْ بِأَبِي‏.‏ فَقَالَ ‏"‏ لِتَخْرُجِ الْعَوَاتِقُ ذَوَاتُ الْخُدُورِ ـ أَوِ الْعَوَاتِقُ وَذَوَاتُ الْخُدُورِ ـ وَالْحُيَّضُ، فَيَشْهَدْنَ الْخَيْرَ، وَدَعْوَةَ الْمُسْلِمِينَ، وَيَعْتَزِلُ الْحُيَّضُ الْمُصَلَّى ‏"‏‏.‏ فَقُلْتُ الْحَائِضُ‏.‏ فَقَالَتْ أَوَ لَيْسَ تَشْهَدُ عَرَفَةَ، وَتَشْهَدُ كَذَا وَتَشْهَدُ كَذَا\hadithno{1652}\hadithtrans{Narrated Hafsa:(On `Id) We used to forbid our virgins to go out (for `Id prayer). A lady came and stayed at the fortress of Bani Khalaf. She mentioned that her sister was married to one of the companions of Allah's Messenger (ﷺ) who participated in twelve Ghazawats along with Allah's Messenger (ﷺ) and her sister was with him in six of them. She said, "We used to dress the wounded and look after the patients." She (her sister) asked Allah's Messenger (ﷺ) , "Is there any harm for a woman to stay at home if she doesn't have a veil?" He said, "She should cover herself with the veil of her companion and she should take part in the good deeds and in the religious gatherings of the believers." When Um 'Atiyya came, I asked her. "Did you hear anything about that?" Um 'Atiyya said, "Bi Abi" and she never mentioned the name of Allah's Messenger (ﷺ) without saying "Bi Abi" (i.e. 'Let my father be sacrificed for you'). We asked her, "Have you heard Allah's Messenger (ﷺ) saying so and so (about women)?" She replied in the affirmative and said, "Let my father be sacrificed for him. He told us that unmarried mature virgins who stay often screened or unmarried young virgins and mature girls who stay often screened should come out and take part in the good deeds and in the religious gatherings of the believers. But the menstruating women should keep away from the Musalla (praying place)." I asked her, "The menstruating women?" She replied, "Don't they present themselves at `Arafat and at such and such places?}}
\hadithdefcmd{bukhari}{1653}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قُلْتُ أَخْبِرْنِي بِشَىْءٍ، عَقَلْتَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْنَ صَلَّى الظُّهْرَ وَالْعَصْرَ يَوْمَ التَّرْوِيَةِ قَالَ بِمِنًى‏.‏ قُلْتُ فَأَيْنَ صَلَّى الْعَصْرَ يَوْمَ النَّفْرِ قَالَ بِالأَبْطَحِ‏.‏ ثُمَّ قَالَ افْعَلْ كَمَا يَفْعَلُ أُمَرَاؤُكَ‏.‏\hadithno{1653}\hadithtrans{Narrated `Abdul `Aziz bin Rufai:I asked Anas bin Malik, "Tell me what you remember from Allah's Messenger (ﷺ) (regarding these questions): Where did he offer the Zuhr and `Asr prayers on the day of Tarwiya (8th day of Dhul-Hijja)?" He replied, "(He offered these prayers) at Mina." I asked, "Where did he offer the `Asr prayer on the day of Nafr (i.e. departure from Mina on the 12th or 13th of Dhul-Hijja)?" He replied, "At Al-Abtah," and then added, "You should do as your chiefs do}}
\hadithdefcmd{bukhari}{1654}{حَدَّثَنَا عَلِيٌّ، سَمِعَ أَبَا بَكْرِ بْنَ عَيَّاشٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، لَقِيتُ أَنَسًا‏.‏ وَحَدَّثَنِي إِسْمَاعِيلُ بْنُ أَبَانَ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ عَبْدِ الْعَزِيزِ، قَالَ خَرَجْتُ إِلَى مِنًى يَوْمَ التَّرْوِيَةِ فَلَقِيتُ أَنَسًا ـ رضى الله عنه ـ ذَاهِبًا عَلَى حِمَارٍ فَقُلْتُ أَيْنَ صَلَّى النَّبِيُّ صلى الله عليه وسلم هَذَا الْيَوْمَ الظُّهْرَ فَقَالَ انْظُرْ حَيْثُ يُصَلِّي أُمَرَاؤُكَ فَصَلِّ‏.‏\hadithno{1654}\hadithtrans{Narrated `Abdul `Aziz:I went out to Mina on the day of Tarwiya and met Anas going on a donkey. I asked him, "Where did the Prophet (ﷺ) offer the Zuhr prayer on this day?" Anas replied, "See where your chiefs pray and pray similarly}}
\hadithdefcmd{bukhari}{1655}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ، وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ صَدْرًا مِنْ خِلاَفَتِهِ‏.‏\hadithno{1655}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) offered a two-rak`at prayer at Mina. Abu Bakr, `Umar and `Uthman, (during the early years of his caliphate) followed the same practice}}
\hadithdefcmd{bukhari}{1656}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ الْهَمْدَانِيِّ، عَنْ حَارِثَةَ بْنِ وَهْبٍ الْخُزَاعِيِّ ـ رضى الله عنه ـ قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ أَكْثَرُ مَا كُنَّا قَطُّ وَآمَنُهُ بِمِنًى رَكْعَتَيْنِ‏.‏\hadithno{1656}\hadithtrans{Narrated Haritha bin Wahab Al-Khuza`i:The Prophet (ﷺ) led us in a two-rak`at prayer at Mina although our number was more than ever and we were in better security than ever}}
\hadithdefcmd{bukhari}{1657}{حَدَّثَنَا قَبِيصَةُ بْنُ عُقْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم رَكْعَتَيْنِ، وَمَعَ أَبِي بَكْرٍ ـ رضى الله عنه ـ رَكْعَتَيْنِ وَمَعَ عُمَرَ ـ رضى الله عنه ـ رَكْعَتَيْنِ، ثُمَّ تَفَرَّقَتْ بِكُمُ الطُّرُقُ، فَيَا لَيْتَ حَظِّي مِنْ أَرْبَعٍ رَكْعَتَانِ مُتَقَبَّلَتَانِ‏.‏\hadithno{1657}\hadithtrans{Narrated `Abdullah bin Mas`ud:I offered (only a) two rak`at prayer with the Prophet (at Mina), and similarly with Abu Bakr and with `Umar, and then you differed in opinions. Wish that I would be lucky enough to have two of the four rak`at accepted (by Allah)}}
\hadithdefcmd{bukhari}{1658}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا سَالِمٌ، قَالَ سَمِعْتُ عُمَيْرًا، مَوْلَى أُمِّ الْفَضْلِ عَنْ أُمِّ الْفَضْلِ، شَكَّ النَّاسُ يَوْمَ عَرَفَةَ فِي صَوْمِ النَّبِيِّ صلى الله عليه وسلم فَبَعَثْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم بِشَرَابٍ فَشَرِبَهُ‏.‏\hadithno{1658}\hadithtrans{Narrated Um Al-Fadl:The people doubted whether the Prophet (ﷺ) was observing the fast on the Day of `Arafat, so I sent something for him to drink and he drank it}}
\hadithdefcmd{bukhari}{1659}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الثَّقَفِيِّ، أَنَّهُ سَأَلَ أَنَسَ بْنَ مَالِكٍ وَهُمَا غَادِيَانِ مِنْ مِنًى إِلَى عَرَفَةَ كَيْفَ كُنْتُمْ تَصْنَعُونَ فِي هَذَا الْيَوْمِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ كَانَ يُهِلُّ مِنَّا الْمُهِلُّ فَلاَ يُنْكِرُ عَلَيْهِ، وَيُكَبِّرُ مِنَّا الْمُكَبِّرُ فَلاَ يُنْكِرُ عَلَيْهِ‏.‏\hadithno{1659}\hadithtrans{Narrated Muhammad bin Abu Bakr Al-Thaqafi:I asked Anas bin Malik while we were proceeding from Mina to `Arafat, "What did you use to do on this day when you were with Allah's Messenger (ﷺ) ?" Anas said, "Some of us used to recite Talbiya and nobody objected to that, and others used to recite Takbir and nobody objected to that}}
\hadithdefcmd{bukhari}{1660}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، قَالَ كَتَبَ عَبْدُ الْمَلِكِ إِلَى الْحَجَّاجِ أَنْ لاَ يُخَالِفَ ابْنَ عُمَرَ فِي الْحَجِّ، فَجَاءَ ابْنُ عُمَرَ ـ رضى الله عنه ـ وَأَنَا مَعَهُ يَوْمَ عَرَفَةَ حِينَ زَالَتِ الشَّمْسُ، فَصَاحَ عِنْدَ سُرَادِقِ الْحَجَّاجِ، فَخَرَجَ وَعَلَيْهِ مِلْحَفَةٌ مُعَصْفَرَةٌ فَقَالَ مَا لَكَ يَا أَبَا عَبْدِ الرَّحْمَنِ فَقَالَ الرَّوَاحَ إِنْ كُنْتَ تُرِيدُ السُّنَّةَ‏.‏ قَالَ هَذِهِ السَّاعَةَ قَالَ نَعَمْ‏.‏ قَالَ فَأَنْظِرْنِي حَتَّى أُفِيضَ عَلَى رَأْسِي ثُمَّ أَخْرُجَ‏.‏ فَنَزَلَ حَتَّى خَرَجَ الْحَجَّاجُ، فَسَارَ بَيْنِي وَبَيْنَ أَبِي، فَقُلْتُ إِنْ كُنْتَ تُرِيدُ السُّنَّةَ فَاقْصُرِ الْخُطْبَةَ وَعَجِّلِ الْوُقُوفَ‏.‏ فَجَعَلَ يَنْظُرُ إِلَى عَبْدِ اللَّهِ، فَلَمَّا رَأَى ذَلِكَ عَبْدُ اللَّهِ قَالَ صَدَقَ‏.‏\hadithno{1660}\hadithtrans{Narrated Salim:`Abdul Malik wrote to Al-Hajjaj that he should not differ from Ibn `Umar during Hajj. On the Day of `Arafat, when the sun declined at midday, Ibn `Umar came along with me and shouted near Al- Hajjaj's cotton (cloth) tent. Al-Hajjaj came Out, wrapping himself with a waist-sheet dyed with safflower, and said, "O Abu `Abdur-Rahman! What is the matter?" He said, If you want to follow the Sunna (the tradition of the Prophet (ﷺ) ) then proceed (to `Arafat)." Al-Hajjaj asked, "At this very hour?" Ibn `Umar said, "Yes." He replied, "Please wait for me till I pour some water over my head (i.e. take a bath) and come out." Then Ibn `Umar dismounted and waited till Al-Hajjaj came out. So, he (Al-Hajjaj) walked in between me and my father (Ibn `Umar). I said to him, "If you want to follow the Sunna then deliver a brief sermon and hurry up for the stay at `Arafat." He started looking at `Abdullah (Ibn `Umar) (inquiringly), and when `Abdullah noticed that, he said that he had told the truth}}
\hadithdefcmd{bukhari}{1661}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، عَنْ عُمَيْرٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ الْعَبَّاسِ عَنْ أُمِّ الْفَضْلِ بِنْتِ الْحَارِثِ، أَنَّ نَاسًا، اخْتَلَفُوا عِنْدَهَا يَوْمَ عَرَفَةَ فِي صَوْمِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ بَعْضُهُمْ هُوَ صَائِمٌ‏.‏ وَقَالَ بَعْضُهُمْ لَيْسَ بِصَائِمٍ‏.‏ فَأَرْسَلَتْ إِلَيْهِ بِقَدَحِ لَبَنٍ وَهْوَ وَاقِفٌ عَلَى بَعِيرِهِ فَشَرِبَهُ‏.‏\hadithno{1661}\hadithtrans{Narrated Um Al-Fadl bint Al Harith:On the day of `Arafat, some people who were with me, differed about the fasting of the Prophet (ﷺ) some said that he was fasting while others said that he was not fasting. So I sent a bowl full of milk to him while he was riding his camel, and he drank that milk}}
\hadithdefcmd{bukhari}{1662}{وَقَالَ اللَّيْثُ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمٌ، أَنَّ الْحَجَّاجَ بْنَ يُوسُفَ، عَامَ نَزَلَ بِابْنِ الزُّبَيْرِ ـ رضى الله عنهما ـ سَأَلَ عَبْدَ اللَّهِ ـ رضى الله عنه ـ كَيْفَ تَصْنَعُ فِي الْمَوْقِفِ يَوْمَ عَرَفَةَ فَقَالَ سَالِمٌ إِنْ كُنْتَ تُرِيدُ السُّنَّةَ فَهَجِّرْ بِالصَّلاَةِ يَوْمَ عَرَفَةَ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ صَدَقَ‏.‏ إِنَّهُمْ كَانُوا يَجْمَعُونَ بَيْنَ الظُّهْرِ وَالْعَصْرِ فِي السُّنَّةِ‏.‏ فَقُلْتُ لِسَالِمٍ أَفَعَلَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ سَالِمٌ وَهَلْ تَتَّبِعُونَ فِي ذَلِكَ إِلاَّ سُنَّتَهُ\hadithno{1662}\hadithtrans{Ibn Shihab said:Salim said, "In the year when Al-Hajjaj bin Yusuf attacked Ibn Az-Zubair, the former asked 'Abdullah (Ibn 'Umar) what to do during the stay on the Day of 'Arafa (9th of Dhul-Hijjah). I said to him, "If you want to follow the Sunna (the legal way of the Prophet (ﷺ)) you should offer the Salat just after midday on the Day of the 'Arafa. 'Abdullah bin 'Umar said, 'He (Salim) has spoken the truth.' " They (the Companions of the Prophet (ﷺ)) used to offer the Zuhr and Asr prayer together according to the Sunna, I asked Salim, "Did Allah's Messenger (ﷺ) do that ?" Salim said, "And in doing that do you (people) follow anything else except his (ﷺ) Sunna?}}
\hadithdefcmd{bukhari}{1663}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ الْمَلِكِ بْنَ مَرْوَانَ، كَتَبَ إِلَى الْحَجَّاجِ أَنْ يَأْتَمَّ، بِعَبْدِ اللَّهِ بْنِ عُمَرَ فِي الْحَجِّ، فَلَمَّا كَانَ يَوْمُ عَرَفَةَ جَاءَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ وَأَنَا مَعَهُ حِينَ زَاغَتِ الشَّمْسُ أَوْ زَالَتْ، فَصَاحَ عِنْدَ فُسْطَاطِهِ أَيْنَ هَذَا فَخَرَحَ إِلَيْهِ فَقَالَ ابْنُ عُمَرَ الرَّوَاحَ‏.‏ فَقَالَ الآنَ قَالَ نَعَمْ‏.‏ قَالَ أَنْظِرْنِي أُفِيضُ عَلَىَّ مَاءً‏.‏ فَنَزَلَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ حَتَّى خَرَجَ، فَسَارَ بَيْنِي وَبَيْنَ أَبِي‏.‏ فَقُلْتُ إِنْ كُنْتَ تُرِيدُ أَنْ تُصِيبَ السُّنَّةَ الْيَوْمَ فَاقْصُرِ الْخُطْبَةَ وَعَجِّلِ الْوُقُوفَ‏.‏ فَقَالَ ابْنُ عُمَرَ صَدَقَ‏.‏\hadithno{1663}\hadithtrans{Narrated Salim bin `Abdullah bin `Umar:`Abdul-Malik bin Marwan wrote to Al-Hajjaj that he should follow `Abdullah bin `Umar in all the ceremonies of Hajj. So when it was the Day of `Arafat (9th of Dhul-Hijja), and after the sun had deviated or had declined from the middle of the sky, I and Ibn `Umar came and he shouted near the cotton (cloth) tent of Al-Hajjaj, "Where is he?" Al-Hajjaj came out. Ibn `Umar said, "Let us proceed (to `Arafat)." Al-Hajjaj asked, "Just now?" Ibn `Umar replied, "Yes." Al-Hajjaj said, "Wait for me till I pour water on me (i.e. take a bath)." So, Ibn `Umar dismounted (and waited) till Al-Hajjaj came out. He was walking between me and my father. I informed Al-Hajjaj, "If you want to follow the Sunna today, then you should shorten the sermon and then hurry up for the stay (at `Arafat)." Ibn `Umar said, "He (Salim) has spoken the truth}}
\hadithdefcmd{bukhari}{1664}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، حَدَّثَنَا مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، كُنْتُ أَطْلُبُ بَعِيرًا لِي‏.‏ وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ مُحَمَّدَ بْنَ جُبَيْرٍ، عَنْ أَبِيهِ، جُبَيْرِ بْنِ مُطْعِمٍ قَالَ أَضْلَلْتُ بَعِيرًا لِي، فَذَهَبْتُ أَطْلُبُهُ يَوْمَ عَرَفَةَ، فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَاقِفًا بِعَرَفَةَ، فَقُلْتُ هَذَا وَاللَّهِ مِنَ الْحُمْسِ فَمَا شَأْنُهُ هَا هُنَا\hadithno{1664}\hadithtrans{Narrated Muhammad bin Jubair bin Mut`im:My father said, "(Before Islam) I was looking for my camel .." The same narration is told by a different sub-narrator. Jubair bin Mut`im said, "My camel was lost and I went out in search of it on the day of `Arafat, and I saw the Prophet (ﷺ) standing in `Arafat. I said to myself: By Allah he is from the Hums (literally: strictly religious, Quraish were called so, as they used to say, 'We are the people of Allah we shall not go out of the sanctuary). What has brought him here?}}
\hadithdefcmd{bukhari}{1665}{حَدَّثَنَا فَرْوَةُ بْنُ أَبِي الْمَغْرَاءِ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ عُرْوَةُ كَانَ النَّاسُ يَطُوفُونَ فِي الْجَاهِلِيَّةِ عُرَاةً إِلاَّ الْحُمْسَ، وَالْحُمْسُ قُرَيْشٌ وَمَا وَلَدَتْ، وَكَانَتِ الْحُمْسُ يَحْتَسِبُونَ عَلَى النَّاسِ يُعْطِي الرَّجُلُ الرَّجُلَ الثِّيَابَ يَطُوفُ فِيهَا، وَتُعْطِي الْمَرْأَةُ الْمَرْأَةَ الثِّيَابَ تَطُوفُ فِيهَا، فَمَنْ لَمْ يُعْطِهِ الْحُمْسُ طَافَ بِالْبَيْتِ عُرْيَانًا، وَكَانَ يُفِيضُ جَمَاعَةُ النَّاسِ مِنْ عَرَفَاتٍ، وَيُفِيضُ الْحُمْسُ مِنْ جَمْعٍ‏.‏ قَالَ وَأَخْبَرَنِي أَبِي عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ هَذِهِ الآيَةَ نَزَلَتْ فِي الْحُمْسِ ‏\{‏ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ‏\}‏ قَالَ كَانُوا يُفِيضُونَ مِنْ جَمْعٍ فَدُفِعُوا إِلَى عَرَفَاتٍ‏.‏\hadithno{1665}\hadithtrans{Narrated `Urwa:During the Pre-Islamic period of Ignorance, the people used to perform Tawaf of the Ka`ba naked except the Hums; and the Hums were Quraish and their offspring. The Hums used to give clothes to the men who would perform the Tawaf wearing them; and women (of the Hums) used to give clothes to the women who would perform the Tawaf wearing them. Those to whom the Hums did not give clothes would perform Tawaf round the Ka`ba naked. Most of the people used to go away (disperse) directly from `Arafat but they (Hums) used to depart after staying at Al-Muzdalifa. `Urwa added, "My father narrated that `Aisha had said, 'The following verses were revealed about the Hums: Then depart from the place whence all the people depart--(2.199) `Urwa added, "They (the Hums) used to stay at Al-Muzdalifa and used to depart from there (to Mina) and so they were sent to `Arafat (by Allah's order)}}
\hadithdefcmd{bukhari}{1666}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ سُئِلَ أُسَامَةُ وَأَنَا جَالِسٌ، كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسِيرُ فِي حَجَّةِ الْوَدَاعِ حِينَ دَفَعَ قَالَ كَانَ يَسِيرُ الْعَنَقَ، فَإِذَا وَجَدَ فَجْوَةً نَصَّ‏.‏ قَالَ هِشَامٌ وَالنَّصُّ فَوْقَ الْعَنَقِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ فَجْوَةٌ مُتَّسَعٌ، وَالْجَمِيعُ فَجَوَاتٌ وَفِجَاءٌ، وَكَذَلِكَ رَكْوَةٌ وَرِكَاءٌ‏.‏ مَنَاصٌ لَيْسَ حِينَ فِرَارٍ‏.‏\hadithno{1666}\hadithtrans{Narrated `Urwa:Usama was asked in my presence, "How was the speed of (the camel of) Allah's Messenger (ﷺ) while departing from `Arafat during the Hajjatul Wada`?" Usama replied, "The Prophet (ﷺ) proceeded on with a modest pace, and when there was enough space he would (make his camel) go very fast}}
\hadithdefcmd{bukhari}{1667}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم حَيْثُ أَفَاضَ مِنْ عَرَفَةَ مَالَ إِلَى الشِّعْبِ فَقَضَى حَاجَتَهُ فَتَوَضَّأَ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتُصَلِّي فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏‏.‏\hadithno{1667}\hadithtrans{Narrated Usama bin Zaid:As soon as the Prophet (ﷺ) departed from `Arafat, he went towards the mountain pass, and there he answered the call of nature. He was asked, "O Allah's Messenger (ﷺ)! Will you offer the prayer here?" He replied, "(The place of) the prayer is ahead of you (i.e. at Al-Muzdalifa)}}
\hadithdefcmd{bukhari}{1668}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ، غَيْرَ أَنَّهُ يَمُرُّ بِالشِّعْبِ الَّذِي أَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَيَدْخُلُ فَيَنْتَفِضُ وَيَتَوَضَّأُ، وَلاَ يُصَلِّي حَتَّى يُصَلِّيَ بِجَمْعٍ‏.‏\hadithno{1668}\hadithtrans{Narrated Nafi`:`Abdullah bin `Umar used to offer the Maghrib and `Isha' prayers together at Jam' (Al-Muzdalifa). But he used to pass by that mountain pass where Allah's Messenger (ﷺ) went, and he would enter it and answer the call of nature and perform ablution, and would not offer any prayer till he had prayed at Jam}}
\hadithdefcmd{bukhari}{1670}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ أَبِي حَرْمَلَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ رَدِفْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَاتٍ فَلَمَّا بَلَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم الشِّعْبَ الأَيْسَرَ الَّذِي دُونَ الْمُزْدَلِفَةِ أَنَاخَ، فَبَالَ ثُمَّ جَاءَ فَصَبَبْتُ عَلَيْهِ الْوَضُوءَ، فَتَوَضَّأَ وُضُوءًا خَفِيفًا‏.‏ فَقُلْتُ الصَّلاَةَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏‏.‏ فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَى الْمُزْدَلِفَةَ، فَصَلَّى ثُمَّ رَدِفَ الْفَضْلُ رَسُولَ اللَّهِ صلى الله عليه وسلم غَدَاةَ جَمْعٍ‏.‏ قَالَ كُرَيْبٌ فَأَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ الْفَضْلِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَزَلْ يُلَبِّي حَتَّى بَلَغَ الْجَمْرَةَ‏.‏\hadithno{1670}\hadithtrans{Narrated Usama bin Zaid:I rode behind Allah's Messenger (ﷺ) from `Arafat and when Allah's Messenger (ﷺ) reached the mountain pass on the left side which is before Al-Muzdalifa he made his camel kneel and then urinated, and then I poured water for his ablution. He performed light ablution and then I said to him: (Is it the time for) the prayer, O Allah's Messenger (ﷺ)!" He replied, "The (place of) prayer is ahead of you (i.e. at Al- Muzdalifa)." So Allah's Messenger (ﷺ) rode till he reached Al-Muzdalifa and then he offered the prayer (there) . Then in the morning (10th Dhul-Hijja) Al-Faql (bin `Abbas) rode behind Allah's Messenger (ﷺ). Kuraib, (a sub-narrator) said that `Abdullah bin `Abbas narrated from Al-Fadl, "Allah's Messenger (ﷺ) kept on reciting Talbiya (during the journey) till he reached the Jamra." (Jamrat-Al-`Aqaba)}}
\hadithdefcmd{bukhari}{1671}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سُوَيْدٍ، حَدَّثَنِي عَمْرُو بْنُ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ أَخْبَرَنِي سَعِيدُ بْنُ جُبَيْرٍ، مَوْلَى وَالِبَةَ الْكُوفِيُّ حَدَّثَنِي ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ دَفَعَ مَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَ عَرَفَةَ فَسَمِعَ النَّبِيُّ صلى الله عليه وسلم وَرَاءَهُ زَجْرًا شَدِيدًا وَضَرْبًا وَصَوْتًا لِلإِبِلِ فَأَشَارَ بِسَوْطِهِ إِلَيْهِمْ وَقَالَ ‏ "‏ أَيُّهَا النَّاسُ عَلَيْكُمْ بِالسَّكِينَةِ، فَإِنَّ الْبِرَّ لَيْسَ بِالإِيضَاعِ ‏"‏‏.‏ أَوْضَعُوا أَسْرَعُوا‏.‏ خِلاَلَكُمْ مِنَ التَّخَلُّلِ بَيْنَكُمْ، وَفَجَّرْنَا خِلاَلَهُمَا‏.‏ بَيْنَهُمَا‏.‏\hadithno{1671}\hadithtrans{Narrated Ibn `Abbas.:I proceeded along with the Prophet (ﷺ) on the day of `Arafat (9th Dhul-Hijja). The Prophet (ﷺ) heard a great hue and cry and the beating of camels behind him. So he beckoned to the people with his lash, "O people! Be quiet. Hastening is not a sign of righteousness}}
\hadithdefcmd{bukhari}{1672}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَهُ يَقُولُ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَةَ، فَنَزَلَ الشِّعْبَ، فَبَالَ ثُمَّ تَوَضَّأَ، وَلَمْ يُسْبِغِ الْوُضُوءَ‏.‏ فَقُلْتُ لَهُ الصَّلاَةُ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏‏.‏ فَجَاءَ الْمُزْدَلِفَةَ، فَتَوَضَّأَ، فَأَسْبَغَ، ثُمَّ أُقِيمَتِ الصَّلاَةُ، فَصَلَّى الْمَغْرِبَ، ثُمَّ أَنَاخَ كُلُّ إِنْسَانٍ بَعِيرَهُ فِي مَنْزِلِهِ، ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّى، وَلَمْ يُصَلِّ بَيْنَهُمَا‏.‏\hadithno{1672}\hadithtrans{Narrated Usama bin Zaid:Allah's Messenger (ﷺ) proceeded from `Arafat and dismounted at the mountainous pass and then urinated and performed a light ablution. I said to him, "(Shall we offer) the prayer?" He replied, "The prayer is ahead of you (i.e. at Al-Muzdalifa)." When he came to Al-Muzdalifa, he performed a perfect ablution. Then Iqama for the prayer was pronounced and he offered the Maghrib prayer and then every person made his camel kneel at his place; and then Iqama for the prayer was pronounced and he offered the (`Isha') prayer and he did not offer any prayer in between them (i.e. Maghrib and `Isha' prayers)}}
\hadithdefcmd{bukhari}{1673}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ جَمَعَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِجَمْعٍ، كُلُّ وَاحِدَةٍ مِنْهُمَا بِإِقَامَةٍ، وَلَمْ يُسَبِّحْ بَيْنَهُمَا وَلاَ عَلَى إِثْرِ كُلِّ وَاحِدَةٍ مِنْهُمَا‏.‏\hadithno{1673}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) offered the Maghrib and `Isha' prayers together at Jam' (i.e. Al-Muzdalifa) with a separate Iqama for each of them and did not offer any optional prayer in between them or after each of them}}
\hadithdefcmd{bukhari}{1674}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي عَدِيُّ بْنُ ثَابِتٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ يَزِيدَ الْخَطْمِيُّ، قَالَ حَدَّثَنِي أَبُو أَيُّوبَ الأَنْصَارِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ فِي حَجَّةِ الْوَدَاعِ الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ‏.‏\hadithno{1674}\hadithtrans{Narrated Abu Aiyub Al-Ansari:Allah's Messenger (ﷺ) offered the Maghrib and `Isha' prayers together at Al-Muzdalifa}}
\hadithdefcmd{bukhari}{1675}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، يَقُولُ حَجَّ عَبْدُ اللَّهِ ـ رضى الله عنه ـ فَأَتَيْنَا الْمُزْدَلِفَةَ حِينَ الأَذَانِ بِالْعَتَمَةِ، أَوْ قَرِيبًا مِنْ ذَلِكَ، فَأَمَرَ رَجُلاً فَأَذَّنَ وَأَقَامَ، ثُمَّ صَلَّى الْمَغْرِبَ، وَصَلَّى بَعْدَهَا رَكْعَتَيْنِ، ثُمَّ دَعَا بِعَشَائِهِ فَتَعَشَّى، ثُمَّ أَمَرَ ـ أُرَى رَجُلاً ـ فَأَذَّنَ وَأَقَامَ ـ قَالَ عَمْرٌو لاَ أَعْلَمُ الشَّكَّ إِلاَّ مِنْ زُهَيْرٍ ـ ثُمَّ صَلَّى الْعِشَاءَ رَكْعَتَيْنِ، فَلَمَّا طَلَعَ الْفَجْرُ قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يُصَلِّي هَذِهِ السَّاعَةَ إِلاَّ هَذِهِ الصَّلاَةَ، فِي هَذَا الْمَكَانِ، مِنْ هَذَا الْيَوْمِ‏.‏ قَالَ عَبْدُ اللَّهِ هُمَا صَلاَتَانِ تُحَوَّلاَنِ عَنْ وَقْتِهِمَا صَلاَةُ الْمَغْرِبِ بَعْدَ مَا يَأْتِي النَّاسُ الْمُزْدَلِفَةَ، وَالْفَجْرُ حِينَ يَبْزُغُ الْفَجْرُ‏.‏ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَفْعَلُهُ‏.‏\hadithno{1675}\hadithtrans{Narrated `Abdur-Rahman bin Yazid:`Abdullah;- performed the Hajj and we reached Al-Muzdalifa at or about the time of the `Isha' prayer. He ordered a man to pronounce the Adhan and Iqama and then he offered the Maghrib prayer and offered two rak`at after it. Then he asked for his supper and took it, and then, I think, he ordered a man to pronounce the Adhan and Iqama (for the `Isha' prayer). (`Amr, a sub-narrator said: The intervening statement 'I think', was said by the sub-narrator Zuhair) (i.e. not by `Abdur-Rahman). Then `Abdullah offered two rak`at of `Isha' prayer. When the day dawned, `Abdullah said, "The Prophet never offered any prayer at this hour except this prayer at this time and at this place and on this day." `Abdullah added, "These two prayers are shifted from their actual times -- the Maghrib prayer (is offered) when the people reached Al-Muzdalifa and the Fajr (morning) prayer at the early dawn." `Abdullah added, "I saw the Prophet (ﷺ) doing that}}
\hadithdefcmd{bukhari}{1676}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ سَالِمٌ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ يُقَدِّمُ ضَعَفَةَ أَهْلِهِ، فَيَقِفُونَ عِنْدَ الْمَشْعَرِ الْحَرَامِ بِالْمُزْدَلِفَةِ بِلَيْلٍ، فَيَذْكُرُونَ اللَّهَ مَا بَدَا لَهُمْ، ثُمَّ يَرْجِعُونَ قَبْلَ أَنْ يَقِفَ الإِمَامُ، وَقَبْلَ أَنْ يَدْفَعَ، فَمِنْهُمْ مَنْ يَقْدَمُ مِنًى لِصَلاَةِ الْفَجْرِ، وَمِنْهُمْ مَنْ يَقْدَمُ بَعْدَ ذَلِكَ، فَإِذَا قَدِمُوا رَمَوُا الْجَمْرَةَ، وَكَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ أَرْخَصَ فِي أُولَئِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1676}\hadithtrans{Narrated Salim:`Abdullah bin `Umar used to send the weak among his family early to Mina. So they used to depart from Al-Mash'ar Al-Haram (that is Al-Muzdalifa) at night (when the moon had set) and invoke Allah as much as they could, and then they would return (to Mina) before the Imam had started from Al- Muzdalifa to Mina. So some of them would reach Mina at the time of the Fajr prayer and some of them would come later. When they reached Mina they would throw pebbles on the Jamra (Jamrat-Al- `Aqaba) Ibn `Umar used to say, "Allah's Messenger (ﷺ) gave the permission to them (weak people) to do so}}
\hadithdefcmd{bukhari}{1677}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ جَمْعٍ بِلَيْلٍ‏.‏\hadithno{1677}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) had sent me from Jam' (i.e. Al-Muzdalifa) at night}}
\hadithdefcmd{bukhari}{1678}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ أَنَا مِمَّنْ، قَدَّمَ النَّبِيُّ صلى الله عليه وسلم لَيْلَةَ الْمُزْدَلِفَةِ فِي ضَعَفَةِ أَهْلِهِ‏.‏\hadithno{1678}\hadithtrans{Narrated Ibn `Abbas:I was among those whom the Prophet (ﷺ) sent on the night of Al-Muzdalifa early being among the weak members of his family}}
\hadithdefcmd{bukhari}{1679}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ، مَوْلَى أَسْمَاءَ عَنْ أَسْمَاءَ، أَنَّهَا نَزَلَتْ لَيْلَةَ جَمْعٍ عِنْدَ الْمُزْدَلِفَةِ، فَقَامَتْ تُصَلِّي، فَصَلَّتْ سَاعَةً، ثُمَّ قَالَتْ يَا بُنَىَّ هَلْ غَابَ الْقَمَرُ قُلْتُ لاَ‏.‏ فَصَلَّتْ سَاعَةً، ثُمَّ قَالَتْ هَلْ غَابَ الْقَمَرُ قُلْتُ نَعَمْ‏.‏ قَالَتْ فَارْتَحِلُوا‏.‏ فَارْتَحَلْنَا، وَمَضَيْنَا حَتَّى رَمَتِ الْجَمْرَةَ، ثُمَّ رَجَعَتْ فَصَلَّتِ الصُّبْحَ فِي مَنْزِلِهَا‏.‏ فَقُلْتُ لَهَا يَا هَنْتَاهْ مَا أُرَانَا إِلاَّ قَدْ غَلَّسْنَا‏.‏ قَالَتْ يَا بُنَىَّ، إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَذِنَ لِلظُّعُنِ‏.‏\hadithno{1679}\hadithtrans{Narrated `Abdullah:(the slave of Asma') During the night of Jam', Asma' got down at Al-Muzdalifa and stood up for (offering) the prayer and offered the prayer for some time and then asked, "O my son! Has the moon set?" I replied in the negative and she again prayed for another period and then asked, "Has the moon set?" I replied, "Yes." So she said that we should set out (for Mina), and we departed and went on till she threw pebbles at the Jamra (Jamrat-Al-`Aqaba) and then she returned to her dwelling place and offered the morning prayer. I asked her, "O you! I think we have come (to Mina) early in the night." She replied, "O my son! Allah's Messenger (ﷺ) gave permission to the women to do so}}
\hadithdefcmd{bukhari}{1680}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ ـ هُوَ ابْنُ الْقَاسِمِ ـ عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اسْتَأْذَنَتْ سَوْدَةُ النَّبِيَّ صلى الله عليه وسلم لَيْلَةَ جَمْعٍ وَكَانَتْ ثَقِيلَةً ثَبْطَةً فَأَذِنَ لَهَا‏.‏\hadithno{1680}\hadithtrans{Narrated `Aisha:Sauda asked the permission of the Prophet (ﷺ) to leave earlier at the night of Jam', and she was a fat and very slow woman. The Prophet (ﷺ) gave her permission}}
\hadithdefcmd{bukhari}{1681}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَفْلَحُ بْنُ حُمَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ نَزَلْنَا الْمُزْدَلِفَةَ فَاسْتَأْذَنَتِ النَّبِيَّ صلى الله عليه وسلم سَوْدَةُ أَنْ تَدْفَعَ قَبْلَ حَطْمَةِ النَّاسِ، وَكَانَتِ امْرَأَةً بَطِيئَةً، فَأَذِنَ لَهَا، فَدَفَعَتْ قَبْلَ حَطْمَةِ النَّاسِ، وَأَقَمْنَا حَتَّى أَصْبَحْنَا نَحْنُ، ثُمَّ دَفَعْنَا بِدَفْعِهِ، فَلأَنْ أَكُونَ اسْتَأْذَنْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا اسْتَأْذَنَتْ سَوْدَةُ أَحَبُّ إِلَىَّ مِنْ مَفْرُوحٍ بِهِ‏.‏\hadithno{1681}\hadithtrans{Narrated `Aisha:We got down at Al-Muzdalifa and Sauda asked the permission of the Prophet (ﷺ) to leave (early) before the rush of the people. She was a slow woman and he gave her permission, so she departed (from Al- Muzdalifa) before the rush of the people. We kept on staying at Al-Muzdalifa till dawn, and set out with the Prophet (ﷺ) but (I suffered so much that) I wished I had taken the permission of Allah's Messenger (ﷺ) as Sauda had done, and that would have been dearer to me than any other happiness}}
\hadithdefcmd{bukhari}{1682}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي عُمَارَةُ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم صَلَّى صَلاَةً بِغَيْرِ مِيقَاتِهَا إِلاَّ صَلاَتَيْنِ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ، وَصَلَّى الْفَجْرَ قَبْلَ مِيقَاتِهَا‏.‏\hadithno{1682}\hadithtrans{Narrated `Abdullah:I never saw the Prophet (ﷺ) offering any prayer not at its stated time except two; he prayed the Maghrib and the `Isha' together and he offered the morning prayer before its usual time}}
\hadithdefcmd{bukhari}{1683}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ خَرَجْنَا مَعَ عَبْدِ اللَّهِ ـ رضى الله عنه ـ إِلَى مَكَّةَ، ثُمَّ قَدِمْنَا جَمْعًا، فَصَلَّى الصَّلاَتَيْنِ، كُلَّ صَلاَةٍ وَحْدَهَا بِأَذَانٍ وَإِقَامَةٍ، وَالْعَشَاءُ بَيْنَهُمَا، ثُمَّ صَلَّى الْفَجْرَ حِينَ طَلَعَ الْفَجْرُ، قَائِلٌ يَقُولُ طَلَعَ الْفَجْرُ‏.‏ وَقَائِلٌ يَقُولُ لَمْ يَطْلُعِ الْفَجْرُ‏.‏ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ هَاتَيْنِ الصَّلاَتَيْنِ حُوِّلَتَا عَنْ وَقْتِهِمَا فِي هَذَا الْمَكَانِ الْمَغْرِبَ وَالْعِشَاءَ، فَلاَ يَقْدَمُ النَّاسُ جَمْعًا حَتَّى يُعْتِمُوا، وَصَلاَةَ الْفَجْرِ هَذِهِ السَّاعَةَ ‏"‏‏.‏ ثُمَّ وَقَفَ حَتَّى أَسْفَرَ، ثُمَّ قَالَ لَوْ أَنَّ أَمِيرَ الْمُؤْمِنِينَ أَفَاضَ الآنَ أَصَابَ السُّنَّةَ‏.‏ فَمَا أَدْرِي أَقَوْلُهُ كَانَ أَسْرَعَ أَمْ دَفْعُ عُثْمَانَ ـ رضى الله عنه ـ فَلَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ يَوْمَ النَّحْرِ‏.‏\hadithno{1683}\hadithtrans{Narrated `Abdur-Rahman bin Yazid:I went out with `Abdullah to Mecca and when we proceeded to Jam', he offered the two prayers (the Maghrib and the `Isha') together, making the Adhan and Iqama separately for each prayer. He took his supper in between the two prayers. He offered the Fajr prayer as soon as the day dawned. Some people said, "The day had dawned (at the time of the prayer)," and others said, "The day had not dawned." `Abdullah then said, "Allah's Messenger (ﷺ) said, 'These two prayers have been shifted from their stated times at this place only (at Al-Muzdalifa); first: The Maghrib and the `Isha'. So the people should not arrive at Al-Muzdalifa till the time of the `Isha' prayer has become due. The second prayer is the morning prayer which is offered at this hour.' " Then `Abdullah stayed there till it became a bit brighter. He then said, "If the chief of the believers hastened onwards to Mina just now, then he had indeed followed the Sunna." I do not know which proceeded the other, his (`Abdullah's) statement or the departure of `Uthman . `Abdullah was reciting Talbiya till he threw pebbles at the Jamrat-Al- `Aqaba on the Day of Nahr (slaughtering) (that is the 10th of Dhul-Hijja)}}
\hadithdefcmd{bukhari}{1684}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، سَمِعْتُ عَمْرَو بْنَ مَيْمُونٍ، يَقُولُ شَهِدْتُ عُمَرَ ـ رضى الله عنه ـ صَلَّى بِجَمْعٍ الصُّبْحَ، ثُمَّ وَقَفَ فَقَالَ إِنَّ الْمُشْرِكِينَ كَانُوا لاَ يُفِيضُونَ حَتَّى تَطْلُعَ الشَّمْسُ، وَيَقُولُونَ أَشْرِقْ ثَبِيرُ‏.‏ وَأَنَّ النَّبِيَّ صلى الله عليه وسلم خَالَفَهُمْ، ثُمَّ أَفَاضَ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ‏.‏\hadithno{1684}\hadithtrans{Narrated `Amr bin Maimun:I saw `Umar, offering the Fajr (morning) prayer at Jam'; then he got up and said, "The pagans did not use to depart (from Jam') till the sun had risen, and they used to say, 'Let the sun shine on Thabir (a mountain).' But the Prophet (ﷺ) contradicted them and departed from Jam' before sunrise}}
\hadithdefcmd{bukhari}{1685}{حَدَّثَنَا أَبُو عَاصِمٍ الضَّحَّاكُ بْنُ مَخْلَدٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَرْدَفَ الْفَضْلَ، فَأَخْبَرَ الْفَضْلُ أَنَّهُ لَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى الْجَمْرَةَ‏.‏\hadithno{1685}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) made Al-Fadl ride behind him, and Al-Fadl informed that he (the Prophet (ﷺ) ) kept on reciting Talbiya till he did the Rami of the Jamra. (Jamrat-Al-`Aqaba)}}
\hadithdefcmd{bukhari}{1686}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ يُونُسَ الأَيْلِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ أُسَامَةَ بْنَ زَيْدٍ ـ رضى الله عنهما ـ كَانَ رِدْفَ النَّبِيِّ صلى الله عليه وسلم مِنْ عَرَفَةَ إِلَى الْمُزْدَلِفَةِ، ثُمَّ أَرْدَفَ الْفَضْلَ مِنَ الْمُزْدَلِفَةِ إِلَى مِنًى ـ قَالَ ـ فَكِلاَهُمَا قَالاَ لَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ‏.‏\hadithno{1686}\hadithtrans{Narrated 'Ubaidullah bin `Abdullah:Ibn `Abbas said, "Usama bin Zaid rode behind the Prophet (ﷺ) from `Arafat to Al-Muzdalifa; and then from Al-Muzdalifa to Mina, Al-Fadl rode behind him." He added, "Both of them (Usama and Al-Fadl) said, 'The Prophet (ﷺ) was constantly reciting Talbiya till he did Rami of the Jamarat-Al-`Aqaba}}
\hadithdefcmd{bukhari}{1688}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا النَّضْرُ، أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا أَبُو جَمْرَةَ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ الْمُتْعَةِ، فَأَمَرَنِي بِهَا، وَسَأَلْتُهُ عَنِ الْهَدْىِ، فَقَالَ فِيهَا جَزُورٌ أَوْ بَقَرَةٌ أَوْ شَاةٌ أَوْ شِرْكٌ فِي دَمٍ قَالَ وَكَأَنَّ نَاسًا كَرِهُوهَا، فَنِمْتُ فَرَأَيْتُ فِي الْمَنَامِ كَأَنَّ إِنْسَانًا يُنَادِي حَجٌّ مَبْرُورٌ، وَمُتْعَةٌ مُتَقَبَّلَةٌ‏.‏ فَأَتَيْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ فَحَدَّثْتُهُ فَقَالَ اللَّهُ أَكْبَرُ سُنَّةُ أَبِي الْقَاسِمِ صلى الله عليه وسلم قَالَ وَقَالَ آدَمُ وَوَهْبُ بْنُ جَرِيرٍ وَغُنْدَرٌ عَنْ شُعْبَةَ عُمْرَةٌ مُتَقَبَّلَةٌ، وَحَجٌّ مَبْرُورٌ‏.‏\hadithno{1688}\hadithtrans{Narrated Abu Jamra:I asked Ibn `Abbas about Hajj-at-Tamattu`. He ordered me to perform it. I asked him about the Hadi (sacrifice). He said, "You have to slaughter a camel, a cow or a sheep, or you may share the Hadi with the others." It seemed that some people disliked it (Hajj-at-Tamattu`). I slept and dreamt as if a person was announcing: "Hajj Mabrur and accepted Mut'ah (Hajj-at-Tamattu`)" I went to Ibn `Abbas and narrated it to him. He said, "Allah is Greater. (That was) the tradition of Abu Al-Qasim (i.e. Prophet). Narrated Shu`ba that the call in the dream was. "An accepted `Umra and Hajj-Mabrur}}
\hadithdefcmd{bukhari}{1689}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ فَقَالَ إِنَّهَا بَدَنَةٌ‏.‏ فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ قَالَ إِنَّهَا بَدَنَةٌ‏.‏ قَالَ ‏"‏ ارْكَبْهَا، وَيْلَكَ ‏"‏‏.‏ فِي الثَّالِثَةِ أَوْ فِي الثَّانِيَةِ‏.‏\hadithno{1689}\hadithtrans{Narrated Abu Huraira':Allah's Messenger (ﷺ) saw a man driving his Badana (sacrificial camel). He said, "Ride on it." The man said, "It is a Badana." The Prophet (ﷺ) said, "Ride on it." He (the man) said, "It is a Badana." The Prophet said, "Ride on it." And on the second or the third time he (the Prophet (ﷺ) ) added, "Woe to you}}
\hadithdefcmd{bukhari}{1690}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، وَشُعْبَةُ، قَالاَ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً، فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ قَالَ إِنَّهَا بَدَنَةٌ‏.‏ قَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ قَالَ إِنَّهَا بَدَنَةٌ‏.‏ قَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ ثَلاَثًا‏.‏\hadithno{1690}\hadithtrans{Narrated Anas:The Prophet (ﷺ) saw a man driving a Badana. He said, "Ride on it." The man replied, "It is a Badana." The Prophet (ﷺ) said (again), "Ride on it." He (the man) said, "It is a Badana." The Prophet (ﷺ) said thrice, "Ride on it}}
\hadithdefcmd{bukhari}{1691}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ تَمَتَّعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ بِالْعُمْرَةِ إِلَى الْحَجِّ، وَأَهْدَى فَسَاقَ مَعَهُ الْهَدْىَ مِنْ ذِي الْحُلَيْفَةِ، وَبَدَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَهَلَّ بِالْعُمْرَةِ، ثُمَّ أَهَلَّ بِالْحَجِّ، فَتَمَتَّعَ النَّاسُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِالْعُمْرَةِ إِلَى الْحَجِّ، فَكَانَ مِنَ النَّاسِ مَنْ أَهْدَى فَسَاقَ الْهَدْىَ، وَمِنْهُمْ مَنْ لَمْ يُهْدِ، فَلَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ، قَالَ لِلنَّاسِ ‏ "‏ مَنْ كَانَ مِنْكُمْ أَهْدَى فَإِنَّهُ لاَ يَحِلُّ لِشَىْءٍ حَرُمَ مِنْهُ حَتَّى يَقْضِيَ حَجَّهُ، وَمَنْ لَمْ يَكُنْ مِنْكُمْ أَهْدَى فَلْيَطُفْ بِالْبَيْتِ، وَبِالصَّفَا وَالْمَرْوَةِ، وَلْيُقَصِّرْ، وَلْيَحْلِلْ، ثُمَّ لِيُهِلَّ بِالْحَجِّ، فَمَنْ لَمْ يَجِدْ هَدْيًا فَلْيَصُمْ ثَلاَثَةَ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةً إِذَا رَجَعَ إِلَى أَهْلِهِ ‏"‏‏.‏ فَطَافَ حِينَ قَدِمَ مَكَّةَ، وَاسْتَلَمَ الرُّكْنَ أَوَّلَ شَىْءٍ، ثُمَّ خَبَّ ثَلاَثَةَ أَطْوَافٍ، وَمَشَى أَرْبَعًا، فَرَكَعَ حِينَ قَضَى طَوَافَهُ بِالْبَيْتِ عِنْدَ الْمَقَامِ رَكْعَتَيْنِ، ثُمَّ سَلَّمَ، فَانْصَرَفَ فَأَتَى الصَّفَا فَطَافَ بِالصَّفَا وَالْمَرْوَةِ سَبْعَةَ أَطْوَافٍ، ثُمَّ لَمْ يَحْلِلْ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى قَضَى حَجَّهُ وَنَحَرَ هَدْيَهُ يَوْمَ النَّحْرِ، وَأَفَاضَ فَطَافَ بِالْبَيْتِ، ثُمَّ حَلَّ مِنْ كُلِّ شَىْءٍ حَرُمَ مِنْهُ، وَفَعَلَ مِثْلَ مَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ أَهْدَى وَسَاقَ الْهَدْىَ مِنَ النَّاسِ‏.‏\hadithno{1691}\hadithtrans{Narrated Ibn `Umar:During the last Hajj (Hajj-al-Wada`) of Allah's Messenger (ﷺ) he performed `Umra and Hajj. He drove a Hadi along with him from Dhul-Hulaifa. Allah's Messenger (ﷺ) started by assuming Ihram for `Umra and Hajj. And the people, too, performed the `Umra and Hajj along with the Prophet. Some of them brought the Hadi and drove it along with them, while the others did not. So, when the Prophet (ﷺ) arrived at Mecca. he said to the people, "Whoever among you has driven the Hadi, should not finish his Ihram till he completes his Hajj. And whoever among you has not (driven) the Hadi with him, should perform Tawaf of the Ka`ba and the Tawaf between Safa and Marwa, then cut short his hair and finish his Ihram, and should later assume Ihram for Hajj; but he must offer a Hadi (sacrifice); and if anyone cannot afford a Hadi, he should fast for three days during the Hajj and seven days when he returns home. The Prophet (ﷺ) performed Tawaf of the Ka`ba on his arrival (at Mecca); he touched the (Black Stone) corner first of all and then did Ramal (fast walking with moving of the shoulders) during the first three rounds round the Ka`ba, and during the last four rounds he walked. After finishing Tawaf of the Ka`ba, he offered a two rak`at prayer at Maqam Ibrahim, and after finishing the prayer he went to Safa and Marwa and performed seven rounds of Tawaf between them and did not do any deed forbidden because of Ihram, till he finished all the ceremonies of his Hajj and sacrificed his Hadi on the day of Nahr (10th day of Dhul-Hijja). He then hastened onwards (to Mecca) and performed Tawaf of the Ka`ba and then everything that was forbidden because of Ihram became permissible. Those who took and drove the Hadi with them did the same as Allah's Messenger (ﷺ) did}}
\hadithdefcmd{bukhari}{1692}{وَعَنْ عُرْوَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ أَخْبَرَتْهُ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي تَمَتُّعِهِ بِالْعُمْرَةِ إِلَى الْحَجِّ فَتَمَتَّعَ النَّاسُ مَعَهُ بِمِثْلِ الَّذِي أَخْبَرَنِي سَالِمٌ عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1692}\hadithtrans{Narrated 'Urwa:" 'Aishah informed me about the Hajj and 'Umra (together) of the Prophet (ﷺ) and so did the people who were with him (during the Hajj and 'Umra) and narration similar to the narration of the Ibn 'Umar (previous hadith)}}
\hadithdefcmd{bukhari}{1693}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهم ـ لأَبِيهِ أَقِمْ، فَإِنِّي لاَ آمَنُهَا أَنْ سَتُصَدُّ عَنِ الْبَيْتِ‏.‏ قَالَ إِذًا أَفْعَلَ كَمَا فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ قَالَ اللَّهُ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏ فَأَنَا أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ عَلَى نَفْسِي الْعُمْرَةَ‏.‏ فَأَهَلَّ بِالْعُمْرَةِ، قَالَ ثُمَّ خَرَجَ حَتَّى إِذَا كَانَ بِالْبَيْدَاءِ أَهَلَّ بِالْحَجِّ وَالْعُمْرَةِ، وَقَالَ مَا شَأْنُ الْحَجِّ وَالْعُمْرَةِ إِلاَّ وَاحِدٌ‏.‏ ثُمَّ اشْتَرَى الْهَدْىَ مِنْ قُدَيْدٍ، ثُمَّ قَدِمَ فَطَافَ لَهُمَا طَوَافًا وَاحِدًا، فَلَمْ يَحِلَّ حَتَّى حَلَّ مِنْهُمَا جَمِيعًا‏.‏\hadithno{1693}\hadithtrans{Narrated Nafi`:`Abdullah (bin `Abdullah) bin `Umar said to his father, "Stay here, for I am afraid that it (affliction between Ibn Az-Zubair and Al-Hajjaj) might prevent you from reaching the Ka`ba." Ibn `Umar said, "(In this case) I would do the same as Allah's Messenger (ﷺ) did, and Allah has said, 'Verily, in Allah's Messenger (ﷺ), you have a good example (to follow).' So, I make you, people, witness that I have made `Umra compulsory for me." So he assumed Ihram for `Umra. Then he went out and when he reached Al- Baida', he assumed Ihram for Hajj and `Umra (together) and said, "The conditions (requisites) of Hajj and `Umra are the same." He, then brought a Hadi from Qudaid. Then he arrived (at Mecca) and performed Tawaf (between Safa and Marwa) once for both Hajj and `Umra and did not finish the Ihram till he had finished both Hajj and `Umra}}
\hadithdefcmd{bukhari}{1694}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَمَرْوَانَ، قَالاَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْمَدِينَةِ زَمَنَ الْحُدَيْبِيَةِ فِي بِضْعَ عَشْرَةَ مِائَةً مِنْ أَصْحَابِهِ، حَتَّى إِذَا كَانُوا بِذِي الْحُلَيْفَةِ قَلَّدَ النَّبِيُّ صلى الله عليه وسلم الْهَدْىَ وَأَشْعَرَ وَأَحْرَمَ بِالْعُمْرَةِ‏.‏\hadithno{1694}\hadithtrans{Narrated Al-Miswar bin Makhrama and Marwan:The Prophet (ﷺ) set out from Medina with over one thousand of his companions (at the time of the Treaty of Hudaibiya) and when they reached Dhul-Hulaifa, the Prophet (ﷺ) garlanded his Hadi and marked it and assumed Ihram for `Umra}}
\hadithdefcmd{bukhari}{1696}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَفْلَحُ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ فَتَلْتُ قَلاَئِدَ بُدْنِ النَّبِيِّ صلى الله عليه وسلم بِيَدَىَّ، ثُمَّ قَلَّدَهَا وَأَشْعَرَهَا وَأَهْدَاهَا، فَمَا حَرُمَ عَلَيْهِ شَىْءٌ كَانَ أُحِلَّ لَهُ‏.‏\hadithno{1696}\hadithtrans{Narrated `Aisha:I twisted with my own hands the garlands for the Budn of the Prophet (ﷺ) who garlanded and marked them, and then made them proceed to Mecca; Yet no permissible thing was regarded as illegal for him then}}
\hadithdefcmd{bukhari}{1697}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، رضى الله عنهم قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا شَأْنُ النَّاسِ حَلُّوا وَلَمْ تَحْلِلْ أَنْتَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي، وَقَلَّدْتُ هَدْيِي، فَلاَ أَحِلُّ حَتَّى أَحِلَّ مِنَ الْحَجِّ ‏"‏‏.‏\hadithno{1697}\hadithtrans{Narrated Hafsa:I said, "O Allah's Messenger (ﷺ)! What is wrong with the people, they have finished their Ihram but you have not?" He said, "I matted my hair and I have garlanded my Hadi, so I will not finish my Ihram till I have finished my Hajj}}
\hadithdefcmd{bukhari}{1698}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عُرْوَةَ، وَعَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُهْدِي مِنَ الْمَدِينَةِ، فَأَفْتِلُ قَلاَئِدَ هَدْيِهِ، ثُمَّ لاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُهُ الْمُحْرِمُ‏.‏\hadithno{1698}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to send the Hadi from Medina and I used to twist the garlands for his Hadi and he did not keep away from any of these things which a Muhrim keeps away from}}
\hadithdefcmd{bukhari}{1699}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا أَفْلَحُ بْنُ حُمَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ فَتَلْتُ قَلاَئِدَ هَدْىِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ أَشْعَرَهَا وَقَلَّدَهَا ـ أَوْ قَلَّدْتُهَا ـ ثُمَّ بَعَثَ بِهَا إِلَى الْبَيْتِ، وَأَقَامَ بِالْمَدِينَةِ، فَمَا حَرُمَ عَلَيْهِ شَىْءٌ كَانَ لَهُ حِلٌّ‏.‏\hadithno{1699}\hadithtrans{Narrated `Aisha:I twisted the garlands for the Hadis of the Prophet (ﷺ) and then he marked and garlanded them (or I garlanded them) and then made them proceed to the Ka`ba but he remained in Medina and no permissible thing was regarded as illegal for him then}}
\hadithdefcmd{bukhari}{1700}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ أَنَّ زِيَادَ بْنَ أَبِي سُفْيَانَ كَتَبَ إِلَى عَائِشَةَ ـ رضى الله عنها ـ إِنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ مَنْ أَهْدَى هَدْيًا حَرُمَ عَلَيْهِ مَا يَحْرُمُ عَلَى الْحَاجِّ حَتَّى يُنْحَرَ هَدْيُهُ‏.‏ قَالَتْ عَمْرَةُ فَقَالَتْ عَائِشَةُ ـ رضى الله عنها ـ لَيْسَ كَمَا قَالَ ابْنُ عَبَّاسٍ، أَنَا فَتَلْتُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ، ثُمَّ قَلَّدَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدَيْهِ، ثُمَّ بَعَثَ بِهَا مَعَ أَبِي فَلَمْ يَحْرُمْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم شَىْءٌ أَحَلَّهُ اللَّهُ حَتَّى نُحِرَ الْهَدْىُ‏.‏\hadithno{1700}\hadithtrans{Narrated `Abdullah bin Abu Bakr bin `Amr bin Hazm:That `Amra bint `Abdur-Rahman had told him, "Zaid bin Abu Sufyan wrote to `Aisha that `Abdullah bin `Abbas had stated, 'Whoever sends his Hadi (to the Ka`ba), all the things which are illegal for a (pilgrim) become illegal for that person till he slaughters it (i.e. till the 10th of Dhul-Hijja).' " `Amra added, `Aisha said, 'It is not like what Ibn `Abbas had said: I twisted the garlands of the Hadis of Allah's Messenger (ﷺ) with my own hands. Then Allah's Messenger (ﷺ) put them round their necks with his own hands, sending them with my father; Yet nothing permitted by Allah was considered illegal for Allah's Apostle till he slaughtered the Hadis}}
\hadithdefcmd{bukhari}{1701}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَهْدَى النَّبِيُّ صلى الله عليه وسلم مَرَّةً غَنَمًا‏.‏\hadithno{1701}\hadithtrans{Narrated `Aisha:Once the Prophet (ﷺ) sent sheep as Hadi}}
\hadithdefcmd{bukhari}{1702}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كُنْتُ أَفْتِلُ الْقَلاَئِدَ لِلنَّبِيِّ صلى الله عليه وسلم فَيُقَلِّدُ الْغَنَمَ، وَيُقِيمُ فِي أَهْلِهِ حَلاَلاً‏.‏\hadithno{1702}\hadithtrans{Narrated `Aisha:I used to make the garlands for (the Hadis of) the Prophet (ﷺ) and he would garland the sheep (with them) and would stay with his family as a non-Muhrim}}
\hadithdefcmd{bukhari}{1703}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا مَنْصُورُ بْنُ الْمُعْتَمِرِ،‏.‏ وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ الْغَنَمِ لِلنَّبِيِّ صلى الله عليه وسلم فَيَبْعَثُ بِهَا، ثُمَّ يَمْكُثُ حَلاَلاً‏.‏\hadithno{1703}\hadithtrans{Narrated Aisha:I used to twist the garlands for the sheep of the Prophet (ﷺ) and he would send them (to the Ka`ba), and stay as a non-Muhrim}}
\hadithdefcmd{bukhari}{1704}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ فَتَلْتُ لِهَدْىِ النَّبِيِّ صلى الله عليه وسلم ـ تَعْنِي الْقَلاَئِدَ ـ قَبْلَ أَنْ يُحْرِمَ‏.‏\hadithno{1704}\hadithtrans{Narrated `Aisha:I twisted (the garlands) for the Hadis of the Prophet (ﷺ) before he assumed Ihram}}
\hadithdefcmd{bukhari}{1705}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْقَاسِمِ، عَنْ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ قَالَتْ فَتَلْتُ قَلاَئِدَهَا مِنْ عِهْنٍ كَانَ عِنْدِي‏.‏\hadithno{1705}\hadithtrans{Narrated `Aisha:I twisted the garlands of the Hadis from the wool which was with me}}
\hadithdefcmd{bukhari}{1706}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ مَعْمَرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً، قَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ قَالَ إِنَّهَا بَدَنَةٌ‏.‏ قَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ قَالَ فَلَقَدْ رَأَيْتُهُ رَاكِبَهَا يُسَايِرُ النَّبِيَّ صلى الله عليه وسلم وَالنَّعْلُ فِي عُنُقِهَا‏.‏ تَابَعَهُ مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1706}\hadithtrans{Narrated `Ikrima:Abu Huraira said, "The Prophet (ﷺ) saw a man driving a Badana (sacrificial camel). The Prophet (ﷺ) said (to him), 'Ride on it.' He replied, 'It is a Badana.' The Prophet (ﷺ) again said, 'Ride on it!' Abu Huraira added, 'Then I saw that man riding it, showing obedience to the Prophet (ﷺ), and a shoe was (hanging) from its neck.' " Narrated Abu Huraira: From the Prophet: (as above)}}
\hadithdefcmd{bukhari}{1707}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَتَصَدَّقَ بِجِلاَلِ الْبُدْنِ الَّتِي نَحَرْتُ وَبِجُلُودِهَا‏.‏\hadithno{1707}\hadithtrans{Narrated `Ali:Allah's Messenger (ﷺ) ordered me to give in charity the skin and the coverings of the Budn which I had slaughtered}}
\hadithdefcmd{bukhari}{1708}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، قَالَ أَرَادَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ الْحَجَّ عَامَ حَجَّةِ الْحَرُورِيَّةِ فِي عَهْدِ ابْنِ الزُّبَيْرِ ـ رضى الله عنهما ـ فَقِيلَ لَهُ إِنَّ النَّاسَ كَائِنٌ بَيْنَهُمْ قِتَالٌ، وَنَخَافُ أَنْ يَصُدُّوكَ‏.‏ فَقَالَ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏ إِذًا أَصْنَعَ كَمَا صَنَعَ، أُشْهِدُكُمْ أَنِّي أَوْجَبْتُ عُمْرَةً‏.‏ حَتَّى كَانَ بِظَاهِرِ الْبَيْدَاءِ قَالَ مَا شَأْنُ الْحَجِّ وَالْعُمْرَةِ إِلاَّ وَاحِدٌ، أُشْهِدُكُمْ أَنِّي جَمَعْتُ حَجَّةً مَعَ عُمْرَةٍ‏.‏ وَأَهْدَى هَدْيًا مُقَلَّدًا اشْتَرَاهُ حَتَّى قَدِمَ، فَطَافَ بِالْبَيْتِ وَبِالصَّفَا، وَلَمْ يَزِدْ عَلَى ذَلِكَ، وَلَمْ يَحْلِلْ مِنْ شَىْءٍ حَرُمَ مِنْهُ حَتَّى يَوْمِ النَّحْرِ، فَحَلَقَ وَنَحَرَ وَرَأَى أَنْ قَدْ قَضَى طَوَافَهُ الْحَجَّ وَالْعُمْرَةَ بِطَوَافِهِ الأَوَّلِ، ثُمَّ قَالَ كَذَلِكَ صَنَعَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{1708}\hadithtrans{Narrated Nafi`:Ibn `Umar intended to perform Hajj in the year of the Hajj of Al-Harawriya during the rule of Ibn Az-Zubair. Some people said to him, "It is very likely that there will be a fight among the people, and we are afraid that they might prevent you (from performing Hajj)." He replied, "Verily, in Allah's Messenger (ﷺ) there is a good example for you (to follow). In this case I would do the same as he had done. I make you witness that I have intended to perform `Umra." When he reached Al-Baida', he said, "The conditions for both Hajj and `Umra are the same. I make you witness that I have intended to perform Hajj along with `Umra." After that he took a garlanded Hadi (to Mecca) which he bought (on the way). When he reached (Mecca), he performed Tawaf of the Ka`ba and of Safa (and Marwa) and did not do more than that. He did not make legal for himself the things which were illegal for a Muhrim till it was the Day of Nahr (sacrifice), when he had his head shaved and slaughtered (the sacrifice) and considered sufficient his first Tawaf (between Safa and Marwa), as a (Sa`i) for his Hajj and `Umra both. He then said, "The Prophet (ﷺ) used to do like that}}
\hadithdefcmd{bukhari}{1709}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، قَالَتْ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ، لاَ نُرَى إِلاَّ الْحَجَّ، فَلَمَّا دَنَوْنَا مِنْ مَكَّةَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ، إِذَا طَافَ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ أَنْ يَحِلَّ، قَالَتْ فَدُخِلَ عَلَيْنَا يَوْمَ النَّحْرِ بِلَحْمِ بَقَرٍ‏.‏ فَقُلْتُ مَا هَذَا قَالَ نَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَزْوَاجِهِ‏.‏ قَالَ يَحْيَى فَذَكَرْتُهُ لِلْقَاسِمِ، فَقَالَ أَتَتْكَ بِالْحَدِيثِ عَلَى وَجْهِهِ‏.‏\hadithno{1709}\hadithtrans{Narrated `Amra bint `Abdur-Rahman:I heard `Aisha saying, "Five days before the end of Dhul-Qa'da we set out from Medina in the company of Allah's Messenger (ﷺ) with the intention of performing Hajj only. When we approached Mecca, Allah's Messenger (ﷺ) ordered those who had no Hadi with them to finish their Ihram after performing Tawaf of the Ka`ba and (Sa`i) between Safa and Marwa." `Aisha added, "On the day of Nahr (slaughtering of sacrifice) beef was brought to us. I asked, 'What is this?' The reply was, 'Allah's Apostle (ﷺ) has slaughtered (sacrifices) on behalf of his wives}}
\hadithdefcmd{bukhari}{1710}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ خَالِدَ بْنَ الْحَارِثِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ ـ رضى الله عنه ـ كَانَ يَنْحَرُ فِي الْمَنْحَرِ‏.‏ قَالَ عُبَيْدُ اللَّهِ مَنْحَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1710}\hadithtrans{Narrated Nafi`:`Abdullah (bin `Umar), used to slaughter (his sacrifice) at the Manhar. ('Ubaidullah, a sub-narrator said, "The Manhar of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{1711}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يَبْعَثُ بِهَدْيِهِ مِنْ جَمْعٍ مِنْ آخِرِ اللَّيْلِ، حَتَّى يُدْخَلَ بِهِ مَنْحَرُ النَّبِيِّ صلى الله عليه وسلم مَعَ حُجَّاجٍ فِيهِمُ الْحُرُّ وَالْمَمْلُوكُ‏.‏\hadithno{1711}\hadithtrans{Narrated Nafi`:Ibn `Umar used to send his Hadi from Jam' (to Mina) in the last third of the night with the pilgrims amongst whom there were free men and slaves, till it was taken into the Manhar (slaughtering place) of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{1712}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ وَذَكَرَ الْحَدِيثَ ـ قَالَ وَنَحَرَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ سَبْعَ بُدْنٍ قِيَامًا، وَضَحَّى بِالْمَدِينَةِ كَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ‏.‏ مُخْتَصَرًا‏.‏\hadithno{1712}\hadithtrans{Narrated Sahl bin Bakkar:The narration of Anas abridged, saying, "The Prophet (ﷺ) slaughtered seven Budn (camels) while standing, with his own hands. On the day of `Id-ul-Adha he slaughtered (sacrificed) two horned rams, black and white in color}}
\hadithdefcmd{bukhari}{1713}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ يُونُسَ، عَنِ زِيَادِ بْنِ جُبَيْرٍ، قَالَ رَأَيْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَتَى عَلَى رَجُلٍ، قَدْ أَنَاخَ بَدَنَتَهُ يَنْحَرُهَا، قَالَ ابْعَثْهَا قِيَامًا مُقَيَّدَةً، سُنَّةَ مُحَمَّدٍ صلى الله عليه وسلم‏.‏ وَقَالَ شُعْبَةُ عَنْ يُونُسَ أَخْبَرَنِي زِيَادٌ‏.‏\hadithno{1713}\hadithtrans{Narrated Ziyad bin Jubair:I saw Ibn `Umar passing by a man who had made his Badana sit to slaughter it. Ibn `Umar said, "Slaughter it while it is standing with one leg tied up as is the tradition of Muhammad}}
\hadithdefcmd{bukhari}{1714}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا، وَالْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ، فَبَاتَ بِهَا، فَلَمَّا أَصْبَحَ رَكِبَ رَاحِلَتَهُ، فَجَعَلَ يُهَلِّلُ وَيُسَبِّحُ، فَلَمَّا عَلاَ عَلَى الْبَيْدَاءِ لَبَّى بِهِمَا جَمِيعًا، فَلَمَّا دَخَلَ مَكَّةَ أَمَرَهُمْ أَنْ يَحِلُّوا‏.‏ وَنَحَرَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ سَبْعَ بُدْنٍ قِيَامًا، وَضَحَّى بِالْمَدِينَةِ كَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ‏.‏\hadithno{1714}\hadithtrans{Narrated Anas:The Prophet (ﷺ) offered four rak`at of Zuhr prayer at Medina; and two rak`at of `Asr prayer at Dhil- Hulaifa and spent the night there and when (the day) dawned, he mounted his Mount and started saying, "None has the right to be worshipped but Allah, and Glorified be Allah." When he reached Al- Baida' he recited Talbiya for both Hajj and `Umra. And when he arrived at Mecca, he ordered them (his companions) to finish their Ihram. The Prophet (ﷺ) slaughtered seven Budn (camel) with his own hands while the camels were standing He also sacrificed two horned rams (black and white in color) at Medina}}
\hadithdefcmd{bukhari}{1715}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا، وَالْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ‏.‏ وَعَنْ أَيُّوبَ عَنْ رَجُلٍ عَنْ أَنَسٍ ـ رضى الله عنه ـ ثُمَّ بَاتَ حَتَّى أَصْبَحَ، فَصَلَّى الصُّبْحَ، ثُمَّ رَكِبَ رَاحِلَتَهُ حَتَّى إِذَا اسْتَوَتْ بِهِ الْبَيْدَاءَ أَهَلَّ بِعُمْرَةٍ وَحَجَّةٍ‏.‏\hadithno{1715}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) offered four rak`at of Zuhr prayer at Medina and two rak`at of `Asr prayer at Dhul-Hulaifa. Narrated Aiyub: "A man said: Anas said, "Then he (the Prophet (ﷺ) passed the night there till dawn and then he offered the morning (Fajr) prayer, and mounted his Mount and when it arrived at Al-Baida' he assumed Ihram for both `Umra and Hajj}}
\hadithdefcmd{bukhari}{1716}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، قَالَ أَخْبَرَنِي ابْنُ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم فَقُمْتُ عَلَى الْبُدْنِ، فَأَمَرَنِي فَقَسَمْتُ لُحُومَهَا، ثُمَّ أَمَرَنِي فَقَسَمْتُ جِلاَلَهَا وَجُلُودَهَا‏.‏ قَالَ سُفْيَانُ وَحَدَّثَنِي عَبْدُ الْكَرِيمِ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ أَمَرَنِي النَّبِيُّ صلى الله عليه وسلم أَنْ أَقُومَ عَلَى الْبُدْنِ، وَلاَ أُعْطِيَ عَلَيْهَا شَيْئًا فِي جِزَارَتِهَا‏.‏\hadithno{1716}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) sent me to supervise the (slaughtering of) Budn (Hadi camels) and ordered me to distribute their meat, and then he ordered me to distribute their covering sheets and skins. 'Ali added, "The Prophet (ﷺ) ordered me to supervise the slaughtering (of the Budn) and not to give anything (of their bodies) to the butcher as wages for slaughtering}}
\hadithdefcmd{bukhari}{1717}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، وَعَبْدُ الْكَرِيمِ الْجَزَرِيُّ، أَنَّ مُجَاهِدًا، أَخْبَرَهُمَا أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى أَخْبَرَهُ أَنَّ عَلِيًّا ـ رضى الله عنه ـ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ أَنْ يَقُومَ عَلَى بُدْنِهِ، وَأَنْ يَقْسِمَ بُدْنَهُ كُلَّهَا، لُحُومَهَا وَجُلُودَهَا وَجِلاَلَهَا، وَلاَ يُعْطِيَ فِي جِزَارَتِهَا شَيْئًا‏.‏\hadithno{1717}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) ordered me to supervise the (slaughtering) of Budn (Hadi camel) and to distribute their meat, skins and covering sheets in charity and not to give anything (of their bodies) to the butcher as wages for slaughtering}}
\hadithdefcmd{bukhari}{1718}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَيْفُ بْنُ أَبِي سُلَيْمَانَ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ حَدَّثَنِي ابْنُ أَبِي لَيْلَى، أَنَّ عَلِيًّا ـ رضى الله عنه ـ حَدَّثَهُ قَالَ أَهْدَى النَّبِيُّ صلى الله عليه وسلم مِائَةَ بَدَنَةٍ، فَأَمَرَنِي بِلُحُومِهَا فَقَسَمْتُهَا، ثُمَّ أَمَرَنِي بِجِلاَلِهَا فَقَسَمْتُهَا، ثُمَّ بِجُلُودِهَا فَقَسَمْتُهَا‏.‏\hadithno{1718}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) offered one hundred Budn as Hadi and ordered me to distribute their meat (in charity) and I did so. Then he ordered me to distribute their covering sheets in charity and I did so. Then he ordered me to distribute their skins in charity and I did so}}
\hadithdefcmd{bukhari}{1719}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنَا عَطَاءٌ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ كُنَّا لاَ نَأْكُلُ مِنْ لُحُومِ بُدْنِنَا فَوْقَ ثَلاَثِ مِنًى، فَرَخَّصَ لَنَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ كُلُوا وَتَزَوَّدُوا ‏"‏‏.‏ فَأَكَلْنَا وَتَزَوَّدْنَا‏.‏ قُلْتُ لِعَطَاءٍ أَقَالَ حَتَّى جِئْنَا الْمَدِينَةَ قَالَ لاَ‏.‏\hadithno{1719}\hadithtrans{Narrated Ibn Juraij:`Ata' said, "I heard Jabir bin `Abdullah saying, 'We never ate the meat of the Budn for more than three days of Mina. Later, the Prophet (ﷺ) gave us permission by saying: 'Eat and take (meat) with you. So we ate (some) and took (some) with us.' " I asked `Ata', "Did Jabir say (that they went on eating the meat) till they reached Medina?" `Ata' replied, "No}}
\hadithdefcmd{bukhari}{1720}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي يَحْيَى، قَالَ حَدَّثَتْنِي عَمْرَةُ، قَالَتْ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ، وَلاَ نَرَى إِلاَّ الْحَجَّ، حَتَّى إِذَا دَنَوْنَا مِنْ مَكَّةَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ إِذَا طَافَ بِالْبَيْتِ ثُمَّ يَحِلُّ‏.‏ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ فَدُخِلَ عَلَيْنَا يَوْمَ النَّحْرِ بِلَحْمِ بَقَرٍ فَقُلْتُ مَا هَذَا فَقِيلَ ذَبَحَ النَّبِيُّ صلى الله عليه وسلم عَنْ أَزْوَاجِهِ‏.‏ قَالَ يَحْيَى فَذَكَرْتُ هَذَا الْحَدِيثَ لِلْقَاسِمِ‏.‏ فَقَالَ أَتَتْكَ بِالْحَدِيثِ عَلَى وَجْهِهِ‏.‏\hadithno{1720}\hadithtrans{Narrated `Amra:I heard `Aisha saying, "We set out (from Medina) along with Allah's Messenger (ﷺ) five days before the end of Dhul-Qa'da with the intention of performing Hajj only. When we approached Mecca, Allah's Apostle ordered those who had no Hadi along with them to finish the Ihram after performing Tawaf of the Ka`ba, (Safa and Marwa). `Aisha added, "Beef was brought to us on the Day of Nahr and I said, 'What is this?' Somebody said, 'The Prophet (ﷺ) has slaughtered (cows) on behalf of his wives}}
\hadithdefcmd{bukhari}{1721}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مَنْصُورٌ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَمَّنْ حَلَقَ قَبْلَ أَنْ يَذْبَحَ وَنَحْوِهِ‏.‏ فَقَالَ ‏ "‏ لاَ حَرَجَ، لاَ حَرَجَ ‏"‏‏.‏\hadithno{1721}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was asked about a person who had his head shaved before slaughtering (his Hadi) (or other similar ceremonies of Hajj). He replied, "There is no harm, there is no harm}}
\hadithdefcmd{bukhari}{1722}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، أَخْبَرَنَا أَبُو بَكْرٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ رَجُلٌ لِلنَّبِيِّ صلى الله عليه وسلم زُرْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏ قَالَ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏ قَالَ ذَبَحْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏ وَقَالَ عَبْدُ الرَّحِيمِ الرَّازِيُّ عَنِ ابْنِ خُثَيْمٍ أَخْبَرَنِي عَطَاءٌ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ الْقَاسِمُ بْنُ يَحْيَى حَدَّثَنِي ابْنُ خُثَيْمٍ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ عَفَّانُ أُرَاهُ عَنْ وُهَيْبٍ، حَدَّثَنَا ابْنُ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ حَمَّادٌ عَنْ قَيْسِ بْنِ سَعْدٍ وَعَبَّادِ بْنِ مَنْصُورٍ عَنْ عَطَاءٍ عَنْ جَابِرٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1722}\hadithtrans{Narrated Ibn `Abbas:A man said to the Prophet (ﷺ) "I performed the Tawaf-al-Ifada before the Rami (throwing pebbles at the Jamra)." The Prophet (ﷺ) replied, "There is no harm." The man said, "I had my head shaved before slaughtering." The Prophet (ﷺ) replied, "There is no harm." He said, "I have slaughtered the Hadi before the Rami." The Prophet (ﷺ) replied, "There is no harm}}
\hadithdefcmd{bukhari}{1723}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ رَمَيْتُ بَعْدَ مَا أَمْسَيْتُ‏.‏ فَقَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏ قَالَ حَلَقْتُ قَبْلَ أَنْ أَنْحَرَ‏.‏ قَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏\hadithno{1723}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was asked by a man who said, "I have done the Rami in the evening." The Prophet (ﷺ) replied, "There is no harm in it." Another man asked, "I had my head shaved before the slaughtering." The Prophet (ﷺ) replied, "There is no harm in it}}
\hadithdefcmd{bukhari}{1724}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ بِالْبَطْحَاءِ‏.‏ فَقَالَ ‏"‏ أَحَجَجْتَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ بِمَا أَهْلَلْتَ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ بِإِهْلاَلٍ كَإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ ‏"‏ أَحْسَنْتَ، انْطَلِقْ فَطُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ‏"‏‏.‏ ثُمَّ أَتَيْتُ امْرَأَةً مِنْ نِسَاءِ بَنِي قَيْسٍ، فَفَلَتْ رَأْسِي، ثُمَّ أَهْلَلْتُ بِالْحَجِّ، فَكُنْتُ أُفْتِي بِهِ النَّاسَ، حَتَّى خِلاَفَةِ عُمَرَ ـ رضى الله عنه ـ فَذَكَرْتُهُ لَهُ‏.‏ فَقَالَ إِنْ نَأْخُذْ بِكِتَابِ اللَّهِ فَإِنَّهُ يَأْمُرُنَا بِالتَّمَامِ، وَإِنْ نَأْخُذْ بِسُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَحِلَّ حَتَّى بَلَغَ الْهَدْىُ مَحِلَّهُ‏.‏\hadithno{1724}\hadithtrans{Narrated Abu Musa:I came upon Allah's Messenger (ﷺ) when he was at Al-Batha. He asked me, "Have you intended to perform the Hajj?" I replied in the affirmative. He asked, "For what have you assumed Ihram?" I replied," I have assumed Ihram with the same intention as that of the Prophet (ﷺ) ." The Prophet (ﷺ) said, "You have done well! Go and perform Tawaf round the Ka`ba and between Safa and Marwa." Then I went to one of the women of Bani Qais and she took out lice from my head. Later, I assumed the Ihram for Hajj. So, I used to give this verdict to the people till the caliphate of `Umar. When I told him about it, he said, "If we take (follow) the Holy Book, then it orders us to complete Hajj and `Umra (Hajj-at- Tamattu`) and if we follow the tradition of Allah's Messenger (ﷺ) then Allah's Messenger (ﷺ) did not finish his Ihram till the Hadi had reached its destination (had been slaughtered). (i.e. Hajj-al-Qiran). (See Hadith No)}}
\hadithdefcmd{bukhari}{1725}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ ـ رضى الله عنهم ـ أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ، مَا شَأْنُ النَّاسِ حَلُّوا بِعُمْرَةٍ وَلَمْ تَحْلِلْ أَنْتَ مِنْ عُمْرَتِكَ قَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي، وَقَلَّدْتُ هَدْيِي، فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏‏.‏\hadithno{1725}\hadithtrans{Narrated Ibn `Umar:Hafsa said, "O Allah's Messenger (ﷺ)! What is wrong with the people; they finished their Ihram after performing `Umra, but you have not finished it after your `Umra?" He replied, "I matted my hair and have garlanded my Hadi. So, I cannot finish my Ihram till I slaughter (my Hadi)}}
\hadithdefcmd{bukhari}{1726}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، قَالَ نَافِعٌ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ حَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّتِهِ‏.‏\hadithno{1726}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) (got) his head shaved after performing his Hajj}}
\hadithdefcmd{bukhari}{1727}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي نَافِعٌ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ مَرَّةً أَوْ مَرَّتَيْنِ‏.‏ قَالَ وَقَالَ عُبَيْدُ اللَّهِ حَدَّثَنِي نَافِعٌ وَقَالَ فِي الرَّابِعَةِ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏‏.‏\hadithno{1727}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "O Allah! Be merciful to those who have their head shaved." The people said, "O Allah's Messenger (ﷺ)! And (invoke Allah for) those who get their hair cut short." The Prophet (ﷺ) said, "O Allah! Be merciful to those who have their head shaved." The people said, "O Allah's Messenger (ﷺ)! And those who get their hair cut short." The Prophet (ﷺ) said (the third time), "And to those who get their hair cut short." Nafi` said that the Prophet (ﷺ) had said once or twice, "O Allah! Be merciful to those who get their head shaved," and on the fourth time he added, "And to those who have their hair cut short}}
\hadithdefcmd{bukhari}{1728}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ اغْفِرْ لِلْمُحَلِّقِينَ ‏"‏‏.‏ قَالُوا وَلِلْمُقَصِّرِينَ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِلْمُحَلِّقِينَ ‏"‏‏.‏ قَالُوا وَلِلْمُقَصِّرِينَ‏.‏ قَالَهَا ثَلاَثًا‏.‏ قَالَ ‏"‏ وَلِلْمُقَصِّرِينَ ‏"‏‏.‏\hadithno{1728}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "O Allah! Forgive those who get their heads shaved." The people asked. "Also those who get their hair cut short?" The Prophet (ﷺ) said, "O Allah! Forgive those who have their heads shaved." The people said, "Also those who get their hair cut short?" The Prophet (invoke Allah for those who have their heads shaved and) at the third time said, "also (forgive) those who get their hair cut short}}
\hadithdefcmd{bukhari}{1729}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، قَالَ حَلَقَ النَّبِيُّ صلى الله عليه وسلم وَطَائِفَةٌ مِنْ أَصْحَابِهِ، وَقَصَّرَ بَعْضُهُمْ‏.‏\hadithno{1729}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) and some of his companions got their heads shaved and some others got their hair cut short}}
\hadithdefcmd{bukhari}{1730}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مُعَاوِيَةَ ـ رضى الله عنهم ـ قَالَ قَصَّرْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِشْقَصٍ‏.‏\hadithno{1730}\hadithtrans{Narrated Muawiya:I cut short the hair of Allah's Messenger (ﷺ) with a long blade}}
\hadithdefcmd{bukhari}{1731}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي كُرَيْبٌ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ أَمَرَ أَصْحَابَهُ أَنْ يَطُوفُوا بِالْبَيْتِ، وَبِالصَّفَا وَالْمَرْوَةِ، ثُمَّ يَحِلُّوا، وَيَحْلِقُوا أَوْ يُقَصِّرُوا‏.‏\hadithno{1731}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) came to Mecca, he ordered his Companions to perform Tawaf round the Ka`ba and between Safa and Marwa, to finish their Ihram and get their hair shaved off or cut short}}
\hadithdefcmd{bukhari}{1732}{وَقَالَ لَنَا أَبُو نُعَيْمٍ حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ طَافَ طَوَافًا وَاحِدًا، ثُمَّ يَقِيلُ ثُمَّ يَأْتِي مِنًى ـ يَعْنِي يَوْمَ النَّحْرِ ـ‏.‏ وَرَفَعَهُ عَبْدُ الرَّزَّاقِ أَخْبَرَنَا عُبَيْدُ اللَّهِ‏.‏\hadithno{1732}\hadithtrans{Narrated Nafi' that Ibn 'Umar (ra) performed only one Tawaf. He would take an afternoon nap and then return to Mina. That was on the day of Nahr (slaughtering)}}
\hadithdefcmd{bukhari}{1733}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ حَجَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فَأَفَضْنَا يَوْمَ النَّحْرِ، فَحَاضَتْ صَفِيَّةُ، فَأَرَادَ النَّبِيُّ صلى الله عليه وسلم مِنْهَا مَا يُرِيدُ الرَّجُلُ مِنْ أَهْلِهِ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهَا حَائِضٌ‏.‏ قَالَ ‏"‏ حَابِسَتُنَا هِيَ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، أَفَاضَتْ يَوْمَ النَّحْرِ‏.‏ قَالَ ‏"‏ اخْرُجُوا ‏"‏‏.‏ وَيُذْكَرُ عَنِ الْقَاسِمِ وَعُرْوَةَ وَالأَسْوَدِ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَفَاضَتْ صَفِيَّةُ يَوْمَ النَّحْرِ‏.‏\hadithno{1733}\hadithtrans{Narrated `Aisha:We performed Hajj with the Prophet (ﷺ) and performed Tawaf-al-ifada on the Day of Nahr (slaughtering). Safiya got her menses and the Prophet desired from her what a husband desires from his wife. I said to him, "O Allah's Messenger (ﷺ)! She is having her menses." He said, "Is she going to detain us?" We informed him that she had performed Tawaf-al-Ifada on the Day of Nahr. He said, "(Then you can) depart}}
\hadithdefcmd{bukhari}{1734}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قِيلَ لَهُ فِي الذَّبْحِ وَالْحَلْقِ وَالرَّمْىِ وَالتَّقْدِيمِ وَالتَّأْخِيرِ فَقَالَ ‏ "‏ لاَ حَرَجَ ‏"‏‏.‏\hadithno{1734}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was asked about the slaughtering, shaving (of the head), and the doing of Rami before or after the due times. He said, "There is no harm in that}}
\hadithdefcmd{bukhari}{1735}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُسْأَلُ يَوْمَ النَّحْرِ بِمِنًى، فَيَقُولُ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏ فَسَأَلَهُ رَجُلٌ، فَقَالَ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ‏.‏ قَالَ ‏"‏ اذْبَحْ، وَلاَ حَرَجَ ‏"‏‏.‏ وَقَالَ رَمَيْتُ بَعْدَ مَا أَمْسَيْتُ‏.‏ فَقَالَ ‏"‏ لاَ حَرَجَ ‏"‏‏.‏\hadithno{1735}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was asked (as regards the ceremonies of Hajj) at Mina on the Day of Nahr and he replied that there was no harm. Then a man said to him, "I got my head shaved before slaughtering." He replied, "Slaughter (now) and there is no harm in it." (Another) man said, "I did the Rami (of the Jimar) after midday." The Prophet (ﷺ) replied, "There was no harm in it}}
\hadithdefcmd{bukhari}{1736}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَفَ فِي حَجَّةِ الْوَدَاعِ، فَجَعَلُوا يَسْأَلُونَهُ، فَقَالَ رَجُلٌ لَمْ أَشْعُرْ فَحَلَقْتُ قَبْلَ أَنْ أَذْبَحَ‏.‏ قَالَ ‏"‏ اذْبَحْ وَلاَ حَرَجَ ‏"‏‏.‏ فَجَاءَ آخَرُ فَقَالَ لَمْ أَشْعُرْ فَنَحَرْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏‏.‏ فَمَا سُئِلَ يَوْمَئِذٍ عَنْ شَىْءٍ قُدِّمَ وَلاَ أُخِّرَ إِلاَّ قَالَ افْعَلْ وَلاَ حَرَجَ‏.‏\hadithno{1736}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) stopped (for a while near the Jimar at Mina) during his last Hajj and the people started asking him questions. A man said, "Ignorantly I got my head shaved before slaughtering." The Prophet replied, "Slaughter (now) and there is no harm in it." Another man said, "Unknowingly I slaughtered the Hadi before doing the Rami." The Prophet (ﷺ) said, "Do Rami now and there is no harm in it." So, on that day, when the Prophet (ﷺ) was asked about anything (about the ceremonies of Hajj) done before or after (its stated time) his reply was, "Do it (now) and there is no harm}}
\hadithdefcmd{bukhari}{1737}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي الزُّهْرِيُّ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنه ـ حَدَّثَهُ أَنَّهُ، شَهِدَ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ النَّحْرِ، فَقَامَ إِلَيْهِ رَجُلٌ، فَقَالَ كُنْتُ أَحْسِبُ أَنَّ كَذَا قَبْلَ كَذَا‏.‏ ثُمَّ قَامَ آخَرُ فَقَالَ كُنْتُ أَحْسِبُ أَنَّ كَذَا قَبْلَ كَذَا حَلَقْتُ قَبْلَ أَنْ أَنْحَرَ، نَحَرْتُ قَبْلَ أَنْ أَرْمِيَ‏.‏ وَأَشْبَاهَ ذَلِكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ افْعَلْ وَلاَ حَرَجَ ‏"‏‏.‏ لَهُنَّ كُلِّهِنَّ، فَمَا سُئِلَ يَوْمَئِذٍ عَنْ شَىْءٍ إِلاَّ قَالَ افْعَلْ وَلاَ حَرَجَ‏.‏\hadithno{1737}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:I witnessed the Prophet (ﷺ) when he was delivering the sermon on the Day of Nahr. A man stood up and said, "I thought that such and such was to be done before such and such. I got my hair shaved before slaughtering." (Another said), "I slaughtered the Hadi before doing the Rami." So, the people asked about many similar things. The Prophet (ﷺ) said, "Do it (now) and there is no harm in all these cases." Whenever the Prophet (ﷺ) was asked about anything on that day, he replied, "Do it (now) and there is no harm in it}}
\hadithdefcmd{bukhari}{1738}{حَدَّثَنَا إِسْحَاقُ، قَالَ أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عِيسَى بْنُ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ قَالَ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى نَاقَتِهِ‏.‏ فَذَكَرَ الْحَدِيثَ‏.‏ تَابَعَهُ مَعْمَرٌ عَنِ الزُّهْرِيِّ‏.‏\hadithno{1738}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:Allah's Messenger (ﷺ) stopped while on his she-camel (the sub-narrator then narrated the Hadith as above, i.e)}}
\hadithdefcmd{bukhari}{1739}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا فُضَيْلُ بْنُ غَزْوَانَ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ النَّاسَ يَوْمَ النَّحْرِ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ‏.‏ أَىُّ يَوْمٍ هَذَا ‏"‏‏.‏ قَالُوا يَوْمٌ حَرَامٌ‏.‏ قَالَ ‏"‏ فَأَىُّ بَلَدٍ هَذَا ‏"‏‏.‏ قَالُوا بَلَدٌ حَرَامٌ‏.‏ قَالَ ‏"‏ فَأَىُّ شَهْرٍ هَذَا ‏"‏‏.‏ قَالُوا شَهْرٌ حَرَامٌ‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ وَأَعْرَاضَكُمْ عَلَيْكُمْ حَرَامٌ، كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا ‏"‏‏.‏ فَأَعَادَهَا مِرَارًا، ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ فَوَالَّذِي نَفْسِي بِيَدِهِ إِنَّهَا لَوَصِيَّتُهُ إِلَى أُمَّتِهِ ـ ‏"‏ فَلْيُبْلِغِ الشَّاهِدُ الْغَائِبَ، لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{1739}\hadithtrans{Narrated `Ikrima:Ibn `Abbas said: "Allah's Messenger (ﷺ) delivered a sermon on the Day of Nahr, and said, 'O people! (Tell me) what is the day today?' The people replied, 'It is the forbidden (sacred) day.' He asked again, 'What town is this?' They replied, 'It is the forbidden (Sacred) town.' He asked, 'Which month is this?' They replied, 'It is the forbidden (Sacred) month.' He said, 'No doubt! Your blood, your properties, and your honor are sacred to one another like the sanctity of this day of yours, in this (sacred) town (Mecca) of yours, in this month of yours.' The Prophet (ﷺ) repeated his statement again and again. After that he raised his head and said, 'O Allah! Haven't conveyed (Your Message) to them'. Haven't I conveyed Your Message to them?' " Ibn `Abbas added, "By Him in Whose Hand my soul is, the following was his will (Prophet's will) to his followers:--It is incumbent upon those who are present to convey this information to those who are absent Beware don't renegade (as) disbelievers (turn into infidels) after me, Striking the necks (cutting the throats) of one another}}
\hadithdefcmd{bukhari}{1740}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَمْرٌو، قَالَ سَمِعْتُ جَابِرَ بْنَ زَيْدٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ بِعَرَفَاتٍ‏.‏ تَابَعَهُ ابْنُ عُيَيْنَةَ عَنْ عَمْرٍو‏.‏\hadithno{1740}\hadithtrans{Narrated Ibn `Abbas:I heard the Prophet (ﷺ) delivering a sermon at `Arafat}}
\hadithdefcmd{bukhari}{1741}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا قُرَّةُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ،، وَرَجُلٌ، أَفْضَلُ فِي نَفْسِي مِنْ عَبْدِ الرَّحْمَنِ حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي بَكْرَةَ ـ رضى الله عنه ـ قَالَ خَطَبَنَا النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّحْرِ، قَالَ ‏"‏ أَتَدْرُونَ أَىُّ يَوْمٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ‏.‏ قَالَ ‏"‏ أَلَيْسَ يَوْمَ النَّحْرِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ أَىُّ شَهْرٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ‏.‏ فَقَالَ ‏"‏ أَلَيْسَ ذُو الْحَجَّةِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ أَىُّ بَلَدٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ‏.‏ قَالَ ‏"‏ أَلَيْسَتْ بِالْبَلْدَةِ الْحَرَامِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ عَلَيْكُمْ حَرَامٌ، كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي شَهْرِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا، إِلَى يَوْمِ تَلْقَوْنَ رَبَّكُمْ‏.‏ أَلاَ هَلْ بَلَّغْتُ ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اشْهَدْ، فَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ، فَرُبَّ مُبَلَّغٍ أَوْعَى مِنْ سَامِعٍ، فَلاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{1741}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) delivered to us a sermon on the Day of Nahr. He said, "Do you know what is the day today?" We said, "Allah and His Apostle know better." He remained silent till we thought that he might give that day another name. He said, "Isn't it the Day of Nahr?" We said, "It is." He further asked, "Which month is this?" We said, "Allah and His Apostle know better." He remained silent till we thought that he might give it another name. He then said, "Isn't it the month of Dhul-Hijja?" We replied: "Yes! It is." He further asked, "What town is this?" We replied, "Allah and His Apostle know it better." He remained silent till we thought that he might give it another name. He then said, "Isn't it the forbidden (Sacred) town (of Mecca)?" We said, "Yes. It is." He said, "No doubt, your blood and your properties are sacred to one another like the sanctity of this day of yours, in this month of yours, in this town of yours, till the day you meet your Lord. No doubt! Haven't I conveyed Allah's message to you? They said, "Yes." He said, "O Allah! Be witness. So it is incumbent upon those who are present to convey it (this information) to those who are absent because the informed one might comprehend it (what I have said) better than the present audience, who will convey it to him. Beware! Do not renegade (as) disbelievers after me by striking the necks (cutting the throats) of one another}}
\hadithdefcmd{bukhari}{1742}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَاصِمُ بْنُ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم بِمِنًى ‏"‏ أَتَدْرُونَ أَىُّ يَوْمٍ هَذَا ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَقَالَ ‏"‏ فَإِنَّ هَذَا يَوْمٌ حَرَامٌ، أَفَتَدْرُونَ أَىُّ بَلَدٍ هَذَا ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ بَلَدٌ حَرَامٌ، أَفَتَدْرُونَ أَىُّ شَهْرٍ هَذَا ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ شَهْرٌ حَرَامٌ ـ قَالَ ـ فَإِنَّ اللَّهَ حَرَّمَ عَلَيْكُمْ دِمَاءَكُمْ وَأَمْوَالَكُمْ وَأَعْرَاضَكُمْ، كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي شَهْرِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا ‏"‏‏.‏ وَقَالَ هِشَامُ بْنُ الْغَازِ أَخْبَرَنِي نَافِعٌ عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ وَقَفَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّحْرِ بَيْنَ الْجَمَرَاتِ فِي الْحَجَّةِ الَّتِي حَجَّ بِهَذَا، وَقَالَ ‏"‏ هَذَا يَوْمُ الْحَجِّ الأَكْبَرِ ‏"‏، فَطَفِقَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ اللَّهُمَّ اشْهَدْ ‏"‏‏.‏ وَوَدَّعَ النَّاسَ‏.‏ فَقَالُوا هَذِهِ حَجَّةُ الْوَدَاعِ‏.‏\hadithno{1742}\hadithtrans{Narrated Ibn `Umar:At Mina, the Prophet (ﷺ) said, "Do you know what is the day today?" The people replied, "Allah and His Apostle know it better." He said, "It is the forbidden (sacred) day. And do you know what town is this?" They replied, "Allah and His Apostle know it better." He said, "This is the forbidden (Sacred) town (Mecca). And do you know which month is this?" The people replied, "Allah and His Apostle know it better." He said, "This is the forbidden (sacred) month." The Prophet (ﷺ) added, "No doubt, Allah made your blood, your properties, and your honor sacred to one another like the sanctity of this day of yours in this month of yours in this town of yours." Narrated Ibn `Umar: On the Day of Nahr (10th of Dhul-Hijja), the Prophet (ﷺ) stood in between the Jamrat during his Hajj which he performed (as in the previous Hadith) and said, "This is the greatest Day (i.e. 10th of Dhul-Hijjah)." The Prophet (ﷺ) started saying repeatedly, "O Allah! Be Witness (I have conveyed Your Message)." He then bade the people farewell. The people said, "This is Hajjat-al-Wada}}
\hadithdefcmd{bukhari}{1743}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{1743}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) permitted the people who provided the pilgrims with water to stay at Mecca during the nights of Mina}}
\hadithdefcmd{bukhari}{1744}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَذِنَ‏.‏\hadithno{1744}\hadithtrans{Narrated Ibn `Umar:That the Prophet (ﷺ) allowed people who provided the pilgrims with water to stay at Mecca during the nights of Mina}}
\hadithdefcmd{bukhari}{1745}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ الْعَبَّاسَ ـ رضى الله عنه ـ اسْتَأْذَنَ النَّبِيَّ صلى الله عليه وسلم لِيَبِيتَ بِمَكَّةَ لَيَالِيَ مِنًى، مِنْ أَجْلِ سِقَايَتِهِ، فَأَذِنَ لَهُ‏.‏ تَابَعَهُ أَبُو أُسَامَةَ وَعُقْبَةُ بْنُ خَالِدٍ وَأَبُو ضَمْرَةَ‏.‏\hadithno{1745}\hadithtrans{Narrated Ibn `Umar:Al-Abbas asked the permission from the Prophet (ﷺ) to stay at Mecca during the nights of Mina in order to provide water to the people, so the Prophet (ﷺ) allowed him}}
\hadithdefcmd{bukhari}{1746}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ وَبَرَةَ، قَالَ سَأَلْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ مَتَى أَرْمِي الْجِمَارَ قَالَ إِذَا رَمَى إِمَامُكَ فَارْمِهْ‏.‏ فَأَعَدْتُ عَلَيْهِ الْمَسْأَلَةَ، قَالَ كُنَّا نَتَحَيَّنُ، فَإِذَا زَالَتِ الشَّمْسُ رَمَيْنَا‏.‏\hadithno{1746}\hadithtrans{Narrated Wabra:I asked Ibn `Umar, "When should I do the Rami of the Jimar?" He replied, "When your leader does that." I asked him again the same question. He replied, "We used to wait till the sun declined and then we would do the Rami (i.e. on the 11th and 12th of Dhul-Hijja)}}
\hadithdefcmd{bukhari}{1747}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ رَمَى عَبْدُ اللَّهِ مِنْ بَطْنِ الْوَادِي، فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ، إِنَّ نَاسًا يَرْمُونَهَا مِنْ فَوْقِهَا، فَقَالَ وَالَّذِي لاَ إِلَهَ غَيْرُهُ هَذَا مَقَامُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ صلى الله عليه وسلم‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْوَلِيدِ حَدَّثَنَا سُفْيَانُ حَدَّثَنَا الأَعْمَشُ بِهَذَا‏.‏\hadithno{1747}\hadithtrans{Narrated `Abdur-Rahman bin Yazid:`Abdullah, did the Rami from the middle of the valley. So, I said, "O, Abu `Abdur-Rahman! Some people do the Rami (of the Jamra) from above it (i.e. from the top of the valley)." He said, "By Him except whom none has the right to be worshipped, this is the place from where the one on whom Surat-al-Baqara was revealed (i.e. Allah's Messenger (ﷺ)) did the Rami}}
\hadithdefcmd{bukhari}{1748}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَ��ْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّهُ انْتَهَى إِلَى الْجَمْرَةِ الْكُبْرَى جَعَلَ الْبَيْتَ عَنْ يَسَارِهِ، وَمِنًى عَنْ يَمِينِهِ، وَرَمَى بِسَبْعٍ، وَقَالَ هَكَذَا رَمَى الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ صلى الله عليه وسلم‏.‏\hadithno{1748}\hadithtrans{Narrated `Abdur-Rahman bin Yazid:When `Abdullah, reached the big Jamra (i.e. Jamrat-ul-Aqaba) he kept the Ka`ba on the left side and Mina on his right side and threw seven pebbles (at the Jamra) and said, "The one on whom Surat-al- Baqara was revealed (i.e. the Prophet) had done the Rami similarly}}
\hadithdefcmd{bukhari}{1749}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الْحَكَمُ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، أَنَّهُ حَجَّ مَعَ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ فَرَآهُ يَرْمِي الْجَمْرَةَ الْكُبْرَى بِسَبْعِ حَصَيَاتٍ، فَجَعَلَ الْبَيْتَ عَنْ يَسَارِهِ، وَمِنًى عَنْ يَمِينِهِ، ثُمَّ قَالَ هَذَا مَقَامُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ‏.‏\hadithno{1749}\hadithtrans{Narrated `Abdur-Rahman bin Yazid:I performed Hajj with Ibn Mas`ud , and saw him doing Rami of the big Jamra (Jamrat-ul-Aqaba) with seven small pebbles, keeping the Ka`ba on his left side and Mina on his right. He then said, "This is the place where the one on whom Surat-al-Baqara was revealed (i.e. Allah's Messenger (ﷺ) ) stood}}
\hadithdefcmd{bukhari}{1750}{حَدَّثَنَا مُسَدَّدٌ، عَنْ عَبْدِ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ الْحَجَّاجَ، يَقُولُ عَلَى الْمِنْبَرِ السُّورَةُ الَّتِي يُذْكَرُ فِيهَا الْبَقَرَةُ، وَالسُّورَةُ الَّتِي يُذْكَرُ فِيهَا آلُ عِمْرَانَ، وَالسُّورَةُ الَّتِي يُذْكَرُ فِيهَا النِّسَاءُ‏.‏ قَالَ فَذَكَرْتُ ذَلِكَ لإِبْرَاهِيمَ، فَقَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ أَنَّهُ كَانَ مَعَ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ حِينَ رَمَى جَمْرَةَ الْعَقَبَةِ، فَاسْتَبْطَنَ الْوَادِيَ، حَتَّى إِذَا حَاذَى بِالشَّجَرَةِ اعْتَرَضَهَا، فَرَمَى بِسَبْعِ حَصَيَاتٍ، يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ، ثُمَّ قَالَ مِنْ هَا هُنَا وَالَّذِي لاَ إِلَهَ غَيْرُهُ قَامَ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ صلى الله عليه وسلم‏.‏\hadithno{1750}\hadithtrans{Narrated Al-A`mash:I heard Al-Hajjaj saying on the pulpit, "The Sura in which Al-Baqara (the cow) is mentioned and the Sura in which the family of `Imran is mentioned and the Sura in which the women (An-Nisa) is mentioned." I mentioned this to Ibrahim, and he said, `Abdur-Rahman bin Yazid told me, 'I was with Ibn Mas`ud, when he did the Rami of the Jamrat-ul-Aqaba. He went down the middle of the valley, and when he came near the tree (which was near the Jamra) he stood opposite to it and threw seven small pebbles and said: 'Allahu-Akbar' on throwing every pebble.' Then he said, 'By Him, except Whom none has the right to be worshipped, here (at this place) stood the one on whom Surat-al-Baqra was revealed (i.e. Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{1751}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ كَانَ يَرْمِي الْجَمْرَةَ الدُّنْيَا بِسَبْعِ حَصَيَاتٍ، يُكَبِّرُ عَلَى إِثْرِ كُلِّ حَصَاةٍ، ثُمَّ يَتَقَدَّمُ حَتَّى يُسْهِلَ فَيَقُومَ مُسْتَقْبِلَ الْقِبْلَةِ فَيَقُومُ طَوِيلاً، وَيَدْعُو وَيَرْفَعُ يَدَيْهِ، ثُمَّ يَرْمِي الْوُسْطَى، ثُمَّ يَأْخُذُ ذَاتَ الشِّمَالِ فَيَسْتَهِلُ وَيَقُومُ مُسْتَقْبِلَ الْقِبْلَةِ فَيَقُومُ طَوِيلاً وَيَدْعُو وَيَرْفَعُ يَدَيْهِ، وَيَقُومُ طَوِيلاً، ثُمَّ يَرْمِي جَمْرَةَ ذَاتِ الْعَقَبَةِ مِنْ بَطْنِ الْوَادِي، وَلاَ يَقِفُ عِنْدَهَا ثُمَّ يَنْصَرِفُ فَيَقُولُ هَكَذَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَفْعَلُهُ‏.‏\hadithno{1751}\hadithtrans{Narrated Salim:Ibn `Umar used to do Rami of the Jamrat-ud-Dunya (the Jamra near to the Khaif mosque) with seven small stones and used to recite Takbir on throwing every pebble. He then would go ahead till he reached the level ground where he would stand facing the Qibla for a long time to invoke (Allah) while raising his hands (while invoking). Then he would do Rami of the Jamrat-ul-Wusta (middle Jamra) and then he would go to the left towards the middle ground, where he would stand facing the Qibla. He would remain standing there for a long period to invoke (Allah) while raising his hands, and would stand there for a long period. Then he would do Rami of the Jamrat-ul-Aqaba from the middle of the valley, but he would not stay by it, and then he would leave and say, "I saw the Prophet (ﷺ) doing like this}}
\hadithdefcmd{bukhari}{1752}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يَرْمِي الْجَمْرَةَ الدُّنْيَا بِسَبْعِ حَصَيَاتٍ، ثُمَّ يُكَبِّرُ عَلَى إِثْرِ كُلِّ حَصَاةٍ، ثُمَّ يَتَقَدَّمُ فَيُسْهِلُ، فَيَقُومُ مُسْتَقْبِلَ الْقِبْلَةِ قِيَامًا طَوِيلاً، فَيَدْعُو وَيَرْفَعُ يَدَيْهِ، ثُمَّ يَرْمِي الْجَمْرَةَ الْوُسْطَى كَذَلِكَ، فَيَأْخُذُ ذَاتَ الشِّمَالِ فَيُسْهِلُ، وَيَقُومُ مُسْتَقْبِلَ الْقِبْلَةِ قِيَامًا طَوِيلاً، فَيَدْعُو وَيَرْفَعُ يَدَيْهِ، ثُمَّ يَرْمِي الْجَمْرَةَ ذَاتَ الْعَقَبَةِ مِنْ بَطْنِ الْوَادِي، وَلاَ يَقِفُ عِنْدَهَا، وَيَقُولُ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ‏.‏\hadithno{1752}\hadithtrans{Narrated Salim bin `Abdullah:`Abdullah bin `Umar used to do Rami of the Jamrat-ud-Dunya with seven small pebbles and used to recite Takbir on throwing each stone. He, then, would proceed further till he reached the level ground, where he would stay for a long time, facing the Qibla to invoke (Allah) while raising his hands. Then he would do Rami of the Jamrat-ul-Wusta similarly and would go to the left towards the level ground, where he would stand for a long time facing the Qibla to invoke (Allah) while raising his hands. Then he would do Rami of the Jamrat-ul-Aqaba from the middle of the valley, but he would not stay by it. Ibn `Umar used to say, "I saw Allah's Messenger (ﷺ) doing like that}}
\hadithdefcmd{bukhari}{1753}{وَقَالَ مُحَمَّدٌ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا رَمَى الْجَمْرَةَ الَّتِي تَلِي مَسْجِدَ مِنًى يَرْمِيهَا بِسَبْعِ حَصَيَاتٍ، يُكَبِّرُ كُلَّمَا رَمَى بِحَصَاةٍ، ثُمَّ تَقَدَّمَ أَمَامَهَا فَوَقَفَ مُسْتَقْبِلَ الْقِبْلَةِ رَافِعًا يَدَيْهِ يَدْعُو، وَكَانَ يُطِيلُ الْوُقُوفَ، ثُمَّ يَأْتِي الْجَمْرَةَ الثَّانِيَةَ، فَيَرْمِيهَا بِسَبْعِ حَصَيَاتٍ، يُكَبِّرُ كُلَّمَا رَمَى بِحَصَاةٍ، ثُمَّ يَنْحَدِرُ ذَاتَ الْيَسَارِ مِمَّا يَلِي الْوَادِيَ، فَيَقِفُ مُسْتَقْبِلَ الْقِبْلَةِ رَافِعًا يَدَيْهِ يَدْعُو، ثُمَّ يَأْتِي الْجَمْرَةَ الَّتِي عِنْدَ الْعَقَبَةِ فَيَرْمِيهَا بِسَبْعِ حَصَيَاتٍ، يُكَبِّرُ عِنْدَ كُلِّ حَصَاةٍ، ثُمَّ يَنْصَرِفُ وَلاَ يَقِفُ عِنْدَهَا‏.‏ قَالَ الزُّهْرِيُّ سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ يُحَدِّثُ مِثْلَ هَذَا عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَانَ ابْنُ عُمَرَ يَفْعَلُهُ‏.‏\hadithno{1753}\hadithtrans{Narrated Az-Zuhri:Whenever Allah's Messenger (ﷺ) stoned the Jamra near Mina Mosque, he would do Ramy of it with seven small pebbles and say Takbir on throwing each pebble. Then he would go ahead and stand facing the Qiblah with his hands raised, and invoke (Allah) and he used to stand for a long period. Then he would come to the second Jamra (Al-Wusta) and stone it will seven small stones, reciting Takbir on throwing each stone. Then he would stand facing the Qiblah with raised hands to invoke (Allah). Then he would come to the Jamra near the 'Aqaba (Jamrat-ul-'Aqaba) and do Ramy of it with seven small pebbles, reciting Takbir on throwing each stone. he then would leave and not stay by it. Narrated Az-Zuhri: I heard Salim bin 'Abdullah saying the same that his father said on the authority of the Prophet (ﷺ). And Ibn 'Umar used to do the same}}
\hadithdefcmd{bukhari}{1754}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، أَنَّهُ سَمِعَ أَبَاهُ ـ وَكَانَ أَفْضَلَ أَهْلِ زَمَانِهِ ـ يَقُولُ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ هَاتَيْنِ حِينَ أَحْرَمَ، وَلِحِلِّهِ حِينَ أَحَلَّ، قَبْلَ أَنْ يَطُوفَ‏.‏ وَبَسَطَتْ يَدَيْهَا‏.‏\hadithno{1754}\hadithtrans{Narrated `Abdur-Rahman bin Al-Qasim:I heard my father who was the best man of his age, saying, "I heard `Aisha saying, 'I perfumed Allah's Apostle with my own hands before finishing his Ihram while yet he had not performed Tawaf-al- Ifada.' She spread her hands (while saying so)}}
\hadithdefcmd{bukhari}{1755}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أُمِرَ النَّاسُ أَنْ يَكُونَ آخِرُ عَهْدِهِمْ بِالْبَيْتِ، إِلاَّ أَنَّهُ خُفِّفَ عَنِ الْحَائِضِ‏.‏\hadithno{1755}\hadithtrans{Narrated Ibn `Abbas:The people were ordered to perform the Tawaf of the Ka`ba (Tawaf-al-Wada`) as the lastly thing, before leaving (Mecca), except the menstruating women who were excused}}
\hadithdefcmd{bukhari}{1756}{حَدَّثَنَا أَصْبَغُ بْنُ الْفَرَجِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ وَالْعَصْرَ، وَالْمَغْرِبَ وَالْعِشَاءَ، ثُمَّ رَقَدَ رَقْدَةً بِالْمُحَصَّبِ، ثُمَّ رَكِبَ إِلَى الْبَيْتِ فَطَافَ بِهِ‏.‏ تَابَعَهُ اللَّيْثُ حَدَّثَنِي خَالِدٌ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ حَدَّثَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1756}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) offered the Zuhr, `Asr, Maghrib and the `Isha' prayers and slept for a while at a place called Al-Muhassab and then rode to the Ka`ba and performed Tawaf round it}}
\hadithdefcmd{bukhari}{1757}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ صَفِيَّةَ بِنْتَ حُيَىٍّ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم حَاضَتْ، فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَحَابِسَتُنَا هِيَ ‏"‏‏.‏ قَالُوا إِنَّهَا قَدْ أَفَاضَتْ‏.‏ قَالَ ‏"‏ فَلاَ إِذًا ‏"‏‏.‏\hadithno{1757}\hadithtrans{Narrated `Aisha:Safiya bint Huyay, the wife of the Prophet (ﷺ) got her menses, and Allah's Messenger (ﷺ) was informed of that. He said, "Would she delay us?" The people said, "She has already performed Tawaf-al-Ifada." He said, "Therefore she will not (delay us)}}
\hadithdefcmd{bukhari}{1759}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، أَنَّ أَهْلَ الْمَدِينَةِ، سَأَلُوا ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ امْرَأَةٍ، طَافَتْ ثُمَّ حَاضَتْ، قَالَ لَهُمْ تَنْفِرُ‏.‏ قَالُوا لاَ نَأْخُذُ بِقَوْلِكَ وَنَدَعَ قَوْلَ زَيْدٍ‏.‏ قَالَ إِذَا قَدِمْتُمُ الْمَدِينَةَ فَسَلُوا‏.‏ فَقَدِمُوا الْمَدِينَةَ فَسَأَلُوا، فَكَانَ فِيمَنْ سَأَلُوا أُمُّ سُلَيْمٍ، فَذَكَرَتْ حَدِيثَ صَفِيَّةَ‏.‏ رَوَاهُ خَالِدٌ وَقَتَادَةُ عَنْ عِكْرِمَةَ‏.‏\hadithno{1759}\hadithtrans{Narrated `Ikrima:The people of Medina asked Ibn `Abbas about a woman who got her menses after performing Tawafal- Ifada. He said, "She could depart (from Mecca)." They said, "We will not act on your verdict and ignore the verdict of Zaid." Ibn `Abbas said, "When you reach Medina, inquire about it." So, when they reached Medina they asked (about that). One of those whom they asked was Um Sulaim. She told them the narration of Safiya}}
\hadithdefcmd{bukhari}{1761}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ رُخِّصَ لِلْحَائِضِ أَنْ تَنْفِرَ إِذَا أَفَاضَتْ‏.‏ قَالَ وَسَمِعْتُ ابْنَ عُمَرَ، يَقُولُ إِنَّهَا لاَ تَنْفِرُ‏.‏ ثُمَّ سَمِعْتُهُ يَقُولُ بَعْدُ إِنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لَهُنَّ‏.‏\hadithno{1761}\hadithtrans{Narrated Ibn `Abbas:A menstruating woman was allowed to leave Mecca if she had done Tawaf-al-Ifada. Tawus (a subnarrator) said from his father, "I heard Ibn `Umar saying that she would not depart. Then later I heard him saying that the Prophet (ﷺ) had allowed them (menstruating women) to depart}}
\hadithdefcmd{bukhari}{1762}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم وَلاَ نُرَى إِلاَّ الْحَجَّ، فَقَدِمَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ، وَلَمْ يَحِلَّ وَكَانَ مَعَهُ الْهَدْىُ، فَطَافَ مَنْ كَانَ مَعَهُ مِنْ نِسَائِهِ وَأَصْحَابِهِ، وَحَلَّ مِنْهُمْ مَنْ لَمْ يَكُنْ مَعَهُ الْهَدْىُ، فَحَاضَتْ هِيَ، فَنَسَكْنَا مَنَاسِكَنَا مِنْ حَجِّنَا، فَلَمَّا كَانَ لَيْلَةُ الْحَصْبَةِ لَيْلَةُ النَّفْرِ، قَالَتْ يَا رَسُولَ اللَّهِ كُلُّ أَصْحَابِكَ يَرْجِعُ بِحَجٍّ وَعُمْرَةٍ غَيْرِي‏.‏ قَالَ ‏"‏ مَا كُنْتِ تَطُوفِي بِالْبَيْتِ لَيَالِيَ قَدِمْنَا ‏"‏‏.‏ قُلْتُ لاَ‏.‏ قَالَ ‏"‏ فَاخْرُجِي مَعَ أَخِيكِ إِلَى التَّنْعِيمِ فَأَهِلِّي بِعُمْرَةٍ، وَمَوْعِدُكِ مَكَانَ كَذَا وَكَذَا ‏"‏‏.‏ فَخَرَجْتُ مَعَ عَبْدِ الرَّحْمَنِ إِلَى التَّنْعِيمِ، فَأَهْلَلْتُ بِعُمْرَةٍ، وَحَاضَتْ صَفِيَّةُ بِنْتُ حُيَىٍّ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَقْرَى حَلْقَى، إِنَّكِ لَحَابِسَتُنَا، أَمَا كُنْتِ طُفْتِ يَوْمَ النَّحْرِ ‏"‏‏.‏ قَالَتْ بَلَى‏.‏ قَالَ ‏"‏ فَلاَ بَأْسَ‏.‏ انْفِرِي ‏"‏‏.‏ فَلَقِيتُهُ مُصْعِدًا عَلَى أَهْلِ مَكَّةَ، وَأَنَا مُنْهَبِطَةٌ، أَوْ أَنَا مُصْعِدَةٌ، وَهُوَ مُنْهَبِطٌ‏.‏ وَقَالَ مُسَدَّدٌ قُلْتُ لاَ‏.‏ تَابَعَهُ جَرِيرٌ عَنْ مَنْصُورٍ فِي قَوْلِهِ لاَ‏.‏\hadithno{1762}\hadithtrans{Narrated `Aisha:We set out with the Prophet (ﷺ) with the intention of performing Hajj only. The Prophet (ﷺ) reached Mecca and performed Tawaf of the Ka`ba and between Safa and Marwa and did not finish the Ihram, because he had the Hadi with him. His companions and his wives performed Tawaf (of the Ka`ba and between Safa and Marwa), and those who had no Hadi with them finished their Ihram. I got the menses and performed all the ceremonies of Hajj. So, when the Night of Hasba (night of departure) came, I said, "O Allah's Messenger (ﷺ)! All your companions are returning with Hajj and `Umra except me." He asked me, "Didn't you perform Tawaf of the Ka`ba (Umra) when you reached Mecca?" I said, "No." He said, "Go to Tan`im with your brother `Abdur-Rahman, and assume Ihram for `Umra and I will wait for you at such and such a place." So I went with `Abdur-Rahman to Tan`im and assumed Ihram for `Umra. Then Safiya bint Huyay got menses. The Prophet (ﷺ) said, " 'Aqra Halqa! You will detain us! Didn't you perform Tawaf-al-Ifada on the Day of Nahr (slaughtering)?" She said, "Yes, I did." He said, "Then there is no harm, depart." So I met the Prophet (ﷺ) when he was ascending the heights towards Mecca and I was descending, or vice-versa}}
\hadithdefcmd{bukhari}{1763}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ أَخْبِرْنِي بِشَىْءٍ، عَقَلْتَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْنَ صَلَّى الظُّهْرَ يَوْمَ التَّرْوِيَةِ قَالَ بِمِنًى‏.‏ قُلْتُ فَأَيْنَ صَلَّى الْعَصْرَ يَوْمَ النَّفْرِ قَالَ بِالأَبْطَحِ‏.‏ افْعَلْ كَمَا يَفْعَلُ أُمَرَاؤُكَ‏.‏\hadithno{1763}\hadithtrans{Narrated `Abdul-Aziz bin Rufai:I asked Anas bin Malik, "Tell me something you have observed about the Prophet (ﷺ) concerning where he offered the Zuhr prayer on the Day of Tarwiya (8th Dhul-Hijja)." Anas replied, "He offered it at Mina." I said, "Where did he offer the `Asr prayer on the Day of Nafr (day of departure from Mina)?" He replied, "At Al-Abtah," and added, "You should do as your leaders do}}
\hadithdefcmd{bukhari}{1764}{حَدَّثَنَا عَبْدُ الْمُتَعَالِ بْنُ طَالِبٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ قَتَادَةَ، حَدَّثَهُ عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ حَدَّثَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى الظُّهْرَ وَالْعَصْرَ، وَالْمَغْرِبَ وَالْعِشَاءَ، وَرَقَدَ رَقْدَةً بِالْمُحَصَّبِ، ثُمَّ رَكِبَ إِلَى الْبَيْتِ فَطَافَ بِهِ‏.‏\hadithno{1764}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) offered the Zuhr, `Asr, Maghrib and `Isha' prayers and slept for a while at a place called Al-Mahassab and then he rode towards the Ka`ba and performed Tawaf (al-Wada)}}
\hadithdefcmd{bukhari}{1765}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ إِنَّمَا كَانَ مَنْزِلٌ يَنْزِلُهُ النَّبِيُّ صلى الله عليه وسلم لِيَكُونَ أَسْمَحَ لِخُرُوجِهِ‏.‏ يَعْنِي بِالأَبْطَحِ‏.‏\hadithno{1765}\hadithtrans{Narrated `Aisha:It (i.e. Al-Abtah) was a place where the Prophet (ﷺ) used to camp so that it might be easier for him to depart}}
\hadithdefcmd{bukhari}{1766}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ لَيْسَ التَّحْصِيبُ بِشَىْءٍ، إِنَّمَا هُوَ مَنْزِلٌ نَزَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1766}\hadithtrans{Narrated Ibn `Abbas:Staying at Al-Mahassab is not one of the ceremonies (of Hajj), but Al-Mahassab is a place where Allah's Messenger (ﷺ) camped (during his Hajjat-al-Wida)}}
\hadithdefcmd{bukhari}{1767}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يَبِيتُ بِذِي طُوًى بَيْنَ الثَّنِيَّتَيْنِ، ثُمَّ يَدْخُلُ مِنَ الثَّنِيَّةِ الَّتِي بِأَعْلَى مَكَّةَ، وَكَانَ إِذَا قَدِمَ مَكَّةَ حَاجًّا أَوْ مُعْتَمِرًا لَمْ يُنِخْ نَاقَتَهُ إِلاَّ عِنْدَ باب الْمَسْجِدِ، ثُمَّ يَدْخُلُ فَيَأْتِي الرُّكْنَ الأَسْوَدَ فَيَبْدَأُ بِهِ، ثُمَّ يَطُوفُ سَبْعًا ثَلاَثًا سَعْيًا، وَأَرْبَعًا مَشْيًا، ثُمَّ يَنْصَرِفُ فَيُصَلِّي سَجْدَتَيْنِ، ثُمَّ يَنْطَلِقُ قَبْلَ أَنْ يَرْجِعَ إِلَى مَنْزِلِهِ، فَيَطُوفُ بَيْنَ الصَّفَا وَالْمَرْوَةِ، وَكَانَ إِذَا صَدَرَ عَنِ الْحَجِّ أَوِ الْعُمْرَةِ أَنَاخَ بِالْبَطْحَاءِ الَّتِي بِذِي الْحُلَيْفَةِ الَّتِي كَانَ النَّبِيُّ صلى الله عليه وسلم يُنِيخُ بِهَا‏.‏\hadithno{1767}\hadithtrans{Narrated Nafi`:Ibn `Umar used to spend the night at Dhi-Tuwa in between the two Thaniyas and then he would enter Mecca through the Thaniya which is at the higher region of Mecca, and whenever he came to Mecca for Hajj or `Umra, he never made his she camel kneel down except near the gate of the Masjid (Sacred Mosque) and then he would enter (it) and go to the Black (stone) Corner and start from there circumambulating the Ka`ba seven times: hastening in the first three rounds (Ramal) and walking in the last four. On finishing, he would offer two rak`at prayer and set out to perform Tawaf between Safa and Marwa before returning to his dwelling place. On returning (to Medina) from Hajj or `Umra, he used to make his camel kneel down at Al-Batha which is at Dhul-Hulaifa, the place where the Prophet used to make his camel kneel down}}
\hadithdefcmd{bukhari}{1768}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ سُئِلَ عُبَيْدُ اللَّهِ عَنِ الْمُحَصَّبِ، فَحَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ،، قَالَ نَزَلَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَعُمَرُ وَابْنُ عُمَرَ‏.‏ وَعَنْ نَافِعٍ أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يُصَلِّي بِهَا ـ يَعْنِي الْمُحَصَّبَ ـ الظُّهْرَ وَالْعَصْرَ ـ أَحْسِبُهُ قَالَ وَالْمَغْرِبَ‏.‏ قَالَ خَالِدٌ لاَ أَشُكُّ فِي الْعِشَاءِ، وَيَهْجَعُ هَجْعَةً، وَيَذْكُرُ ذَلِكَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1768}\hadithtrans{Narrated Khalid bin Al-Harith:'Ubaidullah was asked about Al Mahassab. 'Ubaidullah narrated: Nafi` said, 'Allah's Messenger (ﷺ), `Umar and Ibn `Umar camped there." Nafi` added, "Ibn `Umar used to offer the Zuhr and `Asr prayers at it (i.e. Al-Mahassab)." I think he mentioned the Maghrib prayer also. I said, "I don't doubt about `Isha' (i.e. he used to offer it there also), and he used to sleep there for a while. He used to say, 'The Prophet (ﷺ) used to do the same}}
\hadithdefcmd{bukhari}{1769}{وَقَالَ مُحَمَّدُ بْنُ عِيسَى حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ كَانَ إِذَا أَقْبَلَ بَاتَ بِذِي طُوًى، حَتَّى إِذَا أَصْبَحَ دَخَلَ، وَإِذَا نَفَرَ مَرَّ بِذِي طُوًى وَبَاتَ بِهَا حَتَّى يُصْبِحَ، وَكَانَ يَذْكُرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَفْعَلُ ذَلِكَ‏.‏\hadithno{1769}\hadithtrans{Narrated Nafi':Whenver Ibn 'Umar (ra) approached (Makkah) he used to pass the night at Dhi-Tuwa till dawn, and then he would enter Makkah. On his return, he used to pass by Dhi-Tuwa and pass the night there till dawn, and he used to say that the Prophet (ﷺ) used to do the same}}
\hadithdefcmd{bukhari}{1770}{حَدَّثَنَا عُثْمَانُ بْنُ الْهَيْثَمِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ عَمْرُو بْنُ دِينَارٍ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ كَانَ ذُو الْمَجَازِ وَعُكَاظٌ مَتْجَرَ النَّاسِ فِي الْجَاهِلِيَّةِ، فَلَمَّا جَاءَ الإِسْلاَمُ كَأَنَّهُمْ كَرِهُوا ذَلِكَ حَتَّى نَزَلَتْ ‏\{‏لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَبْتَغُوا فَضْلاً مِنْ رَبِّكُمْ‏\}‏ فِي مَوَاسِمِ الْحَجِّ‏.‏\hadithno{1770}\hadithtrans{Narrated Ibn ' `Abbas:Dhul-Majaz and `Ukaz were the markets of the people during the Pre-Islamic period of ignorance. When the people embraced Islam, they disliked to do bargaining there till the following Holy Verses were revealed:-- There is no harm for you If you seek of the bounty Of your Lord (during Hajj by trading, etc)}}
\hadithdefcmd{bukhari}{1772}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ حَاضَتْ صَفِيَّةُ لَيْلَةَ النَّفْرِ، فَقَالَتْ مَا أُرَانِي إِلاَّ حَابِسَتَكُمْ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَقْرَى حَلْقَى أَطَافَتْ يَوْمَ النَّحْرِ ‏"‏‏.‏ قِيلَ نَعَمْ‏.‏ قَالَ ‏"‏ فَانْفِرِي ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَزَادَنِي مُحَمَّدٌ حَدَّثَنَا مُحَاضِرٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نَذْكُرُ إِلاَّ الْحَجَّ، فَلَمَّا قَدِمْنَا أَمَرَنَا أَنْ نَحِلَّ، فَلَمَّا كَانَتْ لَيْلَةُ النَّفْرِ حَاضَتْ صَفِيَّةُ بِنْتُ حُيَىٍّ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ حَلْقَى عَقْرَى، مَا أُرَاهَا إِلاَّ حَابِسَتَكُمْ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ كُنْتِ طُفْتِ يَوْمَ النَّحْرِ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ قَالَ ‏"‏ فَانْفِرِي ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ إِنِّي لَمْ أَكُنْ حَلَلْتُ‏.‏ قَالَ ‏"‏ فَاعْتَمِرِي مِنَ التَّنْعِيمِ ‏"‏‏.‏ فَخَرَجَ مَعَهَا أَخُوهَا، فَلَقِينَاهُ مُدَّلِجًا‏.‏ فَقَالَ ‏"‏ مَوْعِدُكِ مَكَانَ كَذَا وَكَذَا ‏"‏‏.‏\hadithno{1772}\hadithtrans{Narrated `Aisha:Safiya got her menses on the night of Nafr (departure from Hajj), and she said, "I see that I will detain you." The Prophet (ﷺ) said, "Aqra Halqa! Did she perform the Tawaf on the Day of Nahr (slaughtering)?" Somebody replied in the affirmative. He said, "Then depart." (Different narrators mentioned that) `Aisha said, "We set out with Allah's Apostle (from Medina) with the intention of performing Hajj only. When we reached Mecca, he ordered us to finish the Ihram. When it was the night of Nafr (departure), Safiya bint Huyay got her menses. The Prophet (ﷺ) said, "Halqa Aqra! I think that she will detain you," and added, "Did you perform the Tawaf (Al-Ifada) on the Day of Nahr (slaughtering)?" She replied, "Yes." He said, "Then depart." I said, "O Allah's Apostle! I have not (done the Umra)." He replied, "Perform `Umra from Tan`im." My brother went with me and we came across the Prophet (ﷺ) in the last part of the night. He said, "Wait at such and such a place}}
