% Auto-generated chapter 0 for bukhari
% Hadiths in this chapter: 311

\hadithdefcmd{bukhari}{299}{حَدَّثَنَا قَبِيصَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ، كِلاَنَا جُنُبٌ‏.‏ وَكَانَ يَأْمُرُنِي فَأَتَّزِرُ، فَيُبَاشِرُنِي وَأَنَا حَائِضٌ‏.‏ وَكَانَ يُخْرِجُ رَأْسَهُ إِلَىَّ وَهُوَ مُعْتَكِفٌ، فَأَغْسِلُهُ وَأَنَا حَائِضٌ‏.‏\hadithno{299}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) and I used to take a bath from a single pot while we were Junub. During the menses, he used to order me to put on an Izar (dress worn below the waist) and used to fondle me. While in I`tikaf, he used to bring his head near me and I would wash it while I used to be in my periods (menses)}}
\hadithdefcmd{bukhari}{300}{حَدَّثَنَا قَبِيصَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ، كِلاَنَا جُنُبٌ‏.‏ وَكَانَ يَأْمُرُنِي فَأَتَّزِرُ، فَيُبَاشِرُنِي وَأَنَا حَائِضٌ‏.‏ وَكَانَ يُخْرِجُ رَأْسَهُ إِلَىَّ وَهُوَ مُعْتَكِفٌ، فَأَغْسِلُهُ وَأَنَا حَائِضٌ‏.‏\hadithno{300}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) and I used to take a bath from a single pot while we were Junub. During the menses, he used to order me to put on an Izar (dress worn below the waist) and used to fondle me. While in I`tikaf, he used to bring his head near me and I would wash it while I used to be in my periods (menses)}}
\hadithdefcmd{bukhari}{329}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رُخِّصَ لِلْحَائِضِ أَنْ تَنْفِرَ، إِذَا حَاضَتْ‏.‏ وَكَانَ ابْنُ عُمَرَ يَقُولُ فِي أَوَّلِ أَمْرِهِ إِنَّهَا لاَ تَنْفِرُ‏.‏ ثُمَّ سَمِعْتُهُ يَقُولُ تَنْفِرُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ لَهُنَّ‏.‏\hadithno{329}\hadithtrans{Narrated Ibn `Abbas:A woman is allowed to leave (go back home) if she gets menses (after Tawaf-Al-Ifada). Ibn `Umar formerly used to say that she should not leave but later on I heard him saying, "She may leave, since Allah's Messenger (ﷺ) gave them the permission to leave (after Tawaf-Al-Ifada)}}
\hadithdefcmd{bukhari}{395}{حَدَّثَنَا الْحُمَيْدِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَأَلْنَا ابْنَ عُمَرَ عَنْ رَجُلٍ، طَافَ بِالْبَيْتِ الْعُمْرَةَ، وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ، أَيَأْتِي امْرَأَتَهُ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا، وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، وَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ، وَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏.‏ وَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَقَالَ لاَ يَقْرَبَنَّهَا حَتَّى يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{395}\hadithtrans{Narrated `Amr bin Dinar:I asked Ibn `Umar, "Can a person who has performed the Tawaf around the Ka`ba for `Umra but has not performed the (Sa`i) Tawaf of Safa and Marwa, have a sexual relation with his wife?" Ibn `Umar replied "When the Prophet (ﷺ) reached Mecca he performed the Tawaf around the Ka`ba (circumambulated it seven times) and offered a two-rak`at prayer (at the place) behind the station (of Abraham) and then performed the Tawaf (Sa`i) of Safa and Marwa, and verily in Allah's Messenger (ﷺ) you have a good example." Then we put the same question to Jabir bin `Abdullah and he too replied, "He should not go near his wife (for sexual relation) till he has finished the Tawaf of Safa and Marwa}}
\hadithdefcmd{bukhari}{408}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، وَأَبَا، سَعِيدٍ حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى نُخَامَةً فِي جِدَارِ الْمَسْجِدِ، فَتَنَاوَلَ حَصَاةً فَحَكَّهَا فَقَالَ ‏ "‏ إِذَا تَنَخَّمَ أَحَدُكُمْ فَلاَ يَتَنَخَّمَنَّ قِبَلَ وَجْهِهِ وَلاَ عَنْ يَمِينِهِ، وَلْيَبْصُقْ عَنْ يَسَارِهِ أَوْ تَحْتَ قَدَمِهِ الْيُسْرَى ‏"‏‏.‏\hadithno{408}\hadithtrans{Narrated Abu Huraira and Abu Sa`id:Allah's Messenger (ﷺ) saw some expectoration on the wall of the mosque; he took gravel and scraped it off and said, "If anyone of you wanted to spit he should neither spit in front of him nor on his right but he could spit either on his left or under his left foot}}
\hadithdefcmd{bukhari}{410}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، وَأَبَا، سَعِيدٍ أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى نُخَامَةً فِي حَائِطِ الْمَسْجِدِ، فَتَنَاوَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَصَاةً فَحَتَّهَا ثُمَّ قَالَ ‏ "‏ إِذَا تَنَخَّمَ أَحَدُكُمْ فَلاَ يَتَنَخَّمْ قِبَلَ وَجْهِهِ وَلاَ عَنْ يَمِينِهِ، وَلْيَبْصُقْ عَنْ يَسَارِهِ، أَوْ تَحْتَ قَدَمِهِ الْيُسْرَى ‏"‏‏.‏\hadithno{410}\hadithtrans{Narrated Abu Huraira and Abu Sa`id:Allah's Messenger (ﷺ) saw some expectoration on the wall of the mosque; he took gravel and scraped it off and said, "If anyone of you wanted to spit, he should neither spit in front of him nor on his right but could spit either on his left or under his left foot}}
\hadithdefcmd{bukhari}{435}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَائِشَةَ، وَعَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالاَ لَمَّا نَزَلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم طَفِقَ يَطْرَحُ خَمِيصَةً لَهُ عَلَى وَجْهِهِ، فَإِذَا اغْتَمَّ بِهَا كَشَفَهَا عَنْ وَجْهِهِ، فَقَالَ وَهْوَ كَذَلِكَ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏‏.‏ يُحَذِّرُ مَا صَنَعُوا‏.‏\hadithno{435}\hadithtrans{Narrated `Aisha and `Abdullah bin `Abbas:When the last moment of the life of Allah's Messenger (ﷺ) came he started putting his 'Khamisa' on his face and when he felt hot and short of breath he took it off his face and said, "May Allah curse the Jews and Christians for they built the places of worship at the graves of their Prophets." The Prophet (ﷺ) was warning (Muslims) of what those had done}}
\hadithdefcmd{bukhari}{454}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمًا عَلَى باب حُجْرَتِي، وَالْحَبَشَةُ يَلْعَبُونَ فِي الْمَسْجِدِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتُرُنِي بِرِدَائِهِ، أَنْظُرُ إِلَى لَعِبِهِمْ‏.‏ زَادَ إِبْرَاهِيمُ بْنُ الْمُنْذِرِ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَالْحَبَشَةُ يَلْعَبُونَ بِحِرَابِهِمْ‏.‏\hadithno{454}\hadithtrans{Narrated `Aisha:Once I saw Allah's Messenger (ﷺ) at the door of my house while some Ethiopians were playing in the mosque (displaying their skill with spears). Allah's Messenger (ﷺ) was screening me with his Rida' so as to enable me to see their display. (`Urwa said that `Aisha said, "I saw the Prophet (ﷺ) and the Ethiopians were playing with their spears}}
\hadithdefcmd{bukhari}{478}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ، عَنْ بِشْرٍ، حَدَّثَنَا عَاصِمٌ، حَدَّثَنَا وَاقِدٌ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَوِ ابْنِ عَمْرٍو شَبَّكَ النَّبِيُّ صلى الله عليه وسلم أَصَابِعَهُ‏.‏\hadithno{478}\hadithtrans{Narrated Ibn `Umar or Ibn `Amr:The Prophet (ﷺ) clasped his hands, by interlacing his fingers}}
\hadithdefcmd{bukhari}{521}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخَّرَ الصَّلاَةَ يَوْمًا، فَدَخَلَ عَلَيْهِ عُرْوَةُ بْنُ الزُّبَيْرِ، فَأَخْبَرَهُ أَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ أَخَّرَ الصَّلاَةَ يَوْمًا وَهْوَ بِالْعِرَاقِ، فَدَخَلَ عَلَيْهِ أَبُو مَسْعُودٍ الأَنْصَارِيُّ فَقَالَ مَا هَذَا يَا مُغِيرَةُ أَلَيْسَ قَدْ عَلِمْتَ أَنَّ جِبْرِيلَ نَزَلَ فَصَلَّى، فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ بِهَذَا أُمِرْتُ ‏"‏‏.‏ فَقَالَ عُمَرُ لِعُرْوَةَ اعْلَمْ مَا تُحَدِّثُ أَوَإِنَّ جِبْرِيلَ هُوَ أَقَامَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَقْتَ الصَّلاَةِ‏.‏ قَالَ عُرْوَةُ كَذَلِكَ كَانَ بَشِيرُ بْنُ أَبِي مَسْعُودٍ يُحَدِّثُ عَنْ أَبِيهِ‏.‏ قَالَ عُرْوَةُ وَلَقَدْ حَدَّثَتْنِي عَائِشَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ، وَالشَّمْسُ فِي حُجْرَتِهَا قَبْلَ أَنْ تَظْهَرَ‏.‏\hadithno{521}\hadithtrans{Narrated Ibn Shihab:Once `Umar bin `Abdul `Aziz delayed the prayer and `Urwa bin Az-Zubair went to him and said, "Once in 'Iraq, Al-Mughira bin Shu`ba delayed his prayers and Abi Mas`ud Al-Ansari went to him and said, 'O Mughira! What is this? Don't you know that once Gabriel came and offered the prayer (Fajr prayer) and Allah's Messenger (ﷺ) prayed too, then he prayed again (Zuhr prayer) and so did Allah's Apostle and again he prayed (`Asr prayers and Allah's Messenger (ﷺ) did the same; again he prayed (Maghrib-prayer) and so did Allah's Messenger (ﷺ) and again prayed (`Isha prayer) and so did Allah's Apostle and (Gabriel) said, 'I was ordered to do so (to demonstrate the prayers prescribed to you)?'" `Umar (bin `Abdul `Aziz) said to `Urwa, "Be sure of what you Say. Did Gabriel lead Allah's Messenger (ﷺ) at the stated times of the prayers?" `Urwa replied, "Bashir bin Abi Mas`ud narrated like this on the authority of his father." `Urwa added, "Aisha told me that Allah's Messenger (ﷺ) used to pray `Asr prayer when the sunshine was still inside her residence (during the early time of `Asr)}}
\hadithdefcmd{bukhari}{533}{حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو بَكْرٍ، عَنْ سُلَيْمَانَ، قَالَ صَالِحُ بْنُ كَيْسَانَ حَدَّثَنَا الأَعْرَجُ عَبْدُ الرَّحْمَنِ، وَغَيْرُهُ، عَنْ أَبِي هُرَيْرَةَ‏.‏وَنَافِعٌ مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُمَا حَدَّثَاهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ، فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏‏.‏\hadithno{533}\hadithtrans{Narrated Abu Huraira and `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "If it is very hot, then pray the Zuhr prayer when it becomes (a bit) cooler, as the severity of the heat is from the raging of the Hell-fire}}
\hadithdefcmd{bukhari}{536}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنَ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا بِالصَّلاَةِ، فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏‏.‏ ‏"‏ وَاشْتَكَتِ النَّارُ إِلَى رَبِّهَا فَقَالَتْ يَا رَبِّ أَكَلَ بَعْضِي بَعْضًا‏.‏ فَأَذِنَ لَهَا بِنَفَسَيْنِ نَفَسٍ فِي الشِّتَاءِ، وَنَفَسٍ فِي الصَّيْفِ، فَهُوَ أَشَدُّ مَا تَجِدُونَ مِنَ الْحَرِّ، وَأَشَدُّ مَا تَجِدُونَ مِنَ الزَّمْهَرِيرِ ‏"‏‏.‏\hadithno{536}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "In very hot weather delay the Zuhr prayer till it becomes (a bit) cooler because the severity of heat is from the raging of the Hell-fire. The Hell-fire of Hell complained to its Lord saying: O Lord! My parts are eating (destroying) one another. So Allah allowed it to take two breaths, one in the winter and the other in the summer. The breath in the summer is at the time when you feel the severest heat and the breath in the winter is at the time when you feel the severest cold}}
\hadithdefcmd{bukhari}{570}{حَدَّثَنَا مَحْمُودٌ، قَالَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي نَافِعٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شُغِلَ عَنْهَا لَيْلَةً، فَأَخَّرَهَا حَتَّى رَقَدْنَا فِي الْمَسْجِدِ، ثُمَّ اسْتَيْقَظْنَا ثُمَّ رَقَدْنَا ثُمَّ اسْتَيْقَظْنَا، ثُمَّ خَرَجَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ لَيْسَ أَحَدٌ مِنْ أَهْلِ الأَرْضِ يَنْتَظِرُ الصَّلاَةَ غَيْرُكُمْ ‏"‏‏.‏ وَكَانَ ابْنُ عُمَرَ لاَ يُبَالِي أَقَدَّمَهَا أَمْ أَخَّرَهَا إِذَا كَانَ لاَ يَخْشَى أَنْ يَغْلِبَهُ النَّوْمُ عَنْ وَقْتِهَا، وَكَانَ يَرْقُدُ قَبْلَهَا‏.‏ قَالَ ابْنُ جُرَيْجٍ قُلْتُ لِعَطَاءٍ وَقَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً بِالْعِشَاءِ حَتَّى رَقَدَ النَّاسُ وَاسْتَيْقَظُوا، وَرَقَدُوا وَاسْتَيْقَظُوا، فَقَامَ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ الصَّلاَةَ‏.‏ قَالَ عَطَاءٌ قَالَ ابْنُ عَبَّاسٍ فَخَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم كَأَنِّي أَنْظُرُ إِلَيْهِ الآنَ، يَقْطُرُ رَأْسُهُ مَاءً، وَاضِعًا يَدَهُ عَلَى رَأْسِهِ فَقَالَ ‏"‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ أَنْ يُصَلُّوهَا هَكَذَا ‏"‏‏.‏ فَاسْتَثْبَتُّ عَطَاءً كَيْفَ وَضَعَ النَّبِيُّ صلى الله عليه وسلم عَلَى رَأْسِهِ يَدَهُ كَمَا أَنْبَأَهُ ابْنُ عَبَّاسٍ، فَبَدَّدَ لِي عَطَاءٌ بَيْنَ أَصَابِعِهِ شَيْئًا مِنْ تَبْدِيدٍ، ثُمَّ وَضَعَ أَطْرَافَ أَصَابِعِهِ عَلَى قَرْنِ الرَّأْسِ ثُمَّ ضَمَّهَا، يُمِرُّهَا كَذَلِكَ عَلَى الرَّأْسِ حَتَّى مَسَّتْ إِبْهَامُهُ طَرَفَ الأُذُنِ مِمَّا يَلِي الْوَجْهَ عَلَى الصُّدْغِ، وَنَاحِيَةِ اللِّحْيَةِ، لاَ يُقَصِّرُ وَلاَ يَبْطُشُ إِلاَّ كَذَلِكَ وَقَالَ ‏"‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ أَنْ يُصَلُّوا هَكَذَا ‏"‏‏.‏\hadithno{570}\hadithtrans{Narrated Ibn Juraij from Nafi`:`Abdullah bin `Umar said, "Once Allah's Messenger (ﷺ) was busy (at the time of the `Isha'), so the prayer was delayed so much so that we slept and woke up and slept and woke up again. The Prophet (ﷺ) came out and said, 'None amongst the dwellers of the earth but you have been waiting for the prayer." Ibn `Umar did not find any harm in praying it earlier or in delaying it unless he was afraid that sleep might overwhelm him and he might miss the prayer, and sometimes he used to sleep before the `Isha' prayer. Ibn Juraij said, "I said to `Ata', 'I heard Ibn `Abbas saying: Once Allah's Messenger (ﷺ) delayed the `Isha' prayer to such an extent that the people slept and got up and slept again and got up again. Then `Umar bin Al-Khattab, stood up and reminded the Prophet (ﷺ) of the prayer.' `Ata' said, 'Ibn `Abbas said: The Prophet came out as if I was looking at him at this time, and water was trickling from his head and he was putting his hand on his head and then said, 'Hadn't I thought it hard for my followers, I would have ordered them to pray (`Isha' prayer) at this time.' I asked `Ata' for further information, how the Prophet had kept his hand on his head as he was told by Ibn `Abbas. `Ata' separated his fingers slightly and put their tips on the side of the head, brought the fingers downwards approximating them till the thumb touched the lobe of the ear at the side of the temple and the beard on the face. He neither slowed nor hurried in this action but he acted like that. The Prophet (ﷺ) said: "Hadn't I thought it hard for my followers I would have ordered them to pray at this time}}
\hadithdefcmd{bukhari}{582}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي قَالَ، أَخْبَرَنِي ابْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَحَرَّوْا بِصَلاَتِكُمْ طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا ‏"‏‏.‏ وَقَالَ حَدَّثَنِي ابْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا طَلَعَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَرْتَفِعَ، وَإِذَا غَابَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَغِيبَ ‏"‏‏.‏ تَابَعَهُ عَبْدَةُ‏.‏\hadithno{582}\hadithtrans{Narrated Hisham's father:Ibn `Umar said, "Allah's Messenger (ﷺ) said, 'Do not pray at the time of sunrise and at the time of sunset.' " Ibn `Umar said, "Allah's Messenger (ﷺ) said, 'If the edge of the sun appears (above the horizon) delay the prayer till it becomes high, and if the edge of the sun disappears, delay the prayer till it sets (disappears completely)}}
\hadithdefcmd{bukhari}{622}{حَدَّثَنَا إِسْحَاقُ، قَالَ أَخْبَرَنَا أَبُو أُسَامَةَ، قَالَ عُبَيْدُ اللَّهِ حَدَّثَنَا عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ،‏.‏ وَعَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ‏.‏ ح وَحَدَّثَنِي يُوسُفُ بْنُ عِيسَى الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا الْفَضْلُ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ، فَكُلُوا وَاشْرَبُوا حَتَّى يُؤَذِّنَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏‏.‏\hadithno{622}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Bilal pronounces the Adhan at night, so eat and drink (Suhur) till Ibn Um Maktum pronounces the Adhan}}
\hadithdefcmd{bukhari}{652}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ وَجَدَ غُصْنَ شَوْكٍ عَلَى الطَّرِيقِ فَأَخَّرَهُ، فَشَكَرَ اللَّهُ لَهُ، فَغَفَرَ لَهُ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ الشُّهَدَاءُ خَمْسَةٌ الْمَطْعُونُ، وَالْمَبْطُونُ، وَالْغَرِيقُ، وَصَاحِبُ الْهَدْمِ، وَالشَّهِيدُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ وَقَالَ ‏"‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا لاَسْتَهَمُوا عَلَيْهِ ‏"‏‏.‏ ‏"‏ وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ، وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏‏.‏\hadithno{652}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "While a man was going on a way, he saw a thorny branch and removed it from the way and Allah became pleased by his action and forgave him for that." Then the Prophet (ﷺ) said, "Five are martyrs: One who dies of plague, one who dies of an Abdominal disease, one who dies of drowning, one who is buried alive (and) dies and one who is killed in Allah's cause." (The Prophet (ﷺ) further said, "If the people knew the reward for pronouncing the Adhan and for standing in the first row (in the congregational prayer) and found no other way to get it except by drawing lots they would do so, and if they knew the reward of offering the Zuhr prayer early (in its stated time), they would race for it and if they knew the reward for `Isha' and Fajr prayers in congregation, they would attend them even if they were to crawl}}
\hadithdefcmd{bukhari}{653}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ وَجَدَ غُصْنَ شَوْكٍ عَلَى الطَّرِيقِ فَأَخَّرَهُ، فَشَكَرَ اللَّهُ لَهُ، فَغَفَرَ لَهُ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ الشُّهَدَاءُ خَمْسَةٌ الْمَطْعُونُ، وَالْمَبْطُونُ، وَالْغَرِيقُ، وَصَاحِبُ الْهَدْمِ، وَالشَّهِيدُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ وَقَالَ ‏"‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا لاَسْتَهَمُوا عَلَيْهِ ‏"‏‏.‏ ‏"‏ وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ، وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏‏.‏\hadithno{653}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "While a man was going on a way, he saw a thorny branch and removed it from the way and Allah became pleased by his action and forgave him for that." Then the Prophet (ﷺ) said, "Five are martyrs: One who dies of plague, one who dies of an Abdominal disease, one who dies of drowning, one who is buried alive (and) dies and one who is killed in Allah's cause." (The Prophet (ﷺ) further said, "If the people knew the reward for pronouncing the Adhan and for standing in the first row (in the congregational prayer) and found no other way to get it except by drawing lots they would do so, and if they knew the reward of offering the Zuhr prayer early (in its stated time), they would race for it and if they knew the reward for `Isha' and Fajr prayers in congregation, they would attend them even if they were to crawl}}
\hadithdefcmd{bukhari}{655}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا بَنِي سَلِمَةَ أَلاَ تَحْتَسِبُونَ آثَارَكُمْ ‏"‏‏.‏ وَقَالَ مُجَاهِدٌ فِي قَوْلِهِ ‏\{‏وَنَكْتُبُ مَا قَدَّمُوا وَآثَارَهُمْ‏\}‏ قَالَ خُطَاهُمْ‏.‏ وَقَالَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنِي حُمَيْدٌ، حَدَّثَنِي أَنَسٌ، أَنَّ بَنِي سَلِمَةَ، أَرَادُوا أَنْ يَتَحَوَّلُوا، عَنْ مَنَازِلِهِمْ، فَيَنْزِلُوا قَرِيبًا مِنَ النَّبِيِّ صلى الله عليه وسلم قَالَ فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُعْرُوا ‏\{‏الْمَدِينَةَ‏\}‏ فَقَالَ ‏"‏ أَلاَ تَحْتَسِبُونَ آثَارَكُمْ ‏"‏‏.‏ قَالَ مُجَاهِدٌ خُطَاهُمْ آثَارُهُمْ أَنْ يُمْشَى فِي الأَرْضِ بِأَرْجُلِهِمْ‏.‏\hadithno{655}\hadithtrans{Narrated Humaid:Anas said, "The Prophet (ﷺ) said, 'O Bani Salima! Don't you think that for every step of yours (that you take towards the mosque) there is a reward (while coming for prayer)?" Mujahid said: "Regarding Allah's Statement: "We record that which they have sent before (them), and their traces" (36.12). 'Their traces' means 'their steps.' " And Anas said that the people of Bani Salima wanted to shift to a place near the Prophet (ﷺ) but Allah's Messenger (ﷺ) disliked the idea of leaving their houses uninhabited and said, "Don't you think that you will get the reward for your footprints." Mujahid said, "Their foot prints mean their foot steps and their going on foot}}
\hadithdefcmd{bukhari}{720}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الشُّهَدَاءُ الْغَرِقُ وَالْمَطْعُونُ وَالْمَبْطُونُ وَالْهَدْمُ ‏"‏‏.‏ وَقَالَ ‏"‏ وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا ‏\{‏إِلَيْهِ‏\}‏ وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا، وَلَوْ يَعْلَمُونَ مَا فِي الصَّفِّ الْمُقَدَّمِ لاَسْتَهَمُوا ‏"‏‏.‏\hadithno{720}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Martyrs are those who die because of drowning, plague, an Abdominal disease, or of being buried alive by a falling building." And then he added, "If the people knew the Reward for the Zuhr prayer in its early time, they would race for it. If they knew the reward for the `Isha' and the Fajr prayers in congregation, they would join them even if they had to crawl. If they knew the reward for the first row, they would draw lots for it}}
\hadithdefcmd{bukhari}{818}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، أَنَّ مَالِكَ بْنَ الْحُوَيْرِثِ، قَالَ لأَصْحَابِهِ أَلاَ أُنَبِّئُكُمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَذَاكَ فِي غَيْرِ حِينِ صَلاَةٍ، فَقَامَ، ثُمَّ رَكَعَ فَكَبَّرَ ثُمَّ رَفَعَ رَأْسَهُ، فَقَامَ هُنَيَّةً، ثُمَّ سَجَدَ ثُمَّ رَفَعَ رَأْسَهُ هُنَيَّةً، فَصَلَّى صَلاَةَ عَمْرِو بْنِ سَلِمَةَ شَيْخِنَا هَذَا‏.‏ قَالَ أَيُّوبُ كَانَ يَفْعَلُ شَيْئًا لَمْ أَرَهُمْ يَفْعَلُونَهُ، كَانَ يَقْعُدُ فِي الثَّالِثَةِ وَالرَّابِعَةِ‏.‏ قَالَ فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَأَقَمْنَا عِنْدَهُ فَقَالَ ‏ "‏ لَوْ رَجَعْتُمْ إِلَى أَهْلِيكُمْ صَلُّوا صَلاَةَ كَذَا فِي حِينِ كَذَا، صَلُّوا صَلاَةَ كَذَا فِي حِينِ كَذَا، فَإِذَا حَضَرَتِ الصَّلاَةُ فَلْيُؤَذِّنْ أَحَدُكُمْ وَلْيَؤُمَّكُمْ أَكْبَرُكُمْ ‏"‏\hadithno{818}\hadithtrans{Narrated Abu Qilaba:Once Malik bin Huwairith said to his friends, "Shall I show you how Allah's Messenger (ﷺ) used to offer his prayers?" And it was not the time for any of the compulsory congregational prayers. So he stood up (for the prayer) bowed and said the Takbir, then he raised his head and remained standing for a while and then prostrated and raised his head for a while (sat up for a while). He prayed like our Sheikh `Amr Ibn Salama. (Aiyub said, "The latter used to do a thing which I did not see the people doing i.e. he used to sit between the third and the fourth rak`a). Malik bin Huwairith said, "We came to the Prophet (after embracing Islam) and stayed with him. He said to us, 'When you go back to your families, pray such and such a prayer at such and such a time, pray such and such a prayer at such and such a time, and when there is the time for the prayer then only of you should pronounce the Adhan for the prayer and the oldest of you should lead the prayer}}
\hadithdefcmd{bukhari}{832}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنَا عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فِي الصَّلاَةِ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَفِتْنَةِ الْمَمَاتِ، اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْمَأْثَمِ وَالْمَغْرَمِ ‏"‏‏.‏ فَقَالَ لَهُ قَائِلٌ مَا أَكْثَرَ مَا تَسْتَعِيذُ مِنَ الْمَغْرَمِ فَقَالَ ‏"‏ إِنَّ الرَّجُلَ إِذَا غَرِمَ حَدَّثَ فَكَذَبَ، وَوَعَدَ فَأَخْلَفَ ‏"‏‏.‏ وَعَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَعِيذُ فِي صَلاَتِهِ مِنْ فِتْنَةِ الدَّجَّالِ\hadithno{832}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Allah's Messenger (ﷺ) used to invoke Allah in the prayer saying "Allahumma inni a`udhu bika min `adhabi l-qabr, wa a`udhu bika min fitnati l-masihi d-dajjal, wa a`udhu bika min fitnati l-mahya wa fitnati l-mamat. Allahumma inni a`udhu bika mina l-ma'thami wa l-maghram. (O Allah, I seek refuge with You from the punishment of the grave, from the afflictions of the imposter- Messiah, and from the afflictions of life and death. O Allah, I seek refuge with You from sins and from debt)." Somebody said to him, "Why do you so frequently seek refuge with Allah from being in debt?" The Prophet (ﷺ) replied, "A person in debt tells lies whenever he speaks, and breaks promises whenever he makes (them)." `Aisha also narrated: I heard Allah's Messenger (ﷺ) in his prayer seeking refuge with Allah from the afflictions of Ad-Dajjal}}
\hadithdefcmd{bukhari}{839}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ،، وَزَعَمَ، أَنَّهُ عَقَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَعَقَلَ مَجَّةً مَجَّهَا مِنْ دَلْوٍ كَانَ فِي دَارِهِمْ‏.‏ قَالَ سَمِعْتُ عِتْبَانَ بْنَ مَالِكٍ الأَنْصَارِيَّ، ثُمَّ أَحَدَ بَنِي سَالِمٍ قَالَ كُنْتُ أُصَلِّي لِقَوْمِي بَنِي سَالِمٍ، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ إِنِّي أَنْكَرْتُ بَصَرِي، وَإِنَّ السُّيُولَ تَحُولُ بَيْنِي وَبَيْنَ مَسْجِدِ قَوْمِي، فَلَوَدِدْتُ أَنَّكَ جِئْتَ فَصَلَّيْتَ فِي بَيْتِي مَكَانًا، حَتَّى أَتَّخِذَهُ مَسْجِدًا فَقَالَ ‏"‏ أَفْعَلُ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ فَغَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ مَعَهُ بَعْدَ مَا اشْتَدَّ النَّهَارُ، فَاسْتَأْذَنَ النَّبِيُّ صلى الله عليه وسلم فَأَذِنْتُ لَهُ، فَلَمْ يَجْلِسْ حَتَّى قَالَ ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكَ ‏"‏‏.‏ فَأَشَارَ إِلَيْهِ مِنَ الْمَكَانِ الَّذِي أَحَبَّ أَنْ يُصَلِّيَ فِيهِ، فَقَامَ فَصَفَفْنَا خَلْفَهُ ثُمَّ سَلَّمَ، وَسَلَّمْنَا حِينَ سَلَّمَ‏.‏\hadithno{839}\hadithtrans{Narrated Mahmud bin Ar-Rabi`:I remember Allah's Messenger (ﷺ) and also the mouthful of water which he took from a bucket in our house and ejected (on me). I heard from `Itban bin Malik Al-Ansari, who was one from Bani Salim, saying, "I used to lead my tribe of Bani Salim in prayer. Once I went to the Prophet (ﷺ) and said to him, 'I have weak eyesight and at times the rainwater flood intervenes between me and the mosque of my tribe and I wish that you would come to my house and pray at some place so that I could take that place as a place for praying (mosque). He said, "Allah willing, I shall do that." Next day Allah's Messenger (ﷺ) along with Abu Bakr, came to my house after the sun had risen high and he asked permission to enter. I gave him permission, but he didn't sit till he said to me, "Where do you want me to pray in your house?" I pointed to a place in the house where I wanted him to pray. So he stood up for the prayer and we aligned behind him. He completed the prayer with Taslim and we did the same simultaneously}}
\hadithdefcmd{bukhari}{849}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ هِنْدٍ بِنْتِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا سَلَّمَ يَمْكُثُ فِي مَكَانِهِ يَسِيرًا‏.‏ قَالَ ابْنُ شِهَابٍ فَنُرَى ـ وَاللَّهُ أَعْلَمُ ـ لِكَىْ يَنْفُذَ مَنْ يَنْصَرِفُ مِنَ النِّسَاءِ‏.‏ وَقَالَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا نَافِعُ بْنُ يَزِيدَ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ رَبِيعَةَ، أَنَّ ابْنَ شِهَابٍ، كَتَبَ إِلَيْهِ قَالَ حَدَّثَتْنِي هِنْدُ بِنْتُ الْحَارِثِ الْفِرَاسِيَّةُ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَكَانَتْ مِنْ صَوَاحِبَاتِهَا قَالَتْ كَانَ يُسَلِّمُ فَيَنْصَرِفُ النِّسَاءُ، فَيَدْخُلْنَ بُيُوتَهُنَّ مِنْ قَبْلِ أَنْ يَنْصَرِفَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ ابْنُ وَهْبٍ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ أَخْبَرَتْنِي هِنْدُ الْفِرَاسِيَّةُ‏.‏ وَقَالَ عُثْمَانُ بْنُ عُمَرَ أَخْبَرَنَا يُونُسُ عَنِ الزُّهْرِيِّ حَدَّثَتْنِي هِنْدُ الْفِرَاسِيَّةُ‏.‏ وَقَالَ الزُّبَيْدِيُّ أَخْبَرَنِي الزُّهْرِيُّ أَنَّ هِنْدَ بِنْتَ الْحَارِثِ الْقُرَشِيَّةَ أَخْبَرَتْهُ، وَكَانَتْ تَحْتَ مَعْبَدِ بْنِ الْمِقْدَادِ ـ وَهْوَ حَلِيفُ بَنِي زُهْرَةَ ـ وَكَانَتْ تَدْخُلُ عَلَى أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ شُعَيْبٌ عَنِ الزُّهْرِيِّ حَدَّثَتْنِي هِنْدُ الْقُرَشِيَّةُ‏.‏ وَقَالَ ابْنُ أَبِي عَتِيقٍ عَنِ الزُّهْرِيِّ عَنْ هِنْدٍ الْفِرَاسِيَّةِ‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ حَدَّثَهُ عَنِ ابْنِ شِهَابٍ عَنِ امْرَأَةٍ مِنْ قُرَيْشٍ حَدَّثَتْهُ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{849}\hadithtrans{Narrated Um Salama:"The Prophet (ﷺ) after finishing the prayer with Taslim used to stay at his place for a while." Ibn Shihab said, "I think (and Allah knows better), that he used to wait for the departure of the women who had prayed." Ibn Shihab wrote that he had heard it from Hind bint Al-Harith Al-Firasiya from Um Salama, the wife of the Prophet (Hind was from the companions of Um Salama) who said, "When the Prophet (ﷺ) finished the prayer with Taslim, the women would depart and enter their houses before Allah's Apostle departed}}
\hadithdefcmd{bukhari}{896}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ، أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا، وَأُوتِينَاهُ مِنْ بَعْدِهِمْ، فَهَذَا الْيَوْمُ الَّذِي اخْتَلَفُوا فِيهِ فَهَدَانَا اللَّهُ، فَغَدًا لِلْيَهُودِ وَبَعْدَ غَدٍ لِلنَّصَارَى ‏"‏‏.‏ فَسَكَتَ‏.‏ ثُمَّ قَالَ ‏"‏ حَقٌّ عَلَى كُلِّ مُسْلِمٍ أَنْ يَغْتَسِلَ فِي كُلِّ سَبْعَةِ أَيَّامٍ يَوْمًا يَغْسِلُ فِيهِ رَأْسَهُ وَجَسَدَهُ ‏"‏‏.‏	ثُمَّ قَالَ ‏"‏ حَقٌّ عَلَى كُلِّ مُسْلِمٍ أَنْ يَغْتَسِلَ فِي كُلِّ سَبْعَةِ أَيَّامٍ يَوْمًا يَغْسِلُ فِيهِ رَأْسَهُ وَجَسَدَهُ ‏"‏‏.‏\hadithno{896}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said "We are the last (to come amongst the nations) but (will be) the foremost on the Day of Resurrection. They were given the Holy Scripture before us and we were given the Quran after them. And this was the day (Friday) about which they differed and Allah gave us the guidance (for that). So tomorrow (i.e. Saturday) is the Jews' (day), and the day after tomorrow (i.e. Sunday) is the Christians'." The Prophet (ﷺ) remained silent (for a while) and then said, "It is obligatory for every Muslim that he should take a bath once in seven days, when he should wash his head and body}}
\hadithdefcmd{bukhari}{949}{حَدَّثَنَا أَحْمَدُ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنَا عَمْرٌو، أَنَّ مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ الأَسَدِيَّ، حَدَّثَهُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي جَارِيَتَانِ تُغَنِّيَانِ بِغِنَاءِ بُعَاثَ، فَاضْطَجَعَ عَلَى الْفِرَاشِ وَحَوَّلَ وَجْهَهُ، وَدَخَلَ أَبُو بَكْرٍ فَانْتَهَرَنِي وَقَالَ مِزْمَارَةُ الشَّيْطَانِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَقْبَلَ عَلَيْهِ رَسُولُ اللَّهِ ـ عَلَيْهِ السَّلاَمُ ـ فَقَالَ ‏"‏ دَعْهُمَا ‏"‏ فَلَمَّا غَفَلَ غَمَزْتُهُمَا فَخَرَجَتَا‏.‏ وَكَانَ يَوْمَ عِيدٍ يَلْعَبُ السُّودَانُ بِالدَّرَقِ وَالْحِرَابِ، فَإِمَّا سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم وَإِمَّا قَالَ ‏"‏ تَشْتَهِينَ تَنْظُرِينَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَأَقَامَنِي وَرَاءَهُ خَدِّي عَلَى خَدِّهِ، وَهُوَ يَقُولُ ‏"‏ دُونَكُمْ يَا بَنِي أَرْفِدَةَ ‏"‏‏.‏ حَتَّى إِذَا مَلِلْتُ قَالَ ‏"‏ حَسْبُكِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَاذْهَبِي ‏"‏‏.‏\hadithno{949}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) came to my house while two girls were singing beside me the songs of Buath (a story about the war between the two tribes of the Ansar, the Khazraj and the Aus, before Islam). The Prophet (ﷺ) lay down and turned his face to the other side. Then Abu Bakr came and spoke to me harshly saying, "Musical instruments of Satan near the Prophet (ﷺ) ?" Allah's Messenger (ﷺ) turned his face towards him and said, "Leave them." When Abu Bakr became inattentive, I signaled to those girls to go out and they left. It was the day of `Id, and the Black people were playing with shields and spears; so either I requested the Prophet (ﷺ) or he asked me whether I would like to see the display. I replied in the affirmative. Then the Prophet (ﷺ) made me stand behind him and my cheek was touching his cheek and he was saying, "Carry on! O Bani Arfida," till I got tired. The Prophet (ﷺ) asked me, "Are you satisfied (Is that sufficient for you)?" I replied in the affirmative and he told me to leave}}
\hadithdefcmd{bukhari}{958}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْفِطْرِ، فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ‏.‏ قَالَ وَأَخْبَرَنِي عَطَاءٌ، أَنَّ ابْنَ عَبَّاسٍ، أَرْسَلَ إِلَى ابْنِ الزُّبَيْرِ فِي أَوَّلِ مَا بُويِعَ لَهُ إِنَّهُ لَمْ يَكُنْ يُؤَذَّنُ بِالصَّلاَةِ يَوْمَ الْفِطْرِ، إِنَّمَا الْخُطْبَةُ بَعْدَ الصَّلاَةِ‏.‏ وَأَخْبَرَنِي عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالاَ لَمْ يَكُنْ يُؤَذَّنُ يَوْمَ الْفِطْرِ وَلاَ يَوْمَ الأَضْحَى‏.‏ وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ فَبَدَأَ بِالصَّلاَةِ، ثُمَّ خَطَبَ النَّاسَ بَعْدُ، فَلَّمَا فَرَغَ نَبِيُّ اللَّهِ صلى الله عليه وسلم نَزَلَ فَأَتَى النِّسَاءَ، فَذَكَّرَهُنَّ وَهْوَ يَتَوَكَّأُ عَلَى يَدِ بِلاَلٍ، وَبِلاَلٌ بَاسِطٌ ثَوْبَهُ، يُلْقِي فِيهِ النِّسَاءُ صَدَقَةً‏.‏ قُلْتُ لِعَطَاءٍ أَتَرَى حَقًّا عَلَى الإِمَامِ الآنَ أَنْ يَأْتِيَ النِّسَاءَ فَيُذَكِّرَهُنَّ حِينَ يَفْرُغُ قَالَ إِنَّ ذَلِكَ لَحَقٌّ عَلَيْهِمْ، وَمَا لَهُمْ أَنْ لاَ يَفْعَلُوا\hadithno{958}\hadithtrans{Narrated Ibn Juraij:`Ata' said, "Jabir bin `Abdullah said, 'The Prophet (ﷺ) went out on the Day of `Id-ul-Fitr and offered the prayer before delivering the Khutba, Ata told me that during the early days of Ibn Az-Zubair, Ibn `Abbas had sent a message to him telling him that the Adhan for the `Id Prayer was never pronounced (in the life time of Allah's Messenger (ﷺ)) and the Khutba used to be delivered after the prayer. Ata told me that Ibn `Abbas and Jabir bin `Abdullah, had said, "There was no Adhan for the prayer of `Id-ul-Fitr and `Id-ul-Aqha." `Ata' said, "I heard Jabir bin `Abdullah saying, 'The Prophet (ﷺ) stood up and started with the prayer, and after it he delivered the Khutba. When the Prophet of Allah (ﷺ) finished (the Khutba), he went to the women and preached to them, while he was leaning on Bilal's hand. Bilal was spreading his garment and the ladies were putting alms in it.' " I said to Ata, "Do you think it incumbent upon an Imam to go to the women and preach to them after finishing the prayer and Khutba?" `Ata' said, "No doubt it is incumbent on Imams to do so, and why should they not do so?}}
\hadithdefcmd{bukhari}{959}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْفِطْرِ، فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ‏.‏ قَالَ وَأَخْبَرَنِي عَطَاءٌ، أَنَّ ابْنَ عَبَّاسٍ، أَرْسَلَ إِلَى ابْنِ الزُّبَيْرِ فِي أَوَّلِ مَا بُويِعَ لَهُ إِنَّهُ لَمْ يَكُنْ يُؤَذَّنُ بِالصَّلاَةِ يَوْمَ الْفِطْرِ، إِنَّمَا الْخُطْبَةُ بَعْدَ الصَّلاَةِ‏.‏ وَأَخْبَرَنِي عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالاَ لَمْ يَكُنْ يُؤَذَّنُ يَوْمَ الْفِطْرِ وَلاَ يَوْمَ الأَضْحَى‏.‏ وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ فَبَدَأَ بِالصَّلاَةِ، ثُمَّ خَطَبَ النَّاسَ بَعْدُ، فَلَّمَا فَرَغَ نَبِيُّ اللَّهِ صلى الله عليه وسلم نَزَلَ فَأَتَى النِّسَاءَ، فَذَكَّرَهُنَّ وَهْوَ يَتَوَكَّأُ عَلَى يَدِ بِلاَلٍ، وَبِلاَلٌ بَاسِطٌ ثَوْبَهُ، يُلْقِي فِيهِ النِّسَاءُ صَدَقَةً‏.‏ قُلْتُ لِعَطَاءٍ أَتَرَى حَقًّا عَلَى الإِمَامِ الآنَ أَنْ يَأْتِيَ النِّسَاءَ فَيُذَكِّرَهُنَّ حِينَ يَفْرُغُ قَالَ إِنَّ ذَلِكَ لَحَقٌّ عَلَيْهِمْ، وَمَا لَهُمْ أَنْ لاَ يَفْعَلُوا\hadithno{959}\hadithtrans{Narrated Ibn Juraij:`Ata' said, "Jabir bin `Abdullah said, 'The Prophet (ﷺ) went out on the Day of `Id-ul-Fitr and offered the prayer before delivering the Khutba, Ata told me that during the early days of Ibn Az-Zubair, Ibn `Abbas had sent a message to him telling him that the Adhan for the `Id Prayer was never pronounced (in the life time of Allah's Messenger (ﷺ)) and the Khutba used to be delivered after the prayer. Ata told me that Ibn `Abbas and Jabir bin `Abdullah, had said, "There was no Adhan for the prayer of `Id-ul-Fitr and `Id-ul-Aqha." `Ata' said, "I heard Jabir bin `Abdullah saying, 'The Prophet (ﷺ) stood up and started with the prayer, and after it he delivered the Khutba. When the Prophet of Allah (ﷺ) finished (the Khutba), he went to the women and preached to them, while he was leaning on Bilal's hand. Bilal was spreading his garment and the ladies were putting alms in it.' " I said to Ata, "Do you think it incumbent upon an Imam to go to the women and preach to them after finishing the prayer and Khutba?" `Ata' said, "No doubt it is incumbent on Imams to do so, and why should they not do so?}}
\hadithdefcmd{bukhari}{960}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْفِطْرِ، فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ‏.‏ قَالَ وَأَخْبَرَنِي عَطَاءٌ، أَنَّ ابْنَ عَبَّاسٍ، أَرْسَلَ إِلَى ابْنِ الزُّبَيْرِ فِي أَوَّلِ مَا بُويِعَ لَهُ إِنَّهُ لَمْ يَكُنْ يُؤَذَّنُ بِالصَّلاَةِ يَوْمَ الْفِطْرِ، إِنَّمَا الْخُطْبَةُ بَعْدَ الصَّلاَةِ‏.‏ وَأَخْبَرَنِي عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالاَ لَمْ يَكُنْ يُؤَذَّنُ يَوْمَ الْفِطْرِ وَلاَ يَوْمَ الأَضْحَى‏.‏ وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ فَبَدَأَ بِالصَّلاَةِ، ثُمَّ خَطَبَ النَّاسَ بَعْدُ، فَلَّمَا فَرَغَ نَبِيُّ اللَّهِ صلى الله عليه وسلم نَزَلَ فَأَتَى النِّسَاءَ، فَذَكَّرَهُنَّ وَهْوَ يَتَوَكَّأُ عَلَى يَدِ بِلاَلٍ، وَبِلاَلٌ بَاسِطٌ ثَوْبَهُ، يُلْقِي فِيهِ النِّسَاءُ صَدَقَةً‏.‏ قُلْتُ لِعَطَاءٍ أَتَرَى حَقًّا عَلَى الإِمَامِ الآنَ أَنْ يَأْتِيَ النِّسَاءَ فَيُذَكِّرَهُنَّ حِينَ يَفْرُغُ قَالَ إِنَّ ذَلِكَ لَحَقٌّ عَلَيْهِمْ، وَمَا لَهُمْ أَنْ لاَ يَفْعَلُوا\hadithno{960}\hadithtrans{Narrated Ibn Juraij:`Ata' said, "Jabir bin `Abdullah said, 'The Prophet (ﷺ) went out on the Day of `Id-ul-Fitr and offered the prayer before delivering the Khutba, Ata told me that during the early days of Ibn Az-Zubair, Ibn `Abbas had sent a message to him telling him that the Adhan for the `Id Prayer was never pronounced (in the life time of Allah's Messenger (ﷺ)) and the Khutba used to be delivered after the prayer. Ata told me that Ibn `Abbas and Jabir bin `Abdullah, had said, "There was no Adhan for the prayer of `Id-ul-Fitr and `Id-ul-Aqha." `Ata' said, "I heard Jabir bin `Abdullah saying, 'The Prophet (ﷺ) stood up and started with the prayer, and after it he delivered the Khutba. When the Prophet of Allah (ﷺ) finished (the Khutba), he went to the women and preached to them, while he was leaning on Bilal's hand. Bilal was spreading his garment and the ladies were putting alms in it.' " I said to Ata, "Do you think it incumbent upon an Imam to go to the women and preach to them after finishing the prayer and Khutba?" `Ata' said, "No doubt it is incumbent on Imams to do so, and why should they not do so?}}
\hadithdefcmd{bukhari}{987}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ دَخَلَ عَلَيْهَا وَعِنْدَهَا جَارِيَتَانِ فِي أَيَّامِ مِنًى تُدَفِّفَانِ وَتَضْرِبَانِ، وَالنَّبِيُّ صلى الله عليه وسلم مُتَغَشٍّ بِثَوْبِهِ، فَانْتَهَرَهُمَا أَبُو بَكْرٍ فَكَشَفَ النَّبِيُّ صلى الله عليه وسلم عَنْ وَجْهِهِ فَقَالَ ‏"‏ دَعْهُمَا يَا أَبَا بَكْرٍ فَإِنَّهَا أَيَّامُ عِيدٍ ‏"‏‏.‏ وَتِلْكَ الأَيَّامُ أَيَّامُ مِنًى‏.‏ وَقَالَتْ عَائِشَةُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتُرُنِي، وَأَنَا أَنْظُرُ إِلَى الْحَبَشَةِ وَهُمْ يَلْعَبُونَ فِي الْمَسْجِدِ، فَزَجَرَهُمْ عُمَرُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعْهُمْ، أَمْنًا بَنِي أَرْفِدَةَ ‏"‏‏.‏ يَعْنِي مِنَ الأَمْنِ‏.‏\hadithno{987}\hadithtrans{Narrated `Urwa on the authority of `Aisha:On the days of Mina, (11th, 12th, and 13th of Dhul-Hijjah) Abu Bakr came to her while two young girls were beating the tambourine and the Prophet (ﷺ) was lying covered with his clothes. Abu Bakr scolded them and the Prophet (ﷺ) uncovered his face and said to Abu Bakr, "Leave them, for these days are the days of `Id and the days of Mina." `Aisha further said, "Once the Prophet (ﷺ) was screening me and I was watching the display of black slaves in the Mosque and (`Umar) scolded them. The Prophet (ﷺ) said, 'Leave them. O Bani Arfida! (carry on), you are safe (protected)}}
\hadithdefcmd{bukhari}{1008}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو قُتَيْبَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَتَمَثَّلُ بِشِعْرِ أَبِي طَالِبٍ وَأَبْيَضَ يُسْتَسْقَى الْغَمَامُ بِوَجْهِهِ ثِمَالُ الْيَتَامَى عِصْمَةٌ لِلأَرَامِلِ وَقَالَ عُمَرُ بْنُ حَمْزَةَ حَدَّثَنَا سَالِمٌ، عَنْ أَبِيهِ، رُبَّمَا ذَكَرْتُ قَوْلَ الشَّاعِرِ وَأَنَا أَنْظُرُ، إِلَى وَجْهِ النَّبِيِّ صلى الله عليه وسلم يَسْتَسْقِي، فَمَا يَنْزِلُ حَتَّى يَجِيشَ كُلُّ مِيزَابٍ‏.‏ وَأَبْيَضَ يُسْتَسْقَى الْغَمَامُ بِوَجْهِهِ ثِمَالَ الْيَتَامَى عِصْمَةً لِلأَرَامِلِ وَهْوَ قَوْلُ أَبِي طَالِبٍ‏.‏\hadithno{1008}\hadithtrans{Narrated `Abdullah bin Dinar:My father said, "I heard Ibn `Umar reciting the poetic verses of Abu Talib: And a white (person) (i.e. the Prophet) who is requested to pray for rain and who takes care of the orphans and is the guardian of widows." Salim's father (Ibn `Umar) said, "The following poetic verse occurred to my mind while I was looking at the face of the Prophet (ﷺ) while he was praying for rain. He did not get down till the rain water flowed profusely from every roof-gutter: And a white (person) who is requested to pray for rain and who takes care of the orphans and is the guardian of widows . . . And these were the words of Abu Talib}}
\hadithdefcmd{bukhari}{1049}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ يَهُودِيَّةً جَاءَتْ تَسْأَلُهَا فَقَالَتْ لَهَا أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ‏.‏ فَسَأَلَتْ عَائِشَةُ ـ رضى الله عنها ـ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيُعَذَّبُ النَّاسُ فِي قُبُورِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِذًا بِاللَّهِ مِنْ ذَلِكَ‏.‏ ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ غَدَاةٍ مَرْكَبًا، فَخَسَفَتِ الشَّمْسُ، فَرَجَعَ ضُحًى، فَمَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ ظَهْرَانَىِ الْحُجَرِ، ثُمَّ قَامَ يُصَلِّي، وَقَامَ النَّاسُ وَرَاءَهُ، فَقَامَ قِيَامًا طَوِيلاً، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَسَجَدَ، ثُمَّ قَامَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ قَامَ قِيَامًا طَوِيلاً وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَسَجَدَ وَانْصَرَفَ، فَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ، ثُمَّ أَمَرَهُمْ أَنْ يَتَعَوَّذُوا مِنْ عَذَابِ الْقَبْرِ‏.‏\hadithno{1049}\hadithtrans{Narrated `Amra bint `Abdur-Rahman:A Jewess came to ask `Aisha (the wife of the Prophet) about something. She said to her, "May Allah give you refuge from the punishment of the grave." So `Aisha ' asked Allah's Messenger (ﷺ) "Would the people be punished in their graves?" Allah's Messenger (ﷺ) after seeking refuge with Allah from the punishment of the grave (and thus replied in the affirmative). Then one day, Allah's Messenger (ﷺ) rode to go to some place but the sun eclipsed. He returned in the forenoon and passed through the rear of the dwellings (of his wives) and stood for the (eclipse) prayer, and the people stood behind him. He stood up for a long period and then performed a prolonged bowing which was shorter than the first bowing. Then he raised his head and prostrated. Then he stood up (for the second rak`a) for a long while but the standing was shorter than that of the first rak`a. Then he performed a prolonged bowing which was shorter than the first one. Then he raised his head and prostrated. Then he stood up for a long time but shorter than the first. Then he performed a prolonged bowing but shorter than the first. Then he raised his head and prostrated and finished the prayer and (then delivered the sermon and) said as much as Allah wished. And then he ordered the people to seek refuge with Allah from the punishment of the grave}}
\hadithdefcmd{bukhari}{1055}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ يَهُودِيَّةً، جَاءَتْ تَسْأَلُهَا فَقَالَتْ أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ‏.‏ فَسَأَلَتْ عَائِشَةُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيُعَذَّبُ النَّاسُ فِي قُبُورِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِذًا بِاللَّهِ مِنْ ذَلِكَ‏.‏ ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ غَدَاةٍ مَرْكَبًا، فَكَسَفَتِ الشَّمْسُ فَرَجَعَ ضُحًى، فَمَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ ظَهْرَانَىِ الْحُجَرِ، ثُمَّ قَامَ فَصَلَّى، وَقَامَ النَّاسُ وَرَاءَهُ، فَقَامَ قِيَامًا طَوِيلاً، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَسَجَدَ سُجُودًا طَوِيلاً ثُمَّ قَامَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ قَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ سَجَدَ وَهْوَ دُونَ السُّجُودِ الأَوَّلِ، ثُمَّ انْصَرَفَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ أَنْ يَقُولَ، ثُمَّ أَمَرَهُمْ أَنْ يَتَعَوَّذُوا مِنْ عَذَابِ الْقَبْرِ\hadithno{1055}\hadithtrans{Narrated `Amra bint `Abdur-Rahman:A Jewess came to `Aisha to ask her about something and then she said, "May Allah give you refuge from the punishment of the grave." So `Aisha asked Allah's Messenger (ﷺ), "Would the people be punished in their graves?" Allah's Messenger (ﷺ) asked Allah's refuge from the punishment of the grave (indicating an affirmative reply). Then one day Allah's Messenger (ﷺ) rode (to leave for some place) but the sun eclipsed. He returned on the forenoon and passed through the rear of the dwellings (of his wives) and stood up and started offering the (eclipse) prayer and the people stood behind him. He stood for a long period and then performed a long bowing and then stood straight for a long period which was shorter than that of the first standing, then he performed a prolonged bowing which was shorter than the first bowing, then he raised his head and prostrated for a long time and then stood up (for the second rak`a) for a long while, but the standing was shorter than the standing of the first rak`a. Then he performed a prolonged bowing which was shorter than that of the first one. He then stood up for a long time but shorter than the first, then again performed a long bowing which was shorter than the first and then prostrated for a shorter while than that of the first prostration. Then he finished the prayer and delivered the sermon and) said what Allah wished; and ordered the people to seek refuge with Allah from the punishment of the grave}}
\hadithdefcmd{bukhari}{1065}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ أَخْبَرَنَا ابْنُ نَمِرٍ، سَمِعَ ابْنَ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ جَهَرَ النَّبِيُّ صلى الله عليه وسلم فِي صَلاَةِ الْخُسُوفِ بِقِرَاءَتِهِ، فَإِذَا فَرَغَ مِنْ قِرَاءَتِهِ كَبَّرَ فَرَكَعَ، وَإِذَا رَفَعَ مِنَ الرَّكْعَةِ قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ، رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ ثُمَّ يُعَاوِدُ الْقِرَاءَةَ فِي صَلاَةِ الْكُسُوفِ، أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ‏.‏ وَقَالَ الأَوْزَاعِيُّ وَغَيْرُهُ سَمِعْتُ الزُّهْرِيَّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ الشَّمْسَ، خَسَفَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَعَثَ مُنَادِيًا بِالصَّلاَةُ جَامِعَةٌ، فَتَقَدَّمَ فَصَلَّى أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ‏.‏ وَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ سَمِعَ ابْنَ شِهَابٍ مِثْلَهُ‏.‏ قَالَ الزُّهْرِيُّ فَقُلْتُ مَا صَنَعَ أَخُوكَ ذَلِكَ، عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ مَا صَلَّى إِلاَّ رَكْعَتَيْنِ مِثْلَ الصُّبْحِ إِذْ صَلَّى بِالْمَدِينَةِ‏.‏ قَالَ أَجَلْ، إِنَّهُ أَخْطَأَ السُّنَّةَ‏.‏ تَابَعَهُ سُفْيَانُ بْنُ حُسَيْنٍ وَسُلَيْمَانُ بْنُ كَثِيرٍ عَنِ الزُّهْرِيِّ فِي الْجَهْرِ‏.‏\hadithno{1065}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) recited (the Qur'an) aloud during the eclipse prayer and when he had finished the eclipse prayer he said the Takbir and bowed. When he stood straight from bowing he would say "Sami 'allahu liman hamidah Rabbana wa laka l-hamd." And he would again start reciting. In the eclipse prayer there are four bowing and four prostrations in two rak`at. Al-Auza'i and others said that they had heard Az-Zuhri from 'Urwa from `Aisha saying, "In the lifetime of Allah's Messenger (ﷺ) the sun eclipsed, and he made a person to announce: 'Prayer in congregation.' He led the prayer and performed four bowing and four prostrations in two rak`at." Narrated Al-Walid that `Abdur-Rahman bin Namir had informed him that he had heard the same. Ibn Shihab heard the same. Az-Zuhri said, "I asked ('Urwa), 'What did your brother `Abdullah bin Az-Zubair do? He prayed two rak`at (of the eclipse prayer) like the morning prayer, when he offered the (eclipse) prayer in Medina.' 'Urwa replied that he had missed (i.e. did not pray according to) the Prophet's tradition." Sulaiman bin Kathir and Sufyan bin Husain narrated from Az-Zuhri that the prayer for the eclipse used to be offered with loud recitation}}
\hadithdefcmd{bukhari}{1091}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا أَعْجَلَهُ السَّيْرُ فِي السَّفَرِ يُؤَخِّرُ الْمَغْرِبَ حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ الْعِشَاءِ‏.‏ قَالَ سَالِمٌ وَكَانَ عَبْدُ اللَّهِ يَفْعَلُهُ إِذَا أَعْجَلَهُ السَّيْرُ‏.‏ وَزَادَ اللَّيْثُ قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ سَالِمٌ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِالْمُزْدَلِفَةِ‏.‏ قَالَ سَالِمٌ وَأَخَّرَ ابْنُ عُمَرَ الْمَغْرِبَ، وَكَانَ اسْتُصْرِخَ عَلَى امْرَأَتِهِ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ فَقُلْتُ لَهُ الصَّلاَةُ‏.‏ فَقَالَ سِرْ‏.‏ فَقُلْتُ الصَّلاَةُ‏.‏ فَقَالَ سِرْ‏.‏ حَتَّى سَارَ مِيلَيْنِ أَوْ ثَلاَثَةً ثُمَّ نَزَلَ فَصَلَّى ثُمَّ قَالَ هَكَذَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَلِّي إِذَا أَعْجَلَهُ السَّيْرُ‏.‏ وَقَالَ عَبْدُ اللَّهِ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم إِذَا أَعْجَلَهُ السَّيْرُ يُؤَخِّرُ الْمَغْرِبَ، فَيُصَلِّيهَا ثَلاَثًا ثُمَّ يُسَلِّمُ، ثُمَّ قَلَّمَا يَلْبَثُ حَتَّى يُقِيمَ الْعِشَاءَ فَيُصَلِّيَهَا رَكْعَتَيْنِ ثُمَّ يُسَلِّمُ، وَلاَ يُسَبِّحُ بَعْدَ الْعِشَاءِ حَتَّى يَقُومَ مِنْ جَوْفِ اللَّيْلِ‏.‏\hadithno{1091}\hadithtrans{Narrated `Abdullah bin `Umar:"I saw Allah's Messenger (ﷺ) delaying the Maghrib prayer till he offered it along with the `Isha' prayer whenever he was in a hurry during the journey." Salim narrated, "Ibn `Umar used to do the same whenever he was in a hurry during the journey." And Salim added, "Ibn `Umar used to pray the Maghrib and `Isha' prayers together in Al-Muzdalifa." Salim said, "Ibn `Umar delayed the Maghrib prayer because at that time he heard the news of the death of his wife Safiya bint Abi `Ubaid. I said to him, 'The prayer (is due).' He said, 'Go on.' Again I said, 'The prayer (is due).' He said, 'Go on,' till we covered two or three miles. Then he got down, prayed and said, 'I saw the Prophet (ﷺ) praying in this way, whenever he was in a hurry during the journey.' `Abdullah (bin `Umar) added, "Whenever the Prophet was in a hurry, he used to delay the Maghrib prayer and then offer three rak`at (of the Maghrib) and perform Taslim, and after waiting for a short while, Iqama used to be pronounced for the `Isha' prayer when he would offer two rak`at and perform Taslim. He would never offer any optional prayer till the middle of the night (when he used to pray the Tahajjud)}}
\hadithdefcmd{bukhari}{1121}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَنَا مَعْمَرٌ،‏.‏ وَحَدَّثَنِي مَحْمُودٌ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ كَانَ الرَّجُلُ فِي حَيَاةِ النَّبِيِّ صلى الله عليه وسلم إِذَا رَأَى رُؤْيَا قَصَّهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَمَنَّيْتُ أَنْ أَرَى رُؤْيَا فَأَقُصَّهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَكُنْتُ غُلاَمًا شَابًّا، وَكُنْتُ أَنَامُ فِي الْمَسْجِدِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُ فِي النَّوْمِ كَأَنَّ مَلَكَيْنِ أَخَذَانِي فَذَهَبَا بِي إِلَى النَّارِ فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ، وَإِذَا لَهَا قَرْنَانِ، وَإِذَا فِيهَا أُنَاسٌ قَدْ عَرَفْتُهُمْ فَجَعَلْتُ أَقُولُ أَعُوذُ بِاللَّهِ مِنَ النَّارِ ـ قَالَ ـ فَلَقِيَنَا مَلَكٌ آخَرُ فَقَالَ لِي لَمْ تُرَعْ‏.‏ فَقَصَصْتُهَا عَلَى حَفْصَةَ فَقَصَّتْهَا حَفْصَةُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ، لَوْ كَانَ يُصَلِّي مِنَ اللَّيْلِ ‏"‏‏.‏ فَكَانَ بَعْدُ لاَ يَنَامُ مِنَ اللَّيْلِ إِلاَّ قَلِيلاً‏.‏\hadithno{1121}\hadithtrans{Narrated Salim's father:In the lifetime of the Prophet (ﷺ) whosoever saw a dream would narrate it to Allah's Messenger (ﷺ). I had a wish of seeing a dream to narrate it to Allah's Messenger (ﷺ) I was a grown up boy and used to sleep in the Mosque in the lifetime of the Prophet. I saw in the dream that two angels caught hold of me and took me to the Fire which was built all round like a built well and had two poles in it and the people in it were known to me. I started saying, "I seek refuge with Allah from the Fire." Then I met another angel who told me not to be afraid. I narrated the dream to Hafsa who told it to Allah's Messenger (ﷺ). The Prophet said, "Abdullah is a good man. I wish he prayed Tahajjud." After that `Abdullah (i.e. Salim's father) used to sleep but a little at night}}
\hadithdefcmd{bukhari}{1156}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ رَأَيْتُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم كَأَنَّ بِيَدِي قِطْعَةَ إِسْتَبْرَقٍ، فَكَأَنِّي لاَ أُرِيدُ مَكَانًا مِنَ الْجَنَّةِ إِلاَّ طَارَتْ إِلَيْهِ، وَرَأَيْتُ كَأَنَّ اثْنَيْنِ أَتَيَانِي أَرَادَا أَنْ يَذْهَبَا بِي إِلَى النَّارِ فَتَلَقَّاهُمَا مَلَكٌ فَقَالَ لَمْ تُرَعْ خَلِّيَا عَنْهُ‏.‏ فَقَصَّتْ حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم إِحْدَى رُؤْيَاىَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ لَوْ كَانَ يُصَلِّي مِنَ اللَّيْلِ ‏"‏‏.‏ فَكَانَ عَبْدُ اللَّهِ ـ رضى الله عنه ـ يُصَلِّي مِنَ اللَّيْلِ‏.‏ وَكَانُوا لاَ يَزَالُونَ يَقُصُّونَ عَلَى النَّبِيِّ صلى الله عليه وسلم الرُّؤْيَا أَنَّهَا فِي اللَّيْلَةِ السَّابِعَةِ مِنَ الْعَشْرِ الأَوَاخِرِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرَى رُؤْيَاكُمْ قَدْ تَوَاطَتْ فِي الْعَشْرِ الأَوَاخِرِ، فَمَنْ كَانَ مُتَحَرِّيْهَا فَلْيَتَحَرَّهَا مِنَ الْعَشْرِ الأَوَاخِرِ ‏"‏‏.‏\hadithno{1156}\hadithtrans{Narrated Nafi`:Ibn `Umar said, "In the lifetime of the Prophet (ﷺ) I dreamt that a piece of silk cloth was in my hand and it flew with me to whichever part of Paradise I wanted. I also saw as if two persons (i.e. angels) came to me and wanted to take me to Hell. Then an angel met us and told me not to be afraid. He then told them to leave me. Hafsa narrated one of my dreams to the Prophet (ﷺ) and the Prophet (ﷺ) said, "Abdullah is a good man. Would that he offer the night prayer (Tahajjud)!" So after that day `Abdullah (bin `Umar) started offering Tahajjud. The companions of the Prophet (ﷺ) used to tell him their dreams that (Laila-tul-Qadr) was on the 27th of the month of Ramadan. The Prophet (ﷺ) said, "I see that your dreams agree on the last ten nights of Ramadan and so whoever is in search of it should seek it in the last ten nights of Ramadan}}
\hadithdefcmd{bukhari}{1157}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ رَأَيْتُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم كَأَنَّ بِيَدِي قِطْعَةَ إِسْتَبْرَقٍ، فَكَأَنِّي لاَ أُرِيدُ مَكَانًا مِنَ الْجَنَّةِ إِلاَّ طَارَتْ إِلَيْهِ، وَرَأَيْتُ كَأَنَّ اثْنَيْنِ أَتَيَانِي أَرَادَا أَنْ يَذْهَبَا بِي إِلَى النَّارِ فَتَلَقَّاهُمَا مَلَكٌ فَقَالَ لَمْ تُرَعْ خَلِّيَا عَنْهُ‏.‏ فَقَصَّتْ حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم إِحْدَى رُؤْيَاىَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ لَوْ كَانَ يُصَلِّي مِنَ اللَّيْلِ ‏"‏‏.‏ فَكَانَ عَبْدُ اللَّهِ ـ رضى الله عنه ـ يُصَلِّي مِنَ اللَّيْلِ‏.‏ وَكَانُوا لاَ يَزَالُونَ يَقُصُّونَ عَلَى النَّبِيِّ صلى الله عليه وسلم الرُّؤْيَا أَنَّهَا فِي اللَّيْلَةِ السَّابِعَةِ مِنَ الْعَشْرِ الأَوَاخِرِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرَى رُؤْيَاكُمْ قَدْ تَوَاطَتْ فِي الْعَشْرِ الأَوَاخِرِ، فَمَنْ كَانَ مُتَحَرِّيْهَا فَلْيَتَحَرَّهَا مِنَ الْعَشْرِ الأَوَاخِرِ ‏"‏‏.‏\hadithno{1157}\hadithtrans{Narrated Nafi`:Ibn `Umar said, "In the lifetime of the Prophet (ﷺ) I dreamt that a piece of silk cloth was in my hand and it flew with me to whichever part of Paradise I wanted. I also saw as if two persons (i.e. angels) came to me and wanted to take me to Hell. Then an angel met us and told me not to be afraid. He then told them to leave me. Hafsa narrated one of my dreams to the Prophet (ﷺ) and the Prophet (ﷺ) said, "Abdullah is a good man. Would that he offer the night prayer (Tahajjud)!" So after that day `Abdullah (bin `Umar) started offering Tahajjud. The companions of the Prophet (ﷺ) used to tell him their dreams that (Laila-tul-Qadr) was on the 27th of the month of Ramadan. The Prophet (ﷺ) said, "I see that your dreams agree on the last ten nights of Ramadan and so whoever is in search of it should seek it in the last ten nights of Ramadan}}
\hadithdefcmd{bukhari}{1172}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم سَجْدَتَيْنِ قَبْلَ الظُّهْرِ، وَسَجْدَتَيْنِ بَعْدَ الظُّهْرِ، وَسَجْدَتَيْنِ بَعْدَ الْمَغْرِبِ، وَسَجْدَتَيْنِ بَعْدَ الْعِشَاءِ، وَسَجْدَتَيْنِ بَعْدَ الْجُمُعَةِ، فَأَمَّا الْمَغْرِبُ وَالْعِشَاءُ فَفِي بَيْتِهِ‏.‏ قَالَ ابْنُ أَبِي الزِّنَادِ عَنْ مُوسَى بْنِ عُقْبَةَ عَنْ نَافِعٍ بَعْدَ الْعِشَاءِ فِي أَهْلِهِ‏.‏ تَابَعَهُ كَثِيرُ بْنُ فَرْقَدٍ وَأَيُّوبُ عَنْ نَافِعٍ‏.‏ وَحَدَّثَتْنِي أُخْتِي، حَفْصَةُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي سَجْدَتَيْنِ خَفِيفَتَيْنِ بَعْدَ مَا يَطْلُعُ الْفَجْرُ، وَكَانَتْ سَاعَةً لاَ أَدْخُلُ عَلَى النَّبِيِّ صلى الله عليه وسلم فِيهَا‏.‏ تَابَعَهُ كَثِيرُ بْنُ فَرْقَدٍ وَأَيُّوبُ عَنْ نَافِعٍ‏.‏ وَقَالَ ابْنُ أَبِي الزِّنَادِ عَنْ مُوسَى بْنِ عُقْبَةَ عَنْ نَافِعٍ بَعْدَ الْعِشَاءِ فِي أَهْلِهِ‏.‏\hadithno{1172}\hadithtrans{Narrated Ibn `Umar:I offered with the Prophet (ﷺ) two rak`at before the Zuhr and two rak`at after the Zuhr prayer; two rak`at after Maghrib, `Isha' and the Jumua prayers. Those of the Maghrib and `Isha' were offered in his house. My sister Hafsa told me that the Prophet (ﷺ) used to offer two light rak`at after dawn and it was the time when I never went to the Prophet}}
\hadithdefcmd{bukhari}{1180}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ حَفِظْتُ مِنَ النَّبِيِّ صلى الله عليه وسلم عَشْرَ رَكَعَاتٍ رَكْعَتَيْنِ قَبْلَ الظُّهْرِ، وَرَكْعَتَيْنِ بَعْدَهَا، وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ فِي بَيْتِهِ، وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ فِي بَيْتِهِ، وَرَكْعَتَيْنِ قَبْلَ صَلاَةِ الصُّبْحِ، وَكَانَتْ سَاعَةً لاَ يُدْخَلُ عَلَى النَّبِيِّ صلى الله عليه وسلم فِيهَا‏.‏ حَدَّثَتْنِي حَفْصَةُ، أَنَّهُ كَانَ إِذَا أَذَّنَ الْمُؤَذِّنُ وَطَلَعَ الْفَجْرُ صَلَّى رَكْعَتَيْنِ‏.‏\hadithno{1180}\hadithtrans{Narrated Ibn 'Umar: I remember ten Rakat of Nawafil from the Prophet, two Rakat before the Zuhr prayer and two after it; two Rakat after Maghrib prayer in his house, and two Rakat after 'Isha' prayer in his house, and two Rakat before the Fajr prayer and at that time nobody would enter the house of the Prophet. Hafsa told me that the Prophet (ﷺ) used to offer two Rakat after the call maker had made the Adhan and the day had dawned}}
\hadithdefcmd{bukhari}{1186}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ الأَنْصَارِيُّ، أَنَّهُ عَقَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم، وَعَقَلَ مَجَّةً مَجَّهَا فِي وَجْهِهِ مِنْ بِئْرٍ كَانَتْ فِي دَارِهِمْ‏.‏ فَزَعَمَ مَحْمُودٌ أَنَّهُ سَمِعَ عِتْبَانَ بْنَ مَالِكٍ الأَنْصَارِيّ َ ـ رضى الله عنه ـ وَكَانَ مِمَّنْ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ كُنْتُ أُصَلِّي لِقَوْمِي بِبَنِي سَالِمٍ، وَكَانَ يَحُولُ بَيْنِي وَبَيْنَهُمْ وَادٍ إِذَا جَاءَتِ الأَمْطَارُ فَيَشُقُّ عَلَىَّ اجْتِيَازُهُ قِبَلَ مَسْجِدِهِمْ، فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ إِنِّي أَنْكَرْتُ بَصَرِي، وَإِنَّ الْوَادِيَ الَّذِي بَيْنِي وَبَيْنَ قَوْمِي يَسِيلُ إِذَا جَاءَتِ الأَمْطَارُ فَيَشُقُّ عَلَىَّ اجْتِيَازُهُ، فَوَدِدْتُ أَنَّكَ تَأْتِي فَتُصَلِّي مِنْ بَيْتِي مَكَانًا أَتَّخِذُهُ مُصَلًّى‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَأَفْعَلُ ‏"‏‏.‏ فَغَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ ـ رضى الله عنه ـ بَعْدَ مَا اشْتَدَّ النَّهَارُ فَاسْتَأْذَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَذِنْتُ لَهُ فَلَمْ يَجْلِسْ حَتَّى قَالَ ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكَ ‏"‏‏.‏ فَأَشَرْتُ لَهُ إِلَى الْمَكَانِ الَّذِي أُحِبُّ أَنْ أُصَلِّيَ فِيهِ، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرَ وَصَفَفْنَا وَرَاءَهُ، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ سَلَّمَ وَسَلَّمْنَا حِينَ سَلَّمَ، فَحَبَسْتُهُ عَلَى خَزِيرٍ يُصْنَعُ لَهُ فَسَمِعَ أَهْلُ الدَّارِ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي فَثَابَ رِجَالٌ مِنْهُمْ حَتَّى كَثُرَ الرِّجَالُ فِي الْبَيْتِ‏.‏ فَقَالَ رَجُلٌ مِنْهُمْ مَا فَعَلَ مَالِكٌ لاَ أَرَاهُ‏.‏ فَقَالَ رَجُلٌ مِنْهُمْ ذَاكَ مُنَافِقٌ لاَ يُحِبُّ اللَّهَ وَرَسُولَهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقُلْ ذَاكَ أَلاَ تَرَاهُ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ يَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ ‏"‏‏.‏ فَقَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ أَمَّا نَحْنُ فَوَاللَّهِ لاَ نَرَى وُدَّهُ وَلاَ حَدِيثَهُ إِلاَّ إِلَى الْمُنَافِقِينَ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّ اللَّهَ قَدْ حَرَّمَ عَلَى النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ يَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ ‏"‏‏.‏ قَالَ مَحْمُودٌ فَحَدَّثْتُهَا قَوْمًا فِيهِمْ أَبُو أَيُّوبَ صَاحِبُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَتِهِ الَّتِي تُوُفِّيَ فِيهَا وَيَزِيدُ بْنُ مُعَاوِيَةَ عَلَيْهِمْ بِأَرْضِ الرُّومِ، فَأَنْكَرَهَا عَلَىَّ أَبُو أَيُّوبَ قَالَ وَاللَّهِ مَا أَظُنُّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ مَا قُلْتَ قَطُّ‏.‏ فَكَبُرَ ذَلِكَ عَلَىَّ فَجَعَلْتُ لِلَّهِ عَلَىَّ إِنْ سَلَّمَنِي حَتَّى أَقْفُلَ مِنْ غَزْوَتِي أَنْ أَسْأَلَ عَنْهَا عِتْبَانَ بْنَ مَالِكٍ ـ رضى الله عنه ـ إِنْ وَجَدْتُهُ حَيًّا فِي مَسْجِدِ قَوْمِهِ، فَقَفَلْتُ فَأَهْلَلْتُ بِحَجَّةٍ أَوْ بِعُمْرَةٍ، ثُمَّ سِرْتُ حَتَّى قَدِمْتُ الْمَدِينَةَ فَأَتَيْتُ بَنِي سَالِمٍ، فَإِذَا عِتْبَانُ شَيْخٌ أَعْمَى يُصَلِّي لِقَوْمِهِ فَلَمَّا سَلَّمَ مِنَ الصَّلاَةِ سَلَّمْتُ عَلَيْهِ وَأَخْبَرْتُهُ مَنْ أَنَا، ثُمَّ سَأَلْتُهُ عَنْ ذَلِكَ الْحَدِيثِ فَحَدَّثَنِيهِ كَمَا حَدَّثَنِيهِ أَوَّلَ مَرَّةٍ‏.‏\hadithno{1186}\hadithtrans{Narrated Mahmud bin Ar-rabi' Al-Ansari:that he remembered Allah's Messenger (ﷺ) and he also remembered a mouthful of water which he had thrown on his face, after taking it from a well that was in their house. Mahmud said that he had heard `Itban bin Malik, who was present with Allah's Messenger (ﷺ) in the battle of Badr saying, "I used to lead my people at Bani Salim in the prayer and there was a valley between me and those people. Whenever it rained it used to be difficult for me to cross it to go to their mosque. So I went to Allah's Messenger (ﷺ) and said, 'I have weak eyesight and the valley between me and my people flows during the rainy season and it becomes difficult for me to cross it; I wish you would come to my house and pray at a place so that I could take that place as a praying place.' Allah's Messenger (ﷺ) said, 'I will do so.' So Allah's Messenger (ﷺ) and Abu Bakr came to my house in the (next) morning after the sun had risen high. Allah's Messenger (ﷺ) asked my permission to let him in and I admitted him. He did not sit before saying, 'Where do you want us to offer the prayer in your house?' I pointed to the place where I wanted him to pray. So Allah's Messenger (ﷺ) stood up for the prayer and started the prayer with Takbir and we aligned in rows behind him; and he offered two rak`at, and finished them with Taslim, and we also performed Taslim with him. I detained him for a meal called "Khazir" which I had prepared for him.--("Khazir" is a special type of dish prepared from barley flour and meat soup)-- When the neighbors got the news that Allah's Messenger (ﷺ) was in my house, they poured in till there were a great number of men in the house. One of them said, 'What is wrong with Malik, for I do not see him?' One of them replied, 'He is a hypocrite and does not love Allah and His Apostle.' On that Allah's Apostle said, 'Don't say this. Haven't you seen that he said, 'None has the right to be worshipped but Allah for Allah's sake only.' The man replied, 'Allah and His Apostle know better; but by Allah, we never saw him but helping and talking with the hypocrites.' Allah's Messenger (ﷺ) replied, 'No doubt, whoever says. None has the right to be worshipped but Allah, and by that he wants the pleasures of Allah, then Allah will save him from Hell." Mahmud added, "I told the above narration to some people, one of whom was Abu Aiyub, the companion of Allah's Messenger (ﷺ) in the battle in which he (Abu Aiyub) died and Yazid bin Mu'awiya was their leader in Roman Territory. Abu Aiyub denounced the narration and said, 'I doubt that Allah's Messenger (ﷺ) ever said what you have said.' I felt that too much, and I vowed to Allah that if I remained alive in that holy battle, I would (go to Medina and) ask `Itban bin Malik if he was still living in the mosque of his people. So when he returned, I assumed Ihram for Hajj or `Umra and then I proceeded on till I reached Medina. I went to Bani Salim and `Itban bin Malik, who was by then an old blind man, was leading his people in the prayer. When he finished the prayer, I greeted him and introduced myself to him and then asked him about that narration. He told that narration again in the same manner as he had narrated it the first time}}
\hadithdefcmd{bukhari}{1191}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ ـ هُوَ الدَّوْرَقِيُّ ـ حَدَّثَنَا ابْنُ عُلَيَّةَ، أَخْبَرَنَا أَيُّوبُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ لاَ يُصَلِّي مِنَ الضُّحَى إِلاَّ فِي يَوْمَيْنِ يَوْمَ يَقْدَمُ بِمَكَّةَ، فَإِنَّهُ كَانَ يَقْدَمُهَا ضُحًى، فَيَطُوفُ بِالْبَيْتِ، ثُمَّ يُصَلِّي رَكْعَتَيْنِ خَلْفَ الْمَقَامِ، وَيَوْمَ يَأْتِي مَسْجِدَ قُبَاءٍ، فَإِنَّهُ كَانَ يَأْتِيهِ كُلَّ سَبْتٍ، فَإِذَا دَخَلَ الْمَسْجِدَ كَرِهَ أَنْ يَخْرُجَ مِنْهُ حَتَّى يُصَلِّيَ فِيهِ‏.‏ قَالَ وَكَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَزُورُهُ رَاكِبًا وَمَاشِيًا‏.‏ قَالَ وَكَانَ يَقُولُ إِنَّمَا أَصْنَعُ كَمَا رَأَيْتُ أَصْحَابِي يَصْنَعُونَ، وَلاَ أَمْنَعُ أَحَدًا أَنْ يُصَلِّيَ فِي أَىِّ سَاعَةٍ شَاءَ مِنْ لَيْلٍ أَوْ نَهَارٍ، غَيْرَ أَنْ لاَ تَتَحَرَّوْا طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا‏.‏\hadithno{1191}\hadithtrans{Narrated Nafi`:Ibn `Umar never offered the Duha prayer except on two occasions: (1) Whenever he reached Mecca; and he always used to reach Mecca in the forenoon. He would perform Tawaf round the Ka`ba and then offer two rak`at at the rear of Maqam Ibrahim. (2) Whenever he visited Quba, for he used to visit it every Saturday. When he entered the Mosque, he disliked to leave it without offering a prayer. Ibn `Umar narrated that Allah's Messenger (ﷺ) used to visit the Mosque of Quba (sometime) walking and (sometime) riding. And he (i.e. Ibn `Umar) used to say, "I do only what my companions used to do and I don't forbid anybody to pray at any time during the day or night except that one should not intend to pray at sunrise or sunset}}
\hadithdefcmd{bukhari}{1241}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنِي مَعْمَرٌ، وَيُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ قَالَتْ أَقْبَلَ أَبُو بَكْرٍ ـ رضى الله عنه ـ عَلَى فَرَسِهِ مِنْ مَسْكَنِهِ بِالسُّنْحِ حَتَّى نَزَلَ، فَدَخَلَ الْمَسْجِدَ، فَلَمْ يُكَلِّمِ النَّاسَ، حَتَّى نَزَلَ فَدَخَلَ عَلَى عَائِشَةَ ـ رضى الله عنها ـ فَتَيَمَّمَ النَّبِيَّ صلى الله عليه وسلم وَهُوَ مُسَجًّى بِبُرْدِ حِبَرَةٍ، فَكَشَفَ عَنْ وَجْهِهِ، ثُمَّ أَكَبَّ عَلَيْهِ فَقَبَّلَهُ ثُمَّ بَكَى فَقَالَ بِأَبِي أَنْتَ يَا نَبِيَّ اللَّهِ، لاَ يَجْمَعُ اللَّهُ عَلَيْكَ مَوْتَتَيْنِ، أَمَّا الْمَوْتَةُ الَّتِي كُتِبَتْ عَلَيْكَ فَقَدْ مُتَّهَا‏.‏ قَالَ أَبُو سَلَمَةَ فَأَخْبَرَنِي ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ خَرَجَ وَعُمَرُ ـ رضى الله عنه ـ يُكَلِّمُ النَّاسَ‏.‏ فَقَالَ اجْلِسْ‏.‏ فَأَبَى‏.‏ فَقَالَ اجْلِسْ‏.‏ فَأَبَى، فَتَشَهَّدَ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَمَالَ إِلَيْهِ النَّاسُ، وَتَرَكُوا عُمَرَ فَقَالَ أَمَّا بَعْدُ، فَمَنْ كَانَ مِنْكُمْ يَعْبُدُ مُحَمَّدًا صلى الله عليه وسلم فَإِنَّ مُحَمَّدًا صلى الله عليه وسلم قَدْ مَاتَ، وَمَنْ كَانَ يَعْبُدُ اللَّهَ فَإِنَّ اللَّهَ حَىٌّ لاَ يَمُوتُ، قَالَ اللَّهُ تَعَالَى ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ‏\}‏ إِلَى ‏\{‏الشَّاكِرِينَ‏\}‏ وَاللَّهِ لَكَأَنَّ النَّاسَ لَمْ يَكُونُوا يَعْلَمُونَ أَنَّ اللَّهَ أَنْزَلَ الآيَةَ حَتَّى تَلاَهَا أَبُو بَكْرٍ ـ رضى الله عنه ـ فَتَلَقَّاهَا مِنْهُ النَّاسُ، فَمَا يُسْمَعُ بَشَرٌ إِلاَّ يَتْلُوهَا‏.‏\hadithno{1241}\hadithtrans{Narrated `Aisha:Abu Bakr came riding his horse from his dwelling place in As-Sunh. He got down from it, entered the Mosque and did not speak with anybody till he came to me and went directly to the Prophet, who was covered with a marked blanket. Abu Bakr uncovered his face. He knelt down and kissed him and then started weeping and said, "My father and my mother be sacrificed for you, O Allah's Prophet! Allah will not combine two deaths on you. You have died the death which was written for you." Narrated Abu Salama from Ibn `Abbas : Abu Bakr came out and `Umar , was addressing the people, and Abu Bakr told him to sit down but `Umar refused. Abu Bakr again told him to sit down but `Umar again refused. Then Abu Bakr recited the Tashah-hud (i.e. none has the right to be worshipped but Allah and Muhammad is Allah's Messenger (ﷺ)) and the people attended to Abu Bakr and left `Umar. Abu Bakr said, "Amma ba'du, whoever amongst you worshipped Muhammad, then Muhammad is dead, but whoever worshipped Allah, Allah is alive and will never die. Allah said: 'Muhammad is no more than an Apostle and indeed (many) Apostles have passed away before him ..(up to the) grateful.' " (3.144) (The narrator added, "By Allah, it was as if the people never knew that Allah had revealed this verse before till Abu Bakr recited it and then whoever heard it, started reciting it)}}
\hadithdefcmd{bukhari}{1249}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَصْبَهَانِيِّ، عَنْ ذَكْوَانَ، عَنْ أَبِي سَعِيدٍ، رضى الله عنه أَنَّ النِّسَاءَ، قُلْنَ لِلنَّبِيِّ صلى الله عليه وسلم اجْعَلْ لَنَا يَوْمًا‏.‏ فَوَعَظَهُنَّ، وَقَالَ ‏"‏ أَيُّمَا امْرَأَةٍ مَاتَ لَهَا ثَلاَثَةٌ مِنَ الْوَلَدِ كَانُوا حِجَابًا مِنَ النَّارِ ‏"‏‏.‏ قَالَتِ امْرَأَةٌ وَاثْنَانِ‏.‏ قَالَ ‏"‏ وَاثْنَانِ ‏"‏‏.‏ وَقَالَ شَرِيكٌ عَنِ ابْنِ الأَصْبَهَانِيِّ، حَدَّثَنِي أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ، وَأَبِي، هُرَيْرَةَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ أَبُو هُرَيْرَةَ ‏"‏ لَمْ يَبْلُغُوا الْحِنْثَ ‏"‏‏.‏\hadithno{1249}\hadithtrans{Narrated Abu Sa`id:The women requested the Prophet, "Please fix a day for us." So the Prophet (ﷺ) preached to them and said, "A woman whose three children died would be screened from the Hell Fire by them," Hearing that, a woman asked, "If two died?" The Prophet (ﷺ) replied, "Even two (would screen her from the (Hell) Fire. " And Abu Huraira added, "Those children should be below the age of puberty}}
\hadithdefcmd{bukhari}{1258}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ تُوُفِّيَتْ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم فَخَرَجَ، فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ بِمَاءٍ وَسِدْرٍ، وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ، فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏‏.‏ قَالَتْ فَلَمَّا فَرَغْنَا آذَنَّاهُ، فَأَلْقَى إِلَيْنَا حِقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏‏.‏ وَعَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ ـ رضى الله عنهما ـ بِنَحْوِهِ وَقَالَتْ إِنَّهُ قَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ ‏"‏‏.‏ قَالَتْ حَفْصَةُ قَالَتْ أُمُّ عَطِيَّةَ ـ رضى الله عنها ـ وَجَعَلْنَا رَأْسَهَا ثَلاَثَةَ قُرُونٍ‏.‏\hadithno{1258}\hadithtrans{Narrated Muhammad:Um 'Atiyya said, "One of the daughters of the Prophet (ﷺ) died and he came out and said, 'Wash her three or five times or more, if you think it necessary, with water and Sidr, and last of all put camphor (or some camphor) and when you finish, inform me.' " Um Atiyya added, "When we finished we informed him and he gave us his waist-sheet and said, 'Shroud her in it.' " And Um 'Atiyya (in another narration) added, "The Prophet (ﷺ) said, 'Wash her three, five or seven times or more, if you think it necessary.' " Hafsa said that Um 'Atiyya had also said, "We entwined her hair into three braids}}
\hadithdefcmd{bukhari}{1281}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَخْبَرَتْهُ قَالَتْ، دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا، فَدَعَتْ بِطِيبٍ فَمَسَّتْ ثُمَّ قَالَتْ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ، غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَقُولُ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏‏.‏\hadithno{1281}\hadithtrans{Narrated Zainab bint Abi Salama:I went to Um Habiba, the wife of Prophet, who said, "I heard the Prophets saying, 'It is not legal for a woman who believes in Allah and the Last Day to mourn for any dead person for more than three days except for her husband, (for whom she should mourn) for four months and ten days'." Later I went to Zainab bint Jahsh when her brother died; she asked for some scent, and after using it she said, "I am not in need of scent but I heard Allah's Messenger (ﷺ) saying, 'It is not legal for a woman who believes in Allah and the Last Day to mourn for more than three days for any dead person except her husband, (for whom she should mourn) for four months and ten days}}
\hadithdefcmd{bukhari}{1286}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ تُوُفِّيَتِ ابْنَةٌ لِعُثْمَانَ ـ رضى الله عنه ـ بِمَكَّةَ وَجِئْنَا لِنَشْهَدَهَا، وَحَضَرَهَا ابْنُ عُمَرَ وَابْنُ عَبَّاسٍ ـ رضى الله عنهم ـ وَإِنِّي لَجَالِسٌ بَيْنَهُمَا ـ أَوْ قَالَ جَلَسْتُ إِلَى أَحَدِهِمَا‏.‏ ثُمَّ جَاءَ الآخَرُ، فَجَلَسَ إِلَى جَنْبِي فَقَالَ عَبْدُ اللَّهِ بْنُ عَمَرَ ـ رضى الله عنهما ـ لِعَمْرِو بْنِ عُثْمَانَ أَلاَ تَنْهَى عَنِ الْبُكَاءِ، فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ فَقَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَدْ كَانَ عُمَرُ ـ رضى الله عنه ـ يَقُولُ بَعْضَ ذَلِكَ، ثُمَّ حَدَّثَ قَالَ صَدَرْتُ مَعَ عُمَرَ ـ رضى الله عنه ـ مِنْ مَكَّةَ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ، إِذَا هُوَ بِرَكْبٍ تَحْتَ ظِلِّ سَمُرَةٍ فَقَالَ اذْهَبْ، فَانْظُرْ مَنْ هَؤُلاَءِ الرَّكْبُ قَالَ فَنَظَرْتُ فَإِذَا صُهَيْبٌ، فَأَخْبَرْتُهُ فَقَالَ ادْعُهُ لِي‏.‏ فَرَجَعْتُ إِلَى صُهَيْبٍ فَقُلْتُ ارْتَحِلْ فَالْحَقْ أَمِيرَ الْمُؤْمِنِينَ‏.‏ فَلَمَّا أُصِيبَ عُمَرُ دَخَلَ صُهَيْبٌ يَبْكِي يَقُولُ وَاأَخَاهُ، وَاصَاحِبَاهُ‏.‏ فَقَالَ عُمَرُ ـ رضى الله عنه ـ يَا صُهَيْبُ أَتَبْكِي عَلَىَّ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ يُعَذَّبُ بِبَعْضِ بُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما فَلَمَّا مَاتَ عُمَرُ ـ رضى الله عنه ـ ذَكَرْتُ ذَلِكَ لِعَائِشَةَ ـ رضى الله عنها ـ فَقَالَتْ رَحِمَ اللَّهُ عُمَرَ، وَاللَّهِ مَا حَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّ اللَّهَ لَيُعَذِّبُ الْمُؤْمِنَ بِبُكَاءِ أَهْلِهِ عَلَيْهِ‏.‏ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ لَيَزِيدُ الْكَافِرَ عَذَابًا بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ وَقَالَتْ حَسْبُكُمُ الْقُرْآنُ ‏\{‏وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى‏\}‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ عِنْدَ ذَلِكَ وَاللَّهُ هُوَ أَضْحَكَ وَأَبْكَى‏.‏ قَالَ ابْنُ أَبِي مُلَيْكَةَ وَاللَّهِ مَا قَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ شَيْئًا‏.‏\hadithno{1286}\hadithtrans{Narrated `Abdullah bin 'Ubaidullah bin Abi Mulaika:One of the daughters of `Uthman died at Mecca. We went to attend her funeral procession. Ibn `Umar and Ibn `Abbas were also present. I sat in between them (or said, I sat beside one of them. Then a man came and sat beside me.) `Abdullah bin `Umar said to `Amr bin `Uthman, "Will you not prohibit crying as Allah's Messenger (ﷺ) has said, 'The dead person is tortured by the crying of his relatives.?" Ibn `Abbas said, "`Umar used to say so." Then he added narrating, "I accompanied `Umar on a journey from Mecca till we reached Al-Baida. There he saw some travelers in the shade of a Samura (A kind of forest tree). He said (to me), "Go and see who those travelers are." So I went and saw that one of them was Suhaib. I told this to `Umar who then asked me to call him. So I went back to Suhaib and said to him, "Depart and follow the chief of the faithful believers." Later, when `Umar was stabbed, Suhaib came in weeping and saying, "O my brother, O my friend!" (on this `Umar said to him, "O Suhaib! Are you weeping for me while the Prophet (ﷺ) said, "The dead person is punished by some of the weeping of his relatives?" Ibn `Abbas added, "When `Umar died I told all this to Aisha and she said, 'May Allah be merciful to `Umar. By Allah, Allah's Messenger (ﷺ) did not say that a believer is punished by the weeping of his relatives. But he said, Allah increases the punishment of a non-believer because of the weeping of his relatives." Aisha further added, "The Qur'an is sufficient for you (to clear up this point) as Allah has stated: 'No burdened soul will bear another's burden.' " (35.18). Ibn `Abbas then said, "Only Allah makes one laugh or cry." Ibn `Umar did not say anything after that}}
\hadithdefcmd{bukhari}{1287}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ تُوُفِّيَتِ ابْنَةٌ لِعُثْمَانَ ـ رضى الله عنه ـ بِمَكَّةَ وَجِئْنَا لِنَشْهَدَهَا، وَحَضَرَهَا ابْنُ عُمَرَ وَابْنُ عَبَّاسٍ ـ رضى الله عنهم ـ وَإِنِّي لَجَالِسٌ بَيْنَهُمَا ـ أَوْ قَالَ جَلَسْتُ إِلَى أَحَدِهِمَا‏.‏ ثُمَّ جَاءَ الآخَرُ، فَجَلَسَ إِلَى جَنْبِي فَقَالَ عَبْدُ اللَّهِ بْنُ عَمَرَ ـ رضى الله عنهما ـ لِعَمْرِو بْنِ عُثْمَانَ أَلاَ تَنْهَى عَنِ الْبُكَاءِ، فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ فَقَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَدْ كَانَ عُمَرُ ـ رضى الله عنه ـ يَقُولُ بَعْضَ ذَلِكَ، ثُمَّ حَدَّثَ قَالَ صَدَرْتُ مَعَ عُمَرَ ـ رضى الله عنه ـ مِنْ مَكَّةَ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ، إِذَا هُوَ بِرَكْبٍ تَحْتَ ظِلِّ سَمُرَةٍ فَقَالَ اذْهَبْ، فَانْظُرْ مَنْ هَؤُلاَءِ الرَّكْبُ قَالَ فَنَظَرْتُ فَإِذَا صُهَيْبٌ، فَأَخْبَرْتُهُ فَقَالَ ادْعُهُ لِي‏.‏ فَرَجَعْتُ إِلَى صُهَيْبٍ فَقُلْتُ ارْتَحِلْ فَالْحَقْ أَمِيرَ الْمُؤْمِنِينَ‏.‏ فَلَمَّا أُصِيبَ عُمَرُ دَخَلَ صُهَيْبٌ يَبْكِي يَقُولُ وَاأَخَاهُ، وَاصَاحِبَاهُ‏.‏ فَقَالَ عُمَرُ ـ رضى الله عنه ـ يَا صُهَيْبُ أَتَبْكِي عَلَىَّ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ يُعَذَّبُ بِبَعْضِ بُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما فَلَمَّا مَاتَ عُمَرُ ـ رضى الله عنه ـ ذَكَرْتُ ذَلِكَ لِعَائِشَةَ ـ رضى الله عنها ـ فَقَالَتْ رَحِمَ اللَّهُ عُمَرَ، وَاللَّهِ مَا حَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّ اللَّهَ لَيُعَذِّبُ الْمُؤْمِنَ بِبُكَاءِ أَهْلِهِ عَلَيْهِ‏.‏ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ لَيَزِيدُ الْكَافِرَ عَذَابًا بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏‏.‏ وَقَالَتْ حَسْبُكُمُ الْقُرْآنُ ‏\{‏وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى‏\}‏‏.‏ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ عِنْدَ ذَلِكَ وَاللَّهُ هُوَ أَضْحَكَ وَأَبْكَى‏.‏ قَالَ ابْنُ أَبِي مُلَيْكَةَ وَاللَّهِ مَا قَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ شَيْئًا‏.‏\hadithno{1287}\hadithtrans{Narrated `Abdullah bin 'Ubaidullah bin Abi Mulaika:One of the daughters of `Uthman died at Mecca. We went to attend her funeral procession. Ibn `Umar and Ibn `Abbas were also present. I sat in between them (or said, I sat beside one of them. Then a man came and sat beside me.) `Abdullah bin `Umar said to `Amr bin `Uthman, "Will you not prohibit crying as Allah's Messenger (ﷺ) has said, 'The dead person is tortured by the crying of his relatives.?" Ibn `Abbas said, "`Umar used to say so." Then he added narrating, "I accompanied `Umar on a journey from Mecca till we reached Al-Baida. There he saw some travelers in the shade of a Samura (A kind of forest tree). He said (to me), "Go and see who those travelers are." So I went and saw that one of them was Suhaib. I told this to `Umar who then asked me to call him. So I went back to Suhaib and said to him, "Depart and follow the chief of the faithful believers." Later, when `Umar was stabbed, Suhaib came in weeping and saying, "O my brother, O my friend!" (on this `Umar said to him, "O Suhaib! Are you weeping for me while the Prophet (ﷺ) said, "The dead person is punished by some of the weeping of his relatives?" Ibn `Abbas added, "When `Umar died I told all this to Aisha and she said, 'May Allah be merciful to `Umar. By Allah, Allah's Messenger (ﷺ) did not say that a believer is punished by the weeping of his relatives. But he said, Allah increases the punishment of a non-believer because of the weeping of his relatives." Aisha further added, "The Qur'an is sufficient for you (to clear up this point) as Allah has stated: 'No burdened soul will bear another's burden.' " (35.18). Ibn `Abbas then said, "Only Allah makes one laugh or cry." Ibn `Umar did not say anything after that}}
\hadithdefcmd{bukhari}{1312}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، قَالَ كَانَ سَهْلُ بْنُ حُنَيْفٍ وَقَيْسُ بْنُ سَعْدٍ قَاعِدَيْنِ بِالْقَادِسِيَّةِ، فَمَرُّوا عَلَيْهِمَا بِجَنَازَةٍ فَقَامَا‏.‏ فَقِيلَ لَهُمَا إِنَّهَا مِنْ أَهْلِ الأَرْضِ، أَىْ مِنْ أَهْلِ الذِّمَّةِ فَقَالاَ إِنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّتْ بِهِ جَنَازَةٌ فَقَامَ فَقِيلَ لَهُ إِنَّهَا جَنَازَةُ يَهُودِيٍّ‏.‏ فَقَالَ ‏ "‏ أَلَيْسَتْ نَفْسًا ‏"‏‏.‏ وَقَالَ أَبُو حَمْزَةَ عَنِ الأَعْمَشِ، عَنْ عَمْرٍو، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ كُنْتُ مَعَ قَيْسٍ وَسَهْلٍ ـ رضى الله عنهما ـ فَقَالاَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ زَكَرِيَّاءُ عَنِ الشَّعْبِيِّ عَنِ ابْنِ أَبِي لَيْلَى كَانَ أَبُو مَسْعُودٍ وَقَيْسٌ يَقُومَانِ لِلْجِنَازَةِ‏.‏\hadithno{1312}\hadithtrans{Narrated `Abdur Rahman bin Abi Laila:Sahl bin Hunaif and Qais bin Sa`d were sitting in the city of Al-Qadisiya. A funeral procession passed in front of them and they stood up. They were told that funeral procession was of one of the inhabitants of the land i.e. of a non-believer, under the protection of Muslims. They said, "A funeral procession passed in front of the Prophet (ﷺ) and he stood up. When he was told that it was the coffin of a Jew, he said, "Is it not a living being (soul)?}}
\hadithdefcmd{bukhari}{1323}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ سَمِعْتُ نَافِعًا، يَقُولُ حُدِّثَ ابْنُ عُمَرَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنهم ـ يَقُولُ مَنْ تَبِعَ جَنَازَةً فَلَهُ قِيرَاطٌ‏.‏ فَقَالَ أَكْثَرَ أَبُو هُرَيْرَةَ عَلَيْنَا‏.‏ فَصَدَّقَتْ ـ يَعْنِي عَائِشَةَ ـ أَبَا هُرَيْرَةَ وَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُهُ‏.‏ فَقَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ لَقَدْ فَرَّطْنَا فِي قَرَارِيطَ كَثِيرَةٍ‏.‏ ‏\{‏فَرَّطْتُ‏\}‏ ضَيَّعْتُ مِنْ أَمْرِ اللَّهِ‏.‏\hadithno{1323}\hadithtrans{Narrated Nafi`:Ibn `Umar was told that Abu Huraira said, "Whoever accompanies the funeral procession will have a reward equal to one Qirat." Ibn `Umar said, "Abu Huraira talks of a too enormous reward." Aisha attested Abu Huraira's narration and said, "I heard Allah's Messenger (ﷺ) saying like that." Ibn `Umar said, "We have lost numerous Qirats}}
\hadithdefcmd{bukhari}{1327}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ أَنَّهُمَا حَدَّثَاهُ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَعَى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم النَّجَاشِيَّ صَاحِبَ الْحَبَشَةِ، يَوْمَ الَّذِي مَاتَ فِيهِ فَقَالَ ‏ "‏ اسْتَغْفِرُوا لأَخِيكُمْ ‏"‏‏.‏ وَعَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم صَفَّ بِهِمْ بِالْمُصَلَّى فَكَبَّرَ عَلَيْهِ أَرْبَعًا‏.‏\hadithno{1327}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) informed about the news of the death of An-Najash (King of Ethiopia) on the day he expired. He said, "Ask Allah's forgiveness for your brother. " Narrated Abu Huraira: The Prophet (ﷺ) made them align in rows at the Musalla and said four Takbir}}
\hadithdefcmd{bukhari}{1347}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا لَيْثُ بْنُ سَعْدٍ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ فِي ثَوْبٍ وَاحِدٍ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمْ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدِهِمَا قَدَّمَهُ فِي اللَّحْدِ وَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ ‏"‏‏.‏ وَأَمَرَ بِدَفْنِهِمْ بِدِمَائِهِمْ، وَلَمْ يُصَلِّ عَلَيْهِمْ وَلَمْ يُغَسِّلْهُمْ‏.‏ وَأَخْبَرَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ لِقَتْلَى أُحُدٍ ‏"‏ أَىُّ هَؤُلاَءِ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى رَجُلٍ قَدَّمَهُ فِي اللَّحْدِ قَبْلَ صَاحِبِهِ‏.‏ وَقَالَ جَابِرٌ فَكُفِّنَ أَبِي وَعَمِّي فِي نَمِرَةٍ وَاحِدَةٍ‏.‏ وَقَالَ سُلَيْمَانُ بْنُ كَثِيرٍ حَدَّثَنِي الزُّهْرِيُّ، حَدَّثَنَا مَنْ، سَمِعَ جَابِرًا ـ رضى الله عنه‏.‏\hadithno{1347}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) shrouded every two martyrs of Uhud in one piece of cloth and then he would ask, "Which of them knew more Qur'an?" When one of them was pointed out he would put him first in the grave. He said, "I am a witness on these." Then he ordered them to be buried with blood on their bodies. Neither did he offer their funeral prayer nor did he get them washed. (Jabir bin `Abdullah added): Allah's Messenger (ﷺ) used to ask about the martyrs of Uhud as to which of them knew more of the Qur'an." And when one of them was pointed out as having more of it he would put him first in the grave and then his companions. (Jabir added): My father and my uncle were shrouded in one sheet}}
\hadithdefcmd{bukhari}{1354}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ عُمَرَ انْطَلَقَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي رَهْطٍ قِبَلَ ابْنِ صَيَّادٍ، حَتَّى وَجَدُوهُ يَلْعَبُ مَعَ الصِّبْيَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ، وَقَدْ قَارَبَ ابْنُ صَيَّادٍ الْحُلُمَ فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ ثُمَّ قَالَ لاِبْنِ صَيَّادٍ ‏"‏ تَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏‏.‏ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ‏.‏ فَقَالَ ابْنُ صَيَّادٍ لِلنَّبِيِّ صلى الله عليه وسلم أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَرَفَضَهُ وَقَالَ آمَنْتُ بِاللَّهِ وَبِرُسُلِهِ‏.‏ فَقَالَ لَهُ ‏"‏ مَاذَا تَرَى ‏"‏‏.‏ قَالَ ابْنُ صَيَّادٍ يَأْتِينِي صَادِقٌ وَكَاذِبٌ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏ ثُمَّ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ خَبَأْتُ لَكَ خَبِيئًا ‏"‏‏.‏ فَقَالَ ابْنُ صَيَّادٍ هُوَ الدُّخُّ‏.‏ فَقَالَ ‏"‏ اخْسَأْ، فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏‏.‏ فَقَالَ عُمَرُ ـ رضى الله عنه ـ دَعْنِي يَا رَسُولَ اللَّهِ أَضْرِبْ عُنُقَهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْهُ فَلَنْ تُسَلَّطَ عَلَيْهِ، وَإِنْ لَمْ يَكُنْهُ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏‏.‏ وَقَالَ سَالِمٌ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ انْطَلَقَ بَعْدَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ إِلَى النَّخْلِ الَّتِي فِيهَا ابْنُ صَيَّادٍ وَهُوَ يَخْتِلُ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ ابْنُ صَيَّادٍ فَرَآهُ النَّبِيُّ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ، يَعْنِي فِي قَطِيفَةٍ لَهُ فِيهَا رَمْزَةٌ أَوْ زَمْرَةٌ، فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَتَّقِي بِجُذُوعِ النَّخْلِ فَقَالَتْ لاِبْنِ صَيَّادٍ يَا صَافِ ـ وَهْوَ اسْمُ ابْنِ صَيَّادٍ ـ هَذَا مُحَمَّدٌ صلى الله عليه وسلم‏.‏ فَثَارَ ابْنُ صَيَّادٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏‏.‏ وَقَالَ شُعَيْبٌ فِي حَدِيثِهِ فَرَفَصَهُ رَمْرَمَةٌ، أَوْ زَمْزَمَةٌ‏.‏ وَقَالَ إِسْحَاقُ الْكَلْبِيُّ وَعُقَيْلٌ رَمْرَمَةٌ‏.‏ وَقَالَ مَعْمَرٌ رَمْزَةٌ‏.‏\hadithno{1354}\hadithtrans{Narrated Ibn `Umar:`Umar set out along with the Prophet (ﷺ) with a group of people to Ibn Saiyad till they saw him playing with the boys near the hillocks of Bani Mughala. Ibn Saiyad at that time was nearing his puberty and did not notice (us) until the Prophet (ﷺ) stroked him with his hand and said to him, "Do you testify that I am Allah's Messenger (ﷺ)?" Ibn Saiyad looked at him and said, "I testify that you are the Messenger of illiterates." Then Ibn Saiyad asked the Prophet (ﷺ), "Do you testify that I am Allah's Messenger (ﷺ)?" The Prophet (ﷺ) refuted it and said, "I believe in Allah and His Apostles." Then he said (to Ibn Saiyad), "What do you think?" Ibn Saiyad answered, "True people and liars visit me." The Prophet (ﷺ) said, "You have been confused as to this matter." Then the Prophet (ﷺ) said to him, "I have kept something (in my mind) for you, (can you tell me that?)" Ibn Saiyad said, "It is Al-Dukh (the smoke)." (2) The Prophet (ﷺ) said, "Let you be in ignominy. You cannot cross your limits." On that `Umar, said, "O Allah's Messenger (ﷺ)! Allow me to chop his head off." The Prophet (ﷺ) said, "If he is he (i.e. Dajjal), then you cannot overpower him, and if he is not, then there is no use of murdering him." (Ibn `Umar added): Later on Allah's Messenger (ﷺ) once again went along with Ubai bin Ka`b to the date-palm trees (garden) where Ibn Saiyad was staying. The Prophet (ﷺ) wanted to hear something from Ibn Saiyad before Ibn Saiyad could see him, and the Prophet (ﷺ) saw him lying covered with a sheet and from where his murmurs were heard. Ibn Saiyad's mother saw Allah's Apostle while he was hiding himself behind the trunks of the date-palm trees. She addressed Ibn Saiyad, "O Saf ! (and this was the name of Ibn Saiyad) Here is Muhammad." And with that Ibn Saiyad got up. The Prophet (ﷺ) said, "Had this woman left him (Had she not disturbed him), then Ibn Saiyad would have revealed the reality of his case}}
\hadithdefcmd{bukhari}{1363}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ بِمِلَّةٍ غَيْرِ الإِسْلاَمِ كَاذِبًا مُتَعَمِّدًا فَهُوَ كَمَا قَالَ، وَمَنْ قَتَلَ نَفْسَهُ بِحَدِيدَةٍ عُذِّبَ بِهِ فِي نَارِ جَهَنَّمَ ‏"‏‏.‏ وَقَالَ حَجَّاجُ بْنُ مِنْهَالٍ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الْحَسَنِ، حَدَّثَنَا جُنْدَبٌ ـ رضى الله عنه ـ فِي هَذَا الْمَسْجِدِ فَمَا نَسِينَا، وَمَا نَخَافُ أَنْ يَكْذِبَ جُنْدَبٌ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ كَانَ بِرَجُلٍ جِرَاحٌ فَقَتَلَ نَفْسَهُ فَقَالَ اللَّهُ بَدَرَنِي عَبْدِي بِنَفْسِهِ حَرَّمْتُ عَلَيْهِ الْجَنَّةَ ‏"‏‏.‏\hadithno{1363}\hadithtrans{Narrated Thabit bin Ad-Dahhak:The Prophet (ﷺ) said, "Whoever intentionally swears falsely by a religion other than Islam, then he is what he has said, (e.g. if he says, 'If such thing is not true then I am a Jew,' he is really a Jew). And whoever commits suicide with piece of iron will be punished with the same piece of iron in the Hell Fire." Narrated Jundab the Prophet (ﷺ) said, "A man was inflicted with wounds and he committed suicide, and so Allah said: My slave has caused death on himself hurriedly, so I forbid Paradise for him}}
\hadithdefcmd{bukhari}{1399}{حَدَّثَنَا أَبُو الْيَمَانِ الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ أَبُو بَكْرٍ ـ رضى الله عنه ـ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ فَقَالَ عُمَرُ ـ رضى الله عنه كَيْفَ تُقَاتِلُ النَّاسَ، وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَمَنْ قَالَهَا فَقَدْ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ، وَحِسَابُهُ عَلَى اللَّهِ ‏"‏‏.‏ فَقَالَ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ، فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ، وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا‏.‏ قَالَ عُمَرُ ـ رضى الله عنه ـ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ قَدْ شَرَحَ اللَّهُ صَدْرَ أَبِي بَكْرٍ ـ رضى الله عنه ـ فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏\hadithno{1399}\hadithtrans{Narrated Abu Huraira:When Allah's Messenger (ﷺ) died and Abu Bakr became the caliph some Arabs renegade (reverted to disbelief) (Abu Bakr decided to declare war against them), `Umar, said to Abu Bakr, "How can you fight with these people although Allah's Messenger (ﷺ) said, 'I have been ordered (by Allah) to fight the people till they say: "None has the right to be worshipped but Allah, and whoever said it then he will save his life and property from me except on trespassing the law (rights and conditions for which he will be punished justly), and his accounts will be with Allah.' " Abu Bakr said, "By Allah! I will fight those who differentiate between the prayer and the Zakat as Zakat is the compulsory right to be taken from the property (according to Allah's orders) By Allah! If they refuse to pay me even a she-kid which they used to pay at the time of Allah's Messenger (ﷺ) . I would fight with them for withholding it" Then `Umar said, "By Allah, it was nothing, but Allah opened Abu Bakr's chest towards the decision (to fight) and I came to know that his decision was right}}
\hadithdefcmd{bukhari}{1407}{حَدَّثَنَا عَيَّاشٌ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي الْعَلاَءِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ جَلَسْتُ‏.‏ وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنِي أَبِي، حَدَّثَنَا الْجُرَيْرِيُّ، حَدَّثَنَا أَبُو الْعَلاَءِ بْنُ الشِّخِّيرِ، أَنَّ الأَحْنَفَ بْنَ قَيْسٍ، حَدَّثَهُمْ قَالَ جَلَسْتُ إِلَى مَلإٍ مِنْ قُرَيْشٍ، فَجَاءَ رَجُلٌ خَشِنُ الشَّعَرِ وَالثِّيَابِ وَالْهَيْئَةِ حَتَّى قَامَ عَلَيْهِمْ فَسَلَّمَ ثُمَّ قَالَ بَشِّرِ الْكَانِزِينَ بِرَضْفٍ يُحْمَى عَلَيْهِ فِي نَارِ جَهَنَّمَ، ثُمَّ يُوضَعُ عَلَى حَلَمَةِ ثَدْىِ أَحَدِهِمْ حَتَّى يَخْرُجَ مِنْ نُغْضِ كَتِفِهِ، وَيُوضَعُ عَلَى نُغْضِ كَتِفِهِ حَتَّى يَخْرُجَ مِنْ حَلَمَةِ ثَدْيِهِ يَتَزَلْزَلُ، ثُمَّ وَلَّى فَجَلَسَ إِلَى سَارِيَةٍ، وَتَبِعْتُهُ وَجَلَسْتُ إِلَيْهِ، وَأَنَا لاَ أَدْرِي مَنْ هُوَ فَقُلْتُ لَهُ لاَ أُرَى الْقَوْمَ إِلاَّ قَدْ كَرِهُوا الَّذِي قُلْتَ‏.‏ قَالَ إِنَّهُمْ لاَ يَعْقِلُونَ شَيْئًا‏.‏ قَالَ لِي خَلِيلِي ـ قَالَ قُلْتُ مَنْ خَلِيلُكَ قَالَ النَّبِيُّ صلى الله عليه وسلم ـ ‏"‏ يَا أَبَا ذَرٍّ أَتُبْصِرُ أُحُدًا ‏"‏‏.‏ قَالَ فَنَظَرْتُ إِلَى الشَّمْسِ مَا بَقِيَ مِنَ النَّهَارِ وَأَنَا أُرَى أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يُرْسِلُنِي فِي حَاجَةٍ لَهُ، قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ مَا أُحِبُّ أَنَّ لِي مِثْلَ أُحُدٍ ذَهَبًا أُنْفِقُهُ كُلَّهُ إِلاَّ ثَلاَثَةَ دَنَانِيرَ ‏"‏‏.‏ وَإِنَّ هَؤُلاَءِ لاَ يَعْقِلُونَ، إِنَّمَا يَجْمَعُونَ الدُّنْيَا‏.‏ لاَ وَاللَّهِ لاَ أَسْأَلُهُمْ دُنْيَا، وَلاَ أَسْتَفْتِيهِمْ عَنْ دِينٍ حَتَّى أَلْقَى اللَّهَ‏.‏\hadithno{1407}\hadithtrans{Narrated Al-Ahnaf bin Qais:While I was sitting with some people from Quraish, a man with very rough hair, clothes, and appearance came and stood in front of us, greeted us and said, "Inform those who hoard wealth, that a stone will be heated in the Hell-fire and will be put on the nipples of their breasts till it comes out from the bones of their shoulders and then put on the bones of their shoulders till it comes through the nipples of their breasts the stone will be moving and hitting." After saying that, the person retreated and sat by the side of the pillar, I followed him and sat beside him, and I did not know who he was. I said to him, "I think the people disliked what you had said." He said, "These people do not understand anything, although my friend told me." I asked, "Who is your friend?" He said, "The Prophet (ﷺ) said (to me), 'O Abu Dhar! Do you see the mountain of Uhud?' And on that I (Abu Dhar) started looking towards the sun to judge how much remained of the day as I thought that Allah's Messenger (ﷺ) wanted to send me to do something for him and I said, 'Yes!' He said, 'I do not love to have gold equal to the mountain of Uhud unless I spend it all (in Allah's cause) except three Dinars (pounds). These people do not understand and collect worldly wealth. No, by Allah, Neither I ask them for worldly benefits nor am I in need of their religious advice till I meet Allah, The Honorable, The Majestic}}
\hadithdefcmd{bukhari}{1427}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ حَكِيمِ بْنِ حِزَامٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى، وَابْدَأْ بِمَنْ تَعُولُ، وَخَيْرُ الصَّدَقَةِ عَنْ ظَهْرِ غِنًى، وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ، وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ ‏"‏‏.‏ وَعَنْ وُهَيْبٍ، قَالَ أَخْبَرَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ بِهَذَا‏.‏\hadithno{1427}\hadithtrans{Narrated Hakim bin Hizam:The Prophet (ﷺ) said, "The upper hand is better than the lower hand (i.e. he who gives in charity is better than him who takes it). One should start giving first to his dependents. And the best object of charity is that which is given by a wealthy person (from the money which is left after his expenses). And whoever abstains from asking others for some financial help, Allah will give him and save him from asking others, Allah will make him self-sufficient}}
\hadithdefcmd{bukhari}{1456}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح وَقَالَ اللَّيْثُ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ أَبُو بَكْرٍ ـ رضى الله عنه ـ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا‏.‏ قَالَ عُمَرُ ـ رضى الله عنه ـ فَمَا هُوَ إِلاَّ أَنْ رَأَيْتُ أَنَّ اللَّهَ شَرَحَ صَدْرَ أَبِي بَكْرٍ ـ رضى الله عنه ـ بِالْقِتَالِ، فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏\hadithno{1456}\hadithtrans{Narrated Abu Huraira:Abu Bakr said, "By Allah! If they (pay me the Zakat and) withhold even a young (female) goat which they used to pay during the lifetime of Allah's Messenger (ﷺ), I will fight with them for it." `Umar said, "It was nothing but Allah Who opened Abu Bakr's chest towards the decision to fight, and I came to know that his decision was right}}
\hadithdefcmd{bukhari}{1474}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، قَالَ سَمِعْتُ حَمْزَةَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا يَزَالُ الرَّجُلُ يَسْأَلُ النَّاسَ حَتَّى يَأْتِيَ يَوْمَ الْقِيَامَةِ لَيْسَ فِي وَجْهِهِ مُزْعَةُ لَحْمٍ ‏"‏‏.‏ وَقَالَ إِنَّ الشَّمْسَ تَدْنُو يَوْمَ الْقِيَامَةِ حَتَّى يَبْلُغَ الْعَرَقُ نِصْفَ الأُذُنِ، فَبَيْنَا هُمْ كَذَلِكَ اسْتَغَاثُوا بِآدَمَ، ثُمَّ بِمُوسَى، ثُمَّ بِمُحَمَّدٍ صلى الله عليه وسلم ‏"‏‏.‏ وَزَادَ عَبْدُ اللَّهِ حَدَّثَنِي اللَّيْثُ حَدَّثَنِي ابْنُ أَبِي جَعْفَرٍ ‏"‏ فَيَشْفَعُ لِيُقْضَى بَيْنَ الْخَلْقِ، فَيَمْشِي حَتَّى يَأْخُذَ بِحَلْقَةِ الْبَابِ، فَيَوْمَئِذٍ يَبْعَثُهُ اللَّهُ مَقَامًا مَحْمُودًا، يَحْمَدُهُ أَهْلُ الْجَمْعِ كُلُّهُمْ ‏"‏‏.‏ وَقَالَ مُعَلًّى حَدَّثَنَا وُهَيْبٌ، عَنِ النُّعْمَانِ بْنِ رَاشِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ، أَخِي الزُّهْرِيِّ عَنْ حَمْزَةَ، سَمِعَ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْمَسْأَلَةِ‏.‏\hadithno{1474}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "A man keeps on asking others for something till he comes on the Day of Resurrection without any piece of flesh on his face." The Prophet (ﷺ) added, "On the Day of Resurrection, the Sun will come near (to, the people) to such an extent that the sweat will reach up to the middle of the ears, so, when all the people are in that state, they will ask Adam for help, and then Moses, and then Muhammad (ﷺ) ." The sub-narrator added "Muhammad will intercede with Allah to judge amongst the people. He will proceed on till he will hold the ring of the door (of Paradise) and then Allah will exalt him to Maqam Mahmud (the privilege of intercession, etc.). And all the people of the gathering will send their praises to Allah}}
\hadithdefcmd{bukhari}{1481}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ عَبَّاسٍ السَّاعِدِيِّ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ غَزَوْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم غَزْوَةَ تَبُوكَ فَلَمَّا جَاءَ وَادِيَ الْقُرَى إِذَا امْرَأَةٌ فِي حَدِيقَةٍ لَهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ اخْرُصُوا ‏"‏‏.‏ وَخَرَصَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشَرَةَ أَوْسُقٍ فَقَالَ لَهَا ‏"‏ أَحْصِي مَا يَخْرُجُ مِنْهَا ‏"‏‏.‏ فَلَمَّا أَتَيْنَا تَبُوكَ قَالَ ‏"‏ أَمَا إِنَّهَا سَتَهُبُّ اللَّيْلَةَ رِيحٌ شَدِيدَةٌ فَلاَ يَقُومَنَّ أَحَدٌ، وَمَنْ كَانَ مَعَهُ بَعِيرٌ فَلْيَعْقِلْهُ ‏"‏‏.‏ فَعَقَلْنَاهَا وَهَبَّتْ رِيحٌ شَدِيدَةٌ فَقَامَ رَجُلٌ فَأَلْقَتْهُ بِجَبَلِ طَيِّئٍ ـ وَأَهْدَى مَلِكُ أَيْلَةَ لِلنَّبِيِّ صلى الله عليه وسلم بَغْلَةً بَيْضَاءَ، وَكَسَاهُ بُرْدًا وَكَتَبَ لَهُ بِبَحْرِهِمْ ـ فَلَمَّا أَتَى وَادِيَ الْقُرَى قَالَ لِلْمَرْأَةِ ‏"‏ كَمْ جَاءَ حَدِيقَتُكِ ‏"‏‏.‏ قَالَتْ عَشَرَةَ أَوْسُقٍ خَرْصَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي مُتَعَجِّلٌ إِلَى الْمَدِينَةِ، فَمَنْ أَرَادَ مِنْكُمْ أَنْ يَتَعَجَّلَ مَعِي فَلْيَتَعَجَّلْ ‏"‏‏.‏ فَلَمَّا ـ قَالَ ابْنُ بَكَّارٍ كَلِمَةً مَعْنَاهَا ـ أَشْرَفَ عَلَى الْمَدِينَةِ قَالَ ‏"‏ هَذِهِ طَابَةُ ‏"‏‏.‏ فَلَمَّا رَأَى أُحُدًا قَالَ ‏"‏ هَذَا جُبَيْلٌ يُحِبُّنَا وَنُحِبُّهُ، أَلاَ أُخْبِرُكُمْ بِخَيْرِ دُورِ الأَنْصَارِ ‏"‏‏.‏ قَالُوا بَلَى‏.‏ قَالَ ‏"‏ دُورُ بَنِي النَّجَّارِ، ثُمَّ دُورُ بَنِي عَبْدِ الأَشْهَلِ، ثُمَّ دُورُ بَنِي سَاعِدَةَ، أَوْ دُورُ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ، وَفِي كُلِّ دُورِ الأَنْصَارِ ـ يَعْنِي ـ خَيْرًا ‏"‏‏.‏ وَقَالَ سُلَيْمَانُ بْنُ بِلاَلٍ حَدَّثَنِي عَمْرٌو، ‏"‏ ثُمَّ دَارُ بَنِي الْحَارِثِ، ثُمَّ بَنِي سَاعِدَةَ ‏"‏‏.‏ وَقَالَ سُلَيْمَانُ عَنْ سَعْدِ بْنِ سَعِيدٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَبَّاسٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أُحُدٌ جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ كُلُّ بُسْتَانٍ عَلَيْهِ حَائِطٌ فَهْوَ حَدِيقَةٌ، وَمَا لَمْ يَكُنْ عَلَيْهِ حَائِطٌ لَمْ يَقُلْ حَدِيقَةٌ‏.‏\hadithno{1481}\hadithtrans{Narrated Abu Humaid As-Sa`idi:We took part in the holy battle of Tabuk in the company of the Prophet (ﷺ) and when we arrived at the Wadi-al-Qura, there was a woman in her garden. The Prophet (ﷺ) asked his companions to estimate the amount of the fruits in the garden, and Allah's Messenger (ﷺ) estimated it at ten Awsuq (One Wasaq = 60 Sa's) and 1 Sa'= 3 kg. approximately). The Prophet (ﷺ) said to that lady, "Check what your garden will yield." When we reached Tabuk, the Prophet (ﷺ) said, "There will be a strong wind tonight and so no one should stand and whoever has a camel, should fasten it." So we fastened our camels. A strong wind blew at night and a man stood up and he was blown away to a mountain called Taiy, The King of Aila sent a white mule and a sheet for wearing to the Prophet (ﷺ) as a present, and wrote to the Prophet (ﷺ) that his people would stay in their place (and will pay Jizya taxation.) (1) When the Prophet (ﷺ) reached Wadi-al- Qura he asked that woman how much her garden had yielded. She said, "Ten Awsuq," and that was what Allah's Messenger (ﷺ) had estimated. Then the Prophet (ﷺ) said, "I want to reach Medina quickly, and whoever among you wants to accompany me, should hurry up." The sub-narrator Ibn Bakkar said something which meant: When the Prophet (ﷺ) saw Medina he said, "This is Taba." And when he saw the mountain of Uhud, he said, "This mountain loves us and we love it. Shall I tell you of the best amongst the Ansar?" They replied in the affirmative. He said, "The family of Bani-n-Najjar, and then the family of Bani Sa`ida or Bani Al-Harith bin Al-Khazraj. (The above-mentioned are the best) but there is goodness in all the families of Ansar}}
\hadithdefcmd{bukhari}{1537}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَدَّهِنُ بِالزَّيْتِ‏.‏ فَذَكَرْتُهُ لإِبْرَاهِيمَ قَالَ مَا تَصْنَعُ بِقَوْلِهِ حَدَّثَنِي الأَسْوَدُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفَارِقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ‏.‏\hadithno{1537}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Umar used to oil his hair. I told that to Ibrahim who said, "What do you think about this statement: Narrated Aswad from `Aisha: As if I were now observing the glitter of the scent in the parting of the hair of the Prophet (ﷺ) while he was Muhrim?}}
\hadithdefcmd{bukhari}{1543}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ يُونُسَ الأَيْلِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ أُسَامَةَ ـ رضى الله عنه ـ كَانَ رِدْفَ النَّبِيِّ صلى الله عليه وسلم مِنْ عَرَفَةَ إِلَى الْمُزْدَلِفَةِ، ثُمَّ أَرْدَفَ الْفَضْلَ مِنَ الْمُزْدَلِفَةِ إِلَى مِنًى‏.‏ قَالَ فَكِلاَهُمَا قَالَ لَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم يُلَبِّي، حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ‏.‏\hadithno{1543}\hadithtrans{Narrated 'Ubaidullah bin `Abdullah:Ibn `Abbas' said, "Usama rode behind Allah's Messenger (ﷺ) from `Arafat to Al-Muzdalifa; and then Al-Fadl rode behind Allah's Messenger (ﷺ) from Al-Muzdalifa to Mina." Ibn `Abbas added, "Both of them said, 'The Prophet kept on reciting Talbiya till he did the Rami of Jamrat-Al-`Aqaba}}
\hadithdefcmd{bukhari}{1614}{حَدَّثَنَا أَصْبَغُ، عَنِ ابْنِ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ،، ذَكَرْتُ لِعُرْوَةَ، قَالَ فَأَخْبَرَتْنِي عَائِشَةُ ـ رضى الله عنها ـ أَنَّ أَوَّلَ، شَىْءٍ بَدَأَ بِهِ حِينَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم أَنَّهُ تَوَضَّأَ، ثُمَّ طَافَ، ثُمَّ لَمْ تَكُنْ عُمْرَةً، ثُمَّ حَجَّ أَبُو بَكْرٍ وَعُمَرُ ـ رضى الله عنهما ـ مِثْلَهُ، ثُمَّ حَجَجْتُ مَعَ أَبِي الزُّبَيْرِ ـ رضى الله عنه ـ فَأَوَّلُ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ، ثُمَّ رَأَيْتُ الْمُهَاجِرِينَ وَالأَنْصَارَ يَفْعَلُونَهُ، وَقَدْ أَخْبَرَتْنِي أُمِّي أَنَّهَا أَهَلَّتْ هِيَ وَأُخْتُهَا وَالزُّبَيْرُ وَفُلاَنٌ وَفُلاَنٌ بِعُمْرَةٍ، فَلَمَّا مَسَحُوا الرُّكْنَ حَلُّوا‏.‏\hadithno{1614}\hadithtrans{Narrated `Urwa:`Aisha said, "The first thing the Prophet (ﷺ) did on reaching Mecca, was the ablution and then he performed Tawaf of the Ka`ba and that was not `Umra (alone), (but Hajj-al-Qiran). `Urwa added: Later Abu Bakr and `Umar did the same in their Hajj." And I performed the Hajj with my father Az-Zubair, and the first thing he did was Tawaf of the Ka`ba. Later I saw the Muhajirin (Emigrants) and the Ansar doing the same. My mother (Asma') told me that she, her sister (`Aisha), Az-Zubair and such and such persons assumed Ihram for `Umra, and after they passed their hands over the Black Stone Corner (of the Ka`ba) they finished the Ihram. (i.e. After doing Tawaf of the Ka`ba and Sa`i between Safa-Marwa)}}
\hadithdefcmd{bukhari}{1623}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَأَلْنَا ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَيَقَعُ الرَّجُلُ عَلَى امْرَأَتِهِ فِي الْعُمْرَةِ قَبْلَ أَنْ يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا، ثُمَّ صَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، وَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ، وَقَالَ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏ قَالَ وَسَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ فَقَالَ لاَ يَقْرَبِ امْرَأَتَهُ حَتَّى يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1623}\hadithtrans{Narrated `Amr:We asked Ibn `Umar: "May a man have sexual relations with his wife during the Umra before performing Tawaf between Safa and Marwa?" He said, "Allah's Messenger (ﷺ) arrived (in Mecca) and circumambulated the Ka`ba seven times, then offered two rak`at behind Maqam Ibrahim (the station of Abraham), then performed Tawaf between Safa and Marwa." Ibn `Umar added, "Verily! In Allah's Apostle you have a good example." And I asked Jabir bin `Abdullah (the same question), and he replied, "You should not go near your wives (have sexual relations) till you have finished Tawaf between Safa and Marwa}}
\hadithdefcmd{bukhari}{1630}{حَدَّثَنِي الْحَسَنُ بْنُ مُحَمَّدٍ ـ هُوَ الزَّعْفَرَانِيُّ ـ حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ، قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ ـ رضى الله عنهما ـ يَطُوفُ بَعْدَ الْفَجْرِ، وَيُصَلِّي رَكْعَتَيْنِ‏.‏ قَالَ عَبْدُ الْعَزِيزِ وَرَأَيْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ يُصَلِّي رَكْعَتَيْنِ بَعْدَ الْعَصْرِ، وَيُخْبِرُ أَنَّ عَائِشَةَ ـ رضى الله عنها ـ حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَدْخُلْ بَيْتَهَا إِلاَّ صَلاَّهُمَا‏.‏\hadithno{1630}\hadithtrans{Narrated Abida bin Humaid:`Abdul, `Aziz bin Rufa`i said, "I saw `Abdullah bin Az-Zubair performing Tawaf of the Ka`ba after the morning prayer then offering the two rak`at prayer." `Abdul `Aziz added, "I saw `Abdullah bin Az-Zubair offering a two rak`at prayer after the `Asr prayer." He informed me that Aisha told him that the Prophet (ﷺ) used to offer those two rak`at whenever he entered her house}}
\hadithdefcmd{bukhari}{1641}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ الْقُرَشِيِّ، أَنَّهُ سَأَلَ عُرْوَةَ بْنَ الزُّبَيْرِ فَقَالَ قَدْ حَجَّ النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَتْنِي عَائِشَةُ ـ رضى الله عنها ـ أَنَّهُ أَوَّلُ شَىْءٍ بَدَأَ بِهِ حِينَ قَدِمَ أَنَّهُ تَوَضَّأَ ثُمَّ طَافَ بِالْبَيْتِ ثُمَّ لَمْ تَكُنْ عُمْرَةً، ثُمَّ حَجَّ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَكَانَ أَوَّلَ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ ثُمَّ لَمْ تَكُنْ عُمْرَةً‏.‏ ثُمَّ عُمَرُ ـ رضى الله عنه ـ مِثْلُ ذَلِكَ‏.‏ ثُمَّ حَجَّ عُثْمَانُ ـ رضى الله عنه ـ فَرَأَيْتُهُ أَوَّلُ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ ثُمَّ لَمْ تَكُنْ عُمْرَةٌ، ثُمَّ مُعَاوِيَةُ وَعَبْدُ اللَّهِ بْنُ عُمَرَ، ثُمَّ حَجَجْتُ مَعَ أَبِي الزُّبَيْرِ بْنِ الْعَوَّامِ، فَكَانَ أَوَّلَ شَىْءٍ بَدَأَ بِهِ الطَّوَافُ بِالْبَيْتِ، ثُمَّ لَمْ تَكُنْ عُمْرَةٌ، ثُمَّ رَأَيْتُ الْمُهَاجِرِينَ وَالأَنْصَارَ يَفْعَلُونَ ذَلِكَ، ثُمَّ لَمْ تَكُنْ عُمْرَةٌ، ثُمَّ آخِرُ مَنْ رَأَيْتُ فَعَلَ ذَلِكَ ابْنُ عُمَرَ ثُمَّ لَمْ يَنْقُضْهَا عُمْرَةً، وَهَذَا ابْنُ عُمَرَ عِنْدَهُمْ فَلاَ يَسْأَلُونَهُ، وَلاَ أَحَدٌ مِمَّنْ مَضَى، مَا كَانُوا يَبْدَءُونَ بِشَىْءٍ حَتَّى يَضَعُوا أَقْدَامَهُمْ مِنَ الطَّوَافِ بِالْبَيْتِ، ثُمَّ لاَ يَحِلُّونَ، وَقَدْ رَأَيْتُ أُمِّي وَخَالَتِي، حِينَ تَقْدَمَانِ لاَ تَبْتَدِئَانِ بِشَىْءٍ أَوَّلَ مِنَ الْبَيْتِ، تَطُوفَانِ بِهِ، ثُمَّ لاَ تَحِلاَّنِ‏.‏ وَقَدْ أَخْبَرَتْنِي أُمِّي، أَنَّهَا أَهَلَّتْ هِيَ وَأُخْتُهَا وَالزُّبَيْرُ وَفُلاَنٌ وَفُلاَنٌ بِعُمْرَةٍ، فَلَمَّا مَسَحُوا الرُّكْنَ حَلُّوا‏.‏\hadithno{1641}\hadithtrans{Narrated Muhammad bin `Abdur-Rahman bin Nawfal Al-Qurashi:I asked `Urwa bin Az-Zubair (regarding the Hajj of the Prophet (ﷺ) ). `Urwa replied, "Aisha narrated, 'When the Prophet (ﷺ) reached Mecca, the first thing he started with was the ablution, then he performed Tawaf of the Ka`ba and his intention was not `Umra alone (but Hajj and `Umra together).' " Later Abu Bakr performed the Hajj and the first thing he started with was Tawaf of the Ka`ba and it was not `Umra alone (but Hajj and `Umra together). And then `Umar did the same. Then `Uthman performed the Hajj and the first thing he started with was Tawaf of the Ka`ba and it was not `Umra alone. And then Muawiya and `Abdullah bin `Umar did the same. I performed Hajj with Ibn Az-Zubair and the first thing he started with was Tawaf of the Ka`ba and it was not `Umra alone, (but Hajj and `Umra together). Then I saw the Muhajirin (Emigrants) and Ansar doing the same and it was not `Umra alone. And the last person I saw doing the same was Ibn `Umar, and he did not do another `Umra after finishing the first. Now here is Ibn `Umar present amongst the people! They neither ask him nor anyone of the previous ones. And all these people, on entering Mecca, would not start with anything unless they had performed Tawaf of the Ka`ba, and would not finish their Ihram. And no doubt, I saw my mother and my aunt, on entering Mecca doing nothing before performing Tawaf of the Ka`ba, and they would not finish their Ihram. And my mother informed me that she, her sister, Az-Zubair and such and such persons had assumed Ihram for `Umra and after passing their hands over the Corner (the Black Stone) (i.e. finishing their Umra) they finished their Ihram}}
\hadithdefcmd{bukhari}{1645}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَأَلْنَا ابْنَ عُمَرَ ـ رضى الله عنه ـ عَنْ رَجُلٍ، طَافَ بِالْبَيْتِ فِي عُمْرَةٍ، وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ أَيَأْتِي امْرَأَتَهُ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا، وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، فَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ سَبْعًا ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏ وَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ فَقَالَ لاَ يَقْرَبَنَّهَا حَتَّى يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1645}\hadithtrans{Narrated `Amr bin Dinar:We asked Ibn `Umar whether a man who, while performing `Umra, had performed Tawaf of the Ka`ba; and had not yet performed Tawaf between Safa and Marwa, could have sexual relation with his wife, Ibn `Umar replied "The Prophet (ﷺ) reached Mecca and performed the seven rounds (of Tawaf) of the Ka`ba and then offered a two-rak`at prayer behind Maqam Ibrahim and then performed the seven rounds (of Tawaf) between Safa and Marwa." He added, "Verily! In Allah's Messenger (ﷺ) you have a good example." We asked Jabir bin `Abdullah (the same question) and he said, "He (that man) should not come near (his wife) till he has completed Tawaf between Safa and Marwa}}
\hadithdefcmd{bukhari}{1669}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ أَبِي حَرْمَلَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ رَدِفْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَاتٍ فَلَمَّا بَلَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم الشِّعْبَ الأَيْسَرَ الَّذِي دُونَ الْمُزْدَلِفَةِ أَنَاخَ، فَبَالَ ثُمَّ جَاءَ فَصَبَبْتُ عَلَيْهِ الْوَضُوءَ، فَتَوَضَّأَ وُضُوءًا خَفِيفًا‏.‏ فَقُلْتُ الصَّلاَةَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏‏.‏ فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَى الْمُزْدَلِفَةَ، فَصَلَّى ثُمَّ رَدِفَ الْفَضْلُ رَسُولَ اللَّهِ صلى الله عليه وسلم غَدَاةَ جَمْعٍ‏.‏ قَالَ كُرَيْبٌ فَأَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ الْفَضْلِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَزَلْ يُلَبِّي حَتَّى بَلَغَ الْجَمْرَةَ‏.‏\hadithno{1669}\hadithtrans{Narrated Usama bin Zaid:I rode behind Allah's Messenger (ﷺ) from `Arafat and when Allah's Messenger (ﷺ) reached the mountain pass on the left side which is before Al-Muzdalifa he made his camel kneel and then urinated, and then I poured water for his ablution. He performed light ablution and then I said to him: (Is it the time for) the prayer, O Allah's Messenger (ﷺ)!" He replied, "The (place of) prayer is ahead of you (i.e. at Al- Muzdalifa)." So Allah's Messenger (ﷺ) rode till he reached Al-Muzdalifa and then he offered the prayer (there) . Then in the morning (10th Dhul-Hijja) Al-Faql (bin `Abbas) rode behind Allah's Messenger (ﷺ). Kuraib, (a sub-narrator) said that `Abdullah bin `Abbas narrated from Al-Fadl, "Allah's Messenger (ﷺ) kept on reciting Talbiya (during the journey) till he reached the Jamra." (Jamrat-Al-`Aqaba)}}
\hadithdefcmd{bukhari}{1687}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ يُونُسَ الأَيْلِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ أُسَامَةَ بْنَ زَيْدٍ ـ رضى الله عنهما ـ كَانَ رِدْفَ النَّبِيِّ صلى الله عليه وسلم مِنْ عَرَفَةَ إِلَى الْمُزْدَلِفَةِ، ثُمَّ أَرْدَفَ الْفَضْلَ مِنَ الْمُزْدَلِفَةِ إِلَى مِنًى ـ قَالَ ـ فَكِلاَهُمَا قَالاَ لَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم يُلَبِّي حَتَّى رَمَى جَمْرَةَ الْعَقَبَةِ‏.‏\hadithno{1687}\hadithtrans{Narrated 'Ubaidullah bin `Abdullah:Ibn `Abbas said, "Usama bin Zaid rode behind the Prophet (ﷺ) from `Arafat to Al-Muzdalifa; and then from Al-Muzdalifa to Mina, Al-Fadl rode behind him." He added, "Both of them (Usama and Al-Fadl) said, 'The Prophet (ﷺ) was constantly reciting Talbiya till he did Rami of the Jamarat-Al-`Aqaba}}
\hadithdefcmd{bukhari}{1695}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَمَرْوَانَ، قَالاَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْمَدِينَةِ زَمَنَ الْحُدَيْبِيَةِ فِي بِضْعَ عَشْرَةَ مِائَةً مِنْ أَصْحَابِهِ، حَتَّى إِذَا كَانُوا بِذِي الْحُلَيْفَةِ قَلَّدَ النَّبِيُّ صلى الله عليه وسلم الْهَدْىَ وَأَشْعَرَ وَأَحْرَمَ بِالْعُمْرَةِ‏.‏\hadithno{1695}\hadithtrans{Narrated Al-Miswar bin Makhrama and Marwan:The Prophet (ﷺ) set out from Medina with over one thousand of his companions (at the time of the Treaty of Hudaibiya) and when they reached Dhul-Hulaifa, the Prophet (ﷺ) garlanded his Hadi and marked it and assumed Ihram for `Umra}}
\hadithdefcmd{bukhari}{1758}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، أَنَّ أَهْلَ الْمَدِينَةِ، سَأَلُوا ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ امْرَأَةٍ، طَافَتْ ثُمَّ حَاضَتْ، قَالَ لَهُمْ تَنْفِرُ‏.‏ قَالُوا لاَ نَأْخُذُ بِقَوْلِكَ وَنَدَعَ قَوْلَ زَيْدٍ‏.‏ قَالَ إِذَا قَدِمْتُمُ الْمَدِينَةَ فَسَلُوا‏.‏ فَقَدِمُوا الْمَدِينَةَ فَسَأَلُوا، فَكَانَ فِيمَنْ سَأَلُوا أُمُّ سُلَيْمٍ، فَذَكَرَتْ حَدِيثَ صَفِيَّةَ‏.‏ رَوَاهُ خَالِدٌ وَقَتَادَةُ عَنْ عِكْرِمَةَ‏.‏\hadithno{1758}\hadithtrans{Narrated `Ikrima:The people of Medina asked Ibn `Abbas about a woman who got her menses after performing Tawafal- Ifada. He said, "She could depart (from Mecca)." They said, "We will not act on your verdict and ignore the verdict of Zaid." Ibn `Abbas said, "When you reach Medina, inquire about it." So, when they reached Medina they asked (about that). One of those whom they asked was Um Sulaim. She told them the narration of Safiya}}
\hadithdefcmd{bukhari}{1760}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ رُخِّصَ لِلْحَائِضِ أَنْ تَنْفِرَ إِذَا أَفَاضَتْ‏.‏ قَالَ وَسَمِعْتُ ابْنَ عُمَرَ، يَقُولُ إِنَّهَا لاَ تَنْفِرُ‏.‏ ثُمَّ سَمِعْتُهُ يَقُولُ بَعْدُ إِنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لَهُنَّ‏.‏\hadithno{1760}\hadithtrans{Narrated Ibn `Abbas:A menstruating woman was allowed to leave Mecca if she had done Tawaf-al-Ifada. Tawus (a subnarrator) said from his father, "I heard Ibn `Umar saying that she would not depart. Then later I heard him saying that the Prophet (ﷺ) had allowed them (menstruating women) to depart}}
\hadithdefcmd{bukhari}{1771}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ حَاضَتْ صَفِيَّةُ لَيْلَةَ النَّفْرِ، فَقَالَتْ مَا أُرَانِي إِلاَّ حَابِسَتَكُمْ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَقْرَى حَلْقَى أَطَافَتْ يَوْمَ النَّحْرِ ‏"‏‏.‏ قِيلَ نَعَمْ‏.‏ قَالَ ‏"‏ فَانْفِرِي ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَزَادَنِي مُحَمَّدٌ حَدَّثَنَا مُحَاضِرٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نَذْكُرُ إِلاَّ الْحَجَّ، فَلَمَّا قَدِمْنَا أَمَرَنَا أَنْ نَحِلَّ، فَلَمَّا كَانَتْ لَيْلَةُ النَّفْرِ حَاضَتْ صَفِيَّةُ بِنْتُ حُيَىٍّ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ حَلْقَى عَقْرَى، مَا أُرَاهَا إِلاَّ حَابِسَتَكُمْ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ كُنْتِ طُفْتِ يَوْمَ النَّحْرِ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ قَالَ ‏"‏ فَانْفِرِي ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ إِنِّي لَمْ أَكُنْ حَلَلْتُ‏.‏ قَالَ ‏"‏ فَاعْتَمِرِي مِنَ التَّنْعِيمِ ‏"‏‏.‏ فَخَرَجَ مَعَهَا أَخُوهَا، فَلَقِينَاهُ مُدَّلِجًا‏.‏ فَقَالَ ‏"‏ مَوْعِدُكِ مَكَانَ كَذَا وَكَذَا ‏"‏‏.‏\hadithno{1771}\hadithtrans{Narrated `Aisha:Safiya got her menses on the night of Nafr (departure from Hajj), and she said, "I see that I will detain you." The Prophet (ﷺ) said, "Aqra Halqa! Did she perform the Tawaf on the Day of Nahr (slaughtering)?" Somebody replied in the affirmative. He said, "Then depart." (Different narrators mentioned that) `Aisha said, "We set out with Allah's Apostle (from Medina) with the intention of performing Hajj only. When we reached Mecca, he ordered us to finish the Ihram. When it was the night of Nafr (departure), Safiya bint Huyay got her menses. The Prophet (ﷺ) said, "Halqa Aqra! I think that she will detain you," and added, "Did you perform the Tawaf (Al-Ifada) on the Day of Nahr (slaughtering)?" She replied, "Yes." He said, "Then depart." I said, "O Allah's Apostle! I have not (done the Umra)." He replied, "Perform `Umra from Tan`im." My brother went with me and we came across the Prophet (ﷺ) in the last part of the night. He said, "Wait at such and such a place}}
\hadithdefcmd{bukhari}{1775}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، قَالَ دَخَلْتُ أَنَا وَعُرْوَةُ بْنُ الزُّبَيْرِ الْمَسْجِدَ،، فَإِذَا عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ جَالِسٌ إِلَى حُجْرَةِ عَائِشَةَ، وَإِذَا نَاسٌ يُصَلُّونَ فِي الْمَسْجِدِ صَلاَةَ الضُّحَى‏.‏ قَالَ فَسَأَلْنَاهُ عَنْ صَلاَتِهِمْ‏.‏ فَقَالَ بِدْعَةٌ‏.‏ ثُمَّ قَالَ لَهُ كَمِ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَرْبَعً إِحْدَاهُنَّ فِي رَجَبٍ، فَكَرِهْنَا أَنْ نَرُدَّ عَلَيْهِ‏.‏ قَالَ وَسَمِعْنَا اسْتِنَانَ، عَائِشَةَ أُمِّ الْمُؤْمِنِينَ فِي الْحُجْرَةِ، فَقَالَ عُرْوَةُ يَا أُمَّاهُ، يَا أُمَّ الْمُؤْمِنِينَ‏.‏ أَلاَ تَسْمَعِينَ مَا يَقُولُ أَبُو عَبْدِ الرَّحْمَنِ‏.‏ قَالَتْ مَا يَقُولُ قَالَ يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعَ عُمَرَاتٍ إِحْدَاهُنَّ فِي رَجَبٍ‏.‏ قَالَتْ يَرْحَمُ اللَّهُ أَبَا عَبْدِ الرَّحْمَنِ، مَا اعْتَمَرَ عُمْرَةً إِلاَّ وَهُوَ شَاهِدُهُ، وَمَا اعْتَمَرَ فِي رَجَبٍ قَطُّ‏.‏\hadithno{1775}\hadithtrans{Narrated Mujahid:Urwa bin Az-Zubair and I entered the Mosque (of the Prophet) and saw `Abdullah bin `Umar sitting near the dwelling place of Aisha and some people were offering the Duha prayer. We asked him about their prayer and he replied that it was a heresy. He (Urwa) then asked him how many times the Prophet (ﷺ) had performed `Umra. He replied, 'Four times; one of them was in the month of Rajab." We disliked to contradict him. Then we heard `Aisha, the Mother of faithful believers cleaning her teeth with Siwak in the dwelling place. 'Urwa said, "O Mother! O Mother of the believers! Don't you hear what Abu `Abdur Rahman is saying?" She said, "What does he say?" 'Urwa said, "He says that Allah's Messenger (ﷺ) performed four `Umra and one of them was in the month of Rajab." `Aisha said, "May Allah be merciful to Abu `Abdur Rahman! The Prophet (ﷺ) did not perform any `Umra except that he was with him, and he never performed any `Umra in Rajab}}
\hadithdefcmd{bukhari}{1791}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ جَرِيرٍ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاعْتَمَرْنَا مَعَهُ فَلَمَّا دَخَلَ مَكَّةَ طَافَ وَطُفْنَا مَعَهُ، وَأَتَى الصَّفَا وَالْمَرْوَةَ وَأَتَيْنَاهَا مَعَهُ، وَكُنَّا نَسْتُرُهُ مِنْ أَهْلِ مَكَّةَ أَنْ يَرْمِيَهُ أَحَدٌ‏.‏ فَقَالَ لَهُ صَاحِبٌ لِي أَكَانَ دَخَلَ الْكَعْبَةَ قَالَ لاَ‏.‏ قَالَ فَحَدِّثْنَا مَا، قَالَ لِخَدِيجَةَ‏.‏ قَالَ ‏ "‏ بَشِّرُوا خَدِيجَةَ بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ ‏"‏‏.‏\hadithno{1791}\hadithtrans{Narrated Isma`il:`Abdullah bin Abu `Aufa said: "Allah's Messenger (ﷺ) performed `Umra and we too performed `Umra along with him. When he entered Mecca he performed the Tawaf (of Ka`ba) and we too performed it along with him, and then he came to the As-Safa and Al-Marwa (i.e. performed the Sai) and we also came to them along with him. We were shielding him from the people of Mecca lest they may hit him with an arrow." A friend of his asked him (i.e. `Abdullah bin `Aufa), "Did the Prophet (ﷺ) enter the Ka`ba (during that `Umra)?" He replied in the negative. Then he said, "What did he (the Prophet (ﷺ) ) say about Khadija?" He (Abdullah bin `Aufa) said, "(He said) 'Give Khadija the good tidings that she will have a palace made of Qasab in Paradise and there will be neither noise nor any trouble in it}}
\hadithdefcmd{bukhari}{1793}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَأَلْنَا ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنْ رَجُلٍ، طَافَ بِالْبَيْتِ فِي عُمْرَةٍ، وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ، أَيَأْتِي امْرَأَتَهُ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا، وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، وَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ سَبْعًا، وَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏.‏ قَالَ وَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ فَقَالَ لاَ يَقْرَبَنَّهَا حَتَّى يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1793}\hadithtrans{Narrated `Amr bin Dinar:We asked Ibn `Umar whether a man who had performed the Tawaf of the Ka`ba but had not performed the Tawaf between As-Safa and Al-Marwa yet, was permitted to have sexual relation with his wife. He replied, "The Prophet (ﷺ) arrived (at Mecca) and circumambulated the Ka`ba seven times and then offered a two rak`at prayer behind Maqam-Ibrahim and then performed the going (Tawaf) between As-Safa and Al-Marwa (seven times) (and verily, in Allah's Messenger (ﷺ) you have a good example." And we asked Jabir bin `Abdullah (the same question) and he replied, "He should not go near her till he has finished the going (Tawaf) between As-Safa and Al-Marwa}}
\hadithdefcmd{bukhari}{1918}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ‏.‏وَالْقَاسِمِ بْنِ مُحَمَّدٍ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ بِلاَلاً، كَانَ يُؤَذِّنُ بِلَيْلٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُوا وَاشْرَبُوا حَتَّى يُؤَذِّنَ ابْنُ أُمِّ مَكْتُومٍ، فَإِنَّهُ لاَ يُؤَذِّنُ حَتَّى يَطْلُعَ الْفَجْرُ ‏"‏‏.‏ قَالَ الْقَاسِمُ وَلَمْ يَكُنْ بَيْنَ أَذَانِهِمَا إِلاَّ أَنْ يَرْقَى ذَا وَيَنْزِلَ ذَا‏.‏\hadithno{1918}\hadithtrans{Narrated `Aisha:Bilal used to pronounce the Adhan at night, so Allah's Messenger (ﷺ)? said, "Carry on taking your meals (eat and drink) till Ibn Um Maktum pronounces the Adhan, for he does not pronounce it till it is dawn}}
\hadithdefcmd{bukhari}{1925}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامِ بْنِ الْمُغِيرَةِ أَنَّهُ سَمِعَ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، قَالَ كُنْتُ أَنَا وَأَبِي، حِينَ دَخَلْنَا عَلَى عَائِشَةَ وَأُمِّ سَلَمَةَ ح‏.‏ حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّ أَبَاهُ عَبْدَ الرَّحْمَنِ، أَخْبَرَ مَرْوَانَ، أَنَّ عَائِشَةَ، وَأُمَّ سَلَمَةَ أَخْبَرَتَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُدْرِكُهُ الْفَجْرُ وَهُوَ جُنُبٌ مِنْ أَهْلِهِ، ثُمَّ يَغْتَسِلُ وَيَصُومُ‏.‏ وَقَالَ مَرْوَانُ لِعَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ أُقْسِمُ بِاللَّهِ لَتُقَرِّعَنَّ بِهَا أَبَا هُرَيْرَةَ‏.‏ وَمَرْوَانُ يَوْمَئِذٍ عَلَى الْمَدِينَةِ‏.‏ فَقَالَ أَبُو بَكْرٍ فَكَرِهَ ذَلِكَ عَبْدُ الرَّحْمَنِ، ثُمَّ قُدِّرَ لَنَا أَنْ نَجْتَمِعَ بِذِي الْحُلَيْفَةِ، وَكَانَتْ لأَبِي هُرَيْرَةَ هُنَالِكَ أَرْضٌ، فَقَالَ عَبْدُ الرَّحْمَنِ لأَبِي هُرَيْرَةَ إِنِّي ذَاكِرٌ لَكَ أَمْرًا، وَلَوْلاَ مَرْوَانُ أَقْسَمَ عَلَىَّ فِيهِ لَمْ أَذْكُرْهُ لَكَ‏.‏ فَذَكَرَ قَوْلَ عَائِشَةَ وَأُمِّ سَلَمَةَ‏.‏ فَقَالَ كَذَلِكَ حَدَّثَنِي الْفَضْلُ بْنُ عَبَّاسٍ، وَهُنَّ أَعْلَمُ، وَقَالَ هَمَّامٌ وَابْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِي هُرَيْرَةَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْمُرُ بِالْفِطْرِ‏.‏ وَالأَوَّلُ أَسْنَدُ‏.‏\hadithno{1925}\hadithtrans{Narrated `Aisha and Um Salama:At times Allah's Messenger (ﷺ) used to get up in the morning in the state of Janaba after having sexual relations with his wives. He would then take a bath and fast}}
\hadithdefcmd{bukhari}{1931}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامِ بْنِ الْمُغِيرَةِ أَنَّهُ سَمِعَ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، كُنْتُ أَنَا وَأَبِي،، فَذَهَبْتُ مَعَهُ، حَتَّى دَخَلْنَا عَلَى عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ كَانَ لَيُصْبِحُ جُنُبًا مِنْ جِمَاعٍ غَيْرِ احْتِلاَمٍ، ثُمَّ يَصُومُهُ‏.‏ ثُمَّ دَخَلْنَا عَلَى أُمِّ سَلَمَةَ، فَقَالَتْ مِثْلَ ذَلِكَ\hadithno{1931}\hadithtrans{Narrated Abu Bakr bin `Abdur-Rahman:My father and I went to `Aisha and she said, "I testify that Allah's Messenger (ﷺ) at times used to get up in the morning in a state of Janaba from sexual intercourse, not from a wet dream and then he would fast that day." Then he went to Um Salama and she also narrated a similar thing}}
\hadithdefcmd{bukhari}{1991}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ صَوْمِ يَوْمِ الْفِطْرِ وَالنَّحْرِ، وَعَنِ الصَّمَّاءِ، وَأَنْ يَحْتَبِيَ الرَّجُلُ فِي ثَوْبٍ وَاحِدٍ‏.‏ وَعَنْ صَلاَةٍ، بَعْدَ الصُّبْحِ وَالْعَصْرِ‏.‏\hadithno{1991}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) forbade the fasting of `Id-ul-Fitr and `Id-ul-Adha (two feast days) and also the wearing of As-Samma' (a single garment covering the whole body), and sitting with one's leg drawn up while being wrapped in one garment. He also forbade the prayers after the Fajr (morning) and the `Asr (afternoon) prayers}}
\hadithdefcmd{bukhari}{1997}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عِيسَى، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ،‏.‏ وَعَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهم ـ قَالاَ لَمْ يُرَخَّصْ فِي أَيَّامِ التَّشْرِيقِ أَنْ يُصَمْنَ، إِلاَّ لِمَنْ لَمْ يَجِدِ الْهَدْىَ‏.‏\hadithno{1997}\hadithtrans{Narrated `Aisha and Ibn `Umar:Nobody was allowed to fast on the days of Tashriq except those who could not afford the Hadi (Sacrifice)}}
\hadithdefcmd{bukhari}{2030}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُبَاشِرُنِي وَأَنَا حَائِضٌ‏.‏ وَكَانَ يُخْرِجُ رَأْسَهُ مِنَ الْمَسْجِدِ وَهْوَ مُعْتَكِفٌ فَأَغْسِلُهُ وَأَنَا حَائِضٌ‏.‏\hadithno{2030}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to embrace me during my menses. He also used to put his head out of the mosque while he was in I`tikaf, and I would wash it during my menses}}
\hadithdefcmd{bukhari}{2060}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ أَبِي الْمِنْهَالِ، قَالَ كُنْتُ أَتَّجِرُ فِي الصَّرْفِ، فَسَأَلْتُ زَيْدَ بْنَ أَرْقَمَ ـ رضى الله عنه ـ فَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنِي الْفَضْلُ بْنُ يَعْقُوبَ، حَدَّثَنَا الْحَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، وَعَامِرُ بْنُ مُصْعَبٍ، أَنَّهُمَا سَمِعَا أَبَا الْمِنْهَالِ، يَقُولُ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ وَزَيْدَ بْنَ أَرْقَمَ عَنِ الصَّرْفِ، فَقَالاَ كُنَّا تَاجِرَيْنِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّرْفِ فَقَالَ ‏ "‏ إِنْ كَانَ يَدًا بِيَدٍ فَلاَ بَأْسَ، وَإِنْ كَانَ نَسَاءً فَلاَ يَصْلُحُ ‏"‏‏.‏\hadithno{2060}\hadithtrans{Narrated Abu Al-Minhal:I used to practice money exchange, and I asked Zaid bin 'Arqam about it, and he narrated what the Prophet said in the following: Abu Al-Minhal said, "I asked Al-Bara' bin `Azib and Zaid bin Arqam about practicing money exchange. They replied, 'We were traders in the time of Allah's Messenger (ﷺ) and I asked Allah's Messenger (ﷺ) about money exchange. He replied, 'If it is from hand to hand, there is no harm in it; otherwise it is not permissible}}
\hadithdefcmd{bukhari}{2123}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى، عَنْ نَافِعٍ، حَدَّثَنَا ابْنُ عُمَرَ، أَنَّهُمْ كَانُوا يَشْتَرُونَ الطَّعَامَ مِنَ الرُّكْبَانِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَيَبْعَثُ عَلَيْهِمْ مَنْ يَمْنَعُهُمْ أَنْ يَبِيعُوهُ حَيْثُ اشْتَرَوْهُ، حَتَّى يَنْقُلُوهُ حَيْثُ يُبَاعُ الطَّعَامُ‏.‏ قَالَ وَحَدَّثَنَا ابْنُ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يُبَاعَ الطَّعَامُ إِذَا اشْتَرَاهُ حَتَّى يَسْتَوْفِيَهُ‏.‏\hadithno{2123}\hadithtrans{Narrated Nafi`:Ibn `Umar told us that the people used to buy food from the caravans in the lifetime of the Prophet. The Prophet (ﷺ) used to forbid them to sell it at the very place where they had purchased it (but they were to wait) till they carried it to the market where foodstuff was sold. Ibn `Umar said, 'The Prophet (ﷺ) also forbade the reselling of foodstuff by somebody who had bought it unless he had received it with exact full measure}}
\hadithdefcmd{bukhari}{2153}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ إِذَا زَنَتْ وَلَمْ تُحْصِنْ قَالَ ‏ "‏ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَبِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ لاَ أَدْرِي بَعْدَ الثَّالِثَةِ، أَوِ الرَّابِعَةِ‏.‏\hadithno{2153}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Allah's Messenger (ﷺ) was asked about the slave-girl, if she was a virgin and committed illegal sexual intercourse. The Prophet (ﷺ) said, "If she committed illegal sexual intercourse, lash her, and if she did it a second time, then lash her again, and if she repeated the third time, then sell her even for a hair rope." Ibn Shihab said, "I don't know whether to sell her after the third or fourth offense}}
\hadithdefcmd{bukhari}{2172}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ قَالَ وَالْمُزَابَنَةُ أَنْ يَبِيعَ الثَّمَرَ بِكَيْلٍ، إِنْ زَادَ فَلِي وَإِنْ نَقَصَ فَعَلَىَّ‏.‏ قَالَ وَحَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا بِخَرْصِهَا‏.‏\hadithno{2172}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) forbade Muzabana; and Muzabana is the selling of fresh fruit (without measuring it) for something by measure on the basis that if that thing turns to be more than the fruit, the increase would be for the seller of the fruit, and if it turns to be less, that would be of his lot. Narrated Ibn `Umar from Zaid bin Thabit that the Prophet (ﷺ) allowed the selling of the fruits on the trees after estimation (when they are ripe)}}
\hadithdefcmd{bukhari}{2178}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّ أَبَا صَالِحٍ الزَّيَّاتَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ يَقُولُ الدِّينَارُ بِالدِّينَارِ، وَالدِّرْهَمُ بِالدِّرْهَمِ‏.‏ فَقُلْتُ لَهُ فَإِنَّ ابْنَ عَبَّاسٍ لاَ يَقُولُهُ‏.‏ فَقَالَ أَبُو سَعِيدٍ سَأَلْتُهُ فَقُلْتُ سَمِعْتَهُ مِنَ النَّبِيِّ، صلى الله عليه وسلم، أَوْ وَجَدْتَهُ فِي كِتَابِ اللَّهِ قَالَ كُلُّ ذَلِكَ لاَ أَقُولُ، وَأَنْتُمْ أَعْلَمُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنِّي، وَلَكِنَّنِي أَخْبَرَنِي أُسَامَةُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ رِبًا إِلاَّ فِي النَّسِيئَةِ ‏"‏‏.‏\hadithno{2178}\hadithtrans{Narrated Abu Salih Az-Zaiyat:I heard Abu Sa`id Al-Khudri saying, "The selling of a Dinar for a Dinar, and a Dirham for a Dirham (is permissible)." I said to him, "Ibn `Abbas does not say the same." Abu Sa`id replied, "I asked Ibn `Abbas whether he had heard it from the Prophet (ﷺ) or seen it in the Holy Book. Ibn `Abbas replied, "I do not claim that, and you know Allah's Messenger (ﷺ) better than I, but Usama informed me that the Prophet had said, 'There is no Riba (in money exchange) except when it is not done from hand to hand (i.e. when there is delay in payment)}}
\hadithdefcmd{bukhari}{2180}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي حَبِيبُ بْنُ أَبِي ثَابِتٍ، قَالَ سَمِعْتُ أَبَا الْمِنْهَالِ، قَالَ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ وَزَيْدَ بْنَ أَرْقَمَ ـ رضى الله عنهم ـ عَنِ الصَّرْفِ،، فَكُلُّ وَاحِدٍ مِنْهُمَا يَقُولُ هَذَا خَيْرٌ مِنِّي‏.‏ فَكِلاَهُمَا يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الذَّهَبِ بِالْوَرِقِ دَيْنًا‏.‏\hadithno{2180}\hadithtrans{Narrated Abu Al-Minhal:I asked Al-Bara' bin `Azib and Zaid bin Arqam about money exchanges. Each of them said, "This is better than I," and both of them said, "Allah's Messenger (ﷺ) forbade the selling of silver for gold on credit}}
\hadithdefcmd{bukhari}{2183}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ، وَلاَ تَبِيعُوا الثَّمَرَ بِالتَّمْرِ ‏"‏ قَالَ سَالِمٌ وَأَخْبَرَنِي عَبْدُ اللَّهِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ بَعْدَ ذَلِكَ فِي بَيْعِ الْعَرِيَّةِ بِالرُّطَبِ أَوْ بِالتَّمْرِ، وَلَمْ يُرَخِّصْ فِي غَيْرِهِ‏.‏\hadithno{2183}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Do not sell fruits of dates until they become free from all the dangers of being spoilt or blighted; and do not sell fresh dates for dry dates." Narrated Salim and `Abdullah from Zaid bin Thabit: "Later on Allah's Messenger (ﷺ) permitted the selling of ripe fruits on trees for fresh dates or dried dates in Bai'-al-'Araya, and did not allow it for any other kind of sale}}
\hadithdefcmd{bukhari}{2201}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَعَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى خَيْبَرَ، فَجَاءَهُ بِتَمْرٍ جَنِيبٍ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ، إِنَّا لَنَأْخُذُ الصَّاعَ مِنْ هَذَا بِالصَّاعَيْنِ، وَالصَّاعَيْنِ بِالثَّلاَثَةِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَفْعَلْ، بِعِ الْجَمْعَ بِالدَّرَاهِمِ، ثُمَّ ابْتَعْ بِالدَّرَاهِمِ جَنِيبًا ‏"‏‏.‏\hadithno{2201}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:Allah's Messenger (ﷺ) appointed somebody as a governor of Khaibar. That governor brought to him an excellent kind of dates (from Khaibar). The Prophet (ﷺ) asked, "Are all the dates of Khaibar like this?" He replied, "By Allah, no, O Allah's Messenger (ﷺ)! But we barter one Sa of this (type of dates) for two Sas of dates of ours and two Sas of it for three of ours." Allah's Messenger (ﷺ) said, "Do not do so (as that is a kind of usury) but sell the mixed dates (of inferior quality) for money, and then buy good dates with that money}}
\hadithdefcmd{bukhari}{2232}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، قَالَ حَدَّثَ ابْنُ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ، أَخْبَرَهُ أَنَّ زَيْدَ بْنَ خَالِدٍ وَأَبَا هُرَيْرَةَ رضى الله عنهما أَخْبَرَاهُ أَنَّهُمَا، سَمِعَا رَسُولَ اللَّهِ صلى الله عليه وسلم يُسْأَلُ عَنِ الأَمَةِ تَزْنِي وَلَمْ تُحْصَنْ قَالَ ‏ "‏ اجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ بِيعُوهَا بَعْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏"‏‏.‏\hadithno{2232}\hadithtrans{Narrated Zaid bin Khalid and Abu Huraira:that Allah's Messenger (ﷺ) was asked about an unmarried slave-girl who committed illegal sexual intercourse. They heard him saying, "Flog her, and if she commits illegal sexual intercourse after that, flog her again, and on the third (or the fourth) offense, sell her}}
\hadithdefcmd{bukhari}{2242}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنِ ابْنِ أَبِي الْمُجَالِدِ،‏.‏ وَحَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ أَبِي الْمُجَالِدِ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي مُحَمَّدٌ،، أَوْ عَبْدُ اللَّهِ بْنُ أَبِي الْمُجَالِدِ قَالَ اخْتَلَفَ عَبْدُ اللَّهِ بْنُ شَدَّادِ بْنِ الْهَادِ وَأَبُو بُرْدَةَ فِي السَّلَفِ، فَبَعَثُونِي إِلَى ابْنِ أَبِي أَوْفَى ـ رضى الله عنه ـ فَسَأَلْتُهُ فَقَالَ إِنَّا كُنَّا نُسْلِفُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ، فِي الْحِنْطَةِ، وَالشَّعِيرِ وَالزَّبِيبِ، وَالتَّمْرِ‏.‏ وَسَأَلْتُ ابْنَ أَبْزَى فَقَالَ مِثْلَ ذَلِكَ‏.‏\hadithno{2242}\hadithtrans{Narrated Shu`ba:Muhammad or `Abdullah bin Abu Al-Mujalid said, "Abdullah bin Shaddad and Abu Burda differed regarding As-Salam, so they sent me to Ibn Abi `Aufa and I asked him about it. He replied, 'In the lifetime of Allah's Messenger (ﷺ), Abu Bakr and `Umar, we used to pay in advance the prices of wheat, barley, dried grapes and dates to be delivered later. I also asked Ibn Abza and he, too, replied as above}}
\hadithdefcmd{bukhari}{2247}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ أَبِي الْبَخْتَرِيِّ، قَالَ سَأَلْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ السَّلَمِ، فِي النَّخْلِ فَقَالَ نُهِيَ عَنْ بَيْعِ النَّخْلِ، حَتَّى يَصْلُحَ، وَعَنْ بَيْعِ الْوَرِقِ، نَسَاءً بِنَاجِزٍ‏.‏ وَسَأَلْتُ ابْنَ عَبَّاسٍ عَنِ السَّلَمِ، فِي النَّخْلِ، فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ النَّخْلِ حَتَّى يُؤْكَلَ مِنْهُ، أَوْ يَأْكُلَ مِنْهُ، وَحَتَّى يُوزَنَ‏.‏\hadithno{2247}\hadithtrans{Narrated Abu Al-Bakhtari:I asked Ibn `Umar about Salam (the fruits of) date-palms. He replied, "The Prophet (ﷺ) forbade the sale of dates till their benefit becomes evident and fit for eating and also the sale of silver (for gold) on credit." I asked Ibn `Abbas about Salam for dates and he replied, "The Prophet (ﷺ) forbade the sale of dates till they were fit for eating and could be estimated}}
\hadithdefcmd{bukhari}{2249}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ أَبِي الْبَخْتَرِيِّ، سَأَلْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ السَّلَمِ، فِي النَّخْلِ فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ الثَّمَرِ حَتَّى يَصْلُحَ، وَنَهَى عَنِ الْوَرِقِ بِالذَّهَبِ نَسَاءً بِنَاجِزٍ‏.‏ وَسَأَلْتُ ابْنَ عَبَّاسٍ فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ النَّخْلِ حَتَّى يَأْكُلَ أَوْ يُؤْكَلَ، وَحَتَّى يُوزَنَ‏.‏ قُلْتُ وَمَا يُوزَنُ قَالَ رَجُلٌ عِنْدَهُ حَتَّى يُحْرَزَ‏.‏\hadithno{2249}\hadithtrans{Narrated Abu Al-Bakhtari:I asked Ibn `Umar about Salam for dates. Ibn `Umar replied, "The Prophet (ﷺ) forbade the sale (of the fruits) of date-palms until they were fit for eating and also forbade the sale of silver for gold on credit." I also asked Ibn `Abbas about it. Ibn `Abbas replied, "The Prophet (ﷺ) forbade the sale of dates till they were fit for eating, and could be weighed." I asked him, "What is to be weighed (as the dates are on the trees)?" A man sitting by Ibn `Abbas said, "It means till they are cut and stored}}
\hadithdefcmd{bukhari}{2254}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ الشَّيْبَانِيِّ، عَنْ مُحَمَّدِ بْنِ أَبِي مُجَالِدٍ، قَالَ أَرْسَلَنِي أَبُو بُرْدَةَ وَعَبْدُ اللَّهِ بْنُ شَدَّادٍ إِلَى عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى وَعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى فَسَأَلْتُهُمَا عَنِ السَّلَفِ،‏.‏ فَقَالاَ كُنَّا نُصِيبُ الْمَغَانِمَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَانَ يَأْتِينَا أَنْبَاطٌ مِنْ أَنْبَاطِ الشَّأْمِ فَنُسْلِفُهُمْ فِي الْحِنْطَةِ وَالشَّعِيرِ وَالزَّبِيبِ إِلَى أَجَلٍ مُسَمًّى‏.‏ قَالَ قُلْتُ أَكَانَ لَهُمْ زَرْعٌ، أَوْ لَمْ يَكُنْ لَهُمْ زَرْعٌ قَالاَ مَا كُنَّا نَسْأَلُهُمْ عَنْ ذَلِكَ‏.‏\hadithno{2254}\hadithtrans{Narrated Muhammad bin Abi Al-Mujalid:Abu Burda and `Abdullah bin Shaddad sent me to `Abdur Rahman bin Abza and `Abdullah bin Abi `Aufa to ask them about the Salaf (Salam). They said, "We used to get war booty while we were with Allah's Messenger (ﷺ) and when the peasants of Sham came to us we used to pay them in advance for wheat, barley, and oil to be delivered within a fixed period." I asked them, "Did the peasants own standing crops or not?" They replied, "We never asked them about it}}
\hadithdefcmd{bukhari}{2265}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ يَعْلَى بْنِ أُمَيَّةَ ـ رضى الله عنه ـ قَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم جَيْشَ الْعُسْرَةِ فَكَانَ مِنْ أَوْثَقِ أَعْمَالِي فِي نَفْسِي، فَكَانَ لِي أَجِيرٌ، فَقَاتَلَ إِنْسَانًا، فَعَضَّ أَحَدُهُمَا إِصْبَعَ صَاحِبِهِ، فَانْتَزَعَ إِصْبَعَهُ، فَأَنْدَرَ ثَنِيَّتَهُ فَسَقَطَتْ، فَانْطَلَقَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَهْدَرَ ثَنِيَّتَهُ وَقَالَ ‏ "‏ أَفَيَدَعُ إِصْبَعَهُ فِي فِيكَ تَقْضَمُهَا ـ قَالَ أَحْسِبُهُ قَالَ ـ كَمَا يَقْضَمُ الْفَحْلُ ‏"‏‏.‏ قَالَ ابْنُ جُرَيْجٍ وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، عَنْ جَدِّهِ، بِمِثْلِ هَذِهِ الصِّفَةِ أَنَّ رَجُلاً، عَضَّ يَدَ رَجُلٍ، فَأَنْدَرَ ثَنِيَّتَهُ، فَأَهْدَرَهَا أَبُو بَكْرٍ رضى الله عنه‏.‏\hadithno{2265}\hadithtrans{Narrated Ya`la bin Umaiya:I fought in Jaish-al-Usra (Ghazwa of Tabuk) along with the Prophet (ﷺ) and in my opinion that was the best of my deeds. Then I had an employee, who quarrel led with someone and one of the them bit and cut the other's finger and caused his own tooth to fall out. He then went to the Prophet (with a complaint) but the Prophet (ﷺ) canceled the suit and said to the complainant, "Did you expect him to let his finger in your mouth so that you might snap and cut it (as does a stallion camel)?" Narrated Ibn Juraij from `Abdullah bin Abu Mulaika from his grandfather a similar story: A man bit the hand of another man and caused his own tooth to fall out, but Abu Bakr judged that he had no right for compensation (for the broken tooth)}}
\hadithdefcmd{bukhari}{2285}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ أَنْ يَعْمَلُوهَا وَيَزْرَعُوهَا وَلَهُمْ شَطْرُ مَا يَخْرُجُ مِنْهَا، وَأَنَّ ابْنَ عُمَرَ حَدَّثَهُ أَنَّ الْمَزَارِعَ كَانَتْ تُكْرَى عَلَى شَىْءٍ سَمَّاهُ نَافِعٌ لاَ أَحْفَظُهُ‏.‏ وَأَنَّ رَافِعَ بْنَ خَدِيجٍ حَدَّثَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ حَتَّى أَجْلاَهُمْ عُمَرُ‏.‏\hadithno{2285}\hadithtrans{Narrated `Abdullah bin `Umar:"Allah's Messenger (ﷺ) gave the land of Khaibar to the Jews to work on and cultivate and take half of its yield. Ibn `Umar added, "The land used to be rented for a certain portion (of its yield)." Nafi` mentioned the amount of the portion but I forgot it. Rafi` bin Khadij said, "The Prophet (ﷺ) forbade renting farms." Narrated 'Ubaidullah Nafi` said: Ibn `Umar said: (The contract of Khaibar continued) till `Umar evacuated the Jews (from Khaibar)}}
\hadithdefcmd{bukhari}{2302}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَأَبِي، هُرَيْرَةَ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى خَيْبَرَ، فَجَاءَهُمْ بِتَمْرٍ جَنِيبٍ فَقَالَ ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏‏.‏ فَقَالَ إِنَّا لَنَأْخُذُ الصَّاعَ مِنْ هَذَا بِالصَّاعَيْنِ، وَالصَّاعَيْنِ بِالثَّلاَثَةِ‏.‏ فَقَالَ ‏"‏ لاَ تَفْعَلْ، بِعِ الْجَمْعَ بِالدَّرَاهِمِ، ثُمَّ ابْتَعْ بِالدَّرَاهِمِ جَنِيبًا ‏"‏‏.‏ وَقَالَ فِي الْمِيزَانِ مِثْلَ ذَلِكَ‏.‏\hadithno{2302}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:Allah's Messenger (ﷺ) employed someone as a governor at Khaibar. When the man came to Medina, he brought with him dates called Janib. The Prophet (ﷺ) asked him, "Are all the dates of Khaibar of this kind?" The man replied, "(No), we exchange two Sa's of bad dates for one Sa of this kind of dates (i.e. Janib), or exchange three Sa's for two." On that, the Prophet (ﷺ) said, "Don't do so, as it is a kind of usury (Riba) but sell the dates of inferior quality for money, and then buy Janib with the money". The Prophet said the same thing about dates sold by weight. (See Hadith No)}}
\hadithdefcmd{bukhari}{2307}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ وَزَعَمَ عُرْوَةُ أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ مُسْلِمِينَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ‏.‏ فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا السَّبْىَ، وَإِمَّا الْمَالَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ بِهِمْ ‏"‏‏.‏ وَقَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم انْتَظَرَهُمْ بِضْعَ عَشْرَةَ لَيْلَةً، حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمُسْلِمِينَ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ إِخْوَانَكُمْ هَؤُلاَءِ قَدْ جَاءُونَا تَائِبِينَ، وَإِنِّي قَدْ رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ بِذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ قَدْ طَيَّبْنَا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ فِي ذَلِكَ مِمَّنْ لَمْ يَأْذَنْ، فَارْجِعُوا حَتَّى يَرْفَعُوا إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، ثُمَّ رَجَعُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ قَدْ طَيَّبُوا وَأَذِنُوا‏.‏\hadithno{2307}\hadithtrans{Narrated Marwan bin Al-Hakam and Al-Miswar bin Makhrama:When the delegates of the tribe of Hawazin after embracing Islam, came to Allah's Messenger (ﷺ), he got up. They appealed to him to return their properties and their captives. Allah's Messenger (ﷺ) said to them, "The most beloved statement to me is the true one. So, you have the option of restoring your properties or your captives, for I have delayed distributing them." The narrator added, Allah's Messenger (ﷺ) had been waiting for them for more than ten days on his return from Taif. When they realized that Allah's Apostle would return to them only one of two things, they said, "We choose our captives." So, Allah's Apostle got up in the gathering of the Muslims, praised Allah as He deserved, and said, "Then after! These brethren of yours have come to you with repentance and I see it proper to return their captives to them. So, whoever amongst you likes to do that as a favor, then he can do it, and whoever of you wants to stick to his share till we pay him from the very first booty which Allah will give us then he can do so." The people replied, "We agree to give up our shares willingly as a favor for Allah's Apostle." Then Allah's Messenger (ﷺ) said, "We don't know who amongst you has agreed and who hasn't. Go back and your chiefs may tell us your opinion." So, all of them returned and their chiefs discussed the matter with them and then they (i.e. their chiefs) came to Allah's Messenger (ﷺ) to tell him that they (i.e. the people) had given up their shares gladly and willingly}}
\hadithdefcmd{bukhari}{2314}{حَدَّثَنَا أَبُو الْوَلِيدِ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ زَيْدِ بْنِ خَالِدٍ، وَأَبِي، هُرَيْرَةَ رضى الله عنهما عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَاغْدُ يَا أُنَيْسُ إِلَى امْرَأَةِ هَذَا، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏\hadithno{2314}\hadithtrans{Narrated Zaid bin Khalid and Abu Huraira:The Prophet (ﷺ) said, "O Unais! Go to the wife of this (man) and if she confesses (that she has committed illegal sexual intercourse), then stone her to death}}
\hadithdefcmd{bukhari}{2340}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ كَانُوا يَزْرَعُونَهَا بِالثُّلُثِ وَالرُّبُعِ وَالنِّصْفِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا، فَإِنْ لَمْ يَفْعَلْ فَلْيُمْسِكْ أَرْضَهُ ‏"‏‏.‏ وَقَالَ الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا أَخَاهُ، فَإِنْ أَبَى فَلْيُمْسِكْ أَرْضَهُ ‏"‏‏.‏\hadithno{2340}\hadithtrans{Narrated Jabir:The people used to rent their land for cultivation for one-third, one-fourth or half its yield. The Prophet said, "Whoever has land should cultivate it himself or give it to his (Muslim) brother gratis; otherwise keep it uncultivated." Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "Whoever has land should cultivate it himself or give it to his (Muslim) brother gratis; otherwise he should keep it uncultivated}}
\hadithdefcmd{bukhari}{2343}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يُكْرِي مَزَارِعَهُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ وَصَدْرًا مِنْ إِمَارَةِ مُعَاوِيَةَ‏.‏ ثُمَّ حُدِّثَ عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ، فَذَهَبَ ابْنُ عُمَرَ إِلَى رَافِعٍ فَذَهَبْتُ مَعَهُ، فَسَأَلَهُ فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ كِرَاءِ الْمَزَارِعِ‏.‏ فَقَالَ ابْنُ عُمَرَ قَدْ عَلِمْتَ أَنَّا كُنَّا نُكْرِي مَزَارِعَنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَا عَلَى الأَرْبِعَاءِ وَبِشَىْءٍ مِنَ التِّبْنِ‏.‏\hadithno{2343}\hadithtrans{Narrated Nafi`:Ibn `Umar used to rent his farms in the time of Abu Bakr, `Umar, `Uthman, and in the early days of Muawiya. Then he was told the narration of Rafi` 'bin Khadij that the Prophet (ﷺ) had forbidden the renting of farms. Ibn `Umar went to Rafi` and I accompanied him. He asked Rafi` who replied that the Prophet had forbidden the renting of farms. Ibn `Umar said, "You know that we used to rent our farms in the lifetime of Allah's Messenger (ﷺ) for the yield of the banks of the water streams (rivers) and for certain amount of figs}}
\hadithdefcmd{bukhari}{2346}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ حَدَّثَنِي عَمَّاىَ، أَنَّهُمْ كَانُوا يُكْرُونَ الأَرْضَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم بِمَا يَنْبُتُ عَلَى الأَرْبِعَاءِ أَوْ شَىْءٍ يَسْتَثْنِيهِ صَاحِبُ الأَرْضِ فَنَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ ذَلِكَ فَقُلْتُ لِرَافِعٍ فَكَيْفَ هِيَ بِالدِّينَارِ وَالدِّرْهَمِ فَقَالَ رَافِعٌ لَيْسَ بِهَا بَأْسٌ بِالدِّينَارِ وَالدِّرْهَمِ‏.‏ وَقَالَ اللَّيْثُ وَكَانَ الَّذِي نُهِيَ عَنْ ذَلِكَ مَا لَوْ نَظَرَ فِيهِ ذَوُو الْفَهْمِ بِالْحَلاَلِ وَالْحَرَامِ لَمْ يُجِيزُوهُ، لِمَا فِيهِ مِنَ الْمُخَاطَرَةِ‏.‏\hadithno{2346}\hadithtrans{Narrated Hanzala bin Qais:Rafi` bin Khadij said, "My two uncles told me that they (i.e. the companions of the Prophet) used to rent the land in the lifetime of the Prophet (ﷺ) for the yield on the banks of water streams (rivers) or for a portion of the yield stipulated by the owner of the land. The Prophet (ﷺ) forbade it." I said to Rafi`, "What about renting the land for Dinars and Dirhams?" He replied, "There is no harm in renting for Dinars- Dirhams. Al-Laith said, "If those who have discernment for distinguishing what is legal from what is illegal looked into what has been forbidden concerning this matter they would not permit it, for it is surrounded with dangers}}
\hadithdefcmd{bukhari}{2356}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ يَقْتَطِعُ بِهَا مَالَ امْرِئٍ، هُوَ عَلَيْهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ‏"‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ الآيَةَ‏.‏ فَجَاءَ الأَشْعَثُ فَقَالَ مَا حَدَّثَكُمْ أَبُو عَبْدِ الرَّحْمَنِ، فِيَّ أُنْزِلَتْ هَذِهِ الآيَةُ، كَانَتْ لِي بِئْرٌ فِي أَرْضِ ابْنِ عَمٍّ لِي فَقَالَ لِي ‏"‏ شُهُودَكَ ‏"‏‏.‏ قُلْتُ مَا لِي شُهُودٌ‏.‏ قَالَ ‏"‏ فَيَمِينَهُ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ‏.‏ فَذَكَرَ النَّبِيُّ صلى الله عليه وسلم هَذَا الْحَدِيثَ، فَأَنْزَلَ اللَّهُ ذَلِكَ تَصْدِيقًا لَهُ‏.‏\hadithno{2356}\hadithtrans{Narrated `Abdullah (bin Mas`ud):The Prophet (ﷺ) said, "Whoever takes a false oath to deprive somebody of his property will meet Allah while He will be angry with him." Allah revealed: 'Verily those who purchase a little gain at the cost of Allah's covenant, and their oaths.' ........(3.77) Al-Ashath came (to the place where `Abdullah was narrating) and said, "What has Abu `Abdur- Rahman (i.e. `Abdullah) been telling you? This verse was revealed concerning me. I had a well in the land of a cousin of mine. The Prophet (ﷺ) asked me to bring witnesses (to confirm my claim). I said, 'I don't have witnesses.' He said, 'Let the defendant take an oath then.' I said, 'O Allah's Messenger (ﷺ)! He will take a (false) oath immediately.' Then the Prophet (ﷺ) mentioned the above narration and Allah revealed the verse to confirm what he had said." (See Hadith No)}}
\hadithdefcmd{bukhari}{2360}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ـ رضى الله عنهما ـ أَنَّهُ حَدَّثَهُ أَنَّ رَجُلاً مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرُّ فَأَبَى عَلَيْهِ، فَاخْتَصَمَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلزُّبَيْرِ ‏"‏ اسْقِ يَا زُبَيْرُ، ثُمَّ أَرْسِلِ الْمَاء إِلَى جَارِكَ ‏"‏‏.‏ فَغَضِبَ الأَنْصَارِيُّ، فَقَالَ أَنْ كَانَ ابْنَ عَمَّتِكَ‏.‏ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ اسْقِ يَا زُبَيْرُ، ثُمَّ احْبِسِ الْمَاءَ، حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏‏.‏ فَقَالَ الزُّبَيْرُ وَاللَّهِ إِنِّي لأَحْسِبُ هَذِهِ الآيَةَ نَزَلَتْ فِي ذَلِكَ ‏\{‏فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ‏\}‏‏.‏\hadithno{2360}\hadithtrans{Narrated `Abdullah bin Az-Zubair:An Ansari man quarreled with Az-Zubair in the presence of the Prophet (ﷺ) about the Harra Canals which were used for irrigating the date-palms. The Ansari man said to Az-Zubair, "Let the water pass' but Az-Zubair refused to do so. So, the case was brought before the Prophet (ﷺ) who said to Az-Zubair, "O Zubair! Irrigate (your land) and then let the water pass to your neighbor." On that the Ansari got angry and said to the Prophet, "Is it because he (i.e. Zubair) is your aunt's son?" On that the color of the face of Allah's Messenger (ﷺ) changed (because of anger) and he said, "O Zubair! Irrigate (your land) and then withhold the water till it reaches the walls between the pits round the trees." Zubair said, "By Allah, I think that the following verse was revealed on this occasion": "But no, by your Lord They can have No faith Until they make you judge In all disputes between them}}
\hadithdefcmd{bukhari}{2384}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى، أَخْبَرَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي الْوَلِيدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنِي بُشَيْرُ بْنُ يَسَارٍ، مَوْلَى بَنِي حَارِثَةَ أَنَّ رَافِعَ بْنَ خَدِيجٍ، وَسَهْلَ بْنَ أَبِي حَثْمَةَ، حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ بَيْعِ الثَّمَرِ بِالتَّمْرِ، إِلاَّ أَصْحَابَ الْعَرَايَا فَإِنَّهُ أَذِنَ لَهُمْ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ ابْنُ إِسْحَاقَ حَدَّثَنِي بُشَيْرٌ مِثْلَهُ‏.‏\hadithno{2384}\hadithtrans{Narrated Rafi` 'bin Khadij and Sahl bin Abi Hathma:Allah's Messenger (ﷺ) forbade the sale of Muzabana, i.e. selling of fruits for fruits, except in the case of 'Araya; he allowed the owners of 'Araya such kind of sale}}
\hadithdefcmd{bukhari}{2405}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ عَامِرٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ أُصِيبَ عَبْدُ اللَّهِ وَتَرَكَ عِيَالاً وَدَيْنًا، فَطَلَبْتُ إِلَى أَصْحَابِ الدَّيْنِ أَنْ يَضَعُوا بَعْضًا مِنْ دَيْنِهِ فَأَبَوْا، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَاسْتَشْفَعْتُ بِهِ عَلَيْهِمْ فَأَبَوْا، فَقَالَ ‏"‏ صَنِّفْ تَمْرَكَ كُلَّ شَىْءٍ مِنْهُ عَلَى حِدَتِهِ، عِذْقَ ابْنِ زَيْدٍ عَلَى حِدَةٍ، وَاللِّينَ عَلَى حِدَةٍ، وَالْعَجْوَةَ عَلَى حِدَةٍ، ثُمَّ أَحْضِرْهُمْ حَتَّى آتِيَكَ ‏"‏‏.‏ فَفَعَلْتُ، ثُمَّ جَاءَ صلى الله عليه وسلم فَقَعَدَ عَلَيْهِ، وَكَالَ لِكُلِّ رَجُلٍ حَتَّى اسْتَوْفَى، وَبَقِيَ التَّمْرُ كَمَا هُوَ كَأَنَّهُ لَمْ يُمَسَّ‏.‏ وَغَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم عَلَى نَاضِحٍ لَنَا، فَأَزْحَفَ الْجَمَلُ فَتَخَلَّفَ عَلَىَّ فَوَكَزَهُ النَّبِيُّ صلى الله عليه وسلم مِنْ خَلْفِهِ، قَالَ ‏"‏ بِعْنِيهِ وَلَكَ ظَهْرُهُ إِلَى الْمَدِينَةِ ‏"‏‏.‏ فَلَمَّا دَنَوْنَا اسْتَأْذَنْتُ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي حَدِيثُ عَهْدٍ بِعُرْسٍ‏.‏ قَالَ صلى الله عليه وسلم ‏"‏ فَمَا تَزَوَّجْتَ بِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ قُلْتُ ثَيِّبًا، أُصِيبَ عَبْدُ اللَّهِ وَتَرَكَ جَوَارِيَ صِغَارًا، فَتَزَوَّجْتُ ثَيِّبًا تُعَلِّمُهُنَّ وَتُؤَدِّبُهُنَّ، ثُمَّ قَالَ ‏"‏ ائْتِ أَهْلَكَ ‏"‏‏.‏ فَقَدِمْتُ فَأَخْبَرْتُ خَالِي بِبَيْعِ الْجَمَلِ فَلاَمَنِي، فَأَخْبَرْتُهُ بِإِعْيَاءِ الْجَمَلِ، وَبِالَّذِي كَانَ مِنَ النَّبِيِّ صلى الله عليه وسلم وَوَكْزِهِ إِيَّاهُ، فَلَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم غَدَوْتُ إِلَيْهِ بِالْجَمَلِ، فَأَعْطَانِي ثَمَنَ الْجَمَلِ وَالْجَمَلَ وَسَهْمِي مَعَ الْقَوْمِ‏.‏\hadithno{2405}\hadithtrans{Narrated Jabir:When `Abdullah (my father) died, he left behind children and debts. I asked the lenders to put down some of his debt, but they refused, so I went to the Prophet (ﷺ) to intercede with them, yet they refused. The Prophet (ﷺ) said (to me), "Classify your dates into their different kinds: 'Adha bin Zaid, Lean and 'Ajwa, each kind alone and call all the creditors and wait till I come to you." I did so and the Prophet (ﷺ) came and sat beside the dates and started measuring to each his due till he paid them fully, and the amount of dates remained as it was before, as if he had not touched them. (On another occasion) I took part in one of Ghazawat along with the Prophet (ﷺ) and I was riding one of our camels. The camel got tired and was lagging behind the others. The Prophet (ﷺ) hit it on its back. He said, "Sell it to me, and you have the right to ride it till Medina.'' When we approached Medina, I took the permission from the Prophet (ﷺ) to go to my house, saying, "O Allah's Messenger (ﷺ)! I have newly married." The Prophet (ﷺ) asked, "Have you married a virgin or a matron (a widow or divorcee)?" I said, "I have married a matron, as `Abdullah (my father) died and left behind daughters small in their ages, so I married a matron who may teach them and bring them up with good manners." The Prophet (ﷺ) then said (to me), "Go to your family." When I went there and told my maternal uncle about the selling of the camel, he admonished me for it. On that I told him about its slowness and exhaustion and about what the Prophet (ﷺ) had done to the camel and his hitting it. When the Prophet (ﷺ) arrived, I went to him with the camel in the morning and he gave me its price, the camel itself, and my share from the war booty as he gave the other people}}
\hadithdefcmd{bukhari}{2417}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ وَهْوَ فِيهَا فَاجِرٌ لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ قَالَ فَقَالَ الأَشْعَثُ فِيَّ وَاللَّهِ كَانَ ذَلِكَ، كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي، فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏‏.‏ قُلْتُ لاَ‏.‏ قَالَ فَقَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ، وَيَذْهَبَ بِمَالِي، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏\hadithno{2417}\hadithtrans{Narrated `Abdullah bin Mas`ud:Allah's Messenger (ﷺ) said, "Whoever takes a false oath so as to take the property of a Muslim (illegally) will meet Allah while He will be angry with him." Al-Ash'ath said: By Allah, that saying concerned me. I had common land with a Jew, and the Jew later on denied my ownership, so I took him to the Prophet who asked me whether I had a proof of my ownership. When I replied in the negative, the Prophet asked the Jew to take an oath. I said, "O Allah's Messenger (ﷺ)! He will take an oath and deprive me of my property." So, Allah revealed the following verse: "Verily! Those who purchase a little gain at the cost of Allah's covenant and their oaths}}
\hadithdefcmd{bukhari}{2497}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُثْمَانَ يَعْنِي ابْنَ الأَسْوَدِ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ أَبِي مُسْلِمٍ، قَالَ سَأَلْتُ أَبَا الْمِنْهَالِ عَنِ الصَّرْفِ، يَدًا بِيَدٍ فَقَالَ اشْتَرَيْتُ أَنَا وَشَرِيكٌ، لِي شَيْئًا يَدًا بِيَدٍ وَنَسِيئَةً، فَجَاءَنَا الْبَرَاءُ بْنُ عَازِبٍ فَسَأَلْنَاهُ، فَقَالَ فَعَلْتُ أَنَا وَشَرِيكِي زَيْدُ بْنُ أَرْقَمَ، وَسَأَلْنَا النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ مَا كَانَ يَدًا بِيَدٍ فَخُذُوهُ، وَمَا كَانَ نَسِيئَةً فَذَرُوهُ ‏"‏‏.‏\hadithno{2497}\hadithtrans{Narrated Sulaiman bin Abu Muslim:I asked Abu Minhal about money exchange from hand to hand. He said, "I and a partner of mine bought something partly in cash and partly on credit." Al-Bara' bin `Azib passed by us and we asked about it. He replied, "I and my partner Zaid bin Al-Arqam did the same and then went to the Prophet (ﷺ) and asked him about it. He said, 'Take what was from hand to hand and leave what was on credit}}
\hadithdefcmd{bukhari}{2501}{حَدَّثَنَا أَصْبَغُ بْنُ الْفَرَجِ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي سَعِيدٌ، عَنْ زُهْرَةَ بْنِ مَعْبَدٍ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ هِشَامٍ ـ وَكَانَ قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم ـ وَذَهَبَتْ بِهِ أُمُّهُ زَيْنَبُ بِنْتُ حُمَيْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ بَايِعْهُ‏.‏ فَقَالَ ‏ "‏ هُوَ صَغِيرٌ ‏"‏‏.‏ فَمَسَحَ رَأْسَهُ وَدَعَا لَهُ‏.‏ وَعَنْ زُهْرَةَ بْنِ مَعْبَدٍ، أَنَّهُ كَانَ يَخْرُجُ بِهِ جَدُّهُ عَبْدُ اللَّهِ بْنُ هِشَامٍ إِلَى السُّوقِ فَيَشْتَرِي الطَّعَامَ فَيَلْقَاهُ ابْنُ عُمَرَ وَابْنُ الزُّبَيْرِ ـ رضى الله عنهم ـ فَيَقُولاَنِ لَهُ أَشْرِكْنَا، فَإِنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ دَعَا لَكَ بِالْبَرَكَةِ فَيَشْرَكُهُمْ، فَرُبَّمَا أَصَابَ الرَّاحِلَةَ كَمَا هِيَ، فَيَبْعَثُ بِهَا إِلَى الْمَنْزِلِ‏.‏\hadithno{2501}\hadithtrans{Narrated `Abdullah bin Hisham:that his mother Zainab bint Humaid took him to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! Take the pledge of allegiance from him." But he said, "He is still too young for the pledge," and passed his hand on his (i.e. `Abdullah's) head and invoked for Allah's blessing for him. Zuhra bin Ma`bad stated that he used to go with his grandfather, `Abdullah bin Hisham, to the market to buy foodstuff. Ibn `Umar and Ibn Az-Zubair would meet him and say to him, "Be our partner, as the Prophet (ﷺ) invoked Allah to bless you." So, he would be their partner, and very often he would win a camel's load and send it home}}
\hadithdefcmd{bukhari}{2505}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ‏.‏وَعَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهم ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم صُبْحَ رَابِعَةٍ مِنْ ذِي الْحَجَّةِ مُهِلِّينَ بِالْحَجِّ، لاَ يَخْلِطُهُمْ شَىْءٌ، فَلَمَّا قَدِمْنَا أَمَرَنَا فَجَعَلْنَاهَا عُمْرَةً، وَأَنْ نَحِلَّ إِلَى نِسَائِنَا، فَفَشَتْ فِي ذَلِكَ الْقَالَةُ‏.‏ قَالَ عَطَاءٌ فَقَالَ جَابِرٌ فَيَرُوحُ أَحَدُنَا إِلَى مِنًى وَذَكَرُهُ يَقْطُرُ مَنِيًّا‏.‏ فَقَالَ جَابِرٌ بِكَفِّهِ، فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَامَ خَطِيبًا فَقَالَ ‏"‏ بَلَغَنِي أَنَّ أَقْوَامًا يَقُولُونَ كَذَا وَكَذَا، وَاللَّهِ لأَنَا أَبَرُّ وَأَتْقَى لِلَّهِ مِنْهُمْ، وَلَوْ أَنِّي اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ، وَلَوْلاَ أَنَّ مَعِي الْهَدْىَ لأَحْلَلْتُ ‏"‏‏.‏ فَقَامَ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ فَقَالَ يَا رَسُولَ اللَّهِ هِيَ لَنَا أَوْ لِلأَبَدِ فَقَالَ ‏"‏ لاَ بَلْ لِلأَبَدِ ‏"‏‏.‏ قَالَ وَجَاءَ عَلِيُّ بْنُ أَبِي طَالِبٍ ـ فَقَالَ أَحَدُهُمَا يَقُولُ لَبَّيْكَ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ وَقَالَ الآخَرُ لَبَّيْكَ بِحَجَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ـ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُقِيمَ عَلَى إِحْرَامِهِ، وَأَشْرَكَهُ فِي الْهَدْىِ‏.‏\hadithno{2505}\hadithtrans{Narrated Ibn `Abbas:The Prophet (along with his companions) reached Mecca in the morning of the fourth of Dhul-Hijja assuming Ihram for Hajj only. So when we arrived at Mecca, the Prophet (ﷺ) ordered us to change our intentions of the Ihram for `Umra and that we could finish our Ihram after performing the `Umra and could go to our wives (for sexual intercourse). The people began talking about that. Jabir said surprisingly, "Shall we go to Mina while semen is dribbling from our male organs?" Jabir moved his hand while saying so. When this news reached the Prophet (ﷺ) he delivered a sermon and said, "I have been informed that some peoples were saying so and so; By Allah I fear Allah more than you do, and am more obedient to Him than you. If I had known what I know now, I would not have brought the Hadi (sacrifice) with me and had the Hadi not been with me, I would have finished the Ihram." At that Suraqa bin Malik stood up and asked "O Allah's Messenger (ﷺ)! Is this permission for us only or is it forever?" The Prophet (ﷺ) replied, "It is forever." In the meantime `Ali bin Abu Talib came from Yemen and was saying Labbaik for what the Prophet (ﷺ) has intended. (According to another man, `Ali was saying Labbaik for Hajj similar to Allah's Messenger (ﷺ)). The Prophet (ﷺ) told him to keep on the Ihram and let him share the Hadi with him}}
\hadithdefcmd{bukhari}{2516}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ ـ رضى الله عنه مَنْ حَلَفَ عَلَى يَمِينٍ، يَسْتَحِقُّ بِهَا مَالاً وَهْوَ فِيهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ، فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ فَقَرَأَ إِلَى ‏\{‏عَذَابٌ أَلِيمٌ‏\}‏‏.‏ثُمَّ إِنَّ الأَشْعَثَ بْنَ قَيْسٍ خَرَجَ إِلَيْنَا فَقَالَ مَا يُحَدِّثُكُمْ أَبُو عَبْدِ الرَّحْمَنِ قَالَ فَحَدَّثْنَاهُ قَالَ فَقَالَ صَدَقَ لَفِيَّ وَاللَّهِ أُنْزِلَتْ، كَانَتْ بَيْنِي وَبَيْنَ رَجُلٍ خُصُومَةٌ فِي بِئْرٍ فَاخْتَصَمْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شَاهِدُكَ أَوْ يَمِينُهُ ‏"‏‏.‏ قُلْتُ إِنَّهُ إِذًا يَحْلِفُ وَلاَ يُبَالِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ يَسْتَحِقُّ بِهَا مَالاً هُوَ فِيهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ، ثُمَّ اقْتَرَأَ هَذِهِ الآيَةَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى ‏\{‏وَلَهُمْ عَذَابٌ أَلِيمٌ‏\}‏‏.‏\hadithno{2516}\hadithtrans{Narrated Abu Wail: Abdullah (bin Mas'ud) said, "Whoever took a false oath in order to grab somebody's property will meet Allah while Allah will be angry with him." Allah revealed the following verse to confirm that:--"Verily! Those who purchase a small gain at the cost of Allah's covenant And their oaths...a painful torment." (3.77) Al-Ash'ath bin Qais came to us and asked as to what Abu Abdur-Rehman (i.e. Ibn Mas'ud) was telling you." We related the story to him. On that he said, "He has told the truth. This verse was revealed about me. I had some dispute with another man regarding a well and we took the case before Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) said (to me), "Produce two witnesses (to support your claim); otherwise the defendant has the right to take an oath (to refute your claim).' I said, 'The defendant would not mind to take a false oath." Allah's Messenger (ﷺ) then said, 'Whoever took a false oath in order to grab someone else's property will meet Allah, Allah will be angry with him.' Allah then revealed what Confirmed it." Al-Ash'ath then recited the following Verse:--"Verily! Those who purchase a small gain at the cost of Allah's covenant, And their oaths . . . (to) . . . they shall have a painful torment!' (3.77) (See Hadith No)}}
\hadithdefcmd{bukhari}{2539}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، ذَكَرَ عُرْوَةُ أَنَّ مَرْوَانَ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ فَقَالَ ‏"‏ إِنَّ مَعِي مَنْ تَرَوْنَ، وَأَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ، فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا الْمَالَ، وَإِمَّا السَّبْىَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ بِهِمْ ‏"‏‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم انْتَظَرَهُمْ بِضْعَ عَشْرَةَ لَيْلَةً حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فِي النَّاسِ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ إِخْوَانَكُمْ جَاءُونَا تَائِبِينَ، وَإِنِّي رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ طَيَّبْنَا ذَلِكَ‏.‏ قَالَ ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ مِمَّنْ لَمْ يَأْذَنْ فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ، فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، ثُمَّ رَجَعُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ طَيَّبُوا وَأَذِنُوا، فَهَذَا الَّذِي بَلَغَنَا عَنْ سَبْىِ هَوَازِنَ‏.‏ وَقَالَ أَنَسٌ قَالَ عَبَّاسٌ لِلنَّبِيِّ صلى الله عليه وسلم فَادَيْتُ نَفْسِي، وَفَادَيْتُ عَقِيلاً‏.‏\hadithno{2539}\hadithtrans{Narrated Marwan and Al-Miswar bin Makhrama:When the delegates of the tribe of Hawazin came to the Prophet (ﷺ) and they requested him to return their properties and captives. The Prophet (ﷺ) stood up and said to them, "I have other people with me in this matter (as you see) and the most beloved statement to me is the true one; you may choose either the properties or the prisoners as I have delayed their distribution." The Prophet (ﷺ) had waited for them for more than ten days since his arrival from Ta'if. So, when it became evident to them that the Prophet (ﷺ) was not going to return them except one of the two, they said, "We choose our prisoners." The Prophet got up amongst the people and glorified and praised Allah as He deserved and said, "Then after, these brethren of yours have come to us with repentance, and I see it logical to return them the captives. So, whoever amongst you likes to do that as a favor, then he can do it, and whoever of you likes to stick to his share till we recompense him from the very first war booty which Allah will give us, then he can do so (i.e. give up the present captives)." The people unanimously said, "We do that (return the captives) willingly." The Prophet (ﷺ) said, "We do not know which of you has agreed to it and which have not, so go back and let your leaders forward us your decision." So, all the people then went back and discussed the matter with their leaders who returned and informed the Prophet (ﷺ) that all the people had willingly given their consent to return the captives. This is what has reached us about the captives of Hawazin. Narrated Anas that `Abbas said to the Prophet, "I paid for my ransom and `Aqil's ransom}}
\hadithdefcmd{bukhari}{2556}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُبَيْدُ اللَّهِ، سَمِعْتُ أَبَا هُرَيْرَةَ، وَزَيْدَ بْنَ خَالِدٍ، رضى الله عنهما عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا زَنَتِ الأَمَةُ فَاجْلِدُوهَا، ثُمَّ إِذَا زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِذَا زَنَتْ فَاجْلِدُوهَا، فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ بِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏‏.‏\hadithno{2556}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:The Prophet (ﷺ) said, "If a slave-girl (Ama) commits illegal sexual intercourse, scourge her; if she does it again, scourge her again; if she repeats it, scourge her again." The narrator added that on the third or the fourth offense, the Prophet (ﷺ) said, "Sell her even for a hair rope}}
\hadithdefcmd{bukhari}{2584}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ ذَكَرَ عُرْوَةُ أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، رضى الله عنهما وَمَرْوَانَ أَخْبَرَاهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم حِينَ جَاءَهُ وَفْدُ هَوَازِنَ قَامَ فِي النَّاسِ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ، فَإِنَّ إِخْوَانَكُمْ جَاءُونَا تَائِبِينَ، وَإِنِّي رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا ‏"‏‏.‏ فَقَالَ النَّاسُ طَيَّبْنَا لَكَ‏.‏\hadithno{2584}\hadithtrans{Narrated Al-Miswar bin Makhrama and Marwan:When the delegates of the tribe of Hawazin came to the Prophet (ﷺ) he stood up amongst the people, Glorified and Praised Allah as He deserved, and said, "Then after: Your brethren have come to you with repentance and I see it logical to return to them their captives; so whoever amongst you likes to do that as a favor, then he can do it, and whoever of you like to stick to his share till we give him his right from the very first Fai (war booty) (1) which Allah will bestow on us, then (he can do so)." The people replied, "We do that (to return the captives) willingly as a favor for your sake}}
\hadithdefcmd{bukhari}{2608}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ مُسْلِمِينَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ فَقَالَ لَهُمْ ‏"‏ مَعِي مَنْ تَرَوْنَ، وَأَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ، فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا السَّبْىَ وَإِمَّا الْمَالَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ ‏"‏‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم انْتَظَرَهُمْ بِضْعَ عَشْرَةَ لَيْلَةً حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا‏.‏ فَقَامَ فِي الْمُسْلِمِينَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ إِخْوَانَكُمْ هَؤُلاَءِ جَاءُونَا تَائِبِينَ، وَإِنِّي رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ طَيَّبْنَا يَا رَسُولَ اللَّهِ لَهُمْ‏.‏ فَقَالَ لَهُمْ ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ فِيهِ مِمَّنْ لَمْ يَأْذَنْ، فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، ثُمَّ رَجَعُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ طَيَّبُوا وَأَذِنُوا‏.‏ وَهَذَا الَّذِي بَلَغَنَا مِنْ سَبْىِ هَوَازِنَ هَذَا آخِرُ قَوْلِ الزُّهْرِيِّ، يَعْنِي فَهَذَا الَّذِي بَلَغَنَا‏.‏\hadithno{2608}\hadithtrans{Narrated Marwan bin Al-Hakam and Al-Miswar bin Makhrama:When the delegates of the tribe of Hawazin came to the Prophet (ﷺ) they requested him to return their property and their captives. He said to them, "This concerns also other people along with me as you see, and the best statement to me is the true one, so you may choose one of two alternatives; either the captives or the property and (I have not distributed the booty for) I have been waiting for you." When the Prophet (ﷺ) had returned from Ta'if, he waited for them for more than ten nights. When they came to know that the Prophet (ﷺ) would not return except one of the two, they chose their captives. The Prophet then stood up amongst the Muslims, Glorified and Praised Allah as He deserved, and then said, "Then after: These brothers of yours have come to you with repentance and I see it proper to return their captives, so whoever amongst you likes to do that as a favor, then he can do it, and whoever of you wants to stick to his share till we pay him from the very first Fai (i.e. war booty) which Allah will give us, then he can do so." The people said, "We return (the captives) to them willingly as a favor, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "I do not know who of you has given his consent and who has not; so go back and your leaders may present your decision to me." The people went away, and their leaders discussed the matter with them, and then came to the Prophet (ﷺ) to tell him that all of them had given their consent (to return the captives) willingly. (Az-Zuhri, the sub-narrator said, "This is what we know about the captives of Hawazin)}}
\hadithdefcmd{bukhari}{2615}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسٌ ـ رضى الله عنه ـ قَالَ أُهْدِيَ لِلنَّبِيِّ صلى الله عليه وسلم جُبَّةُ سُنْدُسٍ، وَكَانَ يَنْهَى عَنِ الْحَرِيرِ، فَعَجِبَ النَّاسُ مِنْهَا فَقَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ أَحْسَنُ مِنْ هَذَا ‏"‏‏.‏ وَقَالَ سَعِيدٌ عَنْ قَتَادَةَ، عَنْ أَنَسٍ، إِنَّ أُكَيْدِرَ دُومَةَ أَهْدَى إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2615}\hadithtrans{Narrated Anas:A Jubba (i.e. cloak) made of thick silken cloth was presented to the Prophet. The Prophet (ﷺ) used to forbid people to wear silk. So, the people were pleased to see it. The Prophet (ﷺ) said, "By Him in Whose Hands Muhammad's soul is, the handkerchiefs of Sa`d bin Mu`adh in Paradise are better than this." Anas added, "The present was sent to the Prophet (ﷺ) by Ukaidir (a Christian) from Dauma}}
\hadithdefcmd{bukhari}{2667}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ وَهْوَ فِيهَا فَاجِرٌ، لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ قَالَ فَقَالَ الأَشْعَثُ بْنُ قَيْسٍ فِيَّ وَاللَّهِ كَانَ ذَلِكَ، كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي، فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏‏.‏ قَالَ قُلْتُ لاَ‏.‏ قَالَ فَقَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ وَيَذْهَبَ بِمَالِي‏.‏ قَالَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏\hadithno{2667}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "If somebody takes a false oath in order to get the property of a Muslim (unjustly) by that oath, then Allah will be angry with him when he will meet Him." Al-Ash'ath informed me, "By Allah! This was said regarding me. There was a dispute about a piece of land between me and a man from the Jews who denied my right. I took him to the Prophet. Allah's Messenger (ﷺ) asked me, 'Do you have an evidence?' I replied in the negative. He said to the Jew, 'Take an oath.' I said, 'O Allah's Messenger (ﷺ)! He will surely take an oath and take my property unjustly." So, Allah revealed: "Verily! Those who purchase a little gain at the cost of Allah's covenant and their oaths}}
\hadithdefcmd{bukhari}{2670}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ مَنْ حَلَفَ عَلَى يَمِينٍ يَسْتَحِقُّ بِهَا مَالاً لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ، ثُمَّ أَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ‏\}‏ إِلَى ‏\{‏عَذَابٌ أَلِيمٌ‏\}‏‏.‏ ثُمَّ إِنَّ الأَشْعَثَ بْنَ قَيْسٍ خَرَجَ إِلَيْنَا فَقَالَ مَا يُحَدِّثُكُمْ أَبُو عَبْدِ الرَّحْمَنِ فَحَدَّثْنَاهُ بِمَا، قَالَ، فَقَالَ صَدَقَ لَفِيَّ أُنْزِلَتْ، كَانَ بَيْنِي وَبَيْنَ رَجُلٍ خُصُومَةٌ فِي شَىْءٍ، فَاخْتَصَمْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ شَاهِدَاكَ أَوْ يَمِينُهُ ‏"‏‏.‏ فَقُلْتُ لَهُ إِنَّهُ إِذًا يَحْلِفُ وَلاَ يُبَالِي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ يَسْتَحِقُّ بِهَا مَالاً وَهْوَ فِيهَا فَاجِرٌ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ، ثُمَّ اقْتَرَأَ هَذِهِ الآيَةَ‏.‏\hadithno{2670}\hadithtrans{Narrated Abu Wail:`Abdullah (bin Mas`ud) said, "Whoever takes a (false) oath in order to grab some property (unjustly), Allah will be angry with him when he will meet Him. Allah confirmed that through His Divine Revelation: "Verily! Those who purchase a little gain at the cost of Allah's covenant and their oaths . . . they will have a painful punishment." (3.77) Al-Ash'ath bin Qais came to us and asked, 'What is Abu `Abdur-Rahman (i.e. `Abdullah) telling you? 'We told him what he was narrating to us. He said, 'He was telling the truth; this Divine Verse was revealed in connection with me. There was a dispute between me and another man about something and the case was filed before Allah's Messenger (ﷺ) who said, 'Produce your two witnesses or else the defendant is to take an oath.' I said, The defendant will surely take a (false) oath caring for nothing.' The Prophet (ﷺ) said, 'Whoever takes a false oath in order to grab (other's) property, then Allah will be angry with him when he will meet Him.' Then Allah revealed its confirmation. Al-Ashath then recited the above Divine Verse}}
\hadithdefcmd{bukhari}{2677}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ كَاذِبًا لِيَقْتَطِعَ مَالَ رَجُلٍ ـ أَوْ قَالَ أَخِيهِ ـ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ وَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ فِي الْقُرْآنِ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ الآيَةَ‏.‏ فَلَقِيَنِي الأَشْعَثُ فَقَالَ مَا حَدَّثَكُمْ عَبْدُ اللَّهِ الْيَوْمَ، قُلْتُ كَذَا وَكَذَا‏.‏ قَالَ فِيَّ أُنْزِلَتْ‏.‏\hadithno{2677}\hadithtrans{Narrated Abu Wail from `Abdullah:The Prophet (ﷺ) said, "Whoever takes a false oath in order to grab another man's (or his brother's) property, then Allah will be angry with him when he will meet him." Then Allah confirmed this by revealing the Divine Verse: "Verily! Those who purchase a little gain at the cost of Allah's Covenant and their oaths . . . Will get painful punishment." (3.77) Al-Ash'ath met me and asked, "What did `Abdullah tell you today?" I said, "So and so." He said, "The Verse was revealed regarding my case}}
\hadithdefcmd{bukhari}{2696}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، رضى الله عنهما قَالاَ جَاءَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ فَقَالَ صَدَقَ، اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَالَ الأَعْرَابِيُّ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا، فَزَنَى بِامْرَأَتِهِ، فَقَالُوا لِي عَلَى ابْنِكَ الرَّجْمُ‏.‏ فَفَدَيْتُ ابْنِي مِنْهُ بِمِائَةٍ مِنَ الْغَنَمِ وَوَلِيدَةٍ، ثُمَّ سَأَلْتُ أَهْلَ الْعِلْمِ، فَقَالُوا إِنَّمَا عَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا الْوَلِيدَةُ وَالْغَنَمُ فَرَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَأَمَّا أَنْتَ يَا أُنَيْسُ ـ لِرَجُلٍ ـ فَاغْدُ عَلَى امْرَأَةِ هَذَا فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا عَلَيْهَا أُنَيْسٌ فَرَجَمَهَا‏.‏\hadithno{2696}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A bedouin came and said, "O Allah's Messenger (ﷺ)! Judge between us according to Allah's Laws." His opponent got up and said, "He is right. Judge between us according to Allah's Laws." The bedouin said, "My son was a laborer working for this man, and he committed illegal sexual intercourse with his wife. The people told me that my son should be stoned to death; so, in lieu of that, I paid a ransom of one hundred sheep and a slave girl to save my son. Then I asked the learned scholars who said, "Your son has to be lashed one-hundred lashes and has to be exiled for one year." The Prophet (ﷺ) said, "No doubt I will judge between you according to Allah's Laws. The slave-girl and the sheep are to go back to you, and your son will get a hundred lashes and one year exile." He then addressed somebody, "O Unais! go to the wife of this (man) and stone her to death" So, Unais went and stoned her to death}}
\hadithdefcmd{bukhari}{2711}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَمِعَ مَرْوَانَ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، رضى الله عنهما يُخْبِرَانِ عَنْ أَصْحَابِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ لَمَّا كَاتَبَ سُهَيْلُ بْنُ عَمْرٍو يَوْمَئِذٍ كَانَ فِيمَا اشْتَرَطَ سُهَيْلُ بْنُ عَمْرٍو عَلَى النَّبِيِّ صلى الله عليه وسلم أَنَّهُ لاَ يَأْتِيكَ مِنَّا أَحَدٌ وَإِنْ كَانَ عَلَى دِينِكَ إِلاَّ رَدَدْتَهُ إِلَيْنَا، وَخَلَّيْتَ بَيْنَنَا وَبَيْنَهُ‏.‏ فَكَرِهَ الْمُؤْمِنُونَ ذَلِكَ، وَامْتَعَضُوا مِنْهُ، وَأَبَى سُهَيْلٌ إِلاَّ ذَلِكَ، فَكَاتَبَهُ النَّبِيُّ صلى الله عليه وسلم عَلَى ذَلِكَ، فَرَدَّ يَوْمَئِذٍ أَبَا جَنْدَلٍ عَلَى أَبِيهِ سُهَيْلِ بْنِ عَمْرٍو، وَلَمْ يَأْتِهِ أَحَدٌ مِنَ الرِّجَالِ إِلاَّ رَدَّهُ فِي تِلْكَ الْمُدَّةِ، وَإِنْ كَانَ مُسْلِمًا، وَجَاءَ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ، وَكَانَتْ أُمُّ كُلْثُومٍ بِنْتُ عُقْبَةَ بْنِ أَبِي مُعَيْطٍ مِمَّنْ خَرَجَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ وَهْىَ عَاتِقٌ، فَجَاءَ أَهْلُهَا يَسْأَلُونَ النَّبِيَّ صلى الله عليه وسلم أَنْ يَرْجِعَهَا إِلَيْهِمْ، فَلَمْ يَرْجِعْهَا إِلَيْهِمْ لِمَا أَنْزَلَ اللَّهُ فِيهِنَّ ‏\{‏إِذَا جَاءَكُمُ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ فَامْتَحِنُوهُنَّ اللَّهُ أَعْلَمُ بِإِيمَانِهِنَّ‏\}‏ إِلَى قَوْلِهِ ‏\{‏وَلاَ هُمْ يَحِلُّونَ لَهُنَّ‏\}‏‏.‏\hadithno{2711}\hadithtrans{Narrated Marwan and al-Miswar bin Makhrama:(from the companions of Allah's Messenger (ﷺ)) When Suhail bin `Amr agreed to the Treaty (of Hudaibiya), one of the things he stipulated then, was that the Prophet (ﷺ) should return to them (i.e. the pagans) anyone coming to him from their side, even if he was a Muslim; and would not interfere between them and that person. The Muslims did not like this condition and got disgusted with it. Suhail did not agree except with that condition. So, the Prophet (ﷺ) agreed to that condition and returned Abu Jandal to his father Suhail bin `Amr. Thenceforward the Prophet (ﷺ) returned everyone in that period (of truce) even if he was a Muslim. During that period some believing women emigrants including Um Kulthum bint `Uqba bin Abu Muait who came to Allah's Messenger (ﷺ) and she was a young lady then. Her relative came to the Prophet (ﷺ) and asked him to return her, but the Prophet (ﷺ) did not return her to them for Allah had revealed the following Verse regarding women: "O you who believe! When the believing women come to you as emigrants. Examine them, Allah knows best as to their belief, then if you know them for true believers, Send them not back to the unbelievers, (for) they are not lawful (wives) for the disbelievers, Nor are the unbelievers lawful (husbands) for them}}
\hadithdefcmd{bukhari}{2725}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، رضى الله عنهم أَنَّهُمَا قَالاَ إِنَّ رَجُلاً مِنَ الأَعْرَابِ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولَ اللَّهِ أَنْشُدُكَ اللَّهَ إِلاَّ قَضَيْتَ لِي بِكِتَابِ اللَّهِ‏.‏ فَقَالَ الْخَصْمُ الآخَرُ وَهْوَ أَفْقَهُ مِنْهُ نَعَمْ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَائْذَنْ لِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُلْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا، فَزَنَى بِامْرَأَتِهِ، وَإِنِّي أُخْبِرْتُ أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَوَلِيدَةٍ، فَسَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّمَا عَلَى ابْنِي جَلْدُ مِائَةٍ، وَتَغْرِيبُ عَامٍ، وَأَنَّ عَلَى امْرَأَةِ هَذَا الرَّجْمَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، الْوَلِيدَةُ وَالْغَنَمُ رَدٌّ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، اغْدُ يَا أُنَيْسُ إِلَى امْرَأَةِ هَذَا فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏ قَالَ فَغَدَا عَلَيْهَا فَاعْتَرَفَتْ، فَأَمَرَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَتْ‏.‏\hadithno{2725}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A bedouin came to Allah's Messenger (ﷺ) and said, "O Allah's apostle! I ask you by Allah to judge My case according to Allah's Laws." His opponent, who was more learned than he, said, "Yes, judge between us according to Allah's Laws, and allow me to speak." Allah's Messenger (ﷺ) said, "Speak." He (i .e. the bedouin or the other man) said, "My son was working as a laborer for this (man) and he committed illegal sexual intercourse with his wife. The people told me that it was obligatory that my son should be stoned to death, so in lieu of that I ransomed my son by paying one hundred sheep and a slave girl. Then I asked the religious scholars about it, and they informed me that my son must be lashed one hundred lashes, and be exiled for one year, and the wife of this (man) must be stoned to death." Allah's Messenger (ﷺ) said, "By Him in Whose Hands my soul is, I will judge between you according to Allah's Laws. The slave-girl and the sheep are to be returned to you, your son is to receive a hundred lashes and be exiled for one year. You, Unais, go to the wife of this (man) and if she confesses her guilt, stone her to death." Unais went to that woman next morning and she confessed. Allah's Messenger (ﷺ) ordered that she be stoned to death}}
\hadithdefcmd{bukhari}{2731}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَمَرْوَانَ، يُصَدِّقُ كُلُّ وَاحِدٍ مِنْهُمَا حَدِيثَ صَاحِبِهِ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَمَنَ الْحُدَيْبِيَةِ، حَتَّى كَانُوا بِبَعْضِ الطَّرِيقِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ خَالِدَ بْنَ الْوَلِيدِ بِالْغَمِيمِ فِي خَيْلٍ لِقُرَيْشٍ طَلِيعَةً فَخُذُوا ذَاتَ الْيَمِينِ ‏"‏‏.‏ فَوَاللَّهِ مَا شَعَرَ بِهِمْ خَالِدٌ حَتَّى إِذَا هُمْ بِقَتَرَةِ الْجَيْشِ، فَانْطَلَقَ يَرْكُضُ نَذِيرًا لِقُرَيْشٍ، وَسَارَ النَّبِيُّ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِالثَّنِيَّةِ الَّتِي يُهْبَطُ عَلَيْهِمْ مِنْهَا، بَرَكَتْ بِهِ رَاحِلَتُهُ‏.‏ فَقَالَ النَّاسُ حَلْ حَلْ‏.‏ فَأَلَحَّتْ، فَقَالُوا خَلأَتِ الْقَصْوَاءُ، خَلأَتِ الْقَصْوَاءُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا خَلأَتِ الْقَصْوَاءُ، وَمَا ذَاكَ لَهَا بِخُلُقٍ، وَلَكِنْ حَبَسَهَا حَابِسُ الْفِيلِ، ثُمَّ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَسْأَلُونِي خُطَّةً يُعَظِّمُونَ فِيهَا حُرُمَاتِ اللَّهِ إِلاَّ أَعْطَيْتُهُمْ إِيَّاهَا ‏"‏‏.‏ ثُمَّ زَجَرَهَا فَوَثَبَتْ، قَالَ فَعَدَلَ عَنْهُمْ حَتَّى نَزَلَ بِأَقْصَى الْحُدَيْبِيَةِ، عَلَى ثَمَدٍ قَلِيلِ الْمَاءِ يَتَبَرَّضُهُ النَّاسُ تَبَرُّضًا، فَلَمْ يُلَبِّثْهُ النَّاسُ حَتَّى نَزَحُوهُ، وَشُكِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْعَطَشُ، فَانْتَزَعَ سَهْمًا مِنْ كِنَانَتِهِ، ثُمَّ أَمَرَهُمْ أَنْ يَجْعَلُوهُ فِيهِ، فَوَاللَّهِ مَا زَالَ يَجِيشُ لَهُمْ بِالرِّيِّ حَتَّى صَدَرُوا عَنْهُ، فَبَيْنَمَا هُمْ كَذَلِكَ، إِذْ جَاءَ بُدَيْلُ بْنُ وَرْقَاءَ الْخُزَاعِيُّ فِي نَفَرٍ مِنْ قَوْمِهِ مِنْ خُزَاعَةَ، وَكَانُوا عَيْبَةَ نُصْحِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَهْلِ تِهَامَةَ، فَقَالَ إِنِّي تَرَكْتُ كَعْبَ بْنَ لُؤَىٍّ وَعَامِرَ بْنَ لُؤَىٍّ نَزَلُوا أَعْدَادَ مِيَاهِ الْحُدَيْبِيَةِ، وَمَعَهُمُ الْعُوذُ الْمَطَافِيلُ، وَهُمْ مُقَاتِلُوكَ وَصَادُّوكَ عَنِ الْبَيْتِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا لَمْ نَجِئْ لِقِتَالِ أَحَدٍ، وَلَكِنَّا جِئْنَا مُعْتَمِرِينَ، وَإِنَّ قُرَيْشًا قَدْ نَهِكَتْهُمُ الْحَرْبُ، وَأَضَرَّتْ بِهِمْ، فَإِنْ شَاءُوا مَادَدْتُهُمْ مُدَّةً، وَيُخَلُّوا بَيْنِي وَبَيْنَ النَّاسِ، فَإِنْ أَظْهَرْ فَإِنْ شَاءُوا أَنْ يَدْخُلُوا فِيمَا دَخَلَ فِيهِ النَّاسُ فَعَلُوا، وَإِلاَّ فَقَدْ جَمُّوا، وَإِنْ هُمْ أَبَوْا فَوَالَّذِي نَفْسِي بِيَدِهِ، لأُقَاتِلَنَّهُمْ عَلَى أَمْرِي هَذَا حَتَّى تَنْفَرِدَ سَالِفَتِي، وَلَيُنْفِذَنَّ اللَّهُ أَمْرَهُ ‏"‏‏.‏ فَقَالَ بُدَيْلٌ سَأُبَلِّغُهُمْ مَا تَقُولُ‏.‏ قَالَ فَانْطَلَقَ حَتَّى أَتَى قُرَيْشًا قَالَ إِنَّا قَدْ جِئْنَاكُمْ مِنْ هَذَا الرَّجُلِ، وَسَمِعْنَاهُ يَقُولُ قَوْلاً، فَإِنْ شِئْتُمْ أَنْ نَعْرِضَهُ عَلَيْكُمْ فَعَلْنَا، فَقَالَ سُفَهَاؤُهُمْ لاَ حَاجَةَ لَنَا أَنْ تُخْبِرَنَا عَنْهُ بِشَىْءٍ‏.‏ وَقَالَ ذَوُو الرَّأْىِ مِنْهُمْ هَاتِ مَا سَمِعْتَهُ يَقُولُ‏.‏ قَالَ سَمِعْتُهُ يَقُولُ كَذَا وَكَذَا، فَحَدَّثَهُمْ بِمَا قَالَ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَقَامَ عُرْوَةُ بْنُ مَسْعُودٍ فَقَالَ أَىْ قَوْمِ أَلَسْتُمْ بِالْوَالِدِ قَالُوا بَلَى‏.‏ قَالَ أَوَلَسْتُ بِالْوَلَدِ قَالُوا بَلَى‏.‏ قَالَ فَهَلْ تَتَّهِمُونِي‏.‏ قَالُوا لاَ‏.‏ قَالَ أَلَسْتُمْ تَعْلَمُونَ أَنِّي اسْتَنْفَرْتُ أَهْلَ عُكَاظٍ، فَلَمَّا بَلَّحُوا عَلَىَّ جِئْتُكُمْ بِأَهْلِي وَوَلَدِي وَمَنْ أَطَاعَنِي قَالُوا بَلَى‏.‏ قَالَ فَإِنَّ هَذَا قَدْ عَرَضَ لَكُمْ خُطَّةَ رُشْدٍ، اقْبَلُوهَا وَدَعُونِي آتِهِ‏.‏ قَالُوا ائْتِهِ‏.‏ فَأَتَاهُ فَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم نَحْوًا مِنْ قَوْلِهِ لِبُدَيْلٍ، فَقَالَ عُرْوَةُ عِنْدَ ذَلِكَ أَىْ مُحَمَّدُ، أَرَأَيْتَ إِنِ اسْتَأْصَلْتَ أَمْرَ قَوْمِكَ هَلْ سَمِعْتَ بِأَحَدٍ مِنَ الْعَرَبِ اجْتَاحَ أَهْلَهُ قَبْلَكَ وَإِنْ تَكُنِ الأُخْرَى، فَإِنِّي وَاللَّهِ لأَرَى وُجُوهًا، وَإِنِّي لأَرَى أَوْشَابًا مِنَ النَّاسِ خَلِيقًا أَنْ يَفِرُّوا وَيَدَعُوكَ‏.‏ فَقَالَ لَهُ أَبُو بَكْرٍ امْصُصْ بَظْرَ اللاَّتِ، أَنَحْنُ نَفِرُّ عَنْهُ وَنَدَعُهُ فَقَالَ مَنْ ذَا قَالُوا أَبُو بَكْرٍ‏.‏ قَالَ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ يَدٌ كَانَتْ لَكَ عِنْدِي لَمْ أَجْزِكَ بِهَا لأَجَبْتُكَ‏.‏ قَالَ وَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم فَكُلَّمَا تَكَلَّمَ أَخَذَ بِلِحْيَتِهِ، وَالْمُغِيرَةُ بْنُ شُعْبَةَ قَائِمٌ عَلَى رَأْسِ النَّبِيِّ صلى الله عليه وسلم وَمَعَهُ السَّيْفُ وَعَلَيْهِ الْمِغْفَرُ، فَكُلَّمَا أَهْوَى عُرْوَةُ بِيَدِهِ إِلَى لِحْيَةِ النَّبِيِّ صلى الله عليه وسلم ضَرَبَ يَدَهُ بِنَعْلِ السَّيْفِ، وَقَالَ لَهُ أَخِّرْ يَدَكَ عَنْ لِحْيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَرَفَعَ عُرْوَةُ رَأْسَهُ فَقَالَ مَنْ هَذَا قَالُوا الْمُغِيرَةُ بْنُ شُعْبَةَ‏.‏ فَقَالَ أَىْ غُدَرُ، أَلَسْتُ أَسْعَى فِي غَدْرَتِكَ وَكَانَ الْمُغِيرَةُ صَحِبَ قَوْمًا فِي الْجَاهِلِيَّةِ، فَقَتَلَهُمْ، وَأَخَذَ أَمْوَالَهُمْ، ثُمَّ جَاءَ فَأَسْلَمَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمَّا الإِسْلاَمَ فَأَقْبَلُ، وَأَمَّا الْمَالَ فَلَسْتُ مِنْهُ فِي شَىْءٍ ‏"‏‏.‏ ثُمَّ إِنَّ عُرْوَةَ جَعَلَ يَرْمُقُ أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم بِعَيْنَيْهِ‏.‏ قَالَ فَوَاللَّهِ مَا تَنَخَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم نُخَامَةً إِلاَّ وَقَعَتْ فِي كَفِّ رَجُلٍ مِنْهُمْ فَدَلَكَ بِهَا وَجْهَهُ وَجِلْدَهُ، وَإِذَا أَمَرَهُمُ ابْتَدَرُوا أَمْرَهُ، وَإِذَا تَوَضَّأَ كَادُوا يَقْتَتِلُونَ عَلَى وَضُوئِهِ، وَإِذَا تَكَلَّمَ خَفَضُوا أَصْوَاتَهُمْ عِنْدَهُ، وَمَا يُحِدُّونَ إِلَيْهِ النَّظَرَ تَعْظِيمًا لَهُ، فَرَجَعَ عُرْوَةُ إِلَى أَصْحَابِهِ، فَقَالَ أَىْ قَوْمِ، وَاللَّهِ لَقَدْ وَفَدْتُ عَلَى الْمُلُوكِ، وَوَفَدْتُ عَلَى قَيْصَرَ وَكِسْرَى وَالنَّجَاشِيِّ وَاللَّهِ إِنْ رَأَيْتُ مَلِكًا قَطُّ، يُعَظِّمُهُ أَصْحَابُهُ مَا يُعَظِّمُ أَصْحَابُ مُحَمَّدٍ صلى الله عليه وسلم مُحَمَّدًا، وَاللَّهِ إِنْ تَنَخَّمَ نُخَامَةً إِلاَّ وَقَعَتْ فِي كَفِّ رَجُلٍ مِنْهُمْ، فَدَلَكَ بِهَا وَجْهَهُ وَجِلْدَهُ، وَإِذَا أَمَرَهُمُ ابْتَدَرُوا أَمْرَهُ وَإِذَا تَوَضَّأَ كَادُوا يَقْتَتِلُونَ عَلَى وَضُوئِهِ، وَإِذَا تَكَلَّمَ خَفَضُوا أَصْوَاتَهُمْ عِنْدَهُ، وَمَا يُحِدُّونَ إِلَيْهِ النَّظَرَ تَعْظِيمًا لَهُ، وَإِنَّهُ قَدْ عَرَضَ عَلَيْكُمْ خُطَّةَ رُشْدٍ، فَاقْبَلُوهَا‏.‏ فَقَالَ رَجُلٌ مِنْ بَنِي كِنَانَةَ دَعُونِي آتِهِ‏.‏ فَقَالُوا ائْتِهِ‏.‏ فَلَمَّا أَشْرَفَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَأَصْحَابِهِ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا فُلاَنٌ، وَهْوَ مِنْ قَوْمٍ يُعَظِّمُونَ الْبُدْنَ فَابْعَثُوهَا لَهُ ‏"‏‏.‏ فَبُعِثَتْ لَهُ وَاسْتَقْبَلَهُ النَّاسُ يُلَبُّونَ، فَلَمَّا رَأَى ذَلِكَ قَالَ سُبْحَانَ اللَّهِ مَا يَنْبَغِي لِهَؤُلاَءِ أَنْ يُصَدُّوا عَنِ الْبَيْتِ، فَلَمَّا رَجَعَ إِلَى أَصْحَابِهِ قَالَ رَأَيْتُ الْبُدْنَ قَدْ قُلِّدَتْ وَأُشْعِرَتْ، فَمَا أَرَى أَنْ يُصَدُّوا عَنِ الْبَيْتِ‏.‏ فَقَامَ رَجُلٌ مِنْهُمْ يُقَالُ لَهُ مِكْرَزُ بْنُ حَفْصٍ‏.‏ فَقَالَ دَعُونِي آتِهِ‏.‏ فَقَالُوا ائْتِهِ‏.‏ فَلَمَّا أَشْرَفَ عَلَيْهِمْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَذَا مِكْرَزٌ وَهْوَ رَجُلٌ فَاجِرٌ ‏"‏‏.‏ فَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم، فَبَيْنَمَا هُوَ يُكَلِّمُهُ إِذْ جَاءَ سُهَيْلُ بْنُ عَمْرٍو‏.‏ قَالَ مَعْمَرٌ فَأَخْبَرَنِي أَيُّوبُ عَنْ عِكْرِمَةَ، أَنَّهُ لَمَّا جَاءَ سُهَيْلُ بْنُ عَمْرٍو قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ سَهُلَ لَكُمْ مِنْ أَمْرِكُمْ ‏"‏‏.‏ قَالَ مَعْمَرٌ قَالَ الزُّهْرِيُّ فِي حَدِيثِهِ فَجَاءَ سُهَيْلُ بْنُ عَمْرٍو فَقَالَ هَاتِ، اكْتُبْ بَيْنَنَا وَبَيْنَكُمْ كِتَابًا، فَدَعَا النَّبِيُّ صلى الله عليه وسلم الْكَاتِبَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏"‏‏.‏ قَالَ سُهَيْلٌ أَمَّا الرَّحْمَنُ فَوَاللَّهِ مَا أَدْرِي مَا هُوَ وَلَكِنِ اكْتُبْ بِاسْمِكَ اللَّهُمَّ‏.‏ كَمَا كُنْتَ تَكْتُبُ‏.‏ فَقَالَ الْمُسْلِمُونَ وَاللَّهِ لاَ نَكْتُبُهَا إِلاَّ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اكْتُبْ بِاسْمِكَ اللَّهُمَّ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏‏.‏ فَقَالَ سُهَيْلٌ وَاللَّهِ لَوْ كُنَّا نَعْلَمُ أَنَّكَ رَسُولُ اللَّهِ مَا صَدَدْنَاكَ عَنِ الْبَيْتِ وَلاَ قَاتَلْنَاكَ، وَلَكِنِ اكْتُبْ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَاللَّهِ إِنِّي لَرَسُولُ اللَّهِ وَإِنْ كَذَّبْتُمُونِي‏.‏ اكْتُبْ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ ‏"‏‏.‏ قَالَ الزُّهْرِيُّ وَذَلِكَ لِقَوْلِهِ ‏"‏ لاَ يَسْأَلُونِي خُطَّةً يُعَظِّمُونَ فِيهَا حُرُمَاتِ اللَّهِ إِلاَّ أَعْطَيْتُهُمْ إِيَّاهَا ‏"‏‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى أَنْ تُخَلُّوا بَيْنَنَا وَبَيْنَ الْبَيْتِ فَنَطُوفَ بِهِ ‏"‏‏.‏ فَقَالَ سُهَيْلٌ وَاللَّهِ لاَ تَتَحَدَّثُ الْعَرَبُ أَنَّا أُخِذْنَا ضُغْطَةً وَلَكِنْ ذَلِكَ مِنَ الْعَامِ الْمُقْبِلِ فَكَتَبَ‏.‏ فَقَالَ سُهَيْلٌ وَعَلَى أَنَّهُ لاَ يَأْتِيكَ مِنَّا رَجُلٌ، وَإِنْ كَانَ عَلَى دِينِكَ، إِلاَّ رَدَدْتَهُ إِلَيْنَا‏.‏ قَالَ الْمُسْلِمُونَ سُبْحَانَ اللَّهِ كَيْفَ يُرَدُّ إِلَى الْمُشْرِكِينَ وَقَدْ جَاءَ مُسْلِمًا فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ دَخَلَ أَبُو جَنْدَلِ بْنُ سُهَيْلِ بْنِ عَمْرٍو يَرْسُفُ فِي قُيُودِهِ، وَقَدْ خَرَجَ مِنْ أَسْفَلِ مَكَّةَ، حَتَّى رَمَى بِنَفْسِهِ بَيْنَ أَظْهُرِ الْمُسْلِمِينَ‏.‏ فَقَالَ سُهَيْلٌ هَذَا يَا مُحَمَّدُ أَوَّلُ مَا أُقَاضِيكَ عَلَيْهِ أَنْ تَرُدَّهُ إِلَىَّ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّا لَمْ نَقْضِ الْكِتَابَ بَعْدُ ‏"‏‏.‏ قَالَ فَوَاللَّهِ إِذًا لَمْ أُصَالِحْكَ عَلَى شَىْءٍ أَبَدًا‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَأَجِزْهُ لِي ‏"‏‏.‏ قَالَ مَا أَنَا بِمُجِيزِهِ لَكَ‏.‏ قَالَ ‏"‏ بَلَى، فَافْعَلْ ‏"‏‏.‏ قَالَ مَا أَنَا بِفَاعِلٍ‏.‏ قَالَ مِكْرَزٌ بَلْ قَدْ أَجَزْنَاهُ لَكَ‏.‏ قَالَ أَبُو جَنْدَلٍ أَىْ مَعْشَرَ الْمُسْلِمِينَ، أُرَدُّ إِلَى الْمُشْرِكِينَ وَقَدْ جِئْتُ مُسْلِمًا أَلاَ تَرَوْنَ مَا قَدْ لَقِيتُ وَكَانَ قَدْ عُذِّبَ عَذَابًا شَدِيدًا فِي اللَّهِ‏.‏ قَالَ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ فَأَتَيْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَلَسْتَ نَبِيَّ اللَّهِ حَقًّا قَالَ ‏"‏ بَلَى ‏"‏‏.‏ قُلْتُ أَلَسْنَا عَلَى الْحَقِّ وَعَدُوُّنَا عَلَى الْبَاطِلِ قَالَ ‏"‏ بَلَى ‏"‏‏.‏ قُلْتُ فَلِمَ نُعْطِي الدَّنِيَّةَ فِي دِينِنَا إِذًا قَالَ ‏"‏ إِنِّي رَسُولُ اللَّهِ، وَلَسْتُ أَعْصِيهِ وَهْوَ نَاصِرِي ‏"‏‏.‏ قُلْتُ أَوَلَيْسَ كُنْتَ تُحَدِّثُنَا أَنَّا سَنَأْتِي الْبَيْتَ فَنَطُوفُ بِهِ قَالَ ‏"‏ بَلَى، فَأَخْبَرْتُكَ أَنَّا نَأْتِيهِ الْعَامَ ‏"‏‏.‏ قَالَ قُلْتُ لاَ‏.‏ قَالَ ‏"‏ فَإِنَّكَ آتِيهِ وَمُطَّوِّفٌ بِهِ ‏"‏‏.‏ قَالَ فَأَتَيْتُ أَبَا بَكْرٍ فَقُلْتُ يَا أَبَا بَكْرٍ، أَلَيْسَ هَذَا نَبِيَّ اللَّهِ حَقًّا قَالَ بَلَى‏.‏ قُلْتُ أَلَسْنَا عَلَى الْحَقِّ وَعَدُوُّنَا عَلَى الْبَاطِلِ قَالَ بَلَى‏.‏ قُلْتُ فَلِمَ نُعْطِي الدَّنِيَّةَ فِي دِينِنَا إِذًا قَالَ أَيُّهَا الرَّجُلُ، إِنَّهُ لَرَسُولُ اللَّهِ صلى الله عليه وسلم وَلَيْسَ يَعْصِي رَبَّهُ وَهْوَ نَاصِرُهُ، فَاسْتَمْسِكْ بِغَرْزِهِ، فَوَاللَّهِ إِنَّهُ عَلَى الْحَقِّ‏.‏ قُلْتُ أَلَيْسَ كَانَ يُحَدِّثُنَا أَنَّا سَنَأْتِي الْبَيْتَ وَنَطُوفُ بِهِ قَالَ بَلَى، أَفَأَخْبَرَكَ أَنَّكَ تَأْتِيهِ الْعَامَ قُلْتُ لاَ‏.‏ قَالَ فَإِنَّكَ آتِيهِ وَمُطَّوِّفٌ بِهِ‏.‏ قَالَ الزُّهْرِيِّ قَالَ عُمَرُ فَعَمِلْتُ لِذَلِكَ أَعْمَالاً‏.‏ قَالَ فَلَمَّا فَرَغَ مِنْ قَضِيَّةِ الْكِتَابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ قُومُوا فَانْحَرُوا، ثُمَّ احْلِقُوا ‏"‏‏.‏ قَالَ فَوَاللَّهِ مَا قَامَ مِنْهُمْ رَجُلٌ حَتَّى قَالَ ذَلِكَ ثَلاَثَ مَرَّاتٍ، فَلَمَّا لَمْ يَقُمْ مِنْهُمْ أَحَدٌ دَخَلَ عَلَى أُمِّ سَلَمَةَ، فَذَكَرَ لَهَا مَا لَقِيَ مِنَ النَّاسِ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ يَا نَبِيَّ اللَّهِ، أَتُحِبُّ ذَلِكَ اخْرُجْ ثُمَّ لاَ تُكَلِّمْ أَحَدًا مِنْهُمْ كَلِمَةً حَتَّى تَنْحَرَ بُدْنَكَ، وَتَدْعُوَ حَالِقَكَ فَيَحْلِقَكَ‏.‏ فَخَرَجَ فَلَمْ يُكَلِّمْ أَحَدًا مِنْهُمْ، حَتَّى فَعَلَ ذَلِكَ نَحَرَ بُدْنَهُ، وَدَعَا حَالِقَهُ فَحَلَقَهُ‏.‏ فَلَمَّا رَأَوْا ذَلِكَ، قَامُوا فَنَحَرُوا، وَجَعَلَ بَعْضُهُمْ يَحْلِقُ بَعْضًا، حَتَّى كَادَ بَعْضُهُمْ يَقْتُلُ بَعْضًا غَمًّا، ثُمَّ جَاءَهُ نِسْوَةٌ مُؤْمِنَاتٌ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا جَاءَكُمُ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ فَامْتَحِنُوهُنَّ‏\}‏ حَتَّى بَلَغَ ‏\{‏بِعِصَمِ الْكَوَافِرِ‏\}‏ فَطَلَّقَ عُمَرُ يَوْمَئِذٍ امْرَأَتَيْنِ كَانَتَا لَهُ فِي الشِّرْكِ، فَتَزَوَّجَ إِحْدَاهُمَا مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ، وَالأُخْرَى صَفْوَانُ بْنُ أُمَيَّةَ، ثُمَّ رَجَعَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْمَدِينَةِ، فَجَاءَهُ أَبُو بَصِيرٍ ـ رَجُلٌ مِنْ قُرَيْشٍ ـ وَهْوَ مُسْلِمٌ فَأَرْسَلُوا فِي طَلَبِهِ رَجُلَيْنِ، فَقَالُوا الْعَهْدَ الَّذِي جَعَلْتَ لَنَا‏.‏ فَدَفَعَهُ إِلَى الرَّجُلَيْنِ، فَخَرَجَا بِهِ حَتَّى بَلَغَا ذَا الْحُلَيْفَةِ، فَنَزَلُوا يَأْكُلُونَ مِنْ تَمْرٍ لَهُمْ، فَقَالَ أَبُو بَصِيرٍ لأَحَدِ الرَّجُلَيْنِ وَاللَّهِ إِنِّي لأَرَى سَيْفَكَ هَذَا يَا فُلاَنُ جَيِّدًا‏.‏ فَاسْتَلَّهُ الآخَرُ فَقَالَ أَجَلْ، وَاللَّهِ إِنَّهُ لَجَيِّدٌ، لَقَدْ جَرَّبْتُ بِهِ ثُمَّ جَرَّبْتُ‏.‏ فَقَالَ أَبُو بَصِيرٍ أَرِنِي أَنْظُرْ إِلَيْهِ، فَأَمْكَنَهُ مِنْهُ، فَضَرَبَهُ حَتَّى بَرَدَ، وَفَرَّ الآخَرُ، حَتَّى أَتَى الْمَدِينَةَ، فَدَخَلَ الْمَسْجِدَ يَعْدُو‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ رَآهُ ‏"‏ لَقَدْ رَأَى هَذَا ذُعْرًا ‏"‏‏.‏ فَلَمَّا انْتَهَى إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ قُتِلَ وَاللَّهِ صَاحِبِي وَإِنِّي لَمَقْتُولٌ، فَجَاءَ أَبُو بَصِيرٍ فَقَالَ يَا نَبِيَّ اللَّهِ، قَدْ وَاللَّهِ أَوْفَى اللَّهُ ذِمَّتَكَ، قَدْ رَدَدْتَنِي إِلَيْهِمْ ثُمَّ أَنْجَانِي اللَّهُ مِنْهُمْ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَيْلُ أُمِّهِ مِسْعَرَ حَرْبٍ، لَوْ كَانَ لَهُ أَحَدٌ ‏"‏‏.‏ فَلَمَّا سَمِعَ ذَلِكَ عَرَفَ أَنَّهُ سَيَرُدُّهُ إِلَيْهِمْ، فَخَرَجَ حَتَّى أَتَى سِيفَ الْبَحْرِ‏.‏ قَالَ وَيَنْفَلِتُ مِنْهُمْ أَبُو جَنْدَلِ بْنُ سُهَيْلٍ، فَلَحِقَ بِأَبِي بَصِيرٍ، فَجَعَلَ لاَ يَخْرُجُ مِنْ قُرَيْشٍ رَجُلٌ قَدْ أَسْلَمَ إِلاَّ لَحِقَ بِأَبِي بَصِيرٍ، حَتَّى اجْتَمَعَتْ مِنْهُمْ عِصَابَةٌ، فَوَاللَّهِ مَا يَسْمَعُونَ بِعِيرٍ خَرَجَتْ لِقُرَيْشٍ إِلَى الشَّأْمِ إِلاَّ اعْتَرَضُوا لَهَا، فَقَتَلُوهُمْ، وَأَخَذُوا أَمْوَالَهُمْ، فَأَرْسَلَتْ قُرَيْشٌ إِلَى النَّبِيِّ صلى الله عليه وسلم تُنَاشِدُهُ بِاللَّهِ وَالرَّحِمِ لَمَّا أَرْسَلَ، فَمَنْ أَتَاهُ فَهْوَ آمِنٌ، فَأَرْسَلَ النَّبِيُّ صلى الله عليه وسلم إِلَيْهِمْ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏وَهُوَ الَّذِي كَفَّ أَيْدِيَهُمْ عَنْكُمْ وَأَيْدِيَكُمْ عَنْهُمْ بِبَطْنِ مَكَّةَ مِنْ بَعْدِ أَنْ أَظْفَرَكُمْ عَلَيْهِمْ‏\}‏ حَتَّى بَلَغَ ‏\{‏الْحَمِيَّةَ حَمِيَّةَ الْجَاهِلِيَّةِ‏\}‏ وَكَانَتْ حَمِيَّتُهُمْ أَنَّهُمْ لَمْ يُقِرُّوا أَنَّهُ نَبِيُّ اللَّهِ، وَلَمْ يُقِرُّوا بِبِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ، وَحَالُوا بَيْنَهُمْ وَبَيْنَ الْبَيْتِ‏.‏\hadithno{2731}\hadithtrans{Narrated Al-Miswar bin Makhrama and Marwan:(whose narrations attest each other) Allah's Messenger (ﷺ) set out at the time of Al-Hudaibiya (treaty), and when they proceeded for a distance, he said, "Khalid bin Al-Walid leading the cavalry of Quraish constituting the front of the army, is at a place called Al-Ghamim, so take the way on the right." By Allah, Khalid did not perceive the arrival of the Muslims till the dust arising from the march of the Muslim army reached him, and then he turned back hurriedly to inform Quraish. The Prophet (ﷺ) went on advancing till he reached the Thaniya (i.e. a mountainous way) through which one would go to them (i.e. people of Quraish). The she-camel of the Prophet (ﷺ) sat down. The people tried their best to cause the she-camel to get up but in vain, so they said, "Al-Qaswa' (i.e. the she-camel's name) has become stubborn! Al-Qaswa' has become stubborn!" The Prophet (ﷺ) said, "Al-Qaswa' has not become stubborn, for stubbornness is not her habit, but she was stopped by Him Who stopped the elephant." Then he said, "By the Name of Him in Whose Hands my soul is, if they (i.e. the Quraish infidels) ask me anything which will respect the ordinances of Allah, I will grant it to them." The Prophet (ﷺ) then rebuked the she-camel and she got up. The Prophet (ﷺ) changed his way till he dismounted at the farthest end of Al-Hudaibiya at a pit (i.e. well) containing a little water which the people used in small amounts, and in a short while the people used up all its water and complained to Allah's Messenger (ﷺ); of thirst. The Prophet (ﷺ) took an arrow out of his arrow-case and ordered them to put the arrow in that pit. By Allah, the water started and continued sprouting out till all the people quenched their thirst and returned with satisfaction. While they were still in that state, Budail bin Warqa-al- Khuza`i came with some persons from his tribe Khuza`a and they were the advisers of Allah's Messenger (ﷺ) who would keep no secret from him and were from the people of Tihama. Budail said, "I left Ka`b bin Luai and 'Amir bin Luai residing at the profuse water of Al-Hudaibiya and they had milch camels (or their women and children) with them, and will wage war against you, and will prevent you from visiting the Ka`ba." Allah's Messenger (ﷺ) said, "We have not come to fight anyone, but to perform the `Umra. No doubt, the war has weakened Quraish and they have suffered great losses, so if they wish, I will conclude a truce with them, during which they should refrain from interfering between me and the people (i.e. the 'Arab infidels other than Quraish), and if I have victory over those infidels, Quraish will have the option to embrace Islam as the other people do, if they wish; they will at least get strong enough to fight. But if they do not accept the truce, by Allah in Whose Hands my life is, I will fight with them defending my Cause till I get killed, but (I am sure) Allah will definitely make His Cause victorious." Budail said, "I will inform them of what you have said." So, he set off till he reached Quraish and said, "We have come from that man (i.e. Muhammad) whom we heard saying something which we will disclose to you if you should like." Some of the fools among Quraish shouted that they were not in need of this information, but the wiser among them said, "Relate what you heard him saying." Budail said, "I heard him saying so-and-so," relating what the Prophet (ﷺ) had told him. `Urwa bin Mas`ud got up and said, "O people! Aren't you the sons? They said, "Yes." He added, "Am I not the father?" They said, "Yes." He said, "Do you mistrust me?" They said, "No." He said, "Don't you know that I invited the people of `Ukaz for your help, and when they refused I brought my relatives and children and those who obeyed me (to help you)?" They said, "Yes." He said, "Well, this man (i.e. the Prophet) has offered you a reasonable proposal, you'd better accept it and allow me to meet him." They said, "You may meet him." So, he went to the Prophet (ﷺ) and started talking to him. The Prophet (ﷺ) told him almost the same as he had told Budail. Then `Urwa said, "O Muhammad! Won't you feel any scruple in extirpating your relations? Have you ever heard of anyone amongst the Arabs extirpating his relatives before you? On the other hand, if the reverse should happen, (nobody will aid you, for) by Allah, I do not see (with you) dignified people, but people from various tribes who would run away leaving you alone." Hearing that, Abu Bakr abused him and said, "Do you say we would run and leave the Prophet (ﷺ) alone?" `Urwa said, "Who is that man?" They said, "He is Abu Bakr." `Urwa said to Abu Bakr, "By Him in Whose Hands my life is, were it not for the favor which you did to me and which I did not compensate, I would retort on you." `Urwa kept on talking to the Prophet (ﷺ) and seizing the Prophet's beard as he was talking while Al-Mughira bin Shu`ba was standing near the head of the Prophet, holding a sword and wearing a helmet. Whenever `Urwa stretched his hand towards the beard of the Prophet, Al-Mughira would hit his hand with the handle of the sword and say (to `Urwa), "Remove your hand from the beard of Allah's Messenger (ﷺ)." `Urwa raised his head and asked, "Who is that?" The people said, "He is Al-Mughira bin Shu`ba." `Urwa said, "O treacherous! Am I not doing my best to prevent evil consequences of your treachery?" Before embracing Islam Al-Mughira was in the company of some people. He killed them and took their property and came (to Medina) to embrace Islam. The Prophet (ﷺ) said (to him, "As regards your Islam, I accept it, but as for the property I do not take anything of it (as it was taken through treason). `Urwa then started looking at the Companions of the Prophet. By Allah, whenever Allah's Messenger (ﷺ) spat, the spittle would fall in the hand of one of them (i.e. the Prophet's companions) who would rub it on his face and skin; if he ordered them they would carry his orders immediately; if he performed ablution, they would struggle to take the remaining water; and when they spoke to him, they would lower their voices and would not look at his face constantly out of respect. `Urwa returned to his people and said, "O people! By Allah, I have been to the kings and to Caesar, Khosrau and An- Najashi, yet I have never seen any of them respected by his courtiers as much as Muhammad is respected by his companions. By Allah, if he spat, the spittle would fall in the hand of one of them (i.e. the Prophet's companions) who would rub it on his face and skin; if he ordered them, they would carry out his order immediately; if he performed ablution, they would struggle to take the remaining water; and when they spoke, they would lower their voices and would not look at his face constantly out of respect." `Urwa added, "No doubt, he has presented to you a good reasonable offer, so please accept it." A man from the tribe of Bani Kinana said, "Allow me to go to him," and they allowed him, and when he approached the Prophet and his companions, Allah's Messenger (ﷺ) said, "He is so-and-so who belongs to the tribe that respects the Budn (i.e. camels of the sacrifice). So, bring the Budn in front of him." So, the Budn were brought before him and the people received him while they were reciting Talbiya. When he saw that scene, he said, "Glorified be Allah! It is not fair to prevent these people from visiting the Ka`ba." When he returned to his people, he said, 'I saw the Budn garlanded (with colored knotted ropes) and marked (with stabs on their backs). I do not think it is advisable to prevent them from visiting the Ka`ba." Another person called Mikraz bin Hafs got up and sought their permission to go to Muhammad, and they allowed him, too. When he approached the Muslims, the Prophet (ﷺ) said, "Here is Mikraz and he is a vicious man." Mikraz started talking to the Prophet and as he was talking, Suhail bin `Amr came. When Suhail bin `Amr came, the Prophet (ﷺ) said, "Now the matter has become easy." Suhail said to the Prophet "Please conclude a peace treaty with us." So, the Prophet (ﷺ) called the clerk and said to him, "Write: By the Name of Allah, the most Beneficent, the most Merciful." Suhail said, "As for 'Beneficent,' by Allah, I do not know what it means. So write: By Your Name O Allah, as you used to write previously." The Muslims said, "By Allah, we will not write except: By the Name of Allah, the most Beneficent, the most Merciful." The Prophet (ﷺ) said, "Write: By Your Name O Allah." Then he dictated, "This is the peace treaty which Muhammad, Allah's Messenger (ﷺ) has concluded." Suhail said, "By Allah, if we knew that you are Allah's Messenger (ﷺ) we would not prevent you from visiting the Ka`ba, and would not fight with you. So, write: "Muhammad bin `Abdullah." The Prophet (ﷺ) said, "By Allah! I am the Apostle of Allah even if you people do not believe me. Write: Muhammad bin `Abdullah." (Az-Zuhri said, "The Prophet (ﷺ) accepted all those things, as he had already said that he would accept everything they would demand if it respects the ordinance of Allah, (i.e. by letting him and his companions perform `Umra.)") The Prophet (ﷺ) said to Suhail, "On the condition that you allow us to visit the House (i.e. Ka`ba) so that we may perform Tawaf around it." Suhail said, "By Allah, we will not (allow you this year) so as not to give chance to the 'Arabs to say that we have yielded to you, but we will allow you next year." So, the Prophet (ﷺ) got that written. Then Suhail said, "We also stipulate that you should return to us whoever comes to you from us, even if he embraced your religion." The Muslims said, "Glorified be Allah! How will such a person be returned to the pagans after he has become a Muslim? While they were in this state Abu Jandal bin Suhail bin `Amr came from the valley of Mecca staggering with his fetters and fell down amongst the Muslims. Suhail said, "O Muhammad! This is the very first term with which we make peace with you, i.e. you shall return Abu Jandal to me." The Prophet (ﷺ) said, "The peace treaty has not been written yet." Suhail said, "I will never allow you to keep him." The Prophet (ﷺ) said, "Yes, do." He said, "I won't do." Mikraz said, "We allow you (to keep him)." Abu Jandal said, "O Muslims! Will I be returned to the pagans though I have come as a Muslim? Don't you see how much I have suffered?" Abu Jandal had been tortured severely for the Cause of Allah. `Umar bin Al-Khattab said, "I went to the Prophet (ﷺ) and said, 'Aren't you truly the Messenger of Allah?' The Prophet (ﷺ) said, 'Yes, indeed.' I said, 'Isn't our Cause just and the cause of the enemy unjust?' He said, 'Yes.' I said, 'Then why should we be humble in our religion?' He said, 'I am Allah's Messenger (ﷺ) and I do not disobey Him, and He will make me victorious.' I said, 'Didn't you tell us that we would go to the Ka`ba and perform Tawaf around it?' He said, 'Yes, but did I tell you that we would visit the Ka`ba this year?' I said, 'No.' He said, 'So you will visit it and perform Tawaf around it.' " `Umar further said, "I went to Abu Bakr and said, 'O Abu Bakr! Isn't he truly Allah's Prophet?' He replied, 'Yes.' I said, 'Then why should we be humble in our religion?' He said, 'Indeed, he is Allah's Messenger (ﷺ) and he does not disobey his Lord, and He will make him victorious. Adhere to him as, by Allah, he is on the right.' I said, 'Was he not telling us that we would go to the Ka`ba and perform Tawaf around it?' He said, 'Yes, but did he tell you that you would go to the Ka`ba this year?' I said, 'No.' He said, "You will go to Ka`ba and perform Tawaf around it." (Az-Zuhri said, " `Umar said, 'I performed many good deeds as expiation for the improper questions I asked them.' ") When the writing of the peace treaty was concluded, Allah's Messenger (ﷺ) said to his companions, "Get up and' slaughter your sacrifices and get your head shaved." By Allah none of them got up, and the Prophet repeated his order thrice. When none of them got up, he left them and went to Um Salama and told her of the people's attitudes towards him. Um Salama said, "O the Prophet of Allah (ﷺ)! Do you want your order to be carried out? Go out and don't say a word to anybody till you have slaughtered your sacrifice and call your barber to shave your head." So, the Prophet (ﷺ) went out and did not talk to anyone of them till he did that, i.e. slaughtered the sacrifice and called his barber who shaved his head. Seeing that, the companions of the Prophet (ﷺ) got up, slaughtered their sacrifices, and started shaving the heads of one another, and there was so much rush that there was a danger of killing each other. Then some believing women came (to the Prophet (ﷺ) ); and Allah revealed the following Divine Verses:-- "O you who believe, when the believing women come to you as emigrants examine them . . ." (60.10) `Umar then divorced two wives of his who were infidels. Later on Muawiya bin Abu Sufyan married one of them, and Safwan bin Umaiya married the other. When the Prophet (ﷺ) returned to Medina, Abu Basir, a new Muslim convert from Quraish came to him. The Infidels sent in his pursuit two men who said (to the Prophet (ﷺ) ), "Abide by the promise you gave us." So, the Prophet (ﷺ) handed him over to them. They took him out (of the City) till they reached Dhul-Hulaifa where they dismounted to eat some dates they had with them. Abu Basir said to one of them, "By Allah, O so-and-so, I see you have a fine sword." The other drew it out (of the scabbard) and said, "By Allah, it is very fine and I have tried it many times." Abu Basir said, "Let me have a look at it." When the other gave it to him, he hit him with it till he died, and his companion ran away till he came to Medina and entered the Mosque running. When Allah's Messenger (ﷺ) saw him he said, "This man appears to have been frightened." When he reached the Prophet (ﷺ) he said, "My companion has been murdered and I would have been murdered too." Abu Basir came and said, "O Allah's Messenger (ﷺ), by Allah, Allah has made you fulfill your obligations by your returning me to them (i.e. the Infidels), but Allah has saved me from them." The Prophet (ﷺ) said, "Woe to his mother! what excellent war kindler he would be, should he only have supporters." When Abu Basir heard that he understood that the Prophet (ﷺ) would return him to them again, so he set off till he reached the seashore. Abu Jandal bin Suhail got himself released from them (i.e. infidels) and joined Abu Basir. So, whenever a man from Quraish embraced Islam he would follow Abu Basir till they formed a strong group. By Allah, whenever they heard about a caravan of Quraish heading towards Sham, they stopped it and attacked and killed them (i.e. infidels) and took their properties. The people of Quraish sent a message to the Prophet (ﷺ) requesting him for the Sake of Allah and Kith and kin to send for (i.e. Abu Basir and his companions) promising that whoever (amongst them) came to the Prophet (ﷺ) would be secure. So the Prophet (ﷺ) sent for them (i.e. Abu Basir's companions) and Allah revealed the following Divine Verses: "And it is He Who Has withheld their hands from you and your hands From them in the midst of Mecca, After He made you the victorious over them. ... the unbelievers had pride and haughtiness, in their hearts ... the pride and haughtiness of the time of ignorance." (48.24-26) And their pride and haughtiness was that they did not confess (write in the treaty) that he (i.e. Muhammad) was the Prophet of Allah and refused to write: "In the Name of Allah, the most Beneficent, the Most Merciful," and they (the mushriks) prevented them (the Muslims) from visiting the House (the Ka`bah)}}
\hadithdefcmd{bukhari}{2789}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، فَتُطْعِمُهُ، وَكَانَتْ أُمُّ حَرَامٍ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ، فَدَخَلَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَطْعَمَتْهُ وَجَعَلَتْ تَفْلِي رَأْسَهُ، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ‏.‏ قَالَتْ فَقُلْتُ وَمَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ، يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ، مُلُوكًا عَلَى الأَسِرَّةِ، أَوْ مِثْلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ شَكَّ إِسْحَاقُ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَدَعَا لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ وَضَعَ رَأْسَهُ، ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ فَقُلْتُ وَمَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ كَمَا قَالَ فِي الأَوَّلِ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏‏.‏ فَرَكِبَتِ الْبَحْرَ فِي زَمَانِ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ، فَهَلَكَتْ‏.‏\hadithno{2789}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) used to visit Umm Haram bint Milhan, who would offer him meals. Umm Haram was the wife of Ubada bin As-Samit. Allah's Messenger (ﷺ), once visited her and she provided him with food and started looking for lice in his head. Then Allah's Messenger (ﷺ) slept, and afterwards woke up smiling. Umm Haram asked, "What causes you to smile, O Allah's Messenger (ﷺ)?" He said. "Some of my followers who (in a dream) were presented before me as fighters in Allah's cause (on board a ship) amidst this sea caused me to smile; they were as kings on the thrones (or like kings on the thrones)." (Ishaq, a sub-narrator is not sure as to which expression the Prophet (ﷺ) used.) Umm Haram said, "O Allah's Messenger (ﷺ)! Invoke Allah that he makes me one of them. Allah's Messenger (ﷺ) invoked Allah for her and slept again and woke up smiling. Once again Umm Haram asked, "What makes you smile, O Allah's Messenger (ﷺ)?" He replied, "Some of my followers were presented to me as fighters in Allah's Cause," repeating the same dream. Umm Haram said, "O Allah's Messenger (ﷺ)! Invoke Allah that He makes me one of them." He said, "You are amongst the first ones." It happened that she sailed on the sea during the Caliphate of Mu'awiya bin Abi Sufyan, and after she disembarked, she fell down from her riding animal and died}}
\hadithdefcmd{bukhari}{2800}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنِي اللَّيْثُ، حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ خَالَتِهِ أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، قَالَتْ نَامَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا قَرِيبًا مِنِّي، ثُمَّ اسْتَيْقَظَ يَتَبَسَّمُ‏.‏ فَقُلْتُ مَا أَضْحَكَكَ قَالَ ‏"‏ أُنَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ يَرْكَبُونَ هَذَا الْبَحْرَ الأَخْضَرَ، كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ قَالَتْ فَادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَدَعَا لَهَا، ثُمَّ نَامَ الثَّانِيَةَ، فَفَعَلَ مِثْلَهَا، فَقَالَتْ مِثْلَ قَوْلِهَا، فَأَجَابَهَا مِثْلَهَا‏.‏ فَقَالَتِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَقَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏‏.‏ فَخَرَجَتْ مَعَ زَوْجِهَا عُبَادَةَ بْنِ الصَّامِتِ غَازِيًا أَوَّلَ مَا رَكِبَ الْمُسْلِمُونَ الْبَحْرَ مَعَ مُعَاوِيَةَ، فَلَمَّا انْصَرَفُوا مِنْ غَزْوِهِمْ قَافِلِينَ فَنَزَلُوا الشَّأْمَ، فَقُرِّبَتْ إِلَيْهَا دَابَّةٌ لِتَرْكَبَهَا فَصَرَعَتْهَا فَمَاتَتْ‏.‏\hadithno{2800}\hadithtrans{Narrated Anas bin Malik:Um Haram said, "Once the Prophet (ﷺ) slept in my house near to me and got up smiling. I said, 'What makes you smile?' He replied, 'Some of my followers who (i.e. in a dream) were presented to me sailing on this green sea like kings on thrones.' I said, 'O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." So the Prophet (ﷺ) invoked Allah for her and went to sleep again. He did the same (i.e. got up and told his dream) and Um Haram repeated her question and he gave the same reply. She said, "Invoke Allah to make me one of them." He said, "You are among the first batch." Later on it happened that she went out in the company of her husband 'Ubada bin As-Samit who went for Jihad and it was the first time the Muslims undertook a naval expedition led by Mu'awiya. When the expedition came to an end and they were returning to Sham, a riding animal was presented to her to ride, but the animal let her fall and thus she died}}
\hadithdefcmd{bukhari}{2805}{حَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدٍ الْخُزَاعِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ حُمَيْدٍ، قَالَ سَأَلْتُ أَنَسًا‏.‏ حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، حَدَّثَنَا زِيَادٌ، قَالَ حَدَّثَنِي حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ غَابَ عَمِّي أَنَسُ بْنُ النَّضْرِ عَنْ قِتَالِ بَدْرٍ فَقَالَ يَا رَسُولَ اللَّهِ، غِبْتُ عَنْ أَوَّلِ قِتَالٍ قَاتَلْتَ الْمُشْرِكِينَ، لَئِنِ اللَّهُ أَشْهَدَنِي قِتَالَ الْمُشْرِكِينَ لَيَرَيَنَّ اللَّهُ مَا أَصْنَعُ، فَلَمَّا كَانَ يَوْمُ أُحُدٍ وَانْكَشَفَ الْمُسْلِمُونَ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أَعْتَذِرُ إِلَيْكَ مِمَّا صَنَعَ هَؤُلاَءِ ـ يَعْنِي أَصْحَابَهُ ـ وَأَبْرَأُ إِلَيْكَ مِمَّا صَنَعَ هَؤُلاَءِ ‏"‏ ـ يَعْنِي الْمُشْرِكِينَ ـ ثُمَّ تَقَدَّمَ، فَاسْتَقْبَلَهُ سَعْدُ بْنُ مُعَاذٍ، فَقَالَ يَا سَعْدُ بْنَ مُعَاذٍ، الْجَنَّةَ، وَرَبِّ النَّضْرِ إِنِّي أَجِدُ رِيحَهَا مِنْ دُونِ أُحُدٍ‏.‏ قَالَ سَعْدٌ فَمَا اسْتَطَعْتُ يَا رَسُولَ اللَّهِ مَا صَنَعَ‏.‏ قَالَ أَنَسٌ فَوَجَدْنَا بِهِ بِضْعًا وَثَمَانِينَ ضَرْبَةً بِالسَّيْفِ أَوْ طَعْنَةً بِرُمْحٍ أَوْ رَمْيَةً بِسَهْمٍ، وَوَجَدْنَاهُ قَدْ قُتِلَ وَقَدْ مَثَّلَ بِهِ الْمُشْرِكُونَ، فَمَا عَرَفَهُ أَحَدٌ إِلاَّ أُخْتُهُ بِبَنَانِهِ‏.‏ قَالَ أَنَسٌ كُنَّا نَرَى أَوْ نَظُنُّ أَنَّ هَذِهِ الآيَةَ نَزَلَتْ فِيهِ وَفِي أَشْبَاهِهِ ‏\{‏مِنَ الْمُؤْمِنِينَ رِجَالٌ صَدَقُوا مَا عَاهَدُوا اللَّهَ عَلَيْهِ‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏ وَقَالَ إِنَّ أُخْتَهُ وَهْىَ تُسَمَّى الرُّبَيِّعَ كَسَرَتْ ثَنِيَّةَ امْرَأَةٍ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْقِصَاصِ، فَقَالَ أَنَسٌ يَا رَسُولَ اللَّهِ، وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ تُكْسَرُ ثَنِيَّتُهَا‏.‏ فَرَضُوا بِالأَرْشِ وَتَرَكُوا الْقِصَاصَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏‏.‏\hadithno{2805}\hadithtrans{Narrated Anas:My uncle Anas bin An-Nadr was absent from the Battle of Badr. He said, "O Allah's Messenger (ﷺ)! I was absent from the first battle you fought against the pagans. (By Allah) if Allah gives me a chance to fight the pagans, no doubt. Allah will see how (bravely) I will fight." On the day of Uhud when the Muslims turned their backs and fled, he said, "O Allah! I apologize to You for what these (i.e. his companions) have done, and I denounce what these (i.e. the pagans) have done." Then he advanced and Sa`d bin Mu`adh met him. He said "O Sa`d bin Mu`adh ! By the Lord of An-Nadr, Paradise! I am smelling its aroma coming from before (the mountain of) Uhud," Later on Sa`d said, "O Allah's Apostle! I cannot achieve or do what he (i.e. Anas bin An-Nadr) did. We found more than eighty wounds by swords and arrows on his body. We found him dead and his body was mutilated so badly that none except his sister could recognize him by his fingers." We used to think that the following Verse was revealed concerning him and other men of his sort: "Among the believers are men who have been true to their covenant with Allah.........." (33.23) His sister Ar-Rubbaya' broke a front tooth of a woman and Allah's Messenger (ﷺ) ordered for retaliation. On that Anas (bin An-Nadr) said, "O Allah's Messenger (ﷺ)! By Him Who has sent you with the Truth, my sister's tooth shall not be broken." Then the opponents of Anas's sister accepted the compensation and gave up the claim of retaliation. So Allah's Messenger (ﷺ) said, "There are some people amongst Allah's slaves whose oaths are fulfilled by Allah when they take them}}
\hadithdefcmd{bukhari}{2878}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ الأَنْصَارِيِّ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ابْنَةِ مِلْحَانَ فَاتَّكَأَ عِنْدَهَا، ثُمَّ ضَحِكَ فَقَالَتْ لِمَ تَضْحَكُ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي يَرْكَبُونَ الْبَحْرَ الأَخْضَرَ فِي سَبِيلِ اللَّهِ، مَثَلُهُمْ مَثَلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اجْعَلْهَا مِنْهُمْ ‏"‏‏.‏ ثُمَّ عَادَ فَضَحِكَ، فَقَالَتْ لَهُ مِثْلَ أَوْ مِمَّ ذَلِكَ فَقَالَ لَهَا مِثْلَ ذَلِكَ، فَقَالَتِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ، وَلَسْتِ مِنَ الآخِرِينَ ‏"‏‏.‏ قَالَ قَالَ أَنَسٌ فَتَزَوَّجَتْ عُبَادَةَ بْنَ الصَّامِتِ، فَرَكِبَتِ الْبَحْرَ مَعَ بِنْتِ قَرَظَةَ، فَلَمَّا قَفَلَتْ رَكِبَتْ دَابَّتَهَا فَوَقَصَتْ بِهَا، فَسَقَطَتْ عَنْهَا فَمَاتَتْ‏.‏\hadithno{2878}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) went to the daughter of Milhan and reclined there (and slept) and then (woke up) smiling. She asked, "O Allah's Messenger (ﷺ)! What makes you smile?" He replied, (I dreamt that) some people amongst my followers were sailing on the green sea in Allah's Cause, resembling kings on thrones." She said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." He said, "O Allah! Let her be one of them." Then he (slept again and woke up and) smiled. She asked him the same question and he gave the same reply. She said, "Invoke Allah to make me one of them." He replied, ''You will be amongst the first group of them; you will not be amongst the last." Later on she married 'Ubada bin As-Samit and then she sailed on the sea with bint Qaraza, Mu'awiya's wife (for Jihad). On her return, she mounted her riding animal, which threw her down breaking her neck, and she died on falling down}}
\hadithdefcmd{bukhari}{2895}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ حَدَّثَتْنِي أُمُّ حَرَامٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ يَوْمًا فِي بَيْتِهَا، فَاسْتَيْقَظَ وَهْوَ يَضْحَكُ، قَالَتْ يَا رَسُولَ اللَّهِ، مَا يُضْحِكُكَ قَالَ ‏"‏ عَجِبْتُ مِنْ قَوْمٍ مِنْ أُمَّتِي يَرْكَبُونَ الْبَحْرَ، كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَقَالَ ‏"‏ أَنْتِ مَعَهُمْ ‏"‏‏.‏ ثُمَّ نَامَ، فَاسْتَيْقَظَ وَهْوَ يَضْحَكُ فَقَالَ مِثْلَ ذَلِكَ مَرَّتَيْنِ أَوْ ثَلاَثًا‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَيَقُولُ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ فَتَزَوَّجَ بِهَا عُبَادَةُ بْنُ الصَّامِتِ، فَخَرَجَ بِهَا إِلَى الْغَزْوِ، فَلَمَّا رَجَعَتْ قُرِّبَتْ دَابَّةٌ لِتَرْكَبَهَا، فَوَقَعَتْ فَانْدَقَّتْ عُنُقُهَا‏.‏\hadithno{2895}\hadithtrans{Narrated Anas bin Malik:Um Haram told me that the Prophet (ﷺ) one day took a midday nap in her house. Then he woke up smiling. Um Haram asked, "O Allah's Messenger (ﷺ)! What makes you smile?" He replied "I was astonished to see (in my dream) some people amongst my followers on a sea-voyage looking like kings on the thrones." She said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." He replied, "You are amongst them." He slept again and then woke up smiling and said the same as before twice or thrice. And she said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." And he said, "You are amongst the first batch." 'Ubada bin As-Samit married her (i.e. Um Haram) and then he took her for Jihad. When she returned, an animal was presented to her to ride, but she fell down and her neck was broken}}
\hadithdefcmd{bukhari}{2906}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ عَمْرٌو حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي جَارِيَتَانِ تُغَنِّيَانِ بِغِنَاءِ بُعَاثَ، فَاضْطَجَعَ عَلَى الْفِرَاشِ وَحَوَّلَ وَجْهَهُ، فَدَخَلَ أَبُو بَكْرٍ فَانْتَهَرَنِي وَقَالَ مِزْمَارَةُ الشَّيْطَانِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَأَقْبَلَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ دَعْهُمَا ‏"‏‏.‏ فَلَمَّا غَفَلَ غَمَزْتُهُمَا فَخَرَجَتَا‏.‏ قَالَتْ وَكَانَ يَوْمُ عِيدٍ يَلْعَبُ السُّودَانُ بِالدَّرَقِ وَالْحِرَابِ، فَإِمَّا سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَإِمَّا قَالَ ‏"‏ تَشْتَهِينَ تَنْظُرِينَ ‏"‏‏.‏ فَقَالَتْ نَعَمْ‏.‏ فَأَقَامَنِي وَرَاءَهُ خَدِّي عَلَى خَدِّهِ وَيَقُولُ ‏"‏ دُونَكُمْ بَنِي أَرْفِدَةَ ‏"‏‏.‏ حَتَّى إِذَا مَلِلْتُ قَالَ ‏"‏ حَسْبُكِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَاذْهَبِي ‏"‏‏.‏ قَالَ أَحْمَدُ عَنِ ابْنِ وَهْبٍ، فَلَمَّا غَفَلَ‏.‏\hadithno{2906}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) came to my house while two girls were singing beside me the songs of Bu'ath (a story about the war between the two tribes of the Ansar, i.e. Khazraj and Aus, before Islam.) The Prophet (ﷺ) reclined on the bed and turned his face to the other side. Abu Bakr came and scolded me and said protestingly, "Instrument of Satan in the presence of Allah's Messenger (ﷺ)?" Allah's Messenger (ﷺ) turned his face towards him and said, "Leave them." When Abu Bakr became inattentive, I waved the two girls to go away and they left. It was the day of `Id when negroes used to play with leather shields and spears. Either I requested Allah's Messenger (ﷺ) or he himself asked me whether I would like to see the display. I replied in the affirmative. Then he let me stand behind him and my cheek was touching his cheek and he was saying, "Carry on, O Bani Arfida (i.e. negroes)!" When I got tired, he asked me if that was enough. I replied in the affirmative and he told me to leave}}
\hadithdefcmd{bukhari}{2940}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَى قَيْصَرَ يَدْعُوهُ إِلَى الإِسْلاَمِ، وَبَعَثَ بِكِتَابِهِ إِلَيْهِ مَعَ دِحْيَةَ الْكَلْبِيِّ، وَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَدْفَعَهُ إِلَى عَظِيمِ بُصْرَى لِيَدْفَعَهُ إِلَى قَيْصَرَ، وَكَانَ قَيْصَرُ لَمَّا كَشَفَ اللَّهُ عَنْهُ جُنُودَ فَارِسَ مَشَى مِنْ حِمْصَ إِلَى إِيلِيَاءَ، شُكْرًا لِمَا أَبْلاَهُ اللَّهُ، فَلَمَّا جَاءَ قَيْصَرَ كِتَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ حِينَ قَرَأَهُ الْتَمِسُوا لِي هَا هُنَا أَحَدًا مِنْ قَوْمِهِ لأَسْأَلَهُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ ابْنُ عَبَّاسٍ فَأَخْبَرَنِي أَبُو سُفْيَانَ، أَنَّهُ كَانَ بِالشَّأْمِ فِي رِجَالٍ مِنْ قُرَيْشٍ، قَدِمُوا تِجَارًا فِي الْمُدَّةِ الَّتِي كَانَتْ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ كُفَّارِ قُرَيْشٍ، قَالَ أَبُو سُفْيَانَ فَوَجَدَنَا رَسُولُ قَيْصَرَ بِبَعْضِ الشَّأْمِ فَانْطَلَقَ بِي وَبِأَصْحَابِي حَتَّى قَدِمْنَا إِيلِيَاءَ، فَأُدْخِلْنَا عَلَيْهِ، فَإِذَا هُوَ جَالِسٌ فِي مَجْلِسِ مُلْكِهِ وَعَلَيْهِ التَّاجُ، وَإِذَا حَوْلَهُ عُظَمَاءُ الرُّومِ فَقَالَ لِتُرْجُمَانِهِ سَلْهُمْ أَيُّهُمْ أَقْرَبُ نَسَبًا إِلَى هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ قَالَ أَبُو سُفْيَانَ فَقُلْتُ أَنَا أَقْرَبُهُمْ نَسَبًا‏.‏ قَالَ مَا قَرَابَةُ مَا بَيْنَكَ وَبَيْنَهُ فَقُلْتُ هُوَ ابْنُ عَمِّي، وَلَيْسَ فِي الرَّكْبِ يَوْمَئِذٍ أَحَدٌ مِنْ بَنِي عَبْدِ مَنَافٍ غَيْرِي‏.‏ فَقَالَ قَيْصَرُ أَدْنُوهُ‏.‏ وَأَمَرَ بِأَصْحَابِي فَجُعِلُوا خَلْفَ ظَهْرِي عِنْدَ كَتِفِي، ثُمَّ قَالَ لِتُرْجُمَانِهِ قُلْ لأَصْحَابِهِ إِنِّي سَائِلٌ هَذَا الرَّجُلَ عَنِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ، فَإِنْ كَذَبَ فَكَذِّبُوهُ‏.‏ قَالَ أَبُو سُفْيَانَ وَاللَّهِ لَوْلاَ الْحَيَاءُ يَوْمَئِذٍ مِنْ أَنْ يَأْثُرَ أَصْحَابِي عَنِّي الْكَذِبَ لَكَذَبْتُهُ حِينَ سَأَلَنِي عَنْهُ، وَلَكِنِّي اسْتَحْيَيْتُ أَنْ يَأْثُرُوا الْكَذِبَ عَنِّي فَصَدَقْتُهُ، ثُمَّ قَالَ لِتُرْجُمَانِهِ قُلْ لَهُ كَيْفَ نَسَبُ هَذَا الرَّجُلِ فِيكُمْ قُلْتُ هُوَ فِينَا ذُو نَسَبٍ‏.‏ قَالَ فَهَلْ قَالَ هَذَا الْقَوْلَ أَحَدٌ مِنْكُمْ قَبْلَهُ قُلْتُ لاَ‏.‏ فَقَالَ كُنْتُمْ تَتَّهِمُونَهُ عَلَى الْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ قُلْتُ لاَ‏.‏ قَالَ فَهَلْ كَانَ مِنْ آبَائِهِ مِنْ مَلِكٍ قُلْتُ لاَ‏.‏ قَالَ فَأَشْرَافُ النَّاسِ يَتَّبِعُونَهُ أَمْ ضُعَفَاؤُهُمْ قُلْتُ بَلْ ضُعَفَاؤُهُمْ‏.‏ قَالَ فَيَزِيدُونَ أَوْ يَنْقُصُونَ قُلْتُ بَلْ يَزِيدُونَ‏.‏ قَالَ فَهَلْ يَرْتَدُّ أَحَدٌ سَخْطَةً لِدِينِهِ بَعْدَ أَنْ يَدْخُلَ فِيهِ قُلْتُ لاَ‏.‏ قَالَ فَهَلْ يَغْدِرُ قُلْتُ لاَ، وَنَحْنُ الآنَ مِنْهُ فِي مُدَّةٍ، نَحْنُ نَخَافُ أَنْ يَغْدِرَ‏.‏ قَالَ أَبُو سُفْيَانَ وَلَمْ يُمْكِنِّي كَلِمَةٌ أُدْخِلُ فِيهَا شَيْئًا أَنْتَقِصُهُ بِهِ لاَ أَخَافُ أَنْ تُؤْثَرَ عَنِّي غَيْرُهَا‏.‏ قَالَ فَهَلْ قَاتَلْتُمُوهُ أَوْ قَاتَلَكُمْ قُلْتُ نَعَمْ‏.‏ قَالَ فَكَيْفَ كَانَتْ حَرْبُهُ وَحَرْبُكُمْ قُلْتُ كَانَتْ دُوَلاً وَسِجَالاً، يُدَالُ عَلَيْنَا الْمَرَّةَ وَنُدَالُ عَلَيْهِ الأُخْرَى‏.‏ قَالَ فَمَاذَا يَأْمُرُكُمْ قَالَ يَأْمُرُنَا أَنْ نَعْبُدَ اللَّهَ وَحْدَهُ لاَ نُشْرِكُ بِهِ شَيْئًا، وَيَنْهَانَا عَمَّا كَانَ يَعْبُدُ آبَاؤُنَا، وَيَأْمُرُنَا بِالصَّلاَةِ وَالصَّدَقَةِ وَالْعَفَافِ وَالْوَفَاءِ بِالْعَهْدِ وَأَدَاءِ الأَمَانَةِ‏.‏ فَقَالَ لِتُرْجُمَانِهِ حِينَ قُلْتُ ذَلِكَ لَهُ قُلْ لَهُ إِنِّي سَأَلْتُكَ عَنْ نَسَبِهِ فِيكُمْ، فَزَعَمْتَ أَنَّهُ ذُو نَسَبٍ، وَكَذَلِكَ الرُّسُلُ تُبْعَثُ فِي نَسَبِ قَوْمِهَا، وَسَأَلْتُكَ هَلْ قَالَ أَحَدٌ مِنْكُمْ هَذَا الْقَوْلَ قَبْلَهُ فَزَعَمْتَ أَنْ لاَ، فَقُلْتُ لَوْ كَانَ أَحَدٌ مِنْكُمْ قَالَ هَذَا الْقَوْلَ قَبْلَهُ قُلْتُ رَجُلٌ يَأْتَمُّ بِقَوْلٍ قَدْ قِيلَ قَبْلَهُ‏.‏ وَسَأَلْتُكَ هَلْ كُنْتُمْ تَتَّهِمُونَهُ بِالْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ فَزَعَمْتَ أَنْ لاَ، فَعَرَفْتُ أَنَّهُ لَمْ يَكُنْ لِيَدَعَ الْكَذِبَ عَلَى النَّاسِ وَيَكْذِبَ عَلَى اللَّهِ، وَسَأَلْتُكَ هَلْ كَانَ مِنْ آبَائِهِ مِنْ مَلِكٍ فَزَعَمْتَ أَنْ لاَ، فَقُلْتُ لَوْ كَانَ مِنْ آبَائِهِ مَلِكٌ قُلْتُ يَطْلُبُ مُلْكَ آبَائِهِ‏.‏ وَسَأَلْتُكَ أَشْرَافُ النَّاسِ يَتَّبِعُونَهُ أَمْ ضُعَفَاؤُهُمْ فَزَعَمْتَ أَنَّ ضُعَفَاءَهُمُ اتَّبَعُوهُ، وَهُمْ أَتْبَاعُ الرُّسُلِ، وَسَأَلْتُكَ هَلْ يَزِيدُونَ أَوْ يَنْقُصُونَ فَزَعَمْتَ أَنَّهُمْ يَزِيدُونَ، وَكَذَلِكَ الإِيمَانُ حَتَّى يَتِمَّ، وَسَأَلْتُكَ هَلْ يَرْتَدُّ أَحَدٌ سَخْطَةً لِدِينِهِ بَعْدَ أَنْ يَدْخُلَ فِيهِ فَزَعَمْتَ أَنْ لاَ، فَكَذَلِكَ الإِيمَانُ حِينَ تَخْلِطُ بَشَاشَتُهُ الْقُلُوبَ لاَ يَسْخَطُهُ أَحَدٌ، وَسَأَلْتُكَ هَلْ يَغْدِرُ فَزَعَمْتَ أَنْ لاَ، وَكَذَلِكَ الرُّسُلُ لاَ يَغْدِرُونَ‏.‏ وَسَأَلْتُكَ هَلْ قَاتَلْتُمُوهُ وَقَاتَلَكُمْ فَزَعَمْتَ أَنْ قَدْ فَعَلَ، وَأَنَّ حَرْبَكُمْ وَحَرْبَهُ تَكُونُ دُوَلاً، وَيُدَالُ عَلَيْكُمُ الْمَرَّةَ وَتُدَالُونَ عَلَيْهِ الأُخْرَى، وَكَذَلِكَ الرُّسُلُ تُبْتَلَى، وَتَكُونُ لَهَا الْعَاقِبَةُ، وَسَأَلْتُكَ بِمَاذَا يَأْمُرُكُمْ فَزَعَمْتَ أَنَّهُ يَأْمُرُكُمْ أَنْ تَعْبُدُوا اللَّهَ وَلاَ تُشْرِكُوا بِهِ شَيْئًا، وَيَنْهَاكُمْ عَمَّا كَانَ يَعْبُدُ آبَاؤُكُمْ، وَيَأْمُرُكُمْ بِالصَّلاَةِ وَالصِّدْقِ وَالْعَفَافِ وَالْوَفَاءِ بِالْعَهْدِ، وَأَدَاءِ الأَمَانَةِ، قَالَ وَهَذِهِ صِفَةُ النَّبِيِّ، قَدْ كُنْتُ أَعْلَمُ أَنَّهُ خَارِجٌ، وَلَكِنْ لَمْ أَظُنَّ أَنَّهُ مِنْكُمْ، وَإِنْ يَكُ مَا قُلْتَ حَقًّا، فَيُوشِكُ أَنْ يَمْلِكَ مَوْضِعَ قَدَمَىَّ هَاتَيْنِ، وَلَوْ أَرْجُو أَنْ أَخْلُصَ إِلَيْهِ لَتَجَشَّمْتُ لُقِيَّهُ، وَلَوْ كُنْتُ عِنْدَهُ لَغَسَلْتُ قَدَمَيْهِ‏.‏ قَالَ أَبُو سُفْيَانَ ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُرِئَ فَإِذَا فِيهِ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ عَبْدِ اللَّهِ وَرَسُولِهِ، إِلَى هِرَقْلَ عَظِيمِ الرُّومِ، سَلاَمٌ عَلَى مَنِ اتَّبَعَ الْهُدَى، أَمَّا بَعْدُ فَإِنِّي أَدْعُوكَ بِدِعَايَةِ الإِسْلاَمِ، أَسْلِمْ تَسْلَمْ، وَأَسْلِمْ يُؤْتِكَ اللَّهُ أَجْرَكَ مَرَّتَيْنِ، فَإِنْ تَوَلَّيْتَ فَعَلَيْكَ إِثْمُ الأَرِيسِيِّينَ وَ‏\{‏يَا أَهْلَ الْكِتَابِ تَعَالَوْا إِلَى كَلِمَةٍ سَوَاءٍ بَيْنَنَا وَبَيْنَكُمْ أَنْ لاَ نَعْبُدَ إِلاَّ اللَّهَ وَلاَ نُشْرِكَ بِهِ شَيْئًا وَلاَ يَتَّخِذَ بَعْضُنَا بَعْضًا أَرْبَابًا مِنْ دُونِ اللَّهِ فَإِنْ تَوَلَّوْا فَقُولُوا اشْهَدُوا بِأَنَّا مُسْلِمُونَ‏\}‏‏"‏‏.‏ قَالَ أَبُو سُفْيَانَ فَلَمَّا أَنْ قَضَى مَقَالَتَهُ، عَلَتْ أَصْوَاتُ الَّذِينَ حَوْلَهُ مِنْ عُظَمَاءِ الرُّومِ، وَكَثُرَ لَغَطُهُمْ، فَلاَ أَدْرِي مَاذَا قَالُوا، وَأُمِرَ بِنَا فَأُخْرِجْنَا، فَلَمَّا أَنْ خَرَجْتُ مَعَ أَصْحَابِي وَخَلَوْتُ بِهِمْ قُلْتُ لَهُمْ لَقَدْ أَمِرَ أَمْرُ ابْنِ أَبِي كَبْشَةَ، هَذَا مَلِكُ بَنِي الأَصْفَرِ يَخَافُهُ، قَالَ أَبُو سُفْيَانَ وَاللَّهِ مَا زِلْتُ ذَلِيلاً مُسْتَيْقِنًا بِأَنَّ أَمْرَهُ سَيَظْهَرُ، حَتَّى أَدْخَلَ اللَّهُ قَلْبِي الإِسْلاَمَ وَأَنَا كَارِهٌ‏.‏\hadithno{2940}\hadithtrans{Narrated `Abdullah bin `Abbas:Allah's Messenger (ﷺ) wrote to Caesar and invited him to Islam and sent him his letter with Dihya Al-Kalbi whom Allah's Messenger (ﷺ) ordered to hand it over to the Governor of Busra who would forward it to Caesar. Caesar as a sign of gratitude to Allah, had walked from Hims to Ilya (i.e. Jerusalem) when Allah had granted Him victory over the Persian forces. So, when the letter of Allah's Messenger (ﷺ) reached Caesar, he said after reading it, 'Seek for me any one of his people! (Arabs of Quraish tribe) if present here, in order to ask him about Allah's Messenger (ﷺ). At that time Abu Sufyan bin Harb was in Sham with some men from Quraish who had come (to Sham) as merchants during the truce that had been concluded between Allah's Messenger (ﷺ); and the infidels of Quraish. Abu Sufyan said, Caesar's messenger found us somewhere in Sham so he took me and my companions to Ilya and we were admitted into Caesar's court to find him sitting in his royal court wearing a crown and surrounded by the senior dignitaries of the Byzantine. He said to his translator. 'Ask them who amongst them is a close relation to the man who claims to be a prophet." Abu Sufyan added, "I replied, 'I am the nearest relative to him.' He asked, 'What degree of relationship do you have with him?' I replied, 'He is my cousin,' and there was none of Bani Abu Manaf in the caravan except myself. Caesar said, 'Let him come nearer.' He then ordered that my companions stand behind me near my shoulder and said to his translator, 'Tell his companions that I am going to ask this man about the man who claims to be a prophet. If he tells a lie, they should contradict him immediately." Abu Sufyan added, "By Allah! Had it not been shameful that my companions label me a liar, I would not have spoken the truth about him when he asked me. But I considered it shameful to be called a liar by my companions. So I told the truth. He then said to his translator, 'Ask him what kind of family does he belong to.' I replied, 'He belongs to a noble family amongst us.' He said, 'Has anybody else amongst you ever claimed the same before him? 'I replied, 'No.' He said, 'Had you ever blamed him for telling lies before he claimed what he claimed? ' I replied, 'No.' He said, 'Was anybody amongst his ancestors a king?' I replied, 'No.' He said, "Do the noble or the poor follow him?' I replied, 'It is the poor who follow him.' He said, 'Are they increasing or decreasing (day by day)?' I replied,' They are increasing.' He said, 'Does anybody amongst those who embrace his (the Prophet's) Religion become displeased and then discard his Religion?'. I replied, 'No. ' He said, 'Does he break his promises? I replied, 'No, but we are now at truce with him and we are afraid that he may betray us." Abu Sufyan added, "Other than the last sentence, I could not say anything against him. Caesar then asked, 'Have you ever had a war with him?' I replied, 'Yes.' He said, 'What was the outcome of your battles with him?' I replied, 'The result was unstable; sometimes he was victorious and sometimes we.' He said, 'What does he order you to do?' I said, 'He tells us to worship Allah alone, and not to worship others along with Him, and to leave all that our fore-fathers used to worship. He orders us to pray, give in charity, be chaste, keep promises and return what is entrusted to us.' When I had said that, Caesar said to his translator, 'Say to him: I asked you about his lineage and your reply was that he belonged to a noble family. In fact, all the apostles came from the noblest lineage of their nations. Then I questioned you whether anybody else amongst you had claimed such a thing, and your reply was in the negative. If the answer had been in the affirmative, I would have thought that this man was following a claim that had been said before him. When I asked you whether he was ever blamed for telling lies, your reply was in the negative, so I took it for granted that a person who did not tell a lie about (others) the people could never tell a lie about Allah. Then I asked you whether any of his ancestors was a king. Your reply was in the negative, and if it had been in the affirmative, I would have thought that this man wanted to take back his ancestral kingdom. When I asked you whether the rich or the poor people followed him, you replied that it was the poor who followed him. In fact, such are the followers of the apostles. Then I asked you whether his followers were increasing or decreasing. You replied that they were increasing. In fact, this is the result of true faith till it is complete (in all respects). I asked you whether there was anybody who, after embracing his religion, became displeased and discarded his religion; your reply was in the negative. In fact, this is the sign of true faith, for when its cheerfulness enters and mixes in the hearts completely, nobody will be displeased with it. I asked you whether he had ever broken his promise. You replied in the negative. And such are the apostles; they never break their promises. When I asked you whether you fought with him and he fought with you, you replied that he did, and that sometimes he was victorious and sometimes you. Indeed, such are the apostles; they are put to trials and the final victory is always theirs. Then I asked you what he ordered you. You replied that he ordered you to worship Allah alone and not to worship others along with Him, to leave all that your fore-fathers used to worship, to offer prayers, to speak the truth, to be chaste, to keep promises, and to return what is entrusted to you. These are really the qualities of a prophet who, I knew (from the previous Scriptures) would appear, but I did not know that he would be from amongst you. If what you say should be true, he will very soon occupy the earth under my feet, and if I knew that I would reach him definitely, I would go immediately to meet Him; and were I with him, then I would certainly wash his feet.' " Abu Sufyan added, "Caesar then asked for the letter of Allah's Messenger (ﷺ) and it was read. Its contents were: "In the name of Allah, the most Beneficent, the most Merciful (This letter is) from Muhammad, the slave of Allah, and His Apostle, to Heraclius, the Ruler of the Byzantine. Peace be upon the followers of guidance. Now then, I invite you to Islam (i.e. surrender to Allah), embrace Islam and you will be safe; embrace Islam and Allah will bestow on you a double reward. But if you reject this invitation of Islam, you shall be responsible for misguiding the tillers (i.e. your nation). O people of the Scriptures! Come to a word common to you and us and you, that we worship none but Allah, and that we associate nothing in worship with Him; and that none of us shall take others as Lords besides Allah. Then if they turn away, say: Bear witness that we are (they who have surrendered (unto Him)..(3.64) Abu Sufyan added, "When Heraclius had finished his speech, there was a great hue and cry caused by the Byzantine Royalties surrounding him, and there was so much noise that I did not understand what they said. So, we were turned out of the court. When I went out with my companions and we were alone, I said to them, 'Verily, Ibn Abi Kabsha's (i.e. the Prophet's) affair has gained power. This is the King of Bani Al-Asfar fearing him." Abu Sufyan added, "By Allah, I remained low and was sure that his religion would be victorious till Allah converted me to Islam, though I disliked it}}
\hadithdefcmd{bukhari}{2956}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ ‏"‏‏.‏ وَبِهَذَا الإِسْنَادِ ‏"‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ، وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ، وَمَنْ يُطِعِ الأَمِيرَ فَقَدْ أَطَاعَنِي، وَمَنْ يَعْصِ الأَمِيرَ فَقَدْ عَصَانِي، وَإِنَّمَا الإِمَامُ جُنَّةٌ يُقَاتَلُ مِنْ وَرَائِهِ وَيُتَّقَى بِهِ، فَإِنْ أَمَرَ بِتَقْوَى اللَّهِ وَعَدَلَ، فَإِنَّ لَهُ بِذَلِكَ أَجْرًا، وَإِنْ قَالَ بِغَيْرِهِ، فَإِنَّ عَلَيْهِ مِنْهُ ‏"‏‏.‏\hadithno{2956}\hadithtrans{Narrated Abu Huraira:That he heard Allah's Messenger (ﷺ) saying, "We are the last but will be the foremost to enter Paradise)." The Prophet added, "He who obeys me, obeys Allah, and he who disobeys me, disobeys Allah. He who obeys the chief, obeys me, and he who disobeys the chief, disobeys me. The Imam is like a shelter for whose safety the Muslims should fight and where they should seek protection. If the Imam orders people with righteousness and rules justly, then he will be rewarded for that, and if he does the opposite, he will be responsible for that}}
\hadithdefcmd{bukhari}{2962}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ مُحَمَّدَ بْنَ فُضَيْلٍ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ مُجَاشِعٍ ـ رضى الله عنه ـ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم أَنَا وَأَخِي فَقُلْتُ بَايِعْنَا عَلَى الْهِجْرَةِ‏.‏ فَقَالَ ‏"‏ مَضَتِ الْهِجْرَةُ لأَهْلِهَا ‏"‏‏.‏ فَقُلْتُ عَلاَمَ تُبَايِعُنَا قَالَ ‏"‏ عَلَى الإِسْلاَمِ وَالْجِهَادِ ‏"‏‏.‏\hadithno{2962}\hadithtrans{Narrated Mujashi:My brother and I came to the Prophet (ﷺ) and I requested him to take the pledge of allegiance from us for migration. He said, "Migration has passed away with its people." I asked, "For what will you take the pledge of allegiance from us then?" He said, "I will take (the pledge) for Islam and Jihad}}
\hadithdefcmd{bukhari}{2965}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ وَكَانَ كَاتِبًا لَهُ قَالَ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى ـ رضى الله عنهما ـ فَقَرَأْتُهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَيَّامِهِ الَّتِي لَقِيَ فِيهَا انْتَظَرَ حَتَّى مَالَتِ الشَّمْسُ‏.‏ ثُمَّ قَامَ فِي النَّاسِ قَالَ ‏ "‏ أَيُّهَا النَّاسُ، لاَ تَتَمَنَّوْا لِقَاءَ الْعَدُوِّ، وَسَلُوا اللَّهَ الْعَافِيَةَ، فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا، وَاعْلَمُوا أَنَّ الْجَنَّةَ تَحْتَ ظِلاَلِ السُّيُوفِ، ثُمَّ قَالَ اللَّهُمَّ مُنْزِلَ الْكِتَابِ وَمُجْرِيَ السَّحَابِ وَهَازِمَ الأَحْزَابِ، اهْزِمْهُمْ وَانْصُرْنَا عَلَيْهِمْ ‏"‏‏.‏\hadithno{2965}\hadithtrans{Narrated Salim Abu An-Nadr:The freed slave of `Umar bin 'Ubaidullah who was `Umar's clerk: `Abdullah bin Abi `Aufa wrote him (i.e. `Umar) a letter that contained the following:-- "Once Allah's Messenger (ﷺ) (during a holy battle), waited till the sun had declined and then he got up among the people and said, "O people! Do not wish to face the enemy (in a battle) and ask Allah to save you (from calamities) but if you should face the enemy, then be patient and let it be known to you that Paradise is under the shades of swords." He then said,, "O Allah! The Revealer of the (Holy) Book, the Mover of the clouds, and Defeater of Al-Ahzab (i.e. the clans of infidels), defeat them infidels and bestow victory upon us}}
\hadithdefcmd{bukhari}{3024}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا عَاصِمُ بْنُ يُوسُفَ الْيَرْبُوعِيُّ، حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ مُوسَى بْنِ عُقْبَةَ، قَالَ حَدَّثَنِي سَالِمٌ أَبُو النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ كُنْتُ كَاتِبًا لَهُ قَالَ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى حِينَ خَرَجَ إِلَى الْحَرُورِيَّةِ فَقَرَأْتُهُ فَإِذَا فِيهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَيَّامِهِ الَّتِي لَقِيَ فِيهَا الْعَدُوَّ انْتَظَرَ حَتَّى مَالَتِ الشَّمْسُ‏.‏ ثُمَّ قَامَ فِي النَّاسِ فَقَالَ ‏"‏ أَيُّهَا النَّاسُ لاَ تَمَنَّوْا لِقَاءَ الْعَدُوِّ وَسَلُوا اللَّهَ الْعَافِيَةَ، فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا وَاعْلَمُوا أَنَّ الْجَنَّةَ تَحْتَ ظِلاَلِ السُّيُوفِ ـ ثُمَّ قَالَ ـ اللَّهُمَّ مُنْزِلَ الْكِتَابِ وَمُجْرِيَ السَّحَابِ وَهَازِمَ الأَحْزَابِ اهْزِمْهُمْ وَانْصُرْنَا عَلَيْهِمْ ‏"‏‏.‏ وَقَالَ مُوسَى بْنُ عُقْبَةَ حَدَّثَنِي سَالِم أَبُو النَّضْرِ كُنْتُ كَاتِبًا لِعُمَرَ بْنِ عُبَيْدِ اللَّهِ فَأَتَاهُ كِتَابُ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَمَنَّوْا لِقَاءَ الْعَدُو ‏"‏‏.‏\hadithno{3024}\hadithtrans{Narrated Salim Abu An-Nadr: (the freed slave of 'Umar bin 'Ubaidullah) I was Umar's clerk. Once Abdullah bin Abi Aufa wrote a letter to 'Umar when he proceeded to Al-Haruriya. I read in it that Allah's Messenger (ﷺ) in one of his military expeditions against the enemy, waited till the sun declined and then he got up amongst the people saying, "O people! Do not wish to meet the enemy, and ask Allah for safety, but when you face the enemy, be patient, and remember that Paradise is under the shades of swords." Then he said, "O Allah, the Revealer of the Holy Book, and the Mover of the clouds and the Defeater of the clans, defeat them, and grant us victory over them}}
\hadithdefcmd{bukhari}{3027}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ هَلَكَ كِسْرَى ثُمَّ لاَ يَكُونُ كِسْرَى بَعْدَهُ، وَقَيْصَرٌ لَيَهْلِكَنَّ ثُمَّ لاَ يَكُونُ قَيْصَرٌ بَعْدَهُ، وَلَتُقْسَمَنَّ كُنُوزُهَا فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ وَسَمَّى الْحَرْبَ خَدْعَةً\hadithno{3027}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Khosrau will be ruined, and there will be no Khosrau after him, and Caesar will surely be ruined and there will be no Caesar after him, and you will spend their treasures in Allah's Cause." He called, "War is deceit}}
\hadithdefcmd{bukhari}{3035}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ ـ رضى الله عنه ـ قَالَ مَا حَجَبَنِي النَّبِيُّ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ، وَلاَ رَآنِي إِلاَّ تَبَسَّمَ فِي وَجْهِي‏.‏ وَلَقَدْ شَكَوْتُ إِلَيْهِ إِنِّي لاَ أَثْبُتُ عَلَى الْخَيْلِ‏.‏ فَضَرَبَ بِيَدِهِ فِي صَدْرِي وَقَالَ ‏ "‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏‏.‏\hadithno{3035}\hadithtrans{Narrated Jarir:Allah's Messenger (ﷺ) did not screen himself from me since my embracing Islam, and whenever he saw me he would receive me with a smile. Once I told him that I could not sit firm on horses. He stroke me on the chest with his hand and said, "O Allah! Make him firm and make him a guiding and a rightly guided man}}
\hadithdefcmd{bukhari}{3056}{قَالَ ابْنُ عُمَرَ انْطَلَقَ النَّبِيُّ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ يَأْتِيَانِ النَّخْلَ الَّذِي فِيهِ ابْنُ صَيَّادٍ، حَتَّى إِذَا دَخَلَ النَّخْلَ طَفِقَ النَّبِيُّ صلى الله عليه وسلم يَتَّقِي بِجُذُوعِ النَّخْلِ وَهْوَ يَخْتِلُ ابْنَ صَيَّادٍ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ، وَابْنُ صَيَّادٍ مُضْطَجِعٌ عَلَى فِرَاشِهِ فِي قَطِيفَةٍ لَهُ فِيهَا رَمْزَةٌ، فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ النَّبِيَّ صلى الله عليه وسلم وَهْوَ يَتَّقِي بِجُذُوعِ النَّخْلِ، فَقَالَتْ لاِبْنِ صَيَّادٍ أَىْ صَافِ ـ وَهْوَ اسْمُهُ ـ فَثَارَ ابْنُ صَيَّادٍ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏‏.‏ وَقَالَ سَالِمٌ قَالَ ابْنُ عُمَرَ ثُمَّ قَامَ النَّبِيُّ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏"‏ إِنِّي أُنْذِرُكُمُوهُ، وَمَا مِنْ نَبِيٍّ إِلاَّ قَدْ أَنْذَرَهُ قَوْمَهُ، لَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ، وَلَكِنْ سَأَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ، تَعْلَمُونَ أَنَّهُ أَعْوَرُ وَأَنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ‏"‏‏.‏\hadithno{3056}\hadithtrans{Narrated Ibn Umar: (Later on) Allah's Messenger (ﷺ) (once again) went along with Ubai bin Ka'b to the garden of date-palms where Ibn Saiyad was staying. When the Prophet entered the garden, he started hiding himself behind the trunks of the date-palms as he wanted to hear something from Ibn Saiyad before the latter could see him. Ibn Saiyad was lying in his bed, covered with a velvet sheet from where his murmurs were heard. Ibn Saiyad's mother saw the Prophet (ﷺ) while he was hiding himself behind the trunks of the date-palms. She addressed Ibn Saiyad, "O Saf!" (And this was his name). Ibn Saiyad got up. The Prophet (ﷺ) said, "Had this woman let him to himself, he would have revealed the reality of his case." Then the Prophet (ﷺ) got up amongst the people, glorifying Allah as He deserves, he mentioned Ad-Dajjal, saying, "I warn you about him (i.e. Ad-Dajjal) and there is no prophet who did not warn his nation about him, and Noah warned his nation about him, but I tell you a statement which no prophet informed his nation of. You should understand that he is a one-eyed man and Allah is not one-eyed}}
\hadithdefcmd{bukhari}{3078}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ مُجَاشِعِ بْنِ مَسْعُودٍ، قَالَ جَاءَ مُجَاشِعٌ بِأَخِيهِ مُجَالِدِ بْنِ مَسْعُودٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ هَذَا مُجَالِدٌ يُبَايِعُكَ عَلَى الْهِجْرَةِ‏.‏ فَقَالَ ‏ "‏ لاَ هِجْرَةَ بَعْدَ فَتْحِ مَكَّةَ، وَلَكِنْ أُبَايِعُهُ عَلَى الإِسْلاَمِ ‏"‏‏.‏\hadithno{3078}\hadithtrans{Narrated Abu `Uthman An-Nahdi:Mujashi (bin Mas`ud) took his brother Mujalid bin Mas`ud to the Prophet (ﷺ) and said, "This is Mujalid and he will give a pledge of allegiance to you for migration." The Prophet (ﷺ) said, "There is no migration after the Conquest of Mecca, but I will take his pledge of allegiance for Islam}}
\hadithdefcmd{bukhari}{3092}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّ فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ ابْنَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَأَلَتْ أَبَا بَكْرٍ الصِّدِّيقَ بَعْدَ وَفَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ يَقْسِمَ لَهَا مِيرَاثَهَا، مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِمَّا أَفَاءَ اللَّهُ عَلَيْهِ‏.‏ فَقَالَ لَهَا أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏‏.‏ فَغَضِبَتْ فَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهَجَرَتْ أَبَا بَكْرٍ، فَلَمْ تَزَلْ مُهَاجِرَتَهُ حَتَّى تُوُفِّيَتْ وَعَاشَتْ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم سِتَّةَ أَشْهُرٍ‏.‏ قَالَتْ وَكَانَتْ فَاطِمَةُ تَسْأَلُ أَبَا بَكْرٍ نَصِيبَهَا مِمَّا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ خَيْبَرَ وَفَدَكٍ وَصَدَقَتِهِ بِالْمَدِينَةِ، فَأَبَى أَبُو بَكْرٍ عَلَيْهَا ذَلِكَ، وَقَالَ لَسْتُ تَارِكًا شَيْئًا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْمَلُ بِهِ إِلاَّ عَمِلْتُ بِهِ، فَإِنِّي أَخْشَى إِنْ تَرَكْتُ شَيْئًا مِنْ أَمْرِهِ أَنْ أَزِيغَ‏.‏ فَأَمَّا صَدَقَتُهُ بِالْمَدِينَةِ فَدَفَعَهَا عُمَرُ إِلَى عَلِيٍّ وَعَبَّاسٍ، فَأَمَّا خَيْبَرُ وَفَدَكٌ فَأَمْسَكَهَا عُمَرُ وَقَالَ هُمَا صَدَقَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَتَا لِحُقُوقِهِ الَّتِي تَعْرُوهُ وَنَوَائِبِهِ، وَأَمْرُهُمَا إِلَى مَنْ وَلِيَ الأَمْرَ‏.‏ قَالَ فَهُمَا عَلَى ذَلِكَ إِلَى الْيَوْمِ‏.‏ قَالَ أَبُو عَبْد اللَّهِ اعْتَرَاكَ افْتَعَلْتَ مِنْ عَرَوْتُهُ فَأَصَبْتُهُ وَمِنْهُ يَعْرُوهُ وَاعْتَرَانِي\hadithno{3092}\hadithtrans{Narrated `Aisha:(mother of the believers) After the death of Allah's Apostle Fatima the daughter of Allah's Messenger (ﷺ) asked Abu Bakr As-Siddiq to give her, her share of inheritance from what Allah's Messenger (ﷺ) had left of the Fai (i.e. booty gained without fighting) which Allah had given him. Abu Bakr said to her, "Allah's Apostle said, 'Our property will not be inherited, whatever we (i.e. prophets) leave is Sadaqa (to be used for charity)." Fatima, the daughter of Allah's Messenger (ﷺ) got angry and stopped speaking to Abu Bakr, and continued assuming that attitude till she died. Fatima remained alive for six months after the death of Allah's Messenger (ﷺ). She used to ask Abu Bakr for her share from the property of Allah's Messenger (ﷺ) which he left at Khaibar, and Fadak, and his property at Medina (devoted for charity). Abu Bakr refused to give her that property and said, "I will not leave anything Allah's Messenger (ﷺ) used to do, because I am afraid that if I left something from the Prophet's tradition, then I would go astray." (Later on) `Umar gave the Prophet's property (of Sadaqa) at Medina to `Ali and `Abbas, but he withheld the properties of Khaibar and Fadak in his custody and said, "These two properties are the Sadaqa which Allah's Apostle used to use for his expenditures and urgent needs. Now their management is to be entrusted to the ruler." (Az-Zuhri said, "They have been managed in this way till today)}}
\hadithdefcmd{bukhari}{3131}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ وَزَعَمَ عُرْوَةُ أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، وَمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ مُسْلِمِينَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ، فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا السَّبْىَ وَإِمَّا الْمَالَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ بِهِمْ ‏"‏‏.‏ وَقَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم انْتَظَرَ آخِرَهُمْ بِضْعَ عَشْرَةَ لَيْلَةً، حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ‏.‏ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمُسْلِمِينَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ، فَإِنَّ إِخْوَانَكُمْ هَؤُلاَءِ قَدْ جَاءُونَا تَائِبِينَ، وَإِنِّي قَدْ رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، مَنْ أَحَبَّ أَنْ يُطَيِّبَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ قَدْ طَيَّبْنَا ذَلِكَ يَا رَسُولَ اللَّهِ لَهُمْ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ فِي ذَلِكَ مِمَّنْ لَمْ يَأْذَنْ، فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏ فَرَجَعَ النَّاسُ، فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، ثُمَّ رَجَعُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ قَدْ طَيَّبُوا فَأَذِنُوا‏.‏ فَهَذَا الَّذِي بَلَغَنَا عَنْ سَبْىِ هَوَازِنَ‏.‏\hadithno{3131}\hadithtrans{Narrated Marwan bin Al-Hakam and Miswar bin Makhrama:When the Hawazin delegation came to Allah's Messenger (ﷺ) after they had embraced Islam and requested him to return their properties and war prisoners to them, Allah's Messenger (ﷺ) said, "To me the best talk is the truest, so you may choose either of two things; the war prisoners or the wealth, for I have delayed their distribution." Allah's Messenger (ﷺ) had waited for them for over ten days when he returned from Ta'if. So, when those people came to know that Allah's Messenger (ﷺ) was not going to return to them except one of the two things the said, "We choose our war Prisoners 'Allah's Messenger (ﷺ) stood up amongst the Muslims, and after glorifying Allah as He deserved, he said, "Now then, these brothers of yours have come to us with repentance, and I see it logical that I should return their captives to them, so whoever of you likes to do that as a favor then he can do it, and whoever amongst you likes to stick to his share, let him give up his prisoners and we will compensate him from the very first Fai' (i.e. war booty received without fight) which Allah will give us." On that, all the people said. 'O Allah's Messenger (ﷺ) We have agreed willingly to do so (return the captives)" Then Allah's Messenger (ﷺ) said to them "I do not know who amongst you has agreed to this and who has not. You should return and let your leaders inform me of your agreement." The people returned and their leaders spoke to them, and then came to Allah's Apostle and said, "All the people have agreed willingly to do so and have given the permission to return the war prisoners (without Compensation)" (Az-Zuhri, the sub-narrator states) This is what has been related to us about the captives of Hawazin}}
\hadithdefcmd{bukhari}{3156}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ عَمْرًا، قَالَ كُنْتُ جَالِسًا مَعَ جَابِرِ بْنِ زَيْدٍ وَعَمْرِو بْنِ أَوْسٍ، فَحَدَّثَهُمَا بَجَالَةُ، سَنَةَ سَبْعِينَ ـ عَامَ حَجَّ مُصْعَبُ بْنُ الزُّبَيْرِ بِأَهْلِ الْبَصْرَةِ ـ عِنْدَ دَرَجِ زَمْزَمَ قَالَ كُنْتُ كَاتِبًا لِجَزْءِ بْنِ مُعَاوِيَةَ عَمِّ الأَحْنَفِ، فَأَتَانَا كِتَابُ عُمَرَ بْنِ الْخَطَّابِ قَبْلَ مَوْتِهِ بِسَنَةٍ فَرِّقُوا بَيْنَ كُلِّ ذِي مَحْرَمٍ مِنَ الْمَجُوسِ‏.‏ وَلَمْ يَكُنْ عُمَرُ أَخَذَ الْجِزْيَةَ مِنَ الْمَجُوسِ‏.‏ حَتَّى شَهِدَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَهَا مِنْ مَجُوسِ هَجَرٍ‏.‏\hadithno{3156}\hadithtrans{Narrated `Amr bin Dinar:I was sitting with Jabir bin Zaid and `Amr bin Aus, and Bajala was narrating to them in 70 A.H. the year when Mus`ab bin Az-Zubair was the leader of the pilgrims of Basra. We were sitting at the steps of Zamzam well and Bajala said, "I was the clerk of Juz bin Muawiya, Al-Ahnaf's paternal uncle. A letter came from `Umar bin Al-Khattab one year before his death; and it was read:-- "Cancel every marriage contracted among the Magians between relatives of close kinship (marriages that are regarded illegal in Islam: a relative of this sort being called Dhu-Mahram.)" `Umar did not take the Jizya from the Magian infidels till `Abdur-Rahman bin `Auf testified that Allah's Messenger (ﷺ) had taken the Jizya from the Magians of Hajar}}
\hadithdefcmd{bukhari}{3159}{حَدَّثَنَا الْفَضْلُ بْنُ يَعْقُوبَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ اللَّهِ الثَّقَفِيُّ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، وَزِيَادُ بْنُ جُبَيْرٍ، عَنْ جُبَيْرِ بْنِ حَيَّةَ، قَالَ بَعَثَ عُمَرُ النَّاسَ فِي أَفْنَاءِ الأَمْصَارِ يُقَاتِلُونَ الْمُشْرِكِينَ، فَأَسْلَمَ الْهُرْمُزَانُ فَقَالَ إِنِّي مُسْتَشِيرُكَ فِي مَغَازِيَّ هَذِهِ‏.‏ قَالَ نَعَمْ، مَثَلُهَا وَمَثَلُ مَنْ فِيهَا مِنَ النَّاسِ مِنْ عَدُوِّ الْمُسْلِمِينَ مَثَلُ طَائِرٍ لَهُ رَأْسٌ وَلَهُ جَنَاحَانِ وَلَهُ رِجْلاَنِ، فَإِنْ كُسِرَ أَحَدُ الْجَنَاحَيْنِ نَهَضَتِ الرِّجْلاَنِ بِجَنَاحٍ وَالرَّأْسُ، فَإِنْ كُسِرَ الْجَنَاحُ الآخَرُ نَهَضَتِ الرِّجْلاَنِ وَالرَّأْسُ، وَإِنْ شُدِخَ الرَّأْسُ ذَهَبَتِ الرِّجْلاَنِ وَالْجَنَاحَانِ وَالرَّأْسُ، فَالرَّأْسُ كِسْرَى، وَالْجَنَاحُ قَيْصَرُ، وَالْجَنَاحُ الآخَرُ فَارِسُ، فَمُرِ الْمُسْلِمِينَ فَلْيَنْفِرُوا إِلَى كِسْرَى‏.‏ وَقَالَ بَكْرٌ وَزِيَادٌ جَمِيعًا عَنْ جُبَيْرِ بْنِ حَيَّةَ قَالَ فَنَدَبَنَا عُمَرُ وَاسْتَعْمَلَ عَلَيْنَا النُّعْمَانَ بْنَ مُقَرِّنٍ، حَتَّى إِذَا كُنَّا بِأَرْضِ الْعَدُوِّ، وَخَرَجَ عَلَيْنَا عَامِلُ كِسْرَى فِي أَرْبَعِينَ أَلْفًا، فَقَامَ تُرْجُمَانٌ فَقَالَ لِيُكَلِّمْنِي رَجُلٌ مِنْكُمْ‏.‏ فَقَالَ الْمُغِيرَةُ سَلْ عَمَّا شِئْتَ‏.‏ قَالَ مَا أَنْتُمْ قَالَ نَحْنُ أُنَاسٌ مِنَ الْعَرَبِ كُنَّا فِي شَقَاءٍ شَدِيدٍ وَبَلاَءٍ شَدِيدٍ، نَمَصُّ الْجِلْدَ وَالنَّوَى مِنَ الْجُوعِ، وَنَلْبَسُ الْوَبَرَ وَالشَّعَرَ، وَنَعْبُدُ الشَّجَرَ وَالْحَجَرَ، فَبَيْنَا نَحْنُ كَذَلِكَ، إِذْ بَعَثَ رَبُّ السَّمَوَاتِ وَرَبُّ الأَرَضِينَ تَعَالَى ذِكْرُهُ وَجَلَّتْ عَظَمَتُهُ إِلَيْنَا نَبِيًّا مِنْ أَنْفُسِنَا، نَعْرِفُ أَبَاهُ وَأُمَّهُ، فَأَمَرَنَا نَبِيُّنَا رَسُولُ رَبِّنَا صلى الله عليه وسلم أَنْ نَقَاتِلَكُمْ حَتَّى تَعْبُدُوا اللَّهَ وَحْدَهُ أَوْ تُؤَدُّوا الْجِزْيَةَ، وَأَخْبَرَنَا نَبِيُّنَا صلى الله عليه وسلم عَنْ رِسَالَةِ رَبِّنَا أَنَّهُ مَنْ قُتِلَ مِنَّا صَارَ إِلَى الْجَنَّةِ فِي نَعِيمٍ لَمْ يَرَ مِثْلَهَا قَطُّ، وَمَنْ بَقِيَ مِنَّا مَلَكَ رِقَابَكُمْ‏.‏ فَقَالَ النُّعْمَانُ رُبَّمَا أَشْهَدَكَ اللَّهُ مِثْلَهَا مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يُنَدِّمْكَ وَلَمْ يُخْزِكَ، وَلَكِنِّي شَهِدْتُ الْقِتَالَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا لَمْ يُقَاتِلْ فِي أَوَّلِ النَّهَارِ انْتَظَرَ حَتَّى تَهُبَّ الأَرْوَاحُ وَتَحْضُرَ الصَّلَوَاتُ‏.‏\hadithno{3159}\hadithtrans{Narrated Jubair bin Haiya:`Umar sent the Muslims to the great countries to fight the pagans. When Al-Hurmuzan embraced Islam, `Umar said to him. "I would like to consult you regarding these countries which I intend to invade." Al-Hurmuzan said, "Yes, the example of these countries and their inhabitants who are the enemies. of the Muslims, is like a bird with a head, two wings and two legs; If one of its wings got broken, it would get up over its two legs, with one wing and the head; and if the other wing got broken, it would get up with two legs and a head, but if its head got destroyed, then the two legs, two wings and the head would become useless. The head stands for Khosrau, and one wing stands for Caesar and the other wing stands for Faris. So, order the Muslims to go towards Khosrau." So, `Umar sent us (to Khosrau) appointing An-Nu`man bin Muqrin as our commander. When we reached the land of the enemy, the representative of Khosrau came out with forty-thousand warriors, and an interpreter got up saying, "Let one of you talk to me!" Al-Mughira replied, "Ask whatever you wish." The other asked, "Who are you?" Al-Mughira replied, "We are some people from the Arabs; we led a hard, miserable, disastrous life: we used to suck the hides and the date stones from hunger; we used to wear clothes made up of fur of camels and hair of goats, and to worship trees and stones. While we were in this state, the Lord of the Heavens and the Earths, Elevated is His Remembrance and Majestic is His Highness, sent to us from among ourselves a Prophet whose father and mother are known to us. Our Prophet, the Messenger of our Lord, has ordered us to fight you till you worship Allah Alone or give Jizya (i.e. tribute); and our Prophet has informed us that our Lord says:-- "Whoever amongst us is killed (i.e. martyred), shall go to Paradise to lead such a luxurious life as he has never seen, and whoever amongst us remains alive, shall become your master." (Al-Mughira, then blamed An-Nu`man for delaying the attack and) An-Nu' man said to Al-Mughira, "If you had participated in a similar battle, in the company of Allah's Messenger (ﷺ) he would not have blamed you for waiting, nor would he have disgraced you. But I accompanied Allah's Apostle in many battles and it was his custom that if he did not fight early by daytime, he would wait till the wind had started blowing and the time for the prayer was due (i.e. after midday)}}
\hadithdefcmd{bukhari}{3164}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنِي رَوْحُ بْنُ الْقَاسِمِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لِي ‏"‏ لَوْ قَدْ جَاءَنَا مَالُ الْبَحْرَيْنِ قَدْ أَعْطَيْتُكَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ فَلَمَّا قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَاءَ مَالُ الْبَحْرَيْنِ قَالَ أَبُو بَكْرٍ مَنْ كَانَتْ لَهُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم عِدَةٌ فَلْيَأْتِنِي‏.‏ فَأَتَيْتُهُ فَقُلْتُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ كَانَ قَالَ لِي ‏"‏ لَوْ قَدْ جَاءَنَا مَالُ الْبَحْرَيْنِ لأَعْطَيْتُكَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ فَقَالَ لِي احْثُهْ‏.‏ فَحَثَوْتُ حَثْيَةً فَقَالَ لِي عُدَّهَا‏.‏ فَعَدَدْتُهَا فَإِذَا هِيَ خَمْسُمِائَةٍ، فَأَعْطَانِي أَلْفًا وَخَمْسَمِائَةٍ‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِمَالٍ مِنَ الْبَحْرَيْنِ فَقَالَ ‏"‏ انْثُرُوهُ فِي الْمَسْجِدِ ‏"‏ فَكَانَ أَكْثَرَ مَالٍ أُتِيَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَهُ الْعَبَّاسُ فَقَالَ يَا رَسُولَ اللَّهِ، أَعْطِنِي إِنِّي فَادَيْتُ نَفْسِي وَفَادَيْتُ عَقِيلاً‏.‏ قَالَ ‏"‏ خُذْ ‏"‏‏.‏ فَحَثَا فِي ثَوْبِهِ، ثُمَّ ذَهَبَ يُقِلُّهُ، فَلَمْ يَسْتَطِعْ‏.‏ فَقَالَ أْمُرْ بَعْضَهُمْ يَرْفَعْهُ إِلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَارْفَعْهُ أَنْتَ عَلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ فَنَثَرَ مِنْهُ، ثُمَّ ذَهَبَ يُقِلُّهُ فَلَمْ يَرْفَعْهُ‏.‏ فَقَالَ أْمُرْ بَعْضَهُمْ يَرْفَعْهُ عَلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَارْفَعْهُ أَنْتَ عَلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ فَنَثَرَ ثُمَّ احْتَمَلَهُ عَلَى كَاهِلِهِ ثُمَّ انْطَلَقَ، فَمَا زَالَ يُتْبِعُهُ بَصَرَهُ حَتَّى خَفِيَ عَلَيْنَا عَجَبًا مِنْ حِرْصِهِ، فَمَا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَمَّ مِنْهَا دِرْهَمٌ‏.‏\hadithno{3164}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) once said to me, "If the revenue of Bahrain came, I would give you this much and this much." When Allah's Messenger (ﷺ) had died, the revenue of Bahrain came, and Abu Bakr announced, " Let whoever was promised something by Allah's Messenger (ﷺ) come to me." So, I went to Abu Bakr and said, "Allah's Messenger (ﷺ) said to me, 'If the revenue of Bahrain came, I would give you this much and this. much." On that Abu Bakr said to me, "Scoop (money) with both your hands." I scooped money with both my hands and Abu Bakr asked me to count it. I counted it and it was five-hundred (gold pieces). The total amount he gave me was one thousand and five hundred (gold pieces.) Narrated Anas: Money from Bahrain was brought to the Prophet (ﷺ) . He said, "Spread it in the Mosque." It was the biggest amount that had ever been brought to Allah's Messenger (ﷺ) . In the meantime Al-`Abbas came to him and said, "O Allah's Messenger (ﷺ)! Give me, for I gave the ransom of myself and `Aqil." The Prophet said (to him), "Take." He scooped money with both hands and poured it in his garment and tried to lift it, but he could not and appealed to the Prophet, "Will you order someone to help me in lifting it?" The Prophet (ﷺ) said, "No." Then Al-`Abbas said, "Then will you yourself help me carry it?" The Prophet (ﷺ) said, "No." Then Al `Abbas threw away some of the money, but even then he was not able to lift it, and so he again requested the Prophet (ﷺ) "Will you order someone to help me carry it?" The Prophet said, "No." Then Al-`Abbas said, "Then will you yourself yelp me carry it?" The Prophet (ﷺ) said, 'No." So, Al-`Abbas threw away some more money and lifted it on his shoulder and went away. The Prophet (ﷺ) kept on looking at him with astonishment at his greediness till he went out of our sight. Allah's Messenger (ﷺ) did not get up from there till not a single Dirham remained from that money}}
\hadithdefcmd{bukhari}{3187}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ‏.‏وَعَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ ـ قَالَ أَحَدُهُمَا يُنْصَبُ وَقَالَ الآخَرُ ـ يُرَى يَوْمَ الْقِيَامَةِ يُعْرَفُ بِهِ ‏"‏‏.‏\hadithno{3187}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, ''Every betrayer will have a flag on the Day of Resurrection" One of the two subnarrators said that the flag would be fixed, and the other said that it would be shown on the Day of Resurrection, so that the betrayer might be recognized by it}}
\hadithdefcmd{bukhari}{3252}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ سَنَةٍ، وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏وَظِلٍّ مَمْدُودٍ‏\}‏‏"‏ «وَلَقَابُ قَوْسِ أَحَدِكُمْ فِي الْجَنَّةِ خَيْرٌ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ أَوْ تَغْرُبُ»\hadithno{3252}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said "There is a tree in Paradise (which is so big and huge that) a rider could travel in its shade for a hundred years. And if you wish, you can recite:--'In shade long extended..' (56. 30) and a place in Paradise equal to an arrow bow of one of you, is better than (the whole earth) on which the sun rises and sets}}
\hadithdefcmd{bukhari}{3272}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا طَلَعَ حَاجِبُ الشَّمْسِ فَدَعُوا الصَّلاَةَ حَتَّى تَبْرُزَ، وَإِذَا غَابَ حَاجِبُ الشَّمْسِ فَدَعُوا الصَّلاَةَ حَتَّى تَغِيبَ ‏"‏‏.‏ ‏"‏ وَلاَ تَحَيَّنُوا بِصَلاَتِكُمْ طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا، فَإِنَّهَا تَطْلُعُ بَيْنَ قَرْنَىْ شَيْطَانٍ ‏"‏‏.‏ أَوِ الشَّيْطَانِ‏.‏ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَ هِشَامٌ‏.‏\hadithno{3272}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "When the (upper) edge of the sun appears (in the morning), don't perform a prayer till the sun appears in full, and when the lower edge of the sun sets, don't perform a prayer till it sets completely. And you should not seek to pray at sunrise or sunset for the sun rises between two sides of the head of the devil (or Satan)}}
\hadithdefcmd{bukhari}{3297}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ اقْتُلُوا الْحَيَّاتِ، وَاقْتُلُوا ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ، فَإِنَّهُمَا يَطْمِسَانِ الْبَصَرَ، وَيَسْتَسْقِطَانِ الْحَبَلَ ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ فَبَيْنَا أَنَا أُطَارِدُ، حَيَّةً لأَقْتُلَهَا فَنَادَانِي أَبُو لُبَابَةَ لاَ تَقْتُلْهَا‏.‏ فَقُلْتُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَمَرَ بِقَتْلِ الْحَيَّاتِ‏.‏ قَالَ إِنَّهُ نَهَى بَعْدَ ذَلِكَ عَنْ ذَوَاتِ الْبُيُوتِ، وَهْىَ الْعَوَامِرُ‏.‏\hadithno{3297}\hadithtrans{Narrated Ibn `Umar:That he heard the Prophet (ﷺ) delivering a sermon on the pulpit saying, "Kill snakes and kill Dhu-at- Tufyatain (i.e. a snake with two white lines on its back) and Al-Abtar (i.e. a snake with short or mutilated tail) for they destroy the sight of one's eyes and bring about abortion." (`Abdullah bin `Umar further added): Once while I was chasing a snake in order, to kill it, Abu Lubaba called me saying: "Don't kill it," I said. "Allah's Messenger (ﷺ) ordered us to kill snakes." He said, "But later on he prohibited the killing of snakes living in the houses." (Az-Zuhri said. "Such snakes are called Al-Awamir)}}
\hadithdefcmd{bukhari}{3310}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ أَبِي يُونُسَ الْقُشَيْرِيِّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ ابْنَ عُمَرَ، كَانَ يَقْتُلُ الْحَيَّاتِ ثُمَّ نَهَى قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم هَدَمَ حَائِطًا لَهُ، فَوَجَدَ فِيهِ سِلْخَ حَيَّةٍ فَقَالَ ‏"‏ انْظُرُوا أَيْنَ هُوَ ‏"‏‏.‏ فَنَظَرُوا فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏‏.‏ فَكُنْتُ أَقْتُلُهَا لِذَلِكَ‏.‏ فَلَقِيتُ أَبَا لُبَابَةَ فَأَخْبَرَنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقْتُلُوا الْجِنَّانَ، إِلاَّ كُلَّ أَبْتَرَ ذِي طُفْيَتَيْنِ، فَإِنَّهُ يُسْقِطُ الْوَلَدَ، وَيُذْهِبُ الْبَصَرَ، فَاقْتُلُوهُ ‏"‏‏.‏\hadithno{3310}\hadithtrans{Narrated Abu Mulaika:Ibn `Umar used to kill snakes, but afterwards he forbade their killing and said, "Once the Prophet (ﷺ) pulled down a wall and saw a cast-off skin of a snake in it. He said, 'Look for the snake. 'They found it and the Prophet (ﷺ) said, "Kill it." For this reason I used to kill snakes. Later on I met Abu Lubaba who told me the Prophet (ﷺ) said, 'Do not kill snakes except the short-tailed or mutilated-tailed snake with two white lines on its back, for it causes abortion and makes one blind. So kill it}}
\hadithdefcmd{bukhari}{3312}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يَقْتُلُ الْحَيَّاتِ‏.‏ فَحَدَّثَهُ أَبُو لُبَابَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ جِنَّانِ الْبُيُوتِ، فَأَمْسَكَ عَنْهَا‏.‏\hadithno{3312}\hadithtrans{Narrated Nafi`:Ibn `Umar used to kill snakes but when Abu Lubaba informed him that the Prophet (ﷺ) had forbidden the killing of snakes living in houses, he gave up killing them}}
\hadithdefcmd{bukhari}{3362}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ أَبُو عَبْدِ اللَّهِ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، عَنْ أَبِيهِ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَرْحَمُ اللَّهُ أُمَّ إِسْمَاعِيلَ، لَوْلاَ أَنَّهَا عَجِلَتْ لَكَانَ زَمْزَمُ عَيْنًا مَعِينًا ‏"‏‏.‏ قَالَ الأَنْصَارِيُّ حَدَّثَنَا ابْنُ جُرَيْجٍ، أَمَّا كَثِيرُ بْنُ كَثِيرٍ فَحَدَّثَنِي قَالَ إِنِّي وَعُثْمَانَ بْنَ أَبِي سُلَيْمَانَ جُلُوسٌ مَعَ سَعِيدِ بْنِ جُبَيْرٍ، فَقَالَ مَا هَكَذَا حَدَّثَنِي ابْنُ عَبَّاسٍ، قَالَ أَقْبَلَ إِبْرَاهِيمُ بِإِسْمَاعِيلَ وَأُمِّهِ عَلَيْهِمُ السَّلاَمُ وَهْىَ تُرْضِعُهُ، مَعَهَا شَنَّةٌ ـ لَمْ يَرْفَعْهُ ـ ثُمَّ جَاءَ بِهَا إِبْرَاهِيمُ وَبِابْنِهَا إِسْمَاعِيلَ‏.‏\hadithno{3362}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "May Allah bestow His Mercy on the mother of Ishmael! Had she not hastened (to fill her water-skin with water from the Zamzam well). Zamzam would have been a stream flowing on the surface of the earth." Ibn `Abbas further added, "(The Prophet) Abraham brought Ishmael and his mother (to Mecca) and she was suckling Ishmael and she had a water-skin with her}}
\hadithdefcmd{bukhari}{3395}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا الْعَالِيَةِ، حَدَّثَنَا ابْنُ عَمِّ، نَبِيِّكُمْ ـ يَعْنِي ابْنَ عَبَّاسٍ ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏‏.‏ وَنَسَبَهُ إِلَى أَبِيهِ‏.‏ وَذَكَرَ النَّبِيُّ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ فَقَالَ ‏"‏ مُوسَى آدَمُ طُوَالٌ كَأَنَّهُ مِنْ رِجَالِ شَنُوءَةَ ‏"‏‏.‏ وَقَالَ ‏"‏ عِيسَى جَعْدٌ مَرْبُوعٌ ‏"‏‏.‏ وَذَكَرَ مَالِكًا خَازِنَ النَّارِ، وَذَكَرَ الدَّجَّالَ‏.‏\hadithno{3395}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "One should not say that I am better than Jonah (i.e. Yunus) bin Matta." So, he mentioned his father Matta. The Prophet (ﷺ) mentioned the night of his Ascension and said, "The prophet Moses was brown, a tall person as if from the people of the tribe of Shanu'a. Jesus was a curly-haired man of moderate height." He also mentioned Malik, the gate-keeper of the (Hell) Fire, and Ad-Dajjal}}
\hadithdefcmd{bukhari}{3414}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، عَنِ اللَّيْثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَمَا يَهُودِيٌّ يَعْرِضُ سِلْعَتَهُ أُعْطِيَ بِهَا شَيْئًا كَرِهَهُ‏.‏ فَقَالَ لاَ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ، فَسَمِعَهُ رَجُلٌ مِنَ الأَنْصَارِ فَقَامَ، فَلَطَمَ وَجْهَهُ، وَقَالَ تَقُولُ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ، وَالنَّبِيُّ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا فَذَهَبَ إِلَيْهِ، فَقَالَ أَبَا الْقَاسِمِ، إِنَّ لِي ذِمَّةً وَعَهْدًا، فَمَا بَالُ فُلاَنٍ لَطَمَ وَجْهِي‏.‏ فَقَالَ ‏"‏ لِمَ لَطَمْتَ وَجْهَهُ ‏"‏‏.‏ فَذَكَرَهُ، فَغَضِبَ النَّبِيُّ صلى الله عليه وسلم حَتَّى رُئِيَ فِي وَجْهِهِ، ثُمَّ قَالَ ‏"‏ لاَ تُفَضِّلُوا بَيْنَ أَنْبِيَاءِ اللَّهِ، فَإِنَّهُ يُنْفَخُ فِي الصُّورِ، فَيَصْعَقُ مَنْ فِي السَّمَوَاتِ وَمَنْ فِي الأَرْضِ، إِلاَّ مَنْ شَاءَ اللَّهُ، ثُمَّ يُنْفَخُ فِيهِ أُخْرَى، فَأَكُونُ أَوَّلَ مَنْ بُعِثَ فَإِذَا مُوسَى آخِذٌ بِالْعَرْشِ، فَلاَ أَدْرِي أَحُوسِبَ بِصَعْقَتِهِ يَوْمَ الطُّورِ أَمْ بُعِثَ قَبْلِي -‏ وَلَا أَقُولُ إِنَّ أَحَدًا أَفْضَلُ مِنْ يُونُسَ بْنِ مَتَّى"‏‏.‏\hadithno{3414}\hadithtrans{Narrated Abu Huraira:Once while a Jew was selling something, he was offered a price that he was not pleased with. So, he said, "No, by Him Who gave Moses superiority over all human beings!" Hearing him, an Ansari man got up and slapped him on the face and said, "You say: By Him Who Gave Moses superiority over all human beings although the Prophet (Muhammad) is present amongst us!" The Jew went to the Prophet and said, "O Abu-l-Qasim! I am under the assurance and contract of security, so what right does so-and-so have to slap me?" The Prophet (ﷺ) asked the other, "Why have you slapped". He told him the whole story. The Prophet (ﷺ) became angry, till anger appeared on his face, and said, "Don't give superiority to any prophet amongst Allah's Prophets, for when the trumpet will be blown, everyone on the earth and in the heavens will become unconscious except those whom Allah will exempt. The trumpet will be blown for the second time and I will be the first to be resurrected to see Moses holding Allah's Throne. I will not know whether the unconsciousness which Moses received on the Day of Tur has been sufficient for him, or has he got up before me. And I do not say that there is anybody who is better than Yunus bin Matta}}
\hadithdefcmd{bukhari}{3426}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَثَلِي وَمَثَلُ النَّاسِ كَمَثَلِ رَجُلٍ اسْتَوْقَدَ نَارًا، فَجَعَلَ الْفَرَاشُ وَهَذِهِ الدَّوَابُّ تَقَعُ فِي النَّارِ ‏"‏‏.‏ وَقَالَ ‏"‏ كَانَتِ امْرَأَتَانِ مَعَهُمَا ابْنَاهُمَا جَاءَ الذِّئْبُ فَذَهَبَ بِابْنِ إِحْدَاهُمَا، فَقَالَتْ صَاحِبَتُهَا إِنَّمَا ذَهَبَ بِابْنِكِ‏.‏ وَقَالَتِ الأُخْرَى إِنَّمَا ذَهَبَ بِابْنِكِ‏.‏ فَتَحَاكَمَتَا إِلَى دَاوُدَ، فَقَضَى بِهِ لِلْكُبْرَى فَخَرَجَتَا عَلَى سُلَيْمَانَ بْنِ دَاوُدَ فَأَخْبَرَتَاهُ‏.‏ فَقَالَ ائْتُونِي بِالسِّكِّينِ أَشُقُّهُ بَيْنَهُمَا‏.‏ فَقَالَتِ الصُّغْرَى لاَ تَفْعَلْ يَرْحَمُكَ اللَّهُ، هُوَ ابْنُهَا‏.‏ فَقَضَى بِهِ لِلصُّغْرَى ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ وَاللَّهِ إِنْ سَمِعْتُ بِالسِّكِّينِ إِلاَّ يَوْمَئِذٍ، وَمَا كُنَّا نَقُولُ إِلاَّ الْمُدْيَةُ‏.‏\hadithno{3426}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "My example and the example of the people is like that of a person who lit a fire and let the moths, butterflies and these insects fall in it." He also said, "There were two women, each of whom had a child with her. A wolf came and took away the child of one of them, whereupon the other said, 'It has taken your child.' The first said, 'But it has taken your child.' So they both carried the case before David who judged that the living child be given to the elder lady. So both of them went to Solomon bin David and informed him (of the case). He said, 'Bring me a knife so as to cut the child into two pieces and distribute it between them.' The younger lady said, 'May Allah be merciful to you! Don't do that, for it is her (i.e. the other lady's) child.' So he gave the child to the younger lady}}
\hadithdefcmd{bukhari}{3439}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى، عَنْ نَافِعٍ، قَالَ عَبْدُ اللَّهِ ذَكَرَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا بَيْنَ ظَهْرَىِ النَّاسِ الْمَسِيحَ الدَّجَّالَ، فَقَالَ ‏"‏ إِنَّ اللَّهَ لَيْسَ بِأَعْوَرَ، أَلاَ إِنَّ الْمَسِيحَ الدَّجَّالَ أَعْوَرُ الْعَيْنِ الْيُمْنَى، كَأَنَّ عَيْنَهُ عِنَبَةٌ طَافِيَةٌ ‏"‏‏.‏ ‏"‏ وَأَرَانِي اللَّيْلَةَ عِنْدَ الْكَعْبَةِ فِي الْمَنَامِ، فَإِذَا رَجُلٌ آدَمُ كَأَحْسَنِ مَا يُرَى مِنْ أُدْمِ الرِّجَالِ، تَضْرِبُ لِمَّتُهُ بَيْنَ مَنْكِبَيْهِ، رَجِلُ الشَّعَرِ، يَقْطُرُ رَأْسُهُ مَاءً، وَاضِعًا يَدَيْهِ عَلَى مَنْكِبَىْ رَجُلَيْنِ وَهْوَ يَطُوفُ بِالْبَيْتِ‏.‏ فَقُلْتُ مَنْ هَذَا فَقَالُوا هَذَا الْمَسِيحُ ابْنُ مَرْيَمَ‏.‏ ثُمَّ رَأَيْتُ رَجُلاً وَرَاءَهُ جَعْدًا قَطَطًا أَعْوَرَ عَيْنِ الْيُمْنَى كَأَشْبَهِ مَنْ رَأَيْتُ بِابْنِ قَطَنٍ، وَاضِعًا يَدَيْهِ عَلَى مَنْكِبَىْ رَجُلٍ، يَطُوفُ بِالْبَيْتِ، فَقُلْتُ مَنْ هَذَا قَالُوا الْمَسِيحُ الدَّجَّالُ ‏"‏‏.‏ تَابَعَهُ عُبَيْدُ اللَّهِ عَنْ نَافِعٍ‏.‏\hadithno{3439}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) mentioned the Masih Ad-Dajjal in front of the people saying, Allah is not one-eyed while Masih Ad-Dajjal is blind in the right eye and his eye looks like a bulging out grape. While sleeping near the Ka`ba last night, I saw in my dream a man of brown color the best one can see amongst brown color and his hair was long that it fell between his shoulders. His hair was lank and water was dribbling from his head and he was placing his hands on the shoulders of two men while circumambulating the Ka`ba. I asked, 'Who is this?' They replied, 'This is Jesus, son of Mary.' Behind him I saw a man who had very curly hair and was blind in the right eye, resembling Ibn Qatan (i.e. an infidel) in appearance. He was placing his hands on the shoulders of a person while performing Tawaf around the Ka`ba. I asked, 'Who is this? 'They replied, 'The Masih, Ad-Dajjal}}
\hadithdefcmd{bukhari}{3450}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ قَالَ عُقْبَةُ بْنُ عَمْرٍو لِحُذَيْفَةَ أَلاَ تُحَدِّثُنَا مَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ إِنِّي سَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ مَعَ الدَّجَّالِ إِذَا خَرَجَ مَاءً وَنَارًا، فَأَمَّا الَّذِي يَرَى النَّاسُ أَنَّهَا النَّارُ فَمَاءٌ بَارِدٌ، وَأَمَّا الَّذِي يَرَى النَّاسُ أَنَّهُ مَاءٌ بَارِدٌ فَنَارٌ تُحْرِقُ، فَمَنْ أَدْرَكَ مِنْكُمْ فَلْيَقَعْ فِي الَّذِي يَرَى أَنَّهَا نَارٌ، فَإِنَّهُ عَذْبٌ بَارِدٌ ‏"‏‏.‏ قَالَ حُذَيْفَةُ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ رَجُلاً كَانَ فِيمَنْ كَانَ قَبْلَكُمْ أَتَاهُ الْمَلَكُ لِيَقْبِضَ رُوحَهُ فَقِيلَ لَهُ هَلْ عَمِلْتَ مِنْ خَيْرٍ قَالَ مَا أَعْلَمُ، قِيلَ لَهُ انْظُرْ‏.‏ قَالَ مَا أَعْلَمُ شَيْئًا غَيْرَ أَنِّي كُنْتُ أُبَايِعُ النَّاسَ فِي الدُّنْيَا وَأُجَازِيهِمْ، فَأُنْظِرُ الْمُوسِرَ، وَأَتَجَاوَزُ عَنِ الْمُعْسِرِ‏.‏ فَأَدْخَلَهُ اللَّهُ الْجَنَّةَ ‏"‏‏.‏ فَقَالَ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ رَجُلاً حَضَرَهُ الْمَوْتُ، فَلَمَّا يَئِسَ مِنَ الْحَيَاةِ أَوْصَى أَهْلَهُ إِذَا أَنَا مُتُّ فَاجْمَعُوا لِي حَطَبًا كَثِيرًا وَأَوْقِدُوا فِيهِ نَارًا حَتَّى إِذَا أَكَلَتْ لَحْمِي، وَخَلَصَتْ إِلَى عَظْمِي، فَامْتَحَشْتُ، فَخُذُوهَا فَاطْحَنُوهَا، ثُمَّ انْظُرُوا يَوْمًا رَاحًا فَاذْرُوهُ فِي الْيَمِّ‏.‏ فَفَعَلُوا، فَجَمَعَهُ فَقَالَ لَهُ لِمَ فَعَلْتَ ذَلِكَ قَالَ مِنْ خَشْيَتِكَ‏.‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏‏.‏ قَالَ عُقْبَةُ بْنُ عَمْرٍو، وَأَنَا سَمِعْتُهُ يَقُولُ ذَاكَ، وَكَانَ نَبَّاشًا‏.‏\hadithno{3450}\hadithtrans{Narrated Rabi bin Hirash:`Uqba bin `Amr said to Hudhaifa, "Won't you relate to us of what you have heard from Allah's Apostle ?" He said, "I heard him saying, "When Al-Dajjal appears, he will have fire and water along with him. What the people will consider as cold water, will be fire that will burn (things). So, if anyone of you comes across this, he should fall in the thing which will appear to him as fire, for in reality, it will be fresh cold water." Hudhaifa added, "I also heard him saying, 'From among the people preceding your generation, there was a man whom the angel of death visited to capture his soul. (So his soul was captured) and he was asked if he had done any good deed.' He replied, 'I don't remember any good deed.' He was asked to think it over. He said, 'I do not remember, except that I used to trade with the people in the world and I used to give a respite to the rich and forgive the poor (among my debtors). So Allah made him enter Paradise." Hudhaifa further said, "I also heard him saying, 'Once there was a man on his death-bed, who, losing every hope of surviving said to his family: When I die, gather for me a large heap of wood and make a fire (to burn me). When the fire eats my meat and reaches my bones, and when the bones burn, take and crush them into powder and wait for a windy day to throw it (i.e. the powder) over the sea. They did so, but Allah collected his particles and asked him: Why did you do so? He replied: For fear of You. So Allah forgave him." `Uqba bin `Amr said, "I heard him saying that the Israeli used to dig the grave of the dead (to steal their shrouds)}}
\hadithdefcmd{bukhari}{3451}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، قَالَ قَالَ عُقْبَةُ بْنُ عَمْرٍو لِحُذَيْفَةَ أَلاَ تُحَدِّثُنَا مَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ إِنِّي سَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ مَعَ الدَّجَّالِ إِذَا خَرَجَ مَاءً وَنَارًا، فَأَمَّا الَّذِي يَرَى النَّاسُ أَنَّهَا النَّارُ فَمَاءٌ بَارِدٌ، وَأَمَّا الَّذِي يَرَى النَّاسُ أَنَّهُ مَاءٌ بَارِدٌ فَنَارٌ تُحْرِقُ، فَمَنْ أَدْرَكَ مِنْكُمْ فَلْيَقَعْ فِي الَّذِي يَرَى أَنَّهَا نَارٌ، فَإِنَّهُ عَذْبٌ بَارِدٌ ‏"‏‏.‏ قَالَ حُذَيْفَةُ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ رَجُلاً كَانَ فِيمَنْ كَانَ قَبْلَكُمْ أَتَاهُ الْمَلَكُ لِيَقْبِضَ رُوحَهُ فَقِيلَ لَهُ هَلْ عَمِلْتَ مِنْ خَيْرٍ قَالَ مَا أَعْلَمُ، قِيلَ لَهُ انْظُرْ‏.‏ قَالَ مَا أَعْلَمُ شَيْئًا غَيْرَ أَنِّي كُنْتُ أُبَايِعُ النَّاسَ فِي الدُّنْيَا وَأُجَازِيهِمْ، فَأُنْظِرُ الْمُوسِرَ، وَأَتَجَاوَزُ عَنِ الْمُعْسِرِ‏.‏ فَأَدْخَلَهُ اللَّهُ الْجَنَّةَ ‏"‏‏.‏ فَقَالَ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ رَجُلاً حَضَرَهُ الْمَوْتُ، فَلَمَّا يَئِسَ مِنَ الْحَيَاةِ أَوْصَى أَهْلَهُ إِذَا أَنَا مُتُّ فَاجْمَعُوا لِي حَطَبًا كَثِيرًا وَأَوْقِدُوا فِيهِ نَارًا حَتَّى إِذَا أَكَلَتْ لَحْمِي، وَخَلَصَتْ إِلَى عَظْمِي، فَامْتَحَشْتُ، فَخُذُوهَا فَاطْحَنُوهَا، ثُمَّ انْظُرُوا يَوْمًا رَاحًا فَاذْرُوهُ فِي الْيَمِّ‏.‏ فَفَعَلُوا، فَجَمَعَهُ فَقَالَ لَهُ لِمَ فَعَلْتَ ذَلِكَ قَالَ مِنْ خَشْيَتِكَ‏.‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏‏.‏ قَالَ عُقْبَةُ بْنُ عَمْرٍو، وَأَنَا سَمِعْتُهُ يَقُولُ ذَاكَ، وَكَانَ نَبَّاشًا‏.‏\hadithno{3451}\hadithtrans{Narrated Rabi bin Hirash:`Uqba bin `Amr said to Hudhaifa, "Won't you relate to us of what you have heard from Allah's Apostle ?" He said, "I heard him saying, "When Al-Dajjal appears, he will have fire and water along with him. What the people will consider as cold water, will be fire that will burn (things). So, if anyone of you comes across this, he should fall in the thing which will appear to him as fire, for in reality, it will be fresh cold water." Hudhaifa added, "I also heard him saying, 'From among the people preceding your generation, there was a man whom the angel of death visited to capture his soul. (So his soul was captured) and he was asked if he had done any good deed.' He replied, 'I don't remember any good deed.' He was asked to think it over. He said, 'I do not remember, except that I used to trade with the people in the world and I used to give a respite to the rich and forgive the poor (among my debtors). So Allah made him enter Paradise." Hudhaifa further said, "I also heard him saying, 'Once there was a man on his death-bed, who, losing every hope of surviving said to his family: When I die, gather for me a large heap of wood and make a fire (to burn me). When the fire eats my meat and reaches my bones, and when the bones burn, take and crush them into powder and wait for a windy day to throw it (i.e. the powder) over the sea. They did so, but Allah collected his particles and asked him: Why did you do so? He replied: For fear of You. So Allah forgave him." `Uqba bin `Amr said, "I heard him saying that the Israeli used to dig the grave of the dead (to steal their shrouds)}}
\hadithdefcmd{bukhari}{3453}{حَدَّثَنِي بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنِي مَعْمَرٌ، وَيُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ عَائِشَةَ، وَابْنَ، عَبَّاسٍ رضى الله عنهم قَالاَ لَمَّا نَزَلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم طَفِقَ يَطْرَحُ خَمِيصَةً عَلَى وَجْهِهِ، فَإِذَا اغْتَمَّ كَشَفَهَا عَنْ وَجْهِهِ، فَقَالَ وَهْوَ كَذَلِكَ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى، اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏‏.‏ يُحَذِّرُ مَا صَنَعُوا‏.‏\hadithno{3453}\hadithtrans{Narrated `Aisha and Ibn `Abbas:On his death-bed Allah's Messenger (ﷺ) put a sheet over his-face and when he felt hot, he would remove it from his face. When in that state (of putting and removing the sheet) he said, "May Allah's Curse be on the Jews and the Christians for they build places of worship at the graves of their prophets." (By that) he intended to warn (the Muslim) from what they (i.e. Jews and Christians) had done}}
\hadithdefcmd{bukhari}{3486}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنِي ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ، بَيْدَ كُلُّ أُمَّةٍ أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا وَأُوتِينَا مِنْ بَعْدِهِمْ، فَهَذَا الْيَوْمُ الَّذِي اخْتَلَفُوا، فَغَدًا لِلْيَهُودِ وَبَعْدَ غَدٍ لِلنَّصَارَى ‏"‏‏.‏ ‏"‏عَلَى كُلِّ مُسْلِمٍ فِى كُلِّ سَبْعَةِ أَيَّامٍ يَوْمٌ يَغْسِلُ رَأْسَهُ وَجَسَدَهُ‏"‏\hadithno{3486}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "We are the last (to come) but we will be the foremost on the Day of Resurrection, nations were given the Book (i.e. Scripture) before us, and we were given the Holy Book after them. This (i.e. Friday) is the day about which they differed. So the next day (i.e. Saturday) was prescribed for the Jews and the day after it (i.e. Sunday) for the Christians. It is incumbent on every Muslim to wash his head and body on a Day (i.e. Friday) (at least) in every seven days}}
\hadithdefcmd{bukhari}{3493}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ تَجِدُونَ النَّاسَ مَعَادِنَ، خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا، وَتَجِدُونَ خَيْرَ النَّاسِ فِي هَذَا الشَّأْنِ أَشَدَّهُمْ لَهُ كَرَاهِيَةً ‏"‏‏.‏ ‏"‏ وَتَجِدُونَ شَرَّ النَّاسِ ذَا الْوَجْهَيْنِ، الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ، وَيَأْتِي هَؤُلاَءِ بِوَجْهٍ ‏"‏‏.‏\hadithno{3493}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "You see that the people are of different natures. Those who were the best in the pre-Islamic period, are also the best in Islam if they comprehend religious knowledge. You see that the best amongst the people in this respect (i.e. ambition of ruling) are those who hate it most. And you see that the worst among people is the double faced (person) who appears to these with one face and to the others with another face (i.e a hypocrite)}}
\hadithdefcmd{bukhari}{3495}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ النَّاسُ تَبَعٌ لِقُرَيْشٍ فِي هَذَا الشَّأْنِ، مُسْلِمُهُمْ تَبَعٌ لِمُسْلِمِهِمْ، وَكَافِرُهُمْ تَبَعٌ لِكَافِرِهِمْ ‏"‏‏.‏ "وَالنَّاسُ مَعَادِنُ، خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا، تَجِدُونَ مِنْ خَيْرِ النَّاسِ أَشَدَّ النَّاسِ كَرَاهِيَةً لِهَذَا الشَّأْنِ حَتَّى يَقَعَ فِيهِ\hadithno{3495}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The tribe of Quraish has precedence over the people in this connection (i.e the right of ruling). The Muslims follow the Muslims amongst them, and the infidels follow the infidels amongst them. People are of different natures: The best amongst them in the pre-Islamic period are the best in Islam provided they comprehend the religious knowledge. You will find that the best amongst the people in this respect (i.e. of ruling) is he who hates it (i.e. the idea of ruling) most, till he is given the pledge of allegiance}}
\hadithdefcmd{bukhari}{3529}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ دَخَلَ عَلَيْهَا وَعِنْدَهَا جَارِيَتَانِ فِي أَيَّامِ مِنًى تُدَفِّفَانِ وَتَضْرِبَانِ، وَالنَّبِيُّ صلى الله عليه وسلم مُتَغَشٍّ بِثَوْبِهِ، فَانْتَهَرَهُمَا أَبُو بَكْرٍ، فَكَشَفَ النَّبِيُّ صلى الله عليه وسلم عَنْ وَجْهِهِ، فَقَالَ ‏"‏ دَعْهُمَا يَا أَبَا بَكْرٍ، فَإِنَّهَا أَيَّامُ عِيدٍ، وَتِلْكَ الأَيَّامُ أَيَّامُ مِنًى ‏"‏‏.‏ وَقَالَتْ عَائِشَةُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتُرُنِي، وَأَنَا أَنْظُرُ إِلَى الْحَبَشَةِ، وَهُمْ يَلْعَبُونَ فِي الْمَسْجِدِ فَزَجَرَهُمْ ‏\{‏عُمَرُ‏\}‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعْهُمْ أَمْنًا بَنِي أَرْفَدَةَ ‏"‏‏.‏ يَعْنِي مِنَ الأَمْنِ‏.‏\hadithno{3529}\hadithtrans{Narrated `Aisha:That during the Mina days, Abu Bakr came to her, while there were two girls with her, beating drums, and the Prophet (ﷺ) was (lying) covering himself with his garment. Abu Bakr rebuked the two girls, but the Prophet (ﷺ) uncovered his face and said, "O Abu Bakr! Leave them, for these are the days of Id (festival)." Those days were the days of Mina-. `Aisha added, "I was being screened by the Prophet (ﷺ) while I was watching the Ethiopians playing in the Mosque. `Umar rebuked them, but the Prophet (ﷺ) said, "Leave them, O Bani Arfida! Play. (for) you are safe}}
\hadithdefcmd{bukhari}{3567}{حَدَّثَنِي الْحَسَنُ بْنُ صَبَّاحٍ الْبَزَّارُ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُحَدِّثُ حَدِيثًا لَوْ عَدَّهُ الْعَادُّ لأَحْصَاهُ‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ أَلاَ يُعْجِبُكَ أَبُو فُلاَنٍ جَاءَ فَجَلَسَ إِلَى جَانِبِ حُجْرَتِي يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم، يُسْمِعُنِي ذَلِكَ وَكُنْتُ أُسَبِّحُ فَقَامَ قَبْلَ أَنْ أَقْضِيَ سُبْحَتِي، وَلَوْ أَدْرَكْتُهُ لَرَدَدْتُ عَلَيْهِ، إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَسْرُدُ الْحَدِيثَ كَسَرْدِكُمْ‏.‏\hadithno{3567}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to talk so clearly that if somebody wanted to count the number of his words, he could do so. Narrated `Urwa bin Az-Zubair: `Aisha said (to me), "Don't you wonder at Abu so-and-so who came and sat by my dwelling and started relating the traditions of Allah's Messenger (ﷺ) intending to let me hear that, while I was performing an optional prayer. He left before I finished my optional prayer. Had I found him still there. I would have said to him, 'Allah's Messenger (ﷺ) never talked so quickly and vaguely as you do}}
\hadithdefcmd{bukhari}{3587}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ، وَحَتَّى تُقَاتِلُوا التُّرْكَ، صِغَارَ الأَعْيُنِ، حُمْرَ الْوُجُوهِ، ذُلْفَ الأُنُوفِ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏‏.‏ "«وَتَجِدُونَ مِنْ خَيْرِ النَّاسِ أَشَدَّهُمْ كَرَاهِيَةً لِهَذَا الأَمْرِ، حَتَّى يَقَعَ فِيهِ، وَالنَّاسُ مَعَادِنُ، خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ." "وَلَيَأْتِيَنَّ عَلَى أَحَدِكُمْ زَمَانٌ لأَنْ يَرَانِي أَحَبُّ إِلَيْهِ مِنْ أَنْ يَكُونَ لَهُ مِثْلُ أَهْلِهِ وَمَالِهِ\hadithno{3587}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till you fight a nation wearing hairy shoes, and till you fight the Turks, who will have small eyes, red faces and flat noses; and their faces will be like flat shields. And you will find that the best people are those who hate responsibility of ruling most of all till they are chosen to be the rulers. And the people are of different natures: The best in the pre-Islamic period are the best in Islam. A time will come when any of you will love to see me rather than to have his family and property doubled}}
\hadithdefcmd{bukhari}{3588}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ، وَحَتَّى تُقَاتِلُوا التُّرْكَ، صِغَارَ الأَعْيُنِ، حُمْرَ الْوُجُوهِ، ذُلْفَ الأُنُوفِ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏‏.‏ "«وَتَجِدُونَ مِنْ خَيْرِ النَّاسِ أَشَدَّهُمْ كَرَاهِيَةً لِهَذَا الأَمْرِ، حَتَّى يَقَعَ فِيهِ، وَالنَّاسُ مَعَادِنُ، خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ." "وَلَيَأْتِيَنَّ عَلَى أَحَدِكُمْ زَمَانٌ لأَنْ يَرَانِي أَحَبُّ إِلَيْهِ مِنْ أَنْ يَكُونَ لَهُ مِثْلُ أَهْلِهِ وَمَالِهِ\hadithno{3588}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till you fight a nation wearing hairy shoes, and till you fight the Turks, who will have small eyes, red faces and flat noses; and their faces will be like flat shields. And you will find that the best people are those who hate responsibility of ruling most of all till they are chosen to be the rulers. And the people are of different natures: The best in the pre-Islamic period are the best in Islam. A time will come when any of you will love to see me rather than to have his family and property doubled}}
\hadithdefcmd{bukhari}{3601}{حَدَّثَنَا عَبْدُ الْعَزِيزِ الأُوَيْسِيُّ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَتَكُونُ فِتَنٌ، الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ، وَالْقَائِمُ فِيهَا خَيْرٌ مِنَ الْمَاشِي، وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي، وَمَنْ يُشْرِفْ لَهَا تَسْتَشْرِفْهُ، وَمَنْ وَجَدَ مَلْجَأً أَوْ مَعَاذًا فَلْيَعُذْ بِهِ ‏"‏‏.‏ وَعَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُطِيعِ بْنِ الأَسْوَدِ، عَنْ نَوْفَلِ بْنِ مُعَاوِيَةَ،، مِثْلَ حَدِيثِ أَبِي هُرَيْرَةَ هَذَا، إِلاَّ أَنَّ أَبَا بَكْرٍ، يَزِيدُ ‏"‏ مِنَ الصَّلاَةِ صَلاَةٌ مَنْ فَاتَتْهُ فَكَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏‏.‏\hadithno{3601}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There will be afflictions (and at the time) the sitting person will be better than the standing one, and the standing one will be better than the walking, and the walking will be better than the running. And whoever will look towards those afflictions, they will overtake him, and whoever will find a refuge or a shelter, should take refuge in it." The same narration is reported by Abu Bakr, with the addition, "(The Prophet (ﷺ) said), 'Among the prayers there is a prayer the missing of which will be to one like losing one's family and property}}
\hadithdefcmd{bukhari}{3620}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا نَافِعُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ مُسَيْلِمَةُ الْكَذَّابُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَقُولُ إِنْ جَعَلَ لِي مُحَمَّدٌ الأَمْرَ مِنْ بَعْدِهِ تَبِعْتُهُ‏.‏ وَقَدِمَهَا فِي بَشَرٍ كَثِيرٍ مِنْ قَوْمِهِ، فَأَقْبَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ ثَابِتُ بْنُ قَيْسِ بْنِ شَمَّاسٍ، وَفِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قِطْعَةُ جَرِيدٍ، حَتَّى وَقَفَ عَلَى مُسَيْلِمَةَ فِي أَصْحَابِهِ فَقَالَ ‏"‏ لَوْ سَأَلْتَنِي هَذِهِ الْقِطْعَةَ مَا أَعْطَيْتُكَهَا، وَلَنْ تَعْدُوَ أَمْرَ اللَّهِ فِيكَ، وَلَئِنْ أَدْبَرْتَ لَيَعْقِرَنَّكَ اللَّهُ، وَإِنِّي لأَرَاكَ الَّذِي أُرِيتُ فِيكَ مَا رَأَيْتُ ‏"‏‏.‏ فَأَخْبَرَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا أَنَا نَائِمٌ رَأَيْتُ فِي يَدَىَّ سِوَارَيْنِ مِنْ ذَهَبٍ، فَأَهَمَّنِي شَأْنُهُمَا، فَأُوحِيَ إِلَىَّ فِي الْمَنَامِ أَنِ انْفُخْهُمَا، فَنَفَخْتُهُمَا فَطَارَا فَأَوَّلْتُهُمَا كَذَّابَيْنِ يَخْرُجَانِ بَعْدِي ‏"‏‏.‏ فَكَانَ أَحَدُهُمَا الْعَنْسِيَّ وَالآخَرُ مُسَيْلِمَةَ الْكَذَّابَ صَاحِبَ الْيَمَامَةِ‏.‏\hadithno{3620}\hadithtrans{Narrated Ibn `Abbas:Musailama-al-Kadhdhab (i.e. the liar) came in the life-time of Allah's Messenger (ﷺ) with many of his people (to Medina) and said, "If Muhammad makes me his successor, I will follow him." Allah's Messenger (ﷺ) went up to him with Thabit bin Qais bin Shams; and Allah's Messenger (ﷺ) was carrying a piece of a datepalm leaf in his hand. He stood before Musailama (and his companions) and said, "If you asked me even this piece (of a leaf), I would not give it to you. You cannot avoid the fate you are destined to, by Allah. If you reject Islam, Allah will destroy you. I think that you are most probably the same person whom I have seen in the dream." Abu Huraira told me that Allah's Messenger (ﷺ); said, "While I was sleeping, I saw (in a dream) two gold bracelets round my arm, and that worried me too much. Then I was instructed divinely in my dream, to blow them off and so I blew them off, and they flew away. I interpreted the two bracelets as symbols of two liars who would appear after me. And so one of them was Al-Ansi and the other was Musailama Al-Kadhdhab from Al-Yamama}}
\hadithdefcmd{bukhari}{3623}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَقْبَلَتْ فَاطِمَةُ تَمْشِي، كَأَنَّ مِشْيَتَهَا مَشْىُ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَرْحَبًا بِابْنَتِي ‏"‏‏.‏ ثُمَّ أَجْلَسَهَا عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ، ثُمَّ أَسَرَّ إِلَيْهَا حَدِيثًا، فَبَكَتْ فَقُلْتُ لَهَا لِمَ تَبْكِينَ ثُمَّ أَسَرَّ إِلَيْهَا حَدِيثًا فَضَحِكَتْ فَقُلْتُ مَا رَأَيْتُ كَالْيَوْمِ فَرَحًا أَقْرَبَ مِنْ حُزْنٍ، فَسَأَلْتُهَا عَمَّا قَالَ‏.‏ فَقَالَتْ مَا كُنْتُ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى قُبِضَ النَّبِيُّ صلى الله عليه وسلم فَسَأَلْتُهَا فَقَالَتْ أَسَرَّ إِلَىَّ ‏"‏ إِنَّ جِبْرِيلَ كَانَ يُعَارِضُنِي الْقُرْآنَ كُلَّ سَنَةٍ مَرَّةً، وَإِنَّهُ عَارَضَنِي الْعَامَ مَرَّتَيْنِ، وَلاَ أُرَاهُ إِلاَّ حَضَرَ أَجَلِي، وَإِنَّكِ أَوَّلُ أَهْلِ بَيْتِي لَحَاقًا بِي ‏"‏‏.‏ فَبَكَيْتُ فَقَالَ ‏"‏ أَمَا تَرْضَيْنَ أَنْ تَكُونِي سَيِّدَةَ نِسَاءِ أَهْلِ الْجَنَّةِ ـ أَوْ نِسَاءِ الْمُؤْمِنِينَ ‏"‏‏.‏ فَضَحِكْتُ لِذَلِكَ‏.‏\hadithno{3623}\hadithtrans{Narrated `Aisha:Once Fatima came walking and her gait resembled the gait of the Prophet (ﷺ) . The Prophet (ﷺ) said, "Welcome, O my daughter!" Then he made her sit on his right or on his left side, and then he told her a secret and she started weeping. I asked her, "Why are you weeping?" He again told her a secret and she started laughing. I said, "I never saw happiness so near to sadness as I saw today." I asked her what the Prophet (ﷺ) had told her. She said, "I would never disclose the secret of Allah's Messenger (ﷺ)." When the Prophet (ﷺ) died, I asked her about it. She replied. "The Prophet (ﷺ) said: 'Every year Gabriel used to revise the Qur'an with me once only, but this year he has done so twice. I think this portends my death, and you will be the first of my family to follow me.' So I started weeping. Then he said. 'Don't you like to be the chief of all the ladies of Paradise or the chief of the believing women? So I laughed for that}}
\hadithdefcmd{bukhari}{3625}{حَدَّثَنِي يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَعَا النَّبِيُّ صلى الله عليه وسلم فَاطِمَةَ ابْنَتَهُ فِي شَكْوَاهُ الَّذِي قُبِضَ فِيهِ، فَسَارَّهَا بِشَىْءٍ فَبَكَتْ، ثُمَّ دَعَاهَا، فَسَارَّهَا فَضَحِكَتْ، قَالَتْ فَسَأَلْتُهَا عَنْ ذَلِكَ‏.‏ فَقَالَتْ سَارَّنِي النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَنِي أَنَّهُ يُقْبَضُ فِي وَجَعِهِ الَّذِي تُوُفِّيَ فِيهِ فَبَكَيْتُ، ثُمَّ سَارَّنِي فَأَخْبَرَنِي أَنِّي أَوَّلُ أَهْلِ بَيْتِهِ أَتْبَعُهُ فَضَحِكْتُ‏.‏\hadithno{3625}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) in his fatal illness, called his daughter Fatima and told her a secret because of which she started weeping. Then he called her and told her another secret, and she started laughing. When I asked her about that, she replied, The Prophet (ﷺ) told me that he would die in his fatal illness, and so I wept, but then he secretly told me that from amongst his family, I would be the first to join him, and so I laughed}}
\hadithdefcmd{bukhari}{3642}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا شَبِيبُ بْنُ غَرْقَدَةَ، قَالَ سَمِعْتُ الْحَىَّ، يُحَدِّثُونَ عَنْ عُرْوَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَعْطَاهُ دِينَارًا يَشْتَرِي بِهِ شَاةً، فَاشْتَرَى لَهُ بِهِ شَاتَيْنِ، فَبَاعَ إِحْدَاهُمَا بِدِينَارٍ وَجَاءَهُ بِدِينَارٍ وَشَاةٍ، فَدَعَا لَهُ بِالْبَرَكَةِ فِي بَيْعِهِ، وَكَانَ لَوِ اشْتَرَى التُّرَابَ لَرَبِحَ فِيهِ‏.‏ قَالَ سُفْيَانُ كَانَ الْحَسَنُ بْنُ عُمَارَةَ جَاءَنَا بِهَذَا الْحَدِيثِ عَنْهُ، قَالَ سَمِعَهُ شَبِيبٌ مِنْ عُرْوَةَ، فَأَتَيْتُهُ فَقَالَ شَبِيبٌ إِنِّي لَمْ أَسْمَعْهُ مِنْ عُرْوَةَ، قَالَ سَمِعْتُ الْحَىَّ يُخْبِرُونَهُ عَنْهُ‏.‏ وَلَكِنْ سَمِعْتُهُ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْخَيْرُ مَعْقُودٌ بِنَوَاصِي الْخَيْلِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏ قَالَ وَقَدْ رَأَيْتُ فِي دَارِهِ سَبْعِينَ فَرَسًا‏.‏ قَالَ سُفْيَانُ يَشْتَرِي لَهُ شَاةً كَأَنَّهَا أُضْحِيَّةٌ‏.‏\hadithno{3642}\hadithtrans{Narrated `Urwa:That the Prophet (ﷺ) gave him one Dinar so as to buy a sheep for him. `Urwa bought two sheep for him with the money. Then he sold one of the sheep for one Dinar, and brought one Dinar and a sheep to the Prophet. On that, the Prophet (ﷺ) invoked Allah to bless him in his deals. So `Urwa used to gain (from any deal) even if he bought dust. (In another narration) `Urwa said, "I heard Allah's Messenger (ﷺ) saying, "There is always goodness in horses till the Day of Resurrection." (The subnarrator added, "I saw 70 horses in `Urwa's house.') (Sufyan said, "The Prophet (ﷺ) asked `Urwa to buy a sheep for him as a sacrifice}}
\hadithdefcmd{bukhari}{3667}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَاتَ وَأَبُو بَكْرٍ بِالسُّنْحِ ـ قَالَ إِسْمَاعِيلُ يَعْنِي بِالْعَالِيَةِ ـ فَقَامَ عُمَرُ يَقُولُ وَاللَّهِ مَا مَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَتْ وَقَالَ عُمَرُ وَاللَّهِ مَا كَانَ يَقَعُ فِي نَفْسِي إِلاَّ ذَاكَ وَلَيَبْعَثَنَّهُ اللَّهُ فَلَيَقْطَعَنَّ أَيْدِيَ رِجَالٍ وَأَرْجُلَهُمْ‏.‏ فَجَاءَ أَبُو بَكْرٍ فَكَشَفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَبَّلَهُ قَالَ بِأَبِي أَنْتَ وَأُمِّي طِبْتَ حَيًّا وَمَيِّتًا، وَالَّذِي نَفْسِي بِيَدِهِ لاَ يُذِيقُكَ اللَّهُ الْمَوْتَتَيْنِ أَبَدًا‏.‏ ثُمَّ خَرَجَ فَقَالَ أَيُّهَا الْحَالِفُ عَلَى رِسْلِكَ‏.‏ فَلَمَّا تَكَلَّمَ أَبُو بَكْرٍ جَلَسَ عُمَرُ‏.‏ فَحَمِدَ اللَّهَ أَبُو بَكْرٍ وَأَثْنَى عَلَيْهِ وَقَالَ أَلاَ مَنْ كَانَ يَعْبُدُ مُحَمَّدًا صلى الله عليه وسلم فَإِنَّ مُحَمَّدًا قَدْ مَاتَ، وَمَنْ كَانَ يَعْبُدُ اللَّهَ فَإِنَّ اللَّهَ حَىٌّ لاَ يَمُوتُ‏.‏ وَقَالَ ‏\{‏إِنَّكَ مَيِّتٌ وَإِنَّهُمْ مَيِّتُونَ‏\}‏ وَقَالَ ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ قَدْ خَلَتْ مِنْ قَبْلِهِ الرُّسُلُ أَفَإِنْ مَاتَ أَوْ قُتِلَ انْقَلَبْتُمْ عَلَى أَعْقَابِكُمْ وَمَنْ يَنْقَلِبْ عَلَى عَقِبَيْهِ فَلَنْ يَضُرَّ اللَّهَ شَيْئًا وَسَيَجْزِي اللَّهُ الشَّاكِرِينَ‏\}‏ قَالَ فَنَشَجَ النَّاسُ يَبْكُونَ ـ قَالَ ـ وَاجْتَمَعَتِ الأَنْصَارُ إِلَى سَعْدِ بْنِ عُبَادَةَ فِي سَقِيفَةِ بَنِي سَاعِدَةَ فَقَالُوا مِنَّا أَمِيرٌ وَمِنْكُمْ أَمِيرٌ، فَذَهَبَ إِلَيْهِمْ أَبُو بَكْرٍ وَعُمَرُ بْنُ الْخَطَّابِ وَأَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ، فَذَهَبَ عُمَرُ يَتَكَلَّمُ فَأَسْكَتَهُ أَبُو بَكْرٍ، وَكَانَ عُمَرُ يَقُولُ وَاللَّهِ مَا أَرَدْتُ بِذَلِكَ إِلاَّ أَنِّي قَدْ هَيَّأْتُ كَلاَمًا قَدْ أَعْجَبَنِي خَشِيتُ أَنْ لاَ يَبْلُغَهُ أَبُو بَكْرٍ، ثُمَّ تَكَلَّمَ أَبُو بَكْرٍ فَتَكَلَّمَ أَبْلَغَ النَّاسِ فَقَالَ فِي كَلاَمِهِ نَحْنُ الأُمَرَاءُ وَأَنْتُمُ الْوُزَرَاءُ‏.‏ فَقَالَ حُبَابُ بْنُ الْمُنْذِرِ لاَ وَاللَّهِ لاَ نَفْعَلُ، مِنَّا أَمِيرٌ وَمِنْكُمْ أَمِيرٌ‏.‏ فَقَالَ أَبُو بَكْرٍ لاَ، وَلَكِنَّا الأُمَرَاءُ وَأَنْتُمُ الْوُزَرَاءُ هُمْ أَوْسَطُ الْعَرَبِ دَارًا، وَأَعْرَبُهُمْ أَحْسَابًا فَبَايِعُوا عُمَرَ أَوْ أَبَا عُبَيْدَةَ‏.‏ فَقَالَ عُمَرُ بَلْ نُبَايِعُكَ أَنْتَ، فَأَنْتَ سَيِّدُنَا وَخَيْرُنَا وَأَحَبُّنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَأَخَذَ عُمَرُ بِيَدِهِ فَبَايَعَهُ، وَبَايَعَهُ النَّاسُ، فَقَالَ قَائِلٌ قَتَلْتُمْ سَعْدَ بْنَ عُبَادَةَ‏.‏ فَقَالَ عُمَرُ قَتَلَهُ اللَّهُ‏.‏\hadithno{3667}\hadithtrans{Narrated 'Aisha: (the wife of the Prophet) Allah's Messenger (ﷺ) died while Abu Bakr was at a place called As-Sunah (Al-'Aliya) 'Umar stood up and said, "By Allah! Allah's Messenger (ﷺ) is not dead!" 'Umar (later on) said, "By Allah! Nothing occurred to my mind except that." He said, "Verily! Allah will resurrect him and he will cut the hands and legs of some men." Then Abu Bakr came and uncovered the face of Allah's Messenger (ﷺ), kissed him and said, "Let my mother and father be sacrificed for you, (O Allah's Messenger (ﷺ)), you are good in life and in death. By Allah in Whose Hands my life is, Allah will never make you taste death twice." Then he went out and said, "O oath-taker! Don't be hasty." When Abu Bakr spoke, 'Umar sat down. Abu Bakr praised and glorified Allah and said, No doubt! Whoever worshipped Muhammad, then Muhammad is dead, but whoever worshipped Allah, then Allah is Alive and shall never die." Then he recited Allah's Statement.:-- "(O Muhammad) Verily you will die, and they also will die." (39.30) He also recited:-- "Muhammad is no more than an Apostle; and indeed many Apostles have passed away, before him, If he dies Or is killed, will you then Turn back on your heels? And he who turns back On his heels, not the least Harm will he do to Allah And Allah will give reward to those Who are grateful." (3.144) The people wept loudly, and the Ansar were assembled with Sad bin 'Ubada in the shed of Bani Saida. They said (to the emigrants). "There should be one 'Amir from us and one from you." Then Abu Bakr, Umar bin Al-Khattab and Abu 'baida bin Al-Jarrah went to them. 'Umar wanted to speak but Abu Bakr stopped him. 'Umar later on used to say, "By Allah, I intended only to say something that appealed to me and I was afraid that Abu Bakr would not speak so well. Then Abu Bakr spoke and his speech was very eloquent. He said in his statement, "We are the rulers and you (Ansars) are the ministers (i.e. advisers)," Hubab bin Al-Mundhir said, "No, by Allah we won't accept this. But there must be a ruler from us and a ruler from you." Abu Bakr said, "No, we will be the rulers and you will be the ministers, for they (i.e. Quraish) are the best family amongst the 'Arabs and of best origin. So you should elect either 'Umar or Abu 'Ubaida bin Al-Jarrah as your ruler." 'Umar said (to Abu Bakr), "No but we elect you, for you are our chief and the best amongst us and the most beloved of all of us to Allah's Messenger (ﷺ)." So 'Umar took Abu Bakr's hand and gave the pledge of allegiance and the people too gave the pledge of allegiance to Abu Bakr. Someone said, "You have killed Sad bin Ubada." 'Umar said, "Allah has killed him}}
\hadithdefcmd{bukhari}{3669}{وَقَالَ عَبْدُ اللَّهِ بْنُ سَالِمٍ عَنِ الزُّبَيْدِيِّ، قَالَ عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ أَخْبَرَنِي الْقَاسِمُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ شَخَصَ بَصَرُ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ فِي الرَّفِيقِ الأَعْلَى ‏"‏‏.‏ ثَلاَثًا، وَقَصَّ الْحَدِيثَ، قَالَتْ فَمَا كَانَتْ مِنْ خُطْبَتِهِمَا مِنْ خُطْبَةٍ إِلاَّ نَفَعَ اللَّهُ بِهَا، لَقَدْ خَوَّفَ عُمَرُ النَّاسَ وَإِنَّ فِيهِمْ لَنِفَاقًا، فَرَدَّهُمُ اللَّهُ بِذَلِكَ‏.‏ ثُمَّ لَقَدْ بَصَّرَ أَبُو بَكْرٍ النَّاسَ الْهُدَى وَعَرَّفَهُمُ الْحَقَّ الَّذِي عَلَيْهِمْ وَخَرَجُوا بِهِ يَتْلُونَ ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ قَدْ خَلَتْ مِنْ قَبْلِهِ الرُّسُلُ‏\}‏ إِلَى ‏\{‏الشَّاكِرِينَ‏\}‏\hadithno{3669}\hadithtrans{Aisha said (in another narration), ("When the Prophet (ﷺ) was on his death-bed) he looked up and said thrice, (Amongst) the Highest Companion (See Qur'an 4.69)' Aisha said, Allah benefited the people by their two speeches. 'Umar frightened the people some of whom were hypocrites whom Allah caused to abandon Islam because of 'Umar's speech. Then Abu Bakr led the people to True Guidance and acquainted them with the right path they were to follow so that they went out reciting:-- "Muhammad is no more than an Apostle and indeed many Apostles have passed away before him}}
\hadithdefcmd{bukhari}{3711}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ أَرْسَلَتْ إِلَى أَبِي بَكْرٍ تَسْأَلُهُ مِيرَاثَهَا مِنَ النَّبِيِّ صلى الله عليه وسلم فِيمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم، تَطْلُبُ صَدَقَةَ النَّبِيِّ صلى الله عليه وسلم الَّتِي بِالْمَدِينَةِ وَفَدَكٍ وَمَا بَقِيَ مِنْ خُمُسِ خَيْبَرَ‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ، مَا تَرَكْنَا فَهْوَ صَدَقَةٌ، إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ مِنْ هَذَا الْمَالِ ـ يَعْنِي مَالَ اللَّهِ ـ لَيْسَ لَهُمْ أَنْ يَزِيدُوا عَلَى الْمَأْكَلِ ‏"‏‏.‏ وَإِنِّي وَاللَّهِ لاَ أُغَيِّرُ شَيْئًا مِنْ صَدَقَاتِ النَّبِيِّ صلى الله عليه وسلم الَّتِي كَانَتْ عَلَيْهَا فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم، وَلأَعْمَلَنَّ فِيهَا بِمَا عَمِلَ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ فَتَشَهَّدَ عَلِيٌّ، ثُمَّ قَالَ إِنَّا قَدْ عَرَفْنَا يَا أَبَا بَكْرٍ فَضِيلَتَكَ‏.‏ وَذَكَرَ قَرَابَتَهُمْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَحَقَّهُمْ‏.‏ فَتَكَلَّمَ أَبُو بَكْرٍ فَقَالَ وَالَّذِي نَفْسِي بِيَدِهِ، لَقَرَابَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَبُّ إِلَىَّ أَنْ أَصِلَ مِنْ قَرَابَتِي‏.‏\hadithno{3711}\hadithtrans{Narrated 'Aisha: Fatima sent somebody to Abu Bakr asking him to give her her inheritance from the Prophet (ﷺ) from what Allah had given to His Apostle through Fai (i.e. booty gained without fighting). She asked for the Sadaqa (i.e. wealth assigned for charitable purposes) of the Prophet (ﷺ) at Medina, and Fadak, and what remained of the Khumus (i.e., one-fifth) of the Khaibar booty. Abu Bakr said, "Allah's Messenger (ﷺ) said, 'We (Prophets), our property is not inherited, and whatever we leave is Sadaqa, but Muhammad's Family can eat from this property, i.e. Allah's property, but they have no right to take more than the food they need.' By Allah! I will not bring any change in dealing with the Sadaqa of the Prophet (and will keep them) as they used to be observed in his (i.e. the Prophet's) life-time, and I will dispose with it as Allah's Messenger (ﷺ) used to do," Then 'Ali said, "I testify that None has the right to be worshipped but Allah, and that Muhammad is His Apostle," and added, "O Abu Bakr! We acknowledge your superiority." Then he (i.e. 'Ali) mentioned their own relationship to Allah's Apostle and their right. Abu Bakr then spoke saying, "By Allah in Whose Hands my life is. I love to do good to the relatives of Allah's Apostle rather than to my own relatives}}
\hadithdefcmd{bukhari}{3715}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَعَا النَّبِيُّ صلى الله عليه وسلم فَاطِمَةَ ابْنَتَهُ فِي شَكْوَاهُ الَّذِي قُبِضَ فِيهَا، فَسَارَّهَا بِشَىْءٍ فَبَكَتْ، ثُمَّ دَعَاهَا فَسَارَّهَا فَضَحِكَتْ، قَالَتْ فَسَأَلْتُهَا عَنْ ذَلِكَ‏.‏ فَقَالَتْ سَارَّنِي النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَنِي أَنَّهُ يُقْبَضُ فِي وَجَعِهِ الَّذِي تُوُفِّيَ فِيهِ فَبَكَيْتُ، ثُمَّ سَارَّنِي فَأَخْبَرَنِي أَنِّي أَوَّلُ أَهْلِ بَيْتِهِ أَتْبَعُهُ فَضَحِكْتُ‏.‏\hadithno{3715}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) called his daughter Fatima during his illness in which he died, and told her a secret whereupon she wept. Then he called her again and told her a secret whereupon she laughed. When I asked her about that, she replied, "The Prophet (ﷺ) spoke to me in secret and informed me that he would die in the course of the illness during which he died, so I wept. He again spoke to me in secret and informed me that I would be the first of his family to follow him (after his death) and on that I laughed}}
\hadithdefcmd{bukhari}{3723}{حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ أَبِي عُثْمَانَ، قَالَ لَمْ يَبْقَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَعْضِ تِلْكَ الأَيَّامِ الَّتِي قَاتَلَ فِيهِنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم غَيْرُ طَلْحَةَ وَسَعْدٍ‏.‏ عَنْ حَدِيثِهِمَا‏.‏\hadithno{3723}\hadithtrans{Narrated Abu `Uthman:During one of the Ghazawat in which Allah's Messenger (ﷺ) was fighting, none remained with the Prophet (ﷺ) but Talha and Sa`d}}
\hadithdefcmd{bukhari}{3738}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ الرَّجُلُ فِي حَيَاةِ النَّبِيِّ صلى الله عليه وسلم إِذَا رَأَى رُؤْيَا قَصَّهَا عَلَى النَّبِيِّ صلى الله عليه وسلم، فَتَمَنَّيْتُ أَنْ أَرَى رُؤْيَا أَقُصُّهَا عَلَى النَّبِيِّ صلى الله عليه وسلم، وَكُنْتُ غُلاَمًا أَعْزَبَ، وَكُنْتُ أَنَامُ فِي الْمَسْجِدِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَرَأَيْتُ فِي الْمَنَامِ كَأَنَّ مَلَكَيْنِ أَخَذَانِي فَذَهَبَا بِي إِلَى النَّارِ، فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ، فَإِذَا لَهَا قَرْنَانِ كَقَرْنَىِ الْبِئْرِ، وَإِذَا فِيهَا نَاسٌ قَدْ عَرَفْتُهُمْ، فَجَعَلْتُ أَقُولُ أَعُوذُ بِاللَّهِ مِنَ النَّارِ، أَعُوذُ بِاللَّهِ مِنَ النَّارِ‏.‏ فَلَقِيَهُمَا مَلَكٌ آخَرُ فَقَالَ لِي لَنْ تُرَاعَ‏. فَقَصَصْتُهَا عَلَى حَفْصَةَ‏.‏ فَقَصَّتْهَا حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ، لَوْ كَانَ يُصَلِّي بِاللَّيْلِ ‏"‏‏.‏ قَالَ سَالِمٌ فَكَانَ عَبْدُ اللَّهِ لاَ يَنَامُ مِنَ اللَّيْلِ إِلاَّ قَلِيلاً‏.‏\hadithno{3738}\hadithtrans{Narrated Ibn `Umar:If a man saw a dream during the lifetime of the Prophet (ﷺ) he would narrate it to the Prophet. Once I wished to see a dream and narrate it to the Prophet (ﷺ) I was young, unmarried, and used to sleep in the Mosque during the lifetime of the Prophet. I dreamt that two angels took me and went away with me towards the (Hell) Fire which looked like a well with the inside walls built up, and had two side-walls like those of a well. There I saw some people in it whom I knew. I started saying, "I seek Refuge with Allah from the (Hell) Fire, I seek Refuge with Allah from the (Hell) Fire." Then another angel met the other two and said to me, "Do not be afraid." I narrated my dream to Hafsa who, in her turn, narrated it to the Prophet. He said, "What an excellent man `Abdullah is if he only observes the night prayer." (Salim, a sub-narrator said, "Abdullah used not to sleep at night but very little hence forward)}}
\hadithdefcmd{bukhari}{3741}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ أُخْتِهِ، حَفْصَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ إِنَّ عَبْدَ اللَّهِ رَجُلٌ صَالِحٌ ‏"‏‏.‏\hadithno{3741}\hadithtrans{Narrated Ibn `Umar from Hafsa his sister:That the Prophet (ﷺ) had said to her, "`Abdullah is a pious man}}
\hadithdefcmd{bukhari}{3759}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ سَمِعْتُ مَسْرُوقًا، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ فَاحِشًا وَلاَ مُتَفَحِّشًا وَقَالَ ‏"‏ إِنَّ مِنْ أَحَبِّكُمْ إِلَىَّ أَحْسَنَكُمْ أَخْلاَقًا ‏"‏‏.‏ وَقَالَ ‏"‏ اسْتَقْرِئُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ، وَأُبَىِّ بْنِ كَعْبٍ، وَمُعَاذِ بْنِ جَبَلٍ ‏"‏‏.‏\hadithno{3759}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) neither talked in an insulting manner nor did he ever speak evil intentionally. He used to say, "The most beloved to me amongst you is the one who has the best character and manners." He added, " Learn the Qur'an from (any of these) four persons. `Abdullah bin Mas`ud, Salim the freed slave of Abu Hudhaifa, Ubai bin Ka`b, and Mu`adh bin Jabal}}
\hadithdefcmd{bukhari}{3939}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ أَبَا الْمِنْهَالِ عَبْدَ الرَّحْمَنِ بْنَ مُطْعِمٍ، قَالَ بَاعَ شَرِيكٌ لِي دَرَاهِمَ فِي السُّوقِ نَسِيئَةً فَقُلْتُ سُبْحَانَ اللَّهِ أَيَصْلُحُ هَذَا فَقَالَ سُبْحَانَ اللَّهِ، وَاللَّهِ لَقَدْ بِعْتُهَا فِي السُّوقِ فَمَا عَابَهُ أَحَدٌ، فَسَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ نَتَبَايَعُ هَذَا الْبَيْعَ، فَقَالَ ‏ "‏ مَا كَانَ يَدًا بِيَدٍ فَلَيْسَ بِهِ بَأْسٌ، وَمَا كَانَ نَسِيئَةً فَلاَ يَصْلُحُ ‏"‏‏.‏ وَالْقَ زَيْدَ بْنَ أَرْقَمَ فَاسْأَلْهُ فَإِنَّهُ كَانَ أَعْظَمَنَا تِجَارَةً، فَسَأَلْتُ زَيْدَ بْنَ أَرْقَمَ فَقَالَ مِثْلَهُ‏.‏ وَقَالَ سُفْيَانُ مَرَّةً فَقَالَ قَدِمَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَنَحْنُ نَتَبَايَعُ، وَقَالَ نَسِيئَةً إِلَى الْمَوْسِمِ أَوِ الْحَجِّ‏.‏\hadithno{3939}\hadithtrans{Narrated Abu Al-Minhal `AbdurRahman bin Mut`im:A partner of mine sold some Dirhams on credit in the market. I said, "Glorified be Allah! Is this legal?" He replied, "Glorified be Allah! By Allah, when I sold them in the market, nobody objected to it." Then I asked Al-Bara' bin `Azib (about it) he said, "We used to make such a transaction when the Prophet came to Medina. So he said, 'There is no harm in it if it is done from hand to hand, but it is not allowed on credit.' Go to Zaid bin Al- Arqam and ask him about it for he was the greatest trader of all of us." So I asked Zaid bin Al-Arqam., and he said the same (as Al-Bara) did}}
\hadithdefcmd{bukhari}{3978}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، قَالَ ذُكِرَ عِنْدَ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ ابْنَ عُمَرَ رَفَعَ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ يُعَذَّبُ فِي قَبْرِهِ بِبُكَاءِ أَهْلِهِ ‏"‏‏.‏ فَقَالَتْ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَيُعَذَّبُ بِخَطِيئَتِهِ وَذَنْبِهِ، وَإِنَّ أَهْلَهُ لَيَبْكُونَ عَلَيْهِ الآنَ ‏"‏‏.‏ قَالَتْ وَذَاكَ مِثْلُ قَوْلِهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْقَلِيبِ وَفِيهِ قَتْلَى بَدْرٍ مِنَ الْمُشْرِكِينَ، فَقَالَ لَهُمْ مَا قَالَ إِنَّهُمْ لَيَسْمَعُونَ مَا أَقُولُ‏.‏ إِنَّمَا قَالَ ‏"‏ إِنَّهُمُ الآنَ لَيَعْلَمُونَ أَنَّ مَا كُنْتُ أَقُولُ لَهُمْ حَقٌّ ‏"‏‏.‏ ثُمَّ قَرَأَتْ ‏\{‏إِنَّكَ لاَ تُسْمِعُ الْمَوْتَى‏\}‏ ‏\{‏وَمَا أَنْتَ بِمُسْمِعٍ مَنْ فِي الْقُبُورِ‏\}‏ تَقُولُ حِينَ تَبَوَّءُوا مَقَاعِدَهُمْ مِنَ النَّارِ‏.‏\hadithno{3978}\hadithtrans{Narrated Hisham's father:It was mentioned before `Aisha that Ibn `Umar attributed the following statement to the Prophet (ﷺ) "The dead person is punished in the grave because of the crying and lamentation Of his family." On that, `Aisha said, "But Allah's Messenger (ﷺ) said, 'The dead person is punished for his crimes and sins while his family cry over him then." She added, "And this is similar to the statement of Allah's Messenger (ﷺ) when he stood by the (edge of the) well which contained the corpses of the pagans killed at Badr, 'They hear what I say.' She added, "But he said now they know very well what I used to tell them was the truth." `Aisha then recited: 'You cannot make the dead hear.' (30.52) and 'You cannot make those who are in their Graves, hear you.' (35.22) that is, when they had taken their places in the (Hell) Fire}}
\hadithdefcmd{bukhari}{3980}{حَدَّثَنِي عُثْمَانُ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ وَقَفَ النَّبِيُّ صلى الله عليه وسلم عَلَى قَلِيبِ بَدْرٍ فَقَالَ ‏\{‏هَلْ وَجَدْتُمْ مَا وَعَدَ رَبُّكُمْ حَقًّا ثُمَّ قَالَ إِنَّهُمُ الآنَ يَسْمَعُونَ مَا أَقُولُ‏\}‏ فَذُكِرَ لِعَائِشَةَ فَقَالَتْ إِنَّمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهُمُ الآنَ لَيَعْلَمُونَ أَنَّ الَّذِي كُنْتُ أَقُولُ لَهُمْ هُوَ الْحَقُّ ‏"‏‏.‏ ثُمَّ قَرَأَتْ ‏\{‏إِنَّكَ لاَ تُسْمِعُ الْمَوْتَى‏\}‏ حَتَّى قَرَأَتِ الآيَةَ‏.‏\hadithno{3980}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) stood at the well of Badr (which contained the corpses of the pagans) and said, "Have you found true what your lord promised you?" Then he further said, "They now hear what I say." This was mentioned before `Aisha and she said, "But the Prophet (ﷺ) said, 'Now they know very well that what I used to tell them was the truth.' Then she recited (the Holy Verse):-- "You cannot make the dead hear... ...till the end of Verse}}
\hadithdefcmd{bukhari}{4012}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ قَالَ أَخْبَرَ رَافِعُ بْنُ خَدِيجٍ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَنَّ عَمَّيْهِ، وَكَانَا، شَهِدَا بَدْرًا أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ‏.‏ قُلْتُ لِسَالِمٍ فَتُكْرِيهَا أَنْتَ قَالَ نَعَمْ، إِنَّ رَافِعًا أَكْثَرَ عَلَى نَفْسِهِ‏.‏\hadithno{4012}\hadithtrans{Narrated Az-Zuhri:Salim bin `Abdullah told me that Rafi` bin Khadij told `Abdullah bin `Umar that his two paternal uncles who had fought in the battle of Badr informed him that Allah's Messenger (ﷺ) forbade the renting of fields. I said to Salim, "Do you rent your land?" He said, "Yes, for Rafi` is mistaken}}
\hadithdefcmd{bukhari}{4016}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يَقْتُلُ الْحَيَّاتِ كُلَّهَا‏.‏ حَتَّى حَدَّثَهُ أَبُو لُبَابَةَ الْبَدْرِيُّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ جِنَّانِ الْبُيُوتِ، فَأَمْسَكَ عَنْهَا‏.‏\hadithno{4016}\hadithtrans{Narrated Nafi`:Ibn `Umar used to kill all kinds of snakes until Abu Lubaba Al-Badri told him that the Prophet (ﷺ) had forbidden the killing of harmless snakes living in houses and called Jinnan. So Ibn `Umar gave up killing them}}
\hadithdefcmd{bukhari}{4033}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي مَالِكُ بْنُ أَوْسِ بْنِ الْحَدَثَانِ النَّصْرِيُّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ دَعَاهُ إِذْ جَاءَهُ حَاجِبُهُ يَرْفَا فَقَالَ هَلْ لَكَ فِي عُثْمَانَ، وَعَبْدِ الرَّحْمَنِ، وَالزُّبَيْرِ وَسَعْدٍ يَسْتَأْذِنُونَ فَقَالَ نَعَمْ، فَأَدْخِلْهُمْ‏.‏ فَلَبِثَ قَلِيلاً، ثُمَّ جَاءَ فَقَالَ هَلْ لَكَ فِي عَبَّاسٍ وَعَلِيٍّ يَسْتَأْذِنَانِ قَالَ نَعَمْ‏.‏ فَلَمَّا دَخَلاَ قَالَ عَبَّاسٌ يَا أَمِيرَ الْمُؤْمِنِينَ، اقْضِ بَيْنِي وَبَيْنَ هَذَا، وَهُمَا يَخْتَصِمَانِ فِي الَّذِي أَفَاءَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم مِنْ بَنِي النَّضِيرِ، فَاسْتَبَّ عَلِيٌّ وَعَبَّاسٌ، فَقَالَ الرَّهْطُ يَا أَمِيرَ الْمُؤْمِنِينَ، اقْضِ بَيْنَهُمَا وَأَرِحْ أَحَدَهُمَا مِنَ الآخَرِ‏.‏ فَقَالَ عُمَرُ اتَّئِدُوا، أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ، هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ، مَا تَرَكْنَا صَدَقَةٌ ‏"‏‏.‏ يُرِيدُ بِذَلِكَ نَفْسَهُ‏.‏ قَالُوا قَدْ قَالَ ذَلِكَ‏.‏ فَأَقْبَلَ عُمَرُ عَلَى عَبَّاسٍ وَعَلِيٍّ فَقَالَ أَنْشُدُكُمَا بِاللَّهِ هَلْ تَعْلَمَانِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ قَالَ ذَلِكَ قَالاَ نَعَمْ‏.‏ قَالَ فَإِنِّي أُحَدِّثُكُمْ عَنْ هَذَا الأَمْرِ، إِنَّ اللَّهَ سُبْحَانَهُ كَانَ خَصَّ رَسُولَهُ صلى الله عليه وسلم فِي هَذَا الْفَىْءِ بِشَىْءٍ لَمْ يُعْطِهِ أَحَدًا غَيْرَهُ فَقَالَ جَلَّ ذِكْرُهُ ‏\{‏وَمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْهُمْ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلاَ رِكَابٍ‏\}‏ إِلَى قَوْلِهِ ‏\{‏قَدِيرٌ‏\}‏ فَكَانَتْ هَذِهِ خَالِصَةً لِرَسُولِ اللَّهِ صلى الله عليه وسلم، ثُمَّ وَاللَّهِ مَا احْتَازَهَا دُونَكُمْ، وَلاَ اسْتَأْثَرَهَا عَلَيْكُمْ، لَقَدْ أَعْطَاكُمُوهَا وَقَسَمَهَا فِيكُمْ، حَتَّى بَقِيَ هَذَا الْمَالُ مِنْهَا، فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنْفِقُ عَلَى أَهْلِهِ نَفَقَةَ سَنَتِهِمْ مِنْ هَذَا الْمَالِ، ثُمَّ يَأْخُذُ مَا بَقِيَ فَيَجْعَلُهُ مَجْعَلَ مَالِ اللَّهِ، فَعَمِلَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَيَاتَهُ، ثُمَّ تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ أَبُو بَكْرٍ فَأَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَبَضَهُ أَبُو بَكْرٍ، فَعَمِلَ فِيهِ بِمَا عَمِلَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْتُمْ حِينَئِذٍ‏.‏ فَأَقْبَلَ عَلَى عَلِيٍّ وَعَبَّاسٍ وَقَالَ تَذْكُرَانِ أَنَّ أَبَا بَكْرٍ عَمِلَ فِيهِ كَمَا تَقُولاَنِ، وَاللَّهُ يَعْلَمُ إِنَّهُ فِيهِ لَصَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ ثُمَّ تَوَفَّى اللَّهُ أَبَا بَكْرٍ فَقُلْتُ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ‏.‏ فَقَبَضْتُهُ سَنَتَيْنِ مِنْ إِمَارَتِي أَعْمَلُ فِيهِ بِمَا عَمِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ، وَاللَّهُ يَعْلَمُ أَنِّي فِيهِ صَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ، ثُمَّ جِئْتُمَانِي كِلاَكُمَا وَكَلِمَتُكُمَا وَاحِدَةٌ وَأَمْرُكُمَا جَمِيعٌ، فَجِئْتَنِي ـ يَعْنِي عَبَّاسًا ـ فَقُلْتُ لَكُمَا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ، مَا تَرَكْنَا صَدَقَةٌ ‏"‏‏.‏ فَلَمَّا بَدَا لِي أَنْ أَدْفَعَهُ إِلَيْكُمَا قُلْتُ إِنْ شِئْتُمَا دَفَعْتُهُ إِلَيْكُمَا عَلَى أَنَّ عَلَيْكُمَا عَهْدَ اللَّهِ وَمِيثَاقَهُ لَتَعْمَلاَنِ فِيهِ بِمَا عَمِلَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ، وَمَا عَمِلْتُ فِيهِ مُذْ وَلِيتُ، وَإِلاَّ فَلاَ تُكَلِّمَانِي، فَقُلْتُمَا ادْفَعْهُ إِلَيْنَا بِذَلِكَ‏.‏ فَدَفَعْتُهُ إِلَيْكُمَا، أَفَتَلْتَمِسَانِ مِنِّي قَضَاءً غَيْرَ ذَلِكَ فَوَاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ لاَ أَقْضِي فِيهِ بِقَضَاءٍ غَيْرِ ذَلِكَ حَتَّى تَقُومَ السَّاعَةُ، فَإِنْ عَجَزْتُمَا عَنْهُ، فَادْفَعَا إِلَىَّ فَأَنَا أَكْفِيكُمَاهُ‏.‏ قَالَ فَحَدَّثْتُ هَذَا الْحَدِيثَ، عُرْوَةَ بْنَ الزُّبَيْرِ فَقَالَ صَدَقَ مَالِكُ بْنُ أَوْسٍ، أَنَا سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ أَرْسَلَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم عُثْمَانَ إِلَى أَبِي بَكْرٍ يَسْأَلْنَهُ ثُمُنَهُنَّ مِمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم، فَكُنْتُ أَنَا أَرُدُّهُنَّ، فَقُلْتُ لَهُنَّ أَلاَ تَتَّقِينَ اللَّهَ، أَلَمْ تَعْلَمْنَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏"‏ لاَ نُورَثُ، مَا تَرَكْنَا صَدَقَةٌ ـ يُرِيدُ بِذَلِكَ نَفْسَهُ ـ إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ صلى الله عليه وسلم فِي هَذَا الْمَالِ ‏"‏‏.‏ فَانْتَهَى أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم إِلَى مَا أَخْبَرَتْهُنَّ‏.‏ قَالَ فَكَانَتْ هَذِهِ الصَّدَقَةُ بِيَدِ عَلِيٍّ، مَنَعَهَا عَلِيٌّ عَبَّاسًا فَغَلَبَهُ عَلَيْهَا، ثُمَّ كَانَ بِيَدِ حَسَنِ بْنِ عَلِيٍّ، ثُمَّ بِيَدِ حُسَيْنِ بْنِ عَلِيٍّ، ثُمَّ بِيَدِ عَلِيِّ بْنِ حُسَيْنٍ وَحَسَنِ بْنِ حَسَنٍ، كِلاَهُمَا كَانَا يَتَدَاوَلاَنِهَا، ثُمَّ بِيَدِ زَيْدِ بْنِ حَسَنٍ، وَهْىَ صَدَقَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم حَقًّا‏.‏\hadithno{4033}\hadithtrans{Narrated Malik bin Aus Al-Hadathan An-Nasri:That once `Umar bin Al-Khattab called him and while he was sitting with him, his gatekeeper, Yarfa came and said, "Will you admit `Uthman, `Abdur-Rahman bin `Auf, Az-Zubair and Sa`d (bin Abi Waqqas) who are waiting for your permission?" `Umar said, "Yes, let them come in." After a while, Yarfa- came again and said, "Will you admit `Ali and `Abbas who are asking your permission?" `Umar said, "Yes." So, when the two entered, `Abbas said, "O chief of the believers! Judge between me and this (i.e. `Ali). "Both of them had a dispute regarding the property of Bani An-Nadir which Allah had given to His Apostle as Fai (i.e. booty gained without fighting), `Ali and `Abbas started reproaching each other. The (present) people (i.e. `Uthman and his companions) said, "O chief of the believers! Give your verdict in their case and relieve each from) the other." `Umar said, "Wait I beseech you, by Allah, by Whose Permission both the heaven and the earth stand fast! Do you know that Allah's Messenger (ﷺ) said, 'We (Prophets) our properties are not to be inherited, and whatever we leave, is to be spent in charity,' and he said it about himself?" They (i.e. `Uthman and his company) said, "He did say it. "`Umar then turned towards `Ali and `Abbas and said, "I beseech you both, by Allah! Do you know that Allah's Messenger (ﷺ) said this?" They replied in the affirmative. He said, "Now I am talking to you about this matter. Allah the Glorified favored His Apostle with something of this Fai (i.e. booty won without fighting) which He did not give to anybody else. Allah said:-- "And what Allah gave to His Apostle ("Fai"" Booty) from them--For which you made no expedition With either Calvary or camelry. But Allah gives power to His Apostles Over whomsoever He will And Allah is able to do all things." (59.6) So this property was especially granted to Allah's Messenger (ﷺ) . But by Allah, the Prophet (ﷺ) neither took it all for himself only, nor deprived you of it, but he gave it to all of you and distributed it amongst you till only this remained out of it. And from this Allah's Messenger (ﷺ) used to spend the yearly maintenance for his family, and whatever used to remain, he used to spend it where Allah's Property is spent (i.e. in charity), Allah's Messenger (ﷺ) kept on acting like that during all his life, Then he died, and Abu Bakr said, 'I am the successor of Allah's Messenger (ﷺ).' So he (i.e. Abu Bakr) took charge of this property and disposed of it in the same manner as Allah's Messenger (ﷺ) used to do, and all of you (at that time) knew all about it." Then `Umar turned towards `Ali and `Abbas and said, "You both remember that Abu Bakr disposed of it in the way you have described and Allah knows that, in that matter, he was sincere, pious, rightly guided and the follower of the right. Then Allah caused Abu Bakr to die and I said, 'I am the successor of Allah's Messenger (ﷺ) and Abu Bakr.' So I kept this property in my possession for the first two years of my rule (i.e. Caliphate and I used to dispose of it in the same wa as Allah's Messenger (ﷺ) and Abu Bakr used to do; and Allah knows that I have been sincere, pious, rightly guided an the follower of the right (in this matter). Later on both of you (i.e. `Ali and `Abbas) came to me, and the claim of you both was one and the same, O `Abbas! You also came to me. So I told you both that Allah's Messenger (ﷺ) said, "Our property is not inherited, but whatever we leave is to be given in charity.' Then when I thought that I should better hand over this property to you both on the condition that you will promise and pledge before Allah that you will dispose it off in the same way as Allah's Messenger (ﷺ) and Abu Bakr did and as I have done since the beginning of my caliphate or else you should not speak to me (about it).' So, both of you said to me, 'Hand it over to us on this condition.' And on this condition I handed it over to you. Do you want me now to give a decision other than that (decision)? By Allah, with Whose Permission both the sky and the earth stand fast, I will never give any decision other than that (decision) till the Last Hour is established. But if you are unable to manage it (i.e. that property), then return it to me, and I will manage on your behalf." The sub-narrator said, "I told `Urwa bin Az-Zubair of this Hadith and he said, 'Malik bin Aus has told the truth" I heard `Aisha, the wife of the Prophet (ﷺ) saying, 'The wives of the Prophet (ﷺ) sent `Uthman to Abu Bakr demanding from him their 1/8 of the Fai which Allah had granted to his Apostle. But I used to oppose them and say to them: Will you not fear Allah? Don't you know that the Prophet used to say: Our property is not inherited, but whatever we leave is to be given in charity? The Prophet (ﷺ) mentioned that regarding himself. He added: 'The family of Muhammad can take their sustenance from this property. So the wives of the Prophet (ﷺ) stopped demanding it when I told them of that.' So, this property (of Sadaqa) was in the hands of `Ali who withheld it from `Abbas and overpowered him. Then it came in the hands of Hasan bin `Ali, then in the hands of Husain bin `Ali, and then in the hands of `Ali bin Husain and Hasan bin Hasan, and each of the last two used to manage it in turn, then it came in the hands of Zaid bin Hasan, and it was truly the Sadaqa of Allah's Apostle}}
\hadithdefcmd{bukhari}{4035}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ وَالْعَبَّاسَ أَتَيَا أَبَا بَكْرٍ يَلْتَمِسَانِ مِيرَاثَهُمَا، أَرْضَهُ مِنْ فَدَكٍ، وَسَهْمَهُ مِنْ خَيْبَرَ‏.‏ فَقَالَ أَبُو بَكْرٍ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ نُورَثُ، مَا تَرَكْنَا صَدَقَةٌ، إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ فِي هَذَا الْمَالِ ‏"‏‏.‏ وَاللَّهِ لَقَرَابَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَبُّ إِلَىَّ أَنْ أَصِلَ مِنْ قَرَابَتِي‏.‏\hadithno{4035}\hadithtrans{Narrated `Aisha:Fatima and Al-`Abbas came to Abu Bakr, claiming their inheritance of the Prophet's land of Fadak and his share from Khaibar. Abu Bakr said, "I heard the Prophet (ﷺ) saying, 'Our property is not inherited, and whatever we leave is to be given in charity. But the family of Muhammad can take their sustenance from this property.' By Allah, I would love to do good to the Kith and kin of Allah's Apostle rather than to my own Kith and kin}}
\hadithdefcmd{bukhari}{4043}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ لَقِينَا الْمُشْرِكِينَ يَوْمَئِذٍ، وَأَجْلَسَ النَّبِيُّ صلى الله عليه وسلم جَيْشًا مِنَ الرُّمَاةِ، وَأَمَّرَ عَلَيْهِمْ عَبْدَ اللَّهِ وَقَالَ ‏"‏ لاَ تَبْرَحُوا، إِنْ رَأَيْتُمُونَا ظَهَرْنَا عَلَيْهِمْ فَلاَ تَبْرَحُوا وَإِنْ رَأَيْتُمُوهُمْ ظَهَرُوا عَلَيْنَا فَلاَ تُعِينُونَا ‏"‏‏.‏ فَلَمَّا لَقِينَا هَرَبُوا حَتَّى رَأَيْتُ النِّسَاءَ يَشْتَدِدْنَ فِي الْجَبَلِ، رَفَعْنَ عَنْ سُوقِهِنَّ قَدْ بَدَتْ خَلاَخِلُهُنَّ، فَأَخَذُوا يَقُولُونَ الْغَنِيمَةَ الْغَنِيمَةَ‏.‏ فَقَالَ عَبْدُ اللَّهِ عَهِدَ إِلَىَّ النَّبِيُّ صلى الله عليه وسلم أَنْ لاَ تَبْرَحُوا‏.‏ فَأَبَوْا، فَلَمَّا أَبَوْا صُرِفَ وُجُوهُهُمْ، فَأُصِيبَ سَبْعُونَ قَتِيلاً، وَأَشْرَفَ أَبُو سُفْيَانَ فَقَالَ أَفِي الْقَوْمِ مُحَمَّدٌ فَقَالَ ‏"‏ لاَ تُجِيبُوهُ ‏"‏‏.‏ فَقَالَ أَفِي الْقَوْمِ ابْنُ أَبِي قُحَافَةَ قَالَ ‏"‏ لاَ تُجِيبُوهُ ‏"‏‏.‏ فَقَالَ أَفِي الْقَوْمِ ابْنُ الْخَطَّابِ فَقَالَ إِنَّ هَؤُلاَءِ قُتِلُوا، فَلَوْ كَانُوا أَحْيَاءً لأَجَابُوا، فَلَمْ يَمْلِكْ عُمَرُ نَفْسَهُ فَقَالَ كَذَبْتَ يَا عَدُوَّ اللَّهِ، أَبْقَى اللَّهُ عَلَيْكَ مَا يُخْزِيكَ‏.‏ قَالَ أَبُو سُفْيَانَ أُعْلُ هُبَلْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَجِيبُوهُ ‏"‏‏.‏ قَالُوا مَا نَقُولُ قَالَ ‏"‏ قُولُوا اللَّهُ أَعْلَى وَأَجَلُّ ‏"‏‏.‏ قَالَ أَبُو سُفْيَانَ لَنَا الْعُزَّى وَلاَ عُزَّى لَكُمْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَجِيبُوهُ ‏"‏‏.‏ قَالُوا مَا نَقُولُ قَالَ ‏"‏ قُولُوا اللَّهُ مَوْلاَنَا وَلاَ مَوْلَى لَكُمْ ‏"‏‏.‏ قَالَ أَبُو سُفْيَانَ يَوْمٌ بِيَوْمِ بَدْرٍ، وَالْحَرْبُ سِجَالٌ، وَتَجِدُونَ مُثْلَةً لَمْ آمُرْ بِهَا وَلَمْ تَسُؤْنِي‏.‏ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، قَالَ اصْطَبَحَ الْخَمْرَ يَوْمَ أُحُدٍ نَاسٌ ثُمَّ قُتِلُوا شُهَدَاءَ‏.‏\hadithno{4043}\hadithtrans{Narrated Al-Bara:We faced the pagans on that day (of the battle of Uhud) and the Prophet (ﷺ) placed a batch of archers (at a special place) and appointed `Abdullah (bin Jubair) as their commander and said, "Do not leave this place; if you should see us conquering the enemy, do not leave this place, and if you should see them conquering us, do not (come to) help us," So, when we faced the enemy, they took to their heels till I saw their women running towards the mountain, lifting up their clothes from their legs, revealing their leg-bangles. The Muslims started saying, "The booty, the booty!" `Abdullah bin Jubair said, "The Prophet (ﷺ) had taken a firm promise from me not to leave this place." But his companions refused (to stay). So when they refused (to stay there), (Allah) confused them so that they could not know where to go, and they suffered seventy casualties. Abu Sufyan ascended a high place and said, "Is Muhammad present amongst the people?" The Prophet (ﷺ) said, "Do not answer him." Abu Sufyan said, "Is the son of Abu Quhafa present among the people?" The Prophet (ﷺ) said, "Do not answer him." `Abu Sufyan said, "Is the son of Al-Khattab amongst the people?" He then added, "All these people have been killed, for, were they alive, they would have replied." On that, `Umar could not help saying, "You are a liar, O enemy of Allah! Allah has kept what will make you unhappy." Abu Sufyan said, "Superior may be Hubal!" On that the Prophet said (to his companions), "Reply to him." They asked, "What may we say?" He said, "Say: Allah is More Elevated and More Majestic!" Abu Sufyan said, "We have (the idol) Al-`Uzza, whereas you have no `Uzza!" The Prophet (ﷺ) said (to his companions), "Reply to him." They said, "What may we say?" The Prophet (ﷺ) said, "Say: Allah is our Helper and you have no helper." Abu Sufyan said, "(This) day compensates for our loss at Badr and (in) the battle (the victory) is always undecided and shared in turns by the belligerents. You will see some of your dead men mutilated, but neither did I urge this action, nor am I sorry for it." Narrated Jabir: Some people took wine in the morning of the day of Uhud and were then killed as martyrs}}
\hadithdefcmd{bukhari}{4060}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، عَنْ مُعْتَمِرٍ، عَنْ أَبِيهِ، قَالَ زَعَمَ أَبُو عُثْمَانَ أَنَّهُ لَمْ يَبْقَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَعْضِ تِلْكَ الأَيَّامِ الَّتِي يُقَاتِلُ فِيهِنَّ غَيْرُ طَلْحَةَ وَسَعْدٍ‏.‏ عَنْ حَدِيثِهِمَا‏.‏\hadithno{4060}\hadithtrans{Narrated Mu'tamir's father:`Uthman said that on the day of the battle of Uhud, none remained with the Prophet (ﷺ) but Talha and Sa`d}}
\hadithdefcmd{bukhari}{4079}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ فِي ثَوْبٍ وَاحِدٍ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمْ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدٍ، قَدَّمَهُ فِي اللَّحْدِ، وَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ وَأَمَرَ بِدَفْنِهِمْ بِدِمَائِهِمْ، وَلَمْ يُصَلِّ عَلَيْهِمْ، وَلَمْ يُغَسَّلُوا‏.‏ وَقَالَ أَبُو الْوَلِيدِ عَنْ شُعْبَةَ، عَنِ ابْنِ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرًا، قَالَ لَمَّا قُتِلَ أَبِي جَعَلْتُ أَبْكِي وَأَكْشِفُ الثَّوْبَ عَنْ وَجْهِهِ،، فَجَعَلَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم يَنْهَوْنِي وَالنَّبِيُّ صلى الله عليه وسلم لَمْ يَنْهَ، وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تَبْكِيهِ أَوْ مَا تَبْكِيهِ، مَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا حَتَّى رُفِعَ ‏"‏‏.‏\hadithno{4079}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) used to shroud two martyrs of Uhud in one sheet and then say, "Which of them knew Qur'an more?" When one of the two was pointed out, he would put him first in the grave. Then he said, "I will be a witness for them on the Day of Resurrection." He ordered them to be buried with their blood (on their bodies). Neither was the funeral prayer offered for them, nor were they washed. Jabir added, "When my father was martyred, I started weeping and uncovering his face. The companions of the Prophet (ﷺ) stopped me from doing so but the Prophet (ﷺ) did not stop me. Then the Prophet said, '(O Jabir.) don't weep over him, for the angels kept on covering him with their wings till his body was carried away (for burial)}}
\hadithdefcmd{bukhari}{4157}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ مَرْوَانَ، وَالْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالاَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ فِي بِضْعَ عَشْرَةَ مِائَةً مِنْ أَصْحَابِهِ، فَلَمَّا كَانَ بِذِي الْحُلَيْفَةِ قَلَّدَ الْهَدْىَ وَأَشْعَرَ وَأَحْرَمَ مِنْهَا‏.‏ لاَ أُحْصِي كَمْ سَمِعْتُهُ مِنْ سُفْيَانَ حَتَّى سَمِعْتُهُ يَقُولُ لاَ أَحْفَظُ مِنَ الزُّهْرِيِّ الإِشْعَارَ وَالتَّقْلِيدَ، فَلاَ أَدْرِي ـ يَعْنِي ـ مَوْضِعَ الإِشْعَارِ وَالتَّقْلِيدِ، أَوِ الْحَدِيثَ كُلَّهُ‏.‏\hadithno{4157}\hadithtrans{Narrated Marwan and Al-Miswar bin Makhrama:The Prophet (ﷺ) went out in the company of 1300 to 1500 of his companions in the year of Al-Hudaibiya, and when they reached Dhul-Hulaifa, he garlanded and marked his Hadi and assumed the state of Ihram}}
\hadithdefcmd{bukhari}{4160}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ خَرَجْتُ مَعَ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ إِلَى السُّوقِ، فَلَحِقَتْ عُمَرَ امْرَأَةٌ شَابَّةٌ فَقَالَتْ يَا أَمِيرَ الْمُؤْمِنِينَ هَلَكَ زَوْجِي وَتَرَكَ صِبْيَةً صِغَارًا، وَاللَّهِ مَا يُنْضِجُونَ كُرَاعًا، وَلاَ لَهُمْ زَرْعٌ وَلاَ ضَرْعٌ، وَخَشِيتُ أَنْ تَأْكُلَهُمُ الضَّبُعُ، وَأَنَا بِنْتُ خُفَافِ بْنِ إِيمَاءَ الْغِفَارِيِّ، وَقَدْ شَهِدَ أَبِي الْحُدَيْبِيَةَ مَعَ النَّبِيِّ صلى الله عليه وسلم، فَوَقَفَ مَعَهَا عُمَرُ، وَلَمْ يَمْضِ، ثُمَّ قَالَ مَرْحَبًا بِنَسَبٍ قَرِيبٍ‏.‏ ثُمَّ انْصَرَفَ إِلَى بَعِيرٍ ظَهِيرٍ كَانَ مَرْبُوطًا فِي الدَّارِ، فَحَمَلَ عَلَيْهِ غِرَارَتَيْنِ مَلأَهُمَا طَعَامًا، وَحَمَلَ بَيْنَهُمَا نَفَقَةً وَثِيَابًا، ثُمَّ نَاوَلَهَا بِخِطَامِهِ ثُمَّ قَالَ اقْتَادِيهِ فَلَنْ يَفْنَى حَتَّى يَأْتِيَكُمُ اللَّهُ بِخَيْرٍ‏.‏ فَقَالَ رَجُلٌ يَا أَمِيرَ الْمُؤْمِنِينَ أَكْثَرْتَ لَهَا‏.‏ قَالَ عُمَرُ ثَكِلَتْكَ أُمُّكَ، وَاللَّهِ إِنِّي لأَرَى أَبَا هَذِهِ وَأَخَاهَا قَدْ حَاصَرَا حِصْنًا زَمَانًا، فَافْتَتَحَاهُ، ثُمَّ أَصْبَحْنَا نَسْتَفِيءُ سُهْمَانَهُمَا فِيهِ‏.‏\hadithno{4160}\hadithtrans{(Narrated Aslam:Once I went with `Umar bin Al-Khattab to the market. A young woman followed `Umar and said, "O chief of the believers! My husband has died, leaving little children. By Allah, they have not even a sheep's trotter to cook; they have no farms or animals. I am afraid that they may die because of hunger, and I am the daughter of Khufaf bin Ima Al-Ghafari, and my father witnessed the Pledge of allegiance) of Al-Hudaibiya with the Prophet.' `Umar stopped and did not proceed, and said, "I welcome my near relative." Then he went towards a strong camel which was tied in the house, and carried on to it, two sacks he had loaded with food grains and put between them money and clothes and gave her its rope to hold and said, "Lead it, and this provision will not finish till Allah gives you a good supply." A man said, "O chief of the believers! You have given her too much." "`Umar said disapprovingly. "May your mother be bereaved of you! By Allah, I have seen her father and brother besieging a fort for a long time and conquering it, and then we were discussing what their shares they would have from that war booty}}
\hadithdefcmd{bukhari}{4178}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، حِينَ حَدَّثَ هَذَا الْحَدِيثَ،، حَفِظْتُ بَعْضَهُ، وَثَبَّتَنِي مَعْمَرٌ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَمَرْوَانَ بْنِ الْحَكَمِ، يَزِيدُ أَحَدُهُمَا عَلَى صَاحِبِهِ قَالاَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ فِي بِضْعَ عَشْرَةَ مِائَةً مِنْ أَصْحَابِهِ، فَلَمَّا أَتَى ذَا الْحُلَيْفَةِ قَلَّدَ الْهَدْىَ، وَأَشْعَرَهُ، وَأَحْرَمَ مِنْهَا بِعُمْرَةٍ، وَبَعَثَ عَيْنًا لَهُ مِنْ خُزَاعَةَ، وَسَارَ النَّبِيُّ صلى الله عليه وسلم حَتَّى كَانَ بِغَدِيرِ الأَشْطَاطِ، أَتَاهُ عَيْنُهُ قَالَ إِنَّ قُرَيْشًا جَمَعُوا لَكَ جُمُوعًا، وَقَدْ جَمَعُوا لَكَ الأَحَابِيشَ، وَهُمْ مُقَاتِلُوكَ وَصَادُّوكَ عَنِ الْبَيْتِ وَمَانِعُوكَ‏.‏ فَقَالَ ‏"‏ أَشِيرُوا أَيُّهَا النَّاسُ عَلَىَّ، أَتَرَوْنَ أَنْ أَمِيلَ إِلَى عِيَالِهِمْ وَذَرَارِيِّ هَؤُلاَءِ الَّذِينَ يُرِيدُونَ أَنْ يَصُدُّونَا عَنِ الْبَيْتِ، فَإِنْ يَأْتُونَا كَانَ اللَّهُ عَزَّ وَجَلَّ قَدْ قَطَعَ عَيْنًا مِنَ الْمُشْرِكِينَ، وَإِلاَّ تَرَكْنَاهُمْ مَحْرُوبِينَ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ، خَرَجْتَ عَامِدًا لِهَذَا الْبَيْتِ، لاَ تُرِيدُ قَتْلَ أَحَدٍ وَلاَ حَرْبَ أَحَدٍ، فَتَوَجَّهْ لَهُ، فَمَنْ صَدَّنَا عَنْهُ قَاتَلْنَاهُ‏.‏ قَالَ ‏"‏ امْضُوا عَلَى اسْمِ اللَّهِ ‏"‏‏.‏\hadithno{4178}\hadithtrans{Narrated Al-Miswar bin Makhrama and Marwan bin Al-Hakam:(one of them said more than his friend): The Prophet (ﷺ) set out in the company of more than onethousand of his companions in the year of Al-Hudaibiya, and when he reached Dhul-Hulaifa, he garlanded his Hadi (i.e. sacrificing animal), assumed the state of Ihram for `Umra from that place and sent a spy of his from Khuzi'a (tribe). The Prophet (ﷺ) proceeded on till he reached (a village called) Ghadir-al-Ashtat. There his spy came and said, "The Quraish (infidels) have collected a great number of people against you, and they have collected against you the Ethiopians, and they will fight with you, and will stop you from entering the Ka`ba and prevent you." The Prophet (ﷺ) said, "O people! Give me your opinion. Do you recommend that I should destroy the families and offspring of those who want to stop us from the Ka`ba? If they should come to us (for peace) then Allah will destroy a spy from the pagans, or otherwise we will leave them in a miserable state." On that Abu Bakr said, "O Allah's Apostle! You have come with the intention of visiting this House (i.e. Ka`ba) and you do not want to kill or fight anybody. So proceed to it, and whoever should stop us from it, we will fight him." On that the Prophet (ﷺ) said, "Proceed on, in the Name of Allah}}
\hadithdefcmd{bukhari}{4180}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا يَعْقُوبُ، حَدَّثَنِي ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَمِعَ مَرْوَانَ بْنَ الْحَكَمِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، يُخْبِرَانِ خَبَرًا مِنْ خَبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي عُمْرَةِ الْحُدَيْبِيَةِ فَكَانَ فِيمَا أَخْبَرَنِي عُرْوَةُ عَنْهُمَا أَنَّهُ لَمَّا كَاتَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم سُهَيْلَ بْنَ عَمْرٍو، يَوْمَ الْحُدَيْبِيَةِ عَلَى قَضِيَّةِ الْمُدَّةِ، وَكَانَ فِيمَا اشْتَرَطَ سُهَيْلُ بْنُ عَمْرٍو أَنَّهُ قَالَ لاَ يَأْتِيكَ مِنَّا أَحَدٌ وَإِنْ كَانَ عَلَى دِينِكَ إِلاَّ رَدَدْتَهُ إِلَيْنَا، وَخَلَّيْتَ بَيْنَنَا وَبَيْنَهُ‏.‏ وَأَبَى سُهَيْلٌ أَنْ يُقَاضِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم إِلاَّ عَلَى ذَلِكَ، فَكَرِهَ الْمُؤْمِنُونَ ذَلِكَ وَامَّعَضُوا، فَتَكَلَّمُوا فِيهِ، فَلَمَّا أَبَى سُهَيْلٌ أَنْ يُقَاضِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم إِلاَّ عَلَى ذَلِكَ، كَاتَبَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم، فَرَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا جَنْدَلِ بْنَ سُهَيْلٍ يَوْمَئِذٍ إِلَى أَبِيهِ سُهَيْلِ بْنِ عَمْرٍو، وَلَمْ يَأْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم أَحَدٌ مِنَ الرِّجَالِ إِلاَّ رَدَّهُ فِي تِلْكَ الْمُدَّةِ، وَإِنْ كَانَ مُسْلِمًا، وَجَاءَتِ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ، فَكَانَتْ أُمُّ كُلْثُومٍ بِنْتُ عُقْبَةَ بْنِ مُعَيْطٍ مِمَّنْ خَرَجَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْىَ عَاتِقٌ، فَجَاءَ أَهْلُهَا يَسْأَلُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَرْجِعَهَا إِلَيْهِمْ، حَتَّى أَنْزَلَ اللَّهُ تَعَالَى فِي الْمُؤْمِنَاتِ مَا أَنْزَلَ‏.‏\hadithno{4180}\hadithtrans{Narrated `Urwa bin Az-Zubair:That he heard Marwan bin Al-Hakam and Al-Miswar bin Makhrama relating one of the events that happened to Allah's Messenger (ﷺ) in the `Umra of Al-Hudaibiya. They said, "When Allah's Messenger (ﷺ) concluded the truce with Suhail bin `Amr on the day of Al-Hudaibiya, one of the conditions which Suhail bin `Amr stipulated, was his saying (to the Prophet), "If anyone from us (i.e. infidels) ever comes to you, though he has embraced your religion, you should return him to us, and should not interfere between us and him." Suhail refused to conclude the truce with Allah's Messenger (ﷺ) except on this condition. The believers disliked this condition and got disgusted with it and argued about it. But when Suhail refused to conclude the truce with Allah's Messenger (ﷺ) except on that condition, Allah's Apostle concluded it. Accordingly, Allah's Messenger (ﷺ) then returned Abu Jandal bin Suhail to his father, Suhail bin `Amr, and returned every man coming to him from them during that period even if he was a Muslim. The believing women Emigrants came (to Medina) and Um Kulthum, the daughter of `Uqba bin Abi Mu'ait was one of those who came to Allah's Messenger (ﷺ) and she was an adult at that time. Her relatives came, asking Allah's Messenger (ﷺ) to return her to them, and in this connection, Allah revealed the Verses dealing with the believing (women)}}
\hadithdefcmd{bukhari}{4221}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَدِيُّ بْنُ ثَابِتٍ، عَنِ الْبَرَاءِ، وَعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، رضى الله عنهم أَنَّهُمْ كَانُوا مَعَ النَّبِيِّ صلى الله عليه وسلم فَأَصَابُوا حُمُرًا فَطَبَخُوهَا، فَنَادَى مُنَادِي النَّبِيِّ صلى الله عليه وسلم أَكْفِئُوا الْقُدُورَ‏.‏\hadithno{4221}\hadithtrans{Narrated Al-Bara and `Abdullah bin Abi `Aufa:That when they were in the company of the Prophet, they got some donkeys which they (slaughtered and) cooked. Then the announcer of the Prophet (ﷺ) said, "Turn the cooking pots upside down (i.e. throw out the meat)}}
\hadithdefcmd{bukhari}{4223}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَدِيُّ بْنُ ثَابِتٍ، سَمِعْتُ الْبَرَاءَ، وَابْنَ أَبِي أَوْفَى، يُحَدِّثَانِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ يَوْمَ خَيْبَرَ وَقَدْ نَصَبُوا الْقُدُورَ أَكْفِئُوا الْقُدُورَ‏.‏\hadithno{4223}\hadithtrans{Narrated Al-Bara' and Ibn Abi `Aufa:On the day of Khaibar when the cooking pots were put on the fire, the Prophet (ﷺ) said, "Turn the cooking pots upside down}}
\hadithdefcmd{bukhari}{4240}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ بِنْتَ النَّبِيِّ صلى الله عليه وسلم أَرْسَلَتْ إِلَى أَبِي بَكْرٍ تَسْأَلُهُ مِيرَاثَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِمَّا أَفَاءَ اللَّهُ عَلَيْهِ بِالْمَدِينَةِ وَفَدَكَ، وَمَا بَقِيَ مِنْ خُمُسِ خَيْبَرَ، فَقَالَ أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ، مَا تَرَكْنَا صَدَقَةٌ، إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ صلى الله عليه وسلم فِي هَذَا الْمَالِ ‏"‏‏.‏ وَإِنِّي وَاللَّهِ لاَ أُغَيِّرُ شَيْئًا مِنْ صَدَقَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ حَالِهَا الَّتِي كَانَ عَلَيْهَا فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلأَعْمَلَنَّ فِيهَا بِمَا عَمِلَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَبَى أَبُو بَكْرٍ أَنْ يَدْفَعَ إِلَى فَاطِمَةَ مِنْهَا شَيْئًا فَوَجَدَتْ فَاطِمَةُ عَلَى أَبِي بَكْرٍ فِي ذَلِكَ فَهَجَرَتْهُ، فَلَمْ تُكَلِّمْهُ حَتَّى تُوُفِّيَتْ، وَعَاشَتْ بَعْدَ النَّبِيِّ صلى الله عليه وسلم سِتَّةَ أَشْهُرٍ، فَلَمَّا تُوُفِّيَتْ، دَفَنَهَا زَوْجُهَا عَلِيٌّ لَيْلاً، وَلَمْ يُؤْذِنْ بِهَا أَبَا بَكْرٍ وَصَلَّى عَلَيْهَا، وَكَانَ لِعَلِيٍّ مِنَ النَّاسِ وَجْهٌ حَيَاةَ فَاطِمَةَ، فَلَمَّا تُوُفِّيَتِ اسْتَنْكَرَ عَلِيٌّ وُجُوهَ النَّاسِ، فَالْتَمَسَ مُصَالَحَةَ أَبِي بَكْرٍ وَمُبَايَعَتَهُ، وَلَمْ يَكُنْ يُبَايِعُ تِلْكَ الأَشْهُرَ، فَأَرْسَلَ إِلَى أَبِي بَكْرٍ أَنِ ائْتِنَا، وَلاَ يَأْتِنَا أَحَدٌ مَعَكَ، كَرَاهِيَةً لِمَحْضَرِ عُمَرَ‏.‏ فَقَالَ عُمَرُ لاَ وَاللَّهِ لاَ تَدْخُلُ عَلَيْهِمْ وَحْدَكَ‏.‏ فَقَالَ أَبُو بَكْرٍ وَمَا عَسَيْتَهُمْ أَنْ يَفْعَلُوا بِي، وَاللَّهِ لآتِيَنَّهُمْ‏.‏ فَدَخَلَ عَلَيْهِمْ أَبُو بَكْرٍ، فَتَشَهَّدَ عَلِيٌّ فَقَالَ إِنَّا قَدْ عَرَفْنَا فَضْلَكَ، وَمَا أَعْطَاكَ، اللَّهُ وَلَمْ نَنْفَسْ عَلَيْكَ خَيْرًا سَاقَهُ اللَّهُ إِلَيْكَ، وَلَكِنَّكَ اسْتَبْدَدْتَ عَلَيْنَا بِالأَمْرِ، وَكُنَّا نَرَى لِقَرَابَتِنَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم نَصِيبًا‏.‏ حَتَّى فَاضَتْ عَيْنَا أَبِي بَكْرٍ، فَلَمَّا تَكَلَّمَ أَبُو بَكْرٍ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ لَقَرَابَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَبُّ إِلَىَّ أَنْ أَصِلَ مِنْ قَرَابَتِي، وَأَمَّا الَّذِي شَجَرَ بَيْنِي وَبَيْنَكُمْ مِنْ هَذِهِ الأَمْوَالِ، فَلَمْ آلُ فِيهَا عَنِ الْخَيْرِ، وَلَمْ أَتْرُكْ أَمْرًا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُهُ فِيهَا إِلاَّ صَنَعْتُهُ‏.‏ فَقَالَ عَلِيٌّ لأَبِي بَكْرٍ مَوْعِدُكَ الْعَشِيَّةُ لِلْبَيْعَةِ‏.‏ فَلَمَّا صَلَّى أَبُو بَكْرٍ الظُّهْرَ رَقِيَ عَلَى الْمِنْبَرِ، فَتَشَهَّدَ وَذَكَرَ شَأْنَ عَلِيٍّ، وَتَخَلُّفَهُ عَنِ الْبَيْعَةِ، وَعُذْرَهُ بِالَّذِي اعْتَذَرَ إِلَيْهِ، ثُمَّ اسْتَغْفَرَ، وَتَشَهَّدَ عَلِيٌّ فَعَظَّمَ حَقَّ أَبِي بَكْرٍ، وَحَدَّثَ أَنَّهُ لَمْ يَحْمِلْهُ عَلَى الَّذِي صَنَعَ نَفَاسَةً عَلَى أَبِي بَكْرٍ، وَلاَ إِنْكَارًا لِلَّذِي فَضَّلَهُ اللَّهُ بِهِ، وَلَكِنَّا نَرَى لَنَا فِي هَذَا الأَمْرِ نَصِيبًا، فَاسْتَبَدَّ عَلَيْنَا، فَوَجَدْنَا فِي أَنْفُسِنَا، فَسُرَّ بِذَلِكَ الْمُسْلِمُونَ وَقَالُوا أَصَبْتَ‏.‏ وَكَانَ الْمُسْلِمُونَ إِلَى عَلِيٍّ قَرِيبًا، حِينَ رَاجَعَ الأَمْرَ الْمَعْرُوفَ‏.‏\hadithno{4240}\hadithtrans{Narrated `Aisha:Fatima the daughter of the Prophet (ﷺ) sent someone to Abu Bakr (when he was a caliph), asking for her inheritance of what Allah's Messenger (ﷺ) had left of the property bestowed on him by Allah from the Fai (i.e. booty gained without fighting) in Medina, and Fadak, and what remained of the Khumus of the Khaibar booty. On that, Abu Bakr said, "Allah's Messenger (ﷺ) said, "Our property is not inherited. Whatever we leave, is Sadaqa, but the family of (the Prophet) Muhammad can eat of this property.' By Allah, I will not make any change in the state of the Sadaqa of Allah's Messenger (ﷺ) and will leave it as it was during the lifetime of Allah's Messenger (ﷺ), and will dispose of it as Allah's Messenger (ﷺ) used to do." So Abu Bakr refused to give anything of that to Fatima. So she became angry with Abu Bakr and kept away from him, and did not task to him till she died. She remained alive for six months after the death of the Prophet. When she died, her husband `Ali, buried her at night without informing Abu Bakr and he said the funeral prayer by himself. When Fatima was alive, the people used to respect `Ali much, but after her death, `Ali noticed a change in the people's attitude towards him. So `Ali sought reconciliation with Abu Bakr and gave him an oath of allegiance. `Ali had not given the oath of allegiance during those months (i.e. the period between the Prophet's death and Fatima's death). `Ali sent someone to Abu Bakr saying, "Come to us, but let nobody come with you," as he disliked that `Umar should come, `Umar said (to Abu Bakr), "No, by Allah, you shall not enter upon them alone " Abu Bakr said, "What do you think they will do to me? By Allah, I will go to them' So Abu Bakr entered upon them, and then `Ali uttered Tashah-hud and said (to Abu Bakr), "We know well your superiority and what Allah has given you, and we are not jealous of the good what Allah has bestowed upon you, but you did not consult us in the question of the rule and we thought that we have got a right in it because of our near relationship to Allah's Messenger (ﷺ) ." Thereupon Abu Bakr's eyes flowed with tears. And when Abu Bakr spoke, he said, "By Him in Whose Hand my soul is to keep good relations with the relatives of Allah's Messenger (ﷺ) is dearer to me than to keep good relations with my own relatives. But as for the trouble which arose between me and you about his property, I will do my best to spend it according to what is good, and will not leave any rule or regulation which I saw Allah's Messenger (ﷺ) following, in disposing of it, but I will follow." On that `Ali said to Abu Bakr, "I promise to give you the oath of allegiance in this afternoon." So when Abu Bakr had offered the Zuhr prayer, he ascended the pulpit and uttered the Tashah-hud and then mentioned the story of `Ali and his failure to give the oath of allegiance, and excused him, accepting what excuses he had offered; Then `Ali (got up) and praying (to Allah) for forgiveness, he uttered Tashah-hud, praised Abu Bakr's right, and said, that he had not done what he had done because of jealousy of Abu Bakr or as a protest of what Allah had favored him with. `Ali added, "But we used to consider that we too had some right in this affair (of rulership) and that he (i.e. Abu Bakr) did not consult us in this matter, and therefore caused us to feel sorry." On that all the Muslims became happy and said, "You have done the right thing." The Muslims then became friendly with `Ali as he returned to what the people had done (i.e. giving the oath of allegiance to Abu Bakr)}}
\hadithdefcmd{bukhari}{4244}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَأَبِي، هُرَيْرَةَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى خَيْبَرَ، فَجَاءَهُ بِتَمْرٍ جَنِيبٍ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏‏.‏ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ، إِنَّا لَنَأْخُذُ الصَّاعَ مِنْ هَذَا بِالصَّاعَيْنِ ‏\{‏وَالصَّاعَيْنِ‏\}‏ بِالثَّلاَثَةِ‏.‏ فَقَالَ ‏"‏ لاَ تَفْعَلْ، بِعِ الْجَمْعَ بِالدَّرَاهِمِ، ثُمَّ ابْتَعْ بِالدَّرَاهِمِ جَنِيبًا ‏"‏‏.‏\hadithno{4244}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:Allah's Messenger (ﷺ) appointed a man as the ruler of Khaibar who later brought some Janib (i.e. dates of good quality) to the Prophet. On that, Allah's Messenger (ﷺ) said (to him). "Are all the dates of Khaibar like this?" He said, "No, by Allah, O Allah's Messenger (ﷺ)! But we take one Sa of these (dates of good quality) for two or three Sa's of other dates (of inferior quality)." On that, Allah's Messenger (ﷺ) said, "Do not do so, but first sell the inferior quality dates for money and then with that money, buy Janib}}
\hadithdefcmd{bukhari}{4246}{وَقَالَ عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ عَنْ عَبْدِ الْمَجِيدِ، عَنْ سَعِيدٍ، أَنَّ أَبَا سَعِيدٍ، وَأَبَا، هُرَيْرَةَ حَدَّثَاهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ أَخَا بَنِي عَدِيٍّ مِنَ الأَنْصَارِ إِلَى خَيْبَرَ فَأَمَّرَهُ عَلَيْهَا‏.‏ وَعَنْ عَبْدِ الْمَجِيدِ عَنْ أَبِي صَالِحٍ السَّمَّانِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ مِثْلَهُ\hadithno{4246}\hadithtrans{Abu Sa`id and Abu Huraira said:"The Prophet (ﷺ) made the brother of Bani Adi from the Ansar as the ruler of Khaibar}}
\hadithdefcmd{bukhari}{4253}{حَدَّثَنِي عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، قَالَ دَخَلْتُ أَنَا وَعُرْوَةُ بْنُ الزُّبَيْرِ الْمَسْجِدَ، فَإِذَا عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ جَالِسٌ إِلَى حُجْرَةِ عَائِشَةَ ثُمَّ قَالَ كَمِ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم قَالَ أَرْبَعًا ‏\{‏إِحْدَاهُنَّ فِي رَجَبٍ‏\}‏ ثُمَّ سَمِعْنَا اسْتِنَانَ، عَائِشَةَ قَالَ عُرْوَةُ يَا أُمَّ الْمُؤْمِنِينَ أَلاَ تَسْمَعِينَ مَا يَقُولُ أَبُو عَبْدِ الرَّحْمَنِ إِنَّ النَّبِيَّ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعَ عُمَرٍ‏.‏ فَقَالَتْ مَا اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم عُمْرَةً إِلاَّ وَهْوَ شَاهِدُهُ، وَمَا اعْتَمَرَ فِي رَجَبٍ قَطُّ‏.‏\hadithno{4253}\hadithtrans{Narrated Mujahid:`Urwa and I entered the Mosque and found `Abdullah bin `Umar sitting beside the dwelling place of `Aisha. `Urwa asked (Ibn `Umar), "How many `Umras did the Prophet (ﷺ) perform?" Ibn `Umar replied, "Four, one of which was in Rajab." Then we heard `Aisha brushing her teeth whereupon `Urwa said, "O mother of the believers! Don't you hear what Abu `Abdur-Rahman is saying? He is saying that the Prophet performed four `Umra, one of which was in Rajab." `Aisha said, "The Prophet (ﷺ) did not perform any `Umra but he (i.e. Ibn `Umar) witnessed it. And he (the Prophet (ﷺ) ) never did any `Umra in (the month of) Rajab}}
\hadithdefcmd{bukhari}{4282}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا سَعْدَانُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حَفْصَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ قَالَ زَمَنَ الْفَتْحِ يَا رَسُولَ اللَّهِ، أَيْنَ تَنْزِلُ غَدًا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مِنْ مَنْزِلٍ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ لاَ يَرِثُ الْمُؤْمِنُ الْكَافِرَ، وَلاَ يَرِثُ الْكَافِرُ الْمُؤْمِنَ ‏"‏‏.‏ قِيلَ لِلزُّهْرِيِّ وَمَنْ وَرِثَ أَبَا طَالِبٍ قَالَ وَرِثَهُ عَقِيلٌ وَطَالِبٌ‏.‏ قَالَ مَعْمَرٌ عَنِ الزُّهْرِيِّ أَيْنَ تَنْزِلُ غَدًا‏.‏ فِي حَجَّتِهِ، وَلَمْ يَقُلْ يُونُسُ حَجَّتِهِ وَلاَ زَمَنَ الْفَتْحِ‏.‏\hadithno{4282}\hadithtrans{Narrated `Amr bin `Uthman:Usama bin Zaid said during the Conquest (of Mecca), "O Allah's Messenger (ﷺ)! Where will we encamp tomorrow?" The Prophet (ﷺ) said, "But has `Aqil left for us any house to lodge in?" He then added, "No believer will inherit an infidel's property, and no infidel will inherit the property of a believer." Az- Zuhri was asked, "Who inherited Abu Talib?" Az-Zuhri replied, "Aqil and Talib inherited him}}
\hadithdefcmd{bukhari}{4305}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي عُثْمَانَ، قَالَ حَدَّثَنِي مُجَاشِعٌ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِأَخِي بَعْدَ الْفَتْحِ قُلْتُ يَا رَسُولَ اللَّهِ، جِئْتُكَ بِأَخِي لِتُبَايِعَهُ عَلَى الْهِجْرَةِ‏.‏ قَالَ ‏"‏ ذَهَبَ أَهْلُ الْهِجْرَةِ بِمَا فِيهَا ‏"‏‏.‏ فَقُلْتُ عَلَى أَىِّ شَىْءٍ تُبَايِعُهُ قَالَ ‏"‏ أُبَايِعُهُ عَلَى الإِسْلاَمِ وَالإِيمَانِ وَالْجِهَادِ‏" فَلَقِيتُ أَبَا مَعْبَدٍ بَعْدُ وَكَانَ أَكْبَرَهُمَا فَسَأَلْتُهُ فَقَالَ صَدَقَ مُجَاشِعٌ‏\hadithno{4305}\hadithtrans{Narrated Mujashi:I took my brother to the Prophet (ﷺ) after the Conquest (of Mecca) and said, "O Allah's Messenger (ﷺ)! I have come to you with my brother so that you may take a pledge of allegiance from him for migration." The Prophet (ﷺ) said, The people of migration (i.e. those who migrated to Medina before the Conquest) enjoyed the privileges of migration (i.e. there is no need for migration anymore)." I said to the Prophet, "For what will you take his pledge of allegiance?" The Prophet (ﷺ) said, "I will take his pledge of allegiance for Islam, Belief, and for Jihad (i.e. fighting in Allah's Cause)}}
\hadithdefcmd{bukhari}{4307}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ مُجَاشِعِ بْنِ مَسْعُودٍ، انْطَلَقْتُ بِأَبِي مَعْبَدٍ إِلَى النَّبِيِّ صلى الله عليه وسلم لِيُبَايِعَهُ عَلَى الْهِجْرَةِ، قَالَ ‏ "‏ مَضَتِ الْهِجْرَةُ لأَهْلِهَا، أُبَايِعُهُ عَلَى الإِسْلاَمِ وَالْجِهَادِ." فَلَقِيتُ أَبَا مَعْبَدٍ فَسَأَلْتُهُ فَقَالَ صَدَقَ مُجَاشِعٌ‏.‏ وَقَالَ خَالِدٌ عَنْ أَبِي عُثْمَانَ عَنْ مُجَاشِعٍ أَنَّهُ جَاءَ بِأَخِيهِ مُجَالِدٍ‏.‏\hadithno{4307}\hadithtrans{Narrated Mujashi bin Masud:I took Abu Mabad to the Prophet (ﷺ) in order that he might give him the pledge of allegiance for migration. The Prophet (ﷺ) said, "Migration has gone to its people, but I take the pledge from him (i.e. Abu Mabad) for Islam and Jihad}}
\hadithdefcmd{bukhari}{4318}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي لَيْثٌ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ،‏.‏ وَحَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ،، قَالَ مُحَمَّدُ بْنُ شِهَابٍ وَزَعَمَ عُرْوَةُ بْنُ الزُّبَيْرِ أَنَّ مَرْوَانَ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ مُسْلِمِينَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ، فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَعِي مَنْ تَرَوْنَ، وَأَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ، فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا السَّبْىَ، وَإِمَّا الْمَالَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ بِكُمْ ‏"‏‏.‏ وَكَانَ أَنْظَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِضْعَ عَشْرَةَ لَيْلَةً، حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمُسْلِمِينَ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ، فَإِنَّ إِخْوَانَكُمْ قَدْ جَاءُونَا تَائِبِينَ، وَإِنِّي قَدْ رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَكُونَ عَلَى حَظِّهِ، حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا، فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ قَدْ طَيَّبْنَا ذَلِكَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ فِي ذَلِكَ مِمَّنْ لَمْ يَأْذَنْ فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ ثُمَّ رَجَعُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ قَدْ طَيَّبُوا وَأَذِنُوا‏.‏ هَذَا الَّذِي بَلَغَنِي عَنْ سَبْىِ هَوَازِنَ‏.‏\hadithno{4318}\hadithtrans{Narrated Marwan and Al-Miswar bin Makhrama:When the delegate of Hawazin came to Allah's Messenger (ﷺ) declaring their conversion to Islam and asked him to return their properties and captives, Allah's Messenger (ﷺ) got up and said to them, "There Is involved in this matter, the people whom you see with me, and the most beloved talk to me, is the true one. So choose one of two alternatives: Either the captives or the properties. I have been waiting for you (i.e. have not distributed the booty)." Allah's Messenger (ﷺ) had delayed the distribution of their booty over ten nights after his return from Ta'if. So when they came to know that Allah's Messenger (ﷺ) was not going to return to them but one of the two, they said, "We prefer to have our captives." So Allah's Messenger (ﷺ) got up amongst the Muslims, and praising Allah as He deserved, said, "To proceed! Your brothers have come to you with repentance and I see (it logical) to return their captives. So, whoever of you likes to do that as a favor then he can do it. And whoever of you likes to stick to his share till we give him from the very first booty which Allah will give us, then he can do so." The people said, "We do that (i.e. return the captives) willingly as a favor, 'O Allah's Messenger (ﷺ)!" Allah's Messenger (ﷺ) said, "We do not know which of you have agreed to it and which have not; so go back and let your chiefs forward us your decision." They went back and their chief's spoke to them, and they (i.e. the chiefs) returned to Allah's Messenger (ﷺ) and informed him that all of them had agreed (to give up their captives) with pleasure, and had given their permission (i.e. that the captives be returned to their people). (The sub-narrator said, "That is what has reached me about the captives of Hawazin tribe)}}
\hadithdefcmd{bukhari}{4326}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ، قَالَ سَمِعْتُ سَعْدًا ـ وَهْوَ أَوَّلُ مَنْ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ ـ وَأَبَا بَكْرَةَ ـ وَكَانَ تَسَوَّرَ حِصْنَ الطَّائِفِ فِي أُنَاسٍ ـ فَجَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالاَ سَمِعْنَا النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ وَهْوَ يَعْلَمُ فَالْجَنَّةُ عَلَيْهِ حَرَامٌ ‏"‏‏.‏ وَقَالَ هِشَامٌ وَأَخْبَرَنَا مَعْمَرٌ، عَنْ عَاصِمٍ، عَنْ أَبِي الْعَالِيَةِ، أَوْ أَبِي عُثْمَانَ النَّهْدِيِّ قَالَ سَمِعْتُ سَعْدًا، وَأَبَا، بَكْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ عَاصِمٌ قُلْتُ لَقَدْ شَهِدَ عِنْدَكَ رَجُلاَنِ حَسْبُكَ بِهِمَا‏.‏ قَالَ أَجَلْ أَمَّا أَحَدُهُمَا فَأَوَّلُ مَنْ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ، وَأَمَّا الآخَرُ فَنَزَلَ إِلَى النَّبِيِّ صلى الله عليه وسلم ثَالِثَ ثَلاَثَةٍ وَعِشْرِينَ مِنَ الطَّائِفِ‏.‏\hadithno{4326}\hadithtrans{Narrated Abu `Uthman:I heard from Sa`d, the first man who had thrown an arrow in Allah's Cause, and from Abu Bakra who jumped over the wall of the Ta'if Fort along with a few persons and came to the Prophet. They both said, "We heard the Prophet (ﷺ) saying, " If somebody claims to be the son of somebody other than his father knowingly, he will be denied Paradise (i.e. he will not enter Paradise).' " Narrated Ma`mar from `Asim from Abu Al-`Aliya or Abu `Uthman An-Nahdi who said. "I heard Sa`d and Abu Bakra narrating from the Prophet." `Asim said, "I said (to him), 'Very trustworthy persons have narrated to you.' He said, 'Yes, one of them was the first to throw an arrow in Allah's Cause and the other came to the Prophet (ﷺ) in a group of thirty-three persons from Ta'if}}
\hadithdefcmd{bukhari}{4341}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ أَبِي بُرْدَةَ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا مُوسَى وَمُعَاذَ بْنَ جَبَلٍ إِلَى الْيَمَنِ، قَالَ وَبَعَثَ كُلَّ وَاحِدٍ مِنْهُمَا عَلَى مِخْلاَفٍ قَالَ وَالْيَمَنُ مِخْلاَفَانِ ثُمَّ قَالَ ‏ "‏ يَسِّرَا وَلاَ تُعَسِّرَا، وَبَشِّرَا وَلاَ تُنَفِّرَا ‏"‏‏.‏ فَانْطَلَقَ كُلُّ وَاحِدٍ مِنْهُمَا إِلَى عَمَلِهِ، وَكَانَ كُلُّ وَاحِدٍ مِنْهُمَا إِذَا سَارَ فِي أَرْضِهِ كَانَ قَرِيبًا مِنْ صَاحِبِهِ أَحْدَثَ بِهِ عَهْدًا، فَسَلَّمَ عَلَيْهِ، فَسَارَ مُعَاذٌ فِي أَرْضِهِ قَرِيبًا مِنْ صَاحِبِهِ أَبِي مُوسَى، فَجَاءَ يَسِيرُ عَلَى بَغْلَتِهِ حَتَّى انْتَهَى إِلَيْهِ، وَإِذَا هُوَ جَالِسٌ، وَقَدِ اجْتَمَعَ إِلَيْهِ النَّاسُ، وَإِذَا رَجُلٌ عِنْدَهُ قَدْ جُمِعَتْ يَدَاهُ إِلَى عُنُقِهِ فَقَالَ لَهُ مُعَاذٌ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ، أَيَّمَ هَذَا قَالَ هَذَا رَجُلٌ كَفَرَ بَعْدَ إِسْلاَمِهِ‏.‏ قَالَ لاَ أَنْزِلُ حَتَّى يُقْتَلَ‏.‏ قَالَ إِنَّمَا جِيءَ بِهِ لِذَلِكَ فَانْزِلْ‏.‏ قَالَ مَا أَنْزِلُ حَتَّى يُقْتَلَ فَأَمَرَ بِهِ فَقُتِلَ ثُمَّ نَزَلَ فَقَالَ يَا عَبْدَ اللَّهِ، كَيْفَ تَقْرَأُ الْقُرْآنَ قَالَ أَتَفَوَّقُهُ تَفَوُّقًا‏.‏ قَالَ فَكَيْفَ تَقْرَأُ أَنْتَ يَا مُعَاذُ قَالَ أَنَامُ أَوَّلَ اللَّيْلِ فَأَقُومُ وَقَدْ قَضَيْتُ جُزْئِي مِنَ النَّوْمِ، فَأَقْرَأُ مَا كَتَبَ اللَّهُ لِي، فَأَحْتَسِبُ نَوْمَتِي كَمَا أَحْتَسِبُ قَوْمَتِي‏.‏\hadithno{4341}\hadithtrans{Narrated Abu Burda:Allah's Messenger (ﷺ) sent Abu Musa and Mu`adh bin Jabal to Yemen. He sent each of them to administer a province as Yemen consisted of two provinces. The Prophet (ﷺ) said (to them), "Facilitate things for the people and do not make things difficult for them (Be kind and lenient (both of you) with the people, and do not be hard on them) and give the people good tidings and do not repulse them. So each of them went to carry on his job. So when any one of them toured his province and happened to come near (the border of the province of) his companion, he would visit him and greet him. Once Mu`adh toured that part of his state which was near (the border of the province of) his companion Abu Musa. Mu`adh came riding his mule till he reached Abu Musa and saw him sitting, and the people had gathered around him. Behold! There was a man tied with his hands behind his neck. Mu`adh said to Abu Musa, "O `Abdullah bin Qais! What is this?" Abu Musa replied. "This man has reverted to Heathenism after embracing Islam." Mu`adh said, "I will not dismount till he is killed." Abu Musa replied, "He has been brought for this purpose, so come down." Mu`adh said, "I will not dismount till he is killed." So Abu Musa ordered that he be killed, and he was killed. Then Mu`adh dismounted and said, "O `Abdullah (bin Qais)! How do you recite the Qur'an ?" Abu Musa said, "I recite the Qur'an regularly at intervals and piecemeal. How do you recite it O Mu`adh?" Mu`adh said, "I sleep in the first part of the night and then get up after having slept for the time devoted for my sleep and then recite as much as Allah has written for me. So I seek Allah's Reward for both my sleep as well as my prayer (at night)}}
\hadithdefcmd{bukhari}{4344}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم جَدَّهُ أَبَا مُوسَى، وَمُعَاذًا إِلَى الْيَمَنِ فَقَالَ ‏"‏ يَسِّرَا وَلاَ تُعَسِّرَا، وَبَشِّرَا وَلاَ تُنَفِّرَا، وَتَطَاوَعَا ‏"‏‏.‏ فَقَالَ أَبُو مُوسَى يَا نَبِيَّ اللَّهِ، إِنَّ أَرْضَنَا بِهَا شَرَابٌ مِنَ الشَّعِيرِ الْمِزْرُ، وَشَرَابٌ مِنَ الْعَسَلِ الْبِتْعُ‏.‏ فَقَالَ ‏"‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏‏.‏ فَانْطَلَقَا فَقَالَ مُعَاذٌ لأَبِي مُوسَى كَيْفَ تَقْرَأُ الْقُرْآنَ قَالَ قَائِمًا وَقَاعِدًا وَعَلَى رَاحِلَتِهِ وَأَتَفَوَّقُهُ تَفَوُّقًا‏.‏ قَالَ أَمَّا أَنَا فَأَنَامُ وَأَقُومُ، فَأَحْتَسِبُ نَوْمَتِي كَمَا أَحْتَسِبُ قَوْمَتِي، وَضَرَبَ فُسْطَاطًا، فَجَعَلاَ يَتَزَاوَرَانِ، فَزَارَ مُعَاذٌ أَبَا مُوسَى، فَإِذَا رَجُلٌ مُوثَقٌ، فَقَالَ مَا هَذَا فَقَالَ أَبُو مُوسَى يَهُودِيٌّ أَسْلَمَ ثُمَّ ارْتَدَّ‏.‏ فَقَالَ مُعَاذٌ لأَضْرِبَنَّ عُنُقَهُ‏.‏ تَابَعَهُ الْعَقَدِيُّ وَوَهْبٌ عَنْ شُعْبَةَ‏.‏ وَقَالَ وَكِيعٌ وَالنَّضْرُ وَأَبُو دَاوُدَ عَنْ شُعْبَةَ، عَنْ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ رَوَاهُ جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ عَنِ الشَّيْبَانِيِّ عَنْ أَبِي بُرْدَةَ‏.‏\hadithno{4344}\hadithtrans{Narrated Abu Burda:That the Prophet (ﷺ) sent his (i.e. Abu Burda's) grandfather, Abu Musa and Mu`adh to Yemen and said to both of them "Facilitate things for the people (Be kind and lenient) and do not make things difficult (for people), and give them good tidings, and do not repulse them and both of you should obey each other." Abu Musa said, "O Allah's Prophet! In our land there is an alcoholic drink (prepared) from barley called Al-Mizr, and another (prepared) from honey, called Al-Bit"' The Prophet (ﷺ) said, "All intoxicants are prohibited." Then both of them proceeded and Mu`adh asked Abu Musa, "How do you recite the Qur'an?" Abu Musa replied, "I recite it while I am standing, sitting or riding my riding animals, at intervals and piecemeal." Mu`adh said, "But I sleep and then get up. I sleep and hope for Allah's Reward for my sleep as I seek His Reward for my night prayer." Then he (i.e. Mu`adh) pitched a tent and they started visiting each other. Once Mu`adh paid a visit to Abu Musa and saw a chained man. Mu`adh asked, "What is this?" Abu Musa said, "(He was) a Jew who embraced Islam and has now turned apostate." Mu`adh said, "I will surely chop off his neck}}
\hadithdefcmd{bukhari}{4353}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ حُمَيْدٍ الطَّوِيلِ، حَدَّثَنَا بَكْرٌ، أَنَّهُ ذَكَرَ لاِبْنِ عُمَرَ أَنَّ أَنَسًا حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَهَلَّ بِعُمْرَةٍ وَحَجَّةٍ، فَقَالَ أَهَلَّ النَّبِيُّ صلى الله عليه وسلم بِالْحَجِّ، وَأَهْلَلْنَا بِهِ مَعَهُ، فَلَمَّا قَدِمْنَا مَكَّةَ قَالَ ‏"‏ مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ فَلْيَجْعَلْهَا عُمْرَةً ‏"‏‏.‏ وَكَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم هَدْىٌ، فَقَدِمَ عَلَيْنَا عَلِيُّ بْنُ أَبِي طَالِبٍ مِنَ الْيَمَنِ حَاجًّا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِمَ أَهْلَلْتَ فَإِنَّ مَعَنَا أَهْلَكَ ‏"‏‏.‏ قَالَ أَهْلَلْتُ بِمَا أَهَلَّ بِهِ النَّبِيُّ صلى الله عليه وسلم‏.‏ قَالَ ‏"‏ فَأَمْسِكْ، فَإِنَّ مَعَنَا هَدْيًا ‏"‏‏.‏\hadithno{4353}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) assumed the state of Ihram for Umra and Hajj, and we too assumed it for Hajj with him. When we arrived at Mecca, the Prophet (ﷺ) said, "Whoever does not possess a Hadi should regard his Ihram for Umra only." The Prophet (ﷺ) had a Hadi with him. `Ali bin Abi Talib came to us from Yemen with the intention of performing Hajj. The Prophet (ﷺ) said (to him), "With what intention have you assumed the Ihram, for your wife is with us?" `Ali said, "I assumed the Ihram with the same intention as that of the Prophet (ﷺ) ." The Prophet (ﷺ) said, "Keep on the state of Ihram, as we have got the Hadi}}
\hadithdefcmd{bukhari}{4373}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا نَافِعُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ مُسَيْلِمَةُ الْكَذَّابُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَقُولُ إِنْ جَعَلَ لِي مُحَمَّدٌ مِنْ بَعْدِهِ تَبِعْتُهُ‏.‏ وَقَدِمَهَا فِي بَشَرٍ كَثِيرٍ مِنْ قَوْمِهِ، فَأَقْبَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ ثَابِتُ بْنُ قَيْسِ بْنِ شَمَّاسٍ، وَفِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قِطْعَةُ جَرِيدٍ حَتَّى وَقَفَ عَلَى مُسَيْلِمَةَ فِي أَصْحَابِهِ، فَقَالَ ‏"‏ لَوْ سَأَلْتَنِي هَذِهِ الْقِطْعَةَ مَا أَعْطَيْتُكَهَا وَلَنْ تَعْدُوَ أَمْرَ اللَّهِ فِيكَ، وَلَئِنْ أَدْبَرْتَ لَيَعْقِرَنَّكَ اللَّهُ، وَإِنِّي لأَرَاكَ الَّذِي أُرِيتُ فِيهِ مَا رَأَيْتُ، وَهَذَا ثَابِتٌ يُجِيبُكَ عَنِّي ‏"‏‏.‏ ثُمَّ انْصَرَفَ عَنْهُ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَسَأَلْتُ عَنْ قَوْلِ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكَ أُرَى الَّذِي أُرِيتُ فِيهِ مَا أُرِيتُ ‏"‏‏.‏ فَأَخْبَرَنِي أَبُو هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُ فِي يَدَىَّ سِوَارَيْنِ مِنْ ذَهَبٍ، فَأَهَمَّنِي شَأْنُهُمَا، فَأُوحِيَ إِلَىَّ فِي الْمَنَامِ أَنِ انْفُخْهُمَا، فَنَفَخْتُهُمَا فَطَارَا فَأَوَّلْتُهُمَا كَذَّابَيْنِ يَخْرُجَانِ بَعْدِي، أَحَدُهُمَا الْعَنْسِيُّ، وَالآخَرُ مُسَيْلِمَةُ ‏"‏‏.‏\hadithno{4373}\hadithtrans{Narrated Ibn `Abbas:Musailima Al-Kadhdhab came during the lifetime of the Prophet (ﷺ) and started saying, "If Muhammad gives me the rule after him, I will follow him." And he came to Medina with a great number of the people of his tribe. Allah's Messenger (ﷺ) went to him in the company of Thabit bin Qais bin Shammas, and at that time, Allah's Messenger (ﷺ) had a stick of a date-palm tree in his hand. When he (i.e. the Prophet (ﷺ) ) stopped near Musailima while the latter was amidst his companions, he said to him, "If you ask me for this piece (of stick), I will not give it to you, and Allah's Order you cannot avoid, (but you will be destroyed), and if you turn your back from this religion, then Allah will destroy you. And I think you are the same person who was shown to me in my dream, and this is Thabit bin Qais who will answer your questions on my behalf." Then the Prophet (ﷺ) went away from him. I asked about the statement of Allah's Messenger (ﷺ) : "You seem to be the same person who was shown to me in my dream," and Abu Huraira informed me that Allah's Messenger (ﷺ) said, "When I was sleeping, I saw (in a dream) two bangles of gold on my hands and that worried me. And then I was inspired Divinely in the dream that I should blow on them, so I blew on them and both the bangles flew away. And I interpreted it that two liars (who would claim to be prophets) would appear after me. One of them has proved to be Al Ansi and the other, Musailima}}
\hadithdefcmd{bukhari}{4376}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، قَالَ سَمِعْتُ مَهْدِيَّ بْنَ مَيْمُونٍ، قَالَ سَمِعْتُ أَبَا رَجَاءٍ الْعُطَارِدِيَّ، يَقُولُ كُنَّا نَعْبُدُ الْحَجَرَ، فَإِذَا وَجَدْنَا حَجَرًا هُوَ أَخْيَرُ مِنْهُ أَلْقَيْنَاهُ وَأَخَذْنَا الآخَرَ، فَإِذَا لَمْ نَجِدْ حَجَرًا جَمَعْنَا جُثْوَةً مِنْ تُرَابٍ، ثُمَّ جِئْنَا بِالشَّاةِ فَحَلَبْنَاهُ عَلَيْهِ، ثُمَّ طُفْنَا بِهِ، فَإِذَا دَخَلَ شَهْرُ رَجَبٍ قُلْنَا مُنَصِّلُ الأَسِنَّةِ‏.‏ فَلاَ نَدَعُ رُمْحًا فِيهِ حَدِيدَةٌ وَلاَ سَهْمًا فِيهِ حَدِيدَةٌ إِلاَّ نَزَعْنَاهُ وَأَلْقَيْنَاهُ شَهْرَ رَجَبٍ‏.‏ وَسَمِعْتُ أَبَا رَجَاءٍ، يَقُولُ كُنْتُ يَوْمَ بُعِثَ النَّبِيُّ صلى الله عليه وسلم غُلاَمًا أَرْعَى الإِبِلَ عَلَى أَهْلِي، فَلَمَّا سَمِعْنَا بِخُرُوجِهِ فَرَرْنَا إِلَى النَّارِ إِلَى مُسَيْلِمَةَ الْكَذَّابِ‏.‏\hadithno{4376}\hadithtrans{Narrated Abu Raja Al-Utaridi:We used to worship stones, and when we found a better stone than the first one, we would throw the first one and take the latter, but if we could not get a stone then we would collect some earth (i.e. soil) and then bring a sheep and milk that sheep over it, and perform the Tawaf around it. When the month of Rajab came, we used (to stop the military actions), calling this month the iron remover, for we used to remove and throw away the iron parts of every spear and arrow in the month of Rajab. Abu Raja' added: When the Prophet (ﷺ) was sent with (Allah's) Message, I was a boy working as a shepherd of my family camels. When we heard the news about the appearance of the Prophet, we ran to the fire, i.e. to Musailima al-Kadhdhab}}
\hadithdefcmd{bukhari}{4378}{حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الْجَرْمِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ عُبَيْدَةَ بْنِ نَشِيطٍ ـ وَكَانَ فِي مَوْضِعٍ آخَرَ اسْمُهُ عَبْدُ اللَّهِ ـ أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ قَالَ بَلَغَنَا أَنَّ مُسَيْلِمَةَ الْكَذَّابَ قَدِمَ الْمَدِينَةَ، فَنَزَلَ فِي دَارِ بِنْتِ الْحَارِثِ، وَكَانَ تَحْتَهُ بِنْتُ الْحَارِثِ بْنِ كُرَيْزٍ، وَهْىَ أُمُّ عَبْدِ اللَّهِ بْنِ عَامِرٍ، فَأَتَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ ثَابِتُ بْنُ قَيْسِ بْنِ شَمَّاسٍ، وَهْوَ الَّذِي يُقَالُ لَهُ خَطِيبُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَضِيبٌ، فَوَقَفَ عَلَيْهِ فَكَلَّمَهُ فَقَالَ لَهُ مُسَيْلِمَةُ إِنْ شِئْتَ خَلَّيْتَ بَيْنَنَا وَبَيْنَ الأَمْرِ، ثُمَّ جَعَلْتَهُ لَنَا بَعْدَكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ سَأَلْتَنِي هَذَا الْقَضِيبَ مَا أَعْطَيْتُكَهُ وَإِنِّي لأَرَاكَ الَّذِي أُرِيتُ فِيهِ مَا أُرِيتُ، وَهَذَا ثَابِتُ بْنُ قَيْسٍ وَسَيُجِيبُكَ عَنِّي ‏"‏‏.‏ فَانْصَرَفَ النَّبِيُّ صلى الله عليه وسلم‏.‏ قَالَ عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ عَنْ رُؤْيَا، رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي ذَكَرَ فَقَالَ ابْنُ عَبَّاسٍ ذُكِرَ لِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَنَا نَائِمٌ أُرِيتُ أَنَّهُ وُضِعَ فِي يَدَىَّ سِوَارَانِ مِنْ ذَهَبٍ، فَفُظِعْتُهُمَا وَكَرِهْتُهُمَا، فَأُذِنَ لِي فَنَفَخْتُهُمَا فَطَارَا، فَأَوَّلْتُهُمَا كَذَّابَيْنِ يَخْرُجَانِ ‏"‏‏.‏ فَقَالَ عُبَيْدُ اللَّهِ أَحَدُهُمَا الْعَنْسِيُّ الَّذِي قَتَلَهُ فَيْرُوزُ بِالْيَمَنِ، وَالآخَرُ مُسَيْلِمَةُ الْكَذَّابُ‏.‏\hadithno{4378}\hadithtrans{Narrated Ubaidullah bin `Abdullah bin `Utba:We were informed that Musailima Al-Kadhdhab had arrived in Medina and stayed in the house of the daughter of Al-Harith. The daughter of Al-Harith bin Kuraiz was his wife and she was the mother of `Abdullah bin 'Amir. There came to him Allah's Messenger (ﷺ) accompanied by Thabit bin Qais bin Shammas who was called the orator of Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) had a stick in his hand then. The Prophet (ﷺ) stopped before Musailima and spoke to him. Musailima said to him, "If you wish, we would not interfere between you and the rule, on condition that the rule will be ours after you... The Prophet said, "If you asked me for this stick, I would not give it to you. I think you are the same person who was shown to me in a dream. And this is Thabit bin Al-Qais who will answer you on my behalf." The Prophet (ﷺ) then went away. I asked Ibn `Abbas about the dream Allah's Messenger (ﷺ) had mentioned. Ibn `Abbas said, "Someone told me that the Prophet (ﷺ) said, "When I was sleeping, I saw in a dream that two gold bangles were put in my hands, and that frightened me and made me dislike them. Then I was allowed to blow on them, and when I blew at them, both of them flew. Then I interpreted them as two liars who would appear.' One of them was Al-`Ansi who was killed by Fairuz in Yemen and the other was Musailima Al-Kadhdhab}}
\hadithdefcmd{bukhari}{4402}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ أَخْبَرَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، أَنَّ أَبَاهُ، حَدَّثَهُ عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا نَتَحَدَّثُ بِحَجَّةِ الْوَدَاعِ وَالنَّبِيُّ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا، وَلاَ نَدْرِي مَا حَجَّةُ الْوَدَاعِ، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ ذَكَرَ الْمَسِيحَ الدَّجَّالَ فَأَطْنَبَ فِي ذِكْرِهِ وَقَالَ ‏"‏ مَا بَعَثَ اللَّهُ مِنْ نَبِيٍّ إِلاَّ أَنْذَرَ أُمَّتَهُ، أَنْذَرَهُ نُوحٌ وَالنَّبِيُّونَ مِنْ بَعْدِهِ، وَإِنَّهُ يَخْرُجُ فِيكُمْ، فَمَا خَفِيَ عَلَيْكُمْ مِنْ شَأْنِهِ فَلَيْسَ يَخْفَى عَلَيْكُمْ أَنَّ رَبَّكُمْ لَيْسَ عَلَى مَا يَخْفَى عَلَيْكُمْ ثَلاَثًا، إِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ، وَإِنَّهُ أَعْوَرُ عَيْنِ الْيُمْنَى، كَأَنَّ عَيْنَهُ عِنَبَةٌ طَافِيَةٌ ‏"‏‏.‏ ‏"‏ أَلاَ إِنَّ اللَّهَ حَرَّمَ عَلَيْكُمْ دِمَاءَكُمْ وَأَمْوَالَكُمْ، كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا، فِي شَهْرِكُمْ هَذَا، أَلاَ هَلْ بَلَّغْتُ ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اشْهَدْ، ثَلاَثًا، وَيْلَكُمْ، أَوْ وَيْحَكُمُ، انْظُرُوا لاَ تَرْجِعُوا بَعْدِي كُفَّارًا، يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{4402}\hadithtrans{Narrated Ibn `Umar:We were talking about Hajjat-ul-Wada`, while the Prophet (ﷺ) was amongst us. We did not know what Hajjat-ul-Wada` signified. The Prophet (ﷺ) praised Allah and then mentioned Al-Masih Ad-Dajjal and described him extensively, saying, "Allah did not send any prophet but that prophet warned his nation of Al-Masih Ad-Dajjal. Noah and the prophets following him warned (their people) of him. He will appear amongst you (O Muhammad's followers), and if it happens that some of his qualities may be hidden from you, but your Lord's State is clear to you and not hidden from you. The Prophet (ﷺ) said it thrice. Verily, your Lord is not blind in one eye, while he (i.e. Ad-Dajjal) is blind in the right eye which looks like a grape bulging out (of its cluster). No doubt,! Allah has made your blood and your properties sacred to one another like the sanctity of this day of yours, in this town of yours, in this month of yours." The Prophet (ﷺ) added: No doubt! Haven't I conveyed Allah's Message to you? " They replied, "Yes," The Prophet (ﷺ) said thrice, "O Allah! Be witness for it." The Prophet (ﷺ) added, "Woe to you!" (or said), "May Allah be merciful to you! Do not become infidels after me (i.e. my death) by cutting the necks (throats) of one another}}
\hadithdefcmd{bukhari}{4433}{حَدَّثَنَا يَسَرَةُ بْنُ صَفْوَانَ بْنِ جَمِيلٍ اللَّخْمِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَعَا النَّبِيُّ صلى الله عليه وسلم فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ فِي شَكْوَاهُ الَّذِي قُبِضَ فِيهِ، فَسَارَّهَا بِشَىْءٍ، فَبَكَتْ، ثُمَّ دَعَاهَا فَسَارَّهَا بِشَىْءٍ فَضَحِكَتْ فَسَأَلْنَا عَنْ ذَلِكَ‏.‏ فَقَالَتْ سَارَّنِي النَّبِيُّ صلى الله عليه وسلم أَنَّهُ يُقْبَضُ فِي وَجَعِهِ الَّذِي تُوُفِّيَ فِيهِ فَبَكَيْتُ، ثُمَّ سَارَّنِي فَأَخْبَرَنِي أَنِّي أَوَّلُ أَهْلِهِ يَتْبَعُهُ فَضَحِكْتُ‏.‏\hadithno{4433}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) called Fatima during his fatal illness and told her something secretly and she wept. Then he called her again and told her something secretly, and she started laughing. When we asked her about that, she said, "The Prophet (ﷺ) first told me secretly that he would expire in that disease in which he died, so I wept; then he told me secretly that I would be the first of his family to follow him, so I laughed ( at that time)}}
\hadithdefcmd{bukhari}{4443}{وَأَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَائِشَةَ، وَعَبْدَ اللَّهِ بْنَ عَبَّاسٍ، رضى الله عنهم قَالاَ لَمَّا نَزَلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم طَفِقَ يَطْرَحُ خَمِيصَةً لَهُ عَلَى وَجْهِهِ، فَإِذَا اغْتَمَّ كَشَفَهَا عَنْ وَجْهِهِ وَهْوَ كَذَلِكَ يَقُولُ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى، اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏‏.‏ يُحَذِّرُ مَا صَنَعُوا‏.‏\hadithno{4443}\hadithtrans{Aisha and `Abdullah bin `Abbas said, "When Allah's Messenger (ﷺ) became ill seriously, he started covering his face with his woolen sheet, and when he felt short of breath, he removed it from his face and said, 'That is so! Allah's curse be on the Jews and the Christians, as they took the graves of their prophets as (places of worship),' intending to warn (the Muslims) of what they had done}}
\hadithdefcmd{bukhari}{4452}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ أَقْبَلَ عَلَى فَرَسٍ مِنْ مَسْكَنِهِ بِالسُّنْحِ حَتَّى نَزَلَ، فَدَخَلَ الْمَسْجِدَ فَلَمْ يُكَلِّمِ النَّاسَ حَتَّى دَخَلَ عَلَى عَائِشَةَ، فَتَيَمَّمَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ مُغَشًّى بِثَوْبِ حِبَرَةٍ، فَكَشَفَ عَنْ وَجْهِهِ ثُمَّ أَكَبَّ عَلَيْهِ فَقَبَّلَهُ وَبَكَى‏.‏ ثُمَّ قَالَ بِأَبِي أَنْتَ وَأُمِّي، وَاللَّهِ لاَ يَجْمَعُ اللَّهُ عَلَيْكَ مَوْتَتَيْنِ، أَمَّا الْمَوْتَةُ الَّتِي كُتِبَتْ عَلَيْكَ فَقَدْ مُتَّهَا‏.‏ قَالَ الزُّهْرِيُّ وَحَدَّثَنِي أَبُو سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ أَبَا بَكْرٍ، خَرَجَ وَعُمَرُ يُكَلِّمُ النَّاسَ فَقَالَ اجْلِسْ يَا عُمَرُ، فَأَبَى عُمَرُ أَنْ يَجْلِسَ‏.‏ فَأَقْبَلَ النَّاسُ إِلَيْهِ وَتَرَكُوا عُمَرَ، فَقَالَ أَبُو بَكْرٍ أَمَّا بَعْدُ مَنْ كَانَ مِنْكُمْ يَعْبُدُ مُحَمَّدًا صلى الله عليه وسلم فَإِنَّ مُحَمَّدًا قَدْ مَاتَ، وَمَنْ كَانَ مِنْكُمْ يَعْبُدُ اللَّهَ فَإِنَّ اللَّهَ حَىٌّ لاَ يَمُوتُ، قَالَ اللَّهُ ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ قَدْ خَلَتْ مِنْ قَبْلِهِ الرُّسُلُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الشَّاكِرِينَ‏\}‏ وَقَالَ وَاللَّهِ لَكَأَنَّ النَّاسَ لَمْ يَعْلَمُوا أَنَّ اللَّهَ أَنْزَلَ هَذِهِ الآيَةَ حَتَّى تَلاَهَا أَبُو بَكْرٍ، فَتَلَقَّاهَا مِنْهُ النَّاسُ كُلُّهُمْ فَمَا أَسْمَعُ بَشَرًا مِنَ النَّاسِ إِلاَّ يَتْلُوهَا‏.‏ فَأَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ أَنَّ عُمَرَ قَالَ وَاللَّهِ مَا هُوَ إِلاَّ أَنْ سَمِعْتُ أَبَا بَكْرٍ تَلاَهَا فَعَقِرْتُ حَتَّى مَا تُقِلُّنِي رِجْلاَىَ، وَحَتَّى أَهْوَيْتُ إِلَى الأَرْضِ حِينَ سَمِعْتُهُ تَلاَهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ مَاتَ‏.‏\hadithno{4452}\hadithtrans{Narrated `Aisha:Abu Bakr came from his house at As-Sunh on a horse. He dismounted and entered the Mosque, but did not speak to the people till he entered upon `Aisha and went straight to Allah's Messenger (ﷺ) who was covered with Hibra cloth (i.e. a kind of Yemenite cloth). He then uncovered the Prophet's face and bowed over him and kissed him and wept, saying, "Let my father and mother be sacrificed for you. By Allah, Allah will never cause you to die twice. As for the death which was written for you, has come upon you." Narrated Ibn `Abbas: Abu Bakr went out while `Umar bin Al-Khattab was talking to the people. Abu Bakr said, "Sit down, O `Umar!" But `Umar refused to sit down. So the people came to Abu Bakr and left `Umar. Abu Bakr said, "To proceed, if anyone amongst you used to worship Muhammad , then Muhammad is dead, but if (anyone of) you used to worship Allah, then Allah is Alive and shall never die. Allah said:--"Muhammad is no more than an Apostle, and indeed (many) apostles have passed away before him..(till the end of the Verse )......Allah will reward to those who are thankful." (3.144) By Allah, it was as if the people never knew that Allah had revealed this Verse before till Abu Bakr recited it and all the people received it from him, and I heard everybody reciting it (then). Narrated Az-Zuhri: Sa`id bin Al-Musaiyab told me that `Umar said, "By Allah, when I heard Abu Bakr reciting it, my legs could not support me and I fell down at the very moment of hearing him reciting it, declaring that the Prophet (ﷺ) had died}}
\hadithdefcmd{bukhari}{4454}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ أَقْبَلَ عَلَى فَرَسٍ مِنْ مَسْكَنِهِ بِالسُّنْحِ حَتَّى نَزَلَ، فَدَخَلَ الْمَسْجِدَ فَلَمْ يُكَلِّمِ النَّاسَ حَتَّى دَخَلَ عَلَى عَائِشَةَ، فَتَيَمَّمَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ مُغَشًّى بِثَوْبِ حِبَرَةٍ، فَكَشَفَ عَنْ وَجْهِهِ ثُمَّ أَكَبَّ عَلَيْهِ فَقَبَّلَهُ وَبَكَى‏.‏ ثُمَّ قَالَ بِأَبِي أَنْتَ وَأُمِّي، وَاللَّهِ لاَ يَجْمَعُ اللَّهُ عَلَيْكَ مَوْتَتَيْنِ، أَمَّا الْمَوْتَةُ الَّتِي كُتِبَتْ عَلَيْكَ فَقَدْ مُتَّهَا‏.‏ قَالَ الزُّهْرِيُّ وَحَدَّثَنِي أَبُو سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ أَبَا بَكْرٍ، خَرَجَ وَعُمَرُ يُكَلِّمُ النَّاسَ فَقَالَ اجْلِسْ يَا عُمَرُ، فَأَبَى عُمَرُ أَنْ يَجْلِسَ‏.‏ فَأَقْبَلَ النَّاسُ إِلَيْهِ وَتَرَكُوا عُمَرَ، فَقَالَ أَبُو بَكْرٍ أَمَّا بَعْدُ مَنْ كَانَ مِنْكُمْ يَعْبُدُ مُحَمَّدًا صلى الله عليه وسلم فَإِنَّ مُحَمَّدًا قَدْ مَاتَ، وَمَنْ كَانَ مِنْكُمْ يَعْبُدُ اللَّهَ فَإِنَّ اللَّهَ حَىٌّ لاَ يَمُوتُ، قَالَ اللَّهُ ‏\{‏وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ قَدْ خَلَتْ مِنْ قَبْلِهِ الرُّسُلُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الشَّاكِرِينَ‏\}‏ وَقَالَ وَاللَّهِ لَكَأَنَّ النَّاسَ لَمْ يَعْلَمُوا أَنَّ اللَّهَ أَنْزَلَ هَذِهِ الآيَةَ حَتَّى تَلاَهَا أَبُو بَكْرٍ، فَتَلَقَّاهَا مِنْهُ النَّاسُ كُلُّهُمْ فَمَا أَسْمَعُ بَشَرًا مِنَ النَّاسِ إِلاَّ يَتْلُوهَا‏.‏ فَأَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ أَنَّ عُمَرَ قَالَ وَاللَّهِ مَا هُوَ إِلاَّ أَنْ سَمِعْتُ أَبَا بَكْرٍ تَلاَهَا فَعَقِرْتُ حَتَّى مَا تُقِلُّنِي رِجْلاَىَ، وَحَتَّى أَهْوَيْتُ إِلَى الأَرْضِ حِينَ سَمِعْتُهُ تَلاَهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ مَاتَ‏.‏\hadithno{4454}\hadithtrans{Narrated `Aisha:Abu Bakr came from his house at As-Sunh on a horse. He dismounted and entered the Mosque, but did not speak to the people till he entered upon `Aisha and went straight to Allah's Messenger (ﷺ) who was covered with Hibra cloth (i.e. a kind of Yemenite cloth). He then uncovered the Prophet's face and bowed over him and kissed him and wept, saying, "Let my father and mother be sacrificed for you. By Allah, Allah will never cause you to die twice. As for the death which was written for you, has come upon you." Narrated Ibn `Abbas: Abu Bakr went out while `Umar bin Al-Khattab was talking to the people. Abu Bakr said, "Sit down, O `Umar!" But `Umar refused to sit down. So the people came to Abu Bakr and left `Umar. Abu Bakr said, "To proceed, if anyone amongst you used to worship Muhammad , then Muhammad is dead, but if (anyone of) you used to worship Allah, then Allah is Alive and shall never die. Allah said:--"Muhammad is no more than an Apostle, and indeed (many) apostles have passed away before him..(till the end of the Verse )......Allah will reward to those who are thankful." (3.144) By Allah, it was as if the people never knew that Allah had revealed this Verse before till Abu Bakr recited it and all the people received it from him, and I heard everybody reciting it (then). Narrated Az-Zuhri: Sa`id bin Al-Musaiyab told me that `Umar said, "By Allah, when I heard Abu Bakr reciting it, my legs could not support me and I fell down at the very moment of hearing him reciting it, declaring that the Prophet (ﷺ) had died}}
\hadithdefcmd{bukhari}{4455}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَائِشَةَ، وَابْنِ، عَبَّاسٍ أَنَّ أَبَا بَكْر ٍ ـ رضى الله عنه ـ قَبَّلَ النَّبِيَّ صلى الله عليه وسلم بَعْدَ مَوْتِهِ‏.‏\hadithno{4455}\hadithtrans{Narrated Aisha and Ibn `Abbas:Abu Bakr kissed the Prophet (ﷺ) after his death}}
\hadithdefcmd{bukhari}{4456}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَائِشَةَ، وَابْنِ، عَبَّاسٍ أَنَّ أَبَا بَكْر ٍ ـ رضى الله عنه ـ قَبَّلَ النَّبِيَّ صلى الله عليه وسلم بَعْدَ مَوْتِهِ‏.‏\hadithno{4456}\hadithtrans{Narrated Aisha and Ibn `Abbas:Abu Bakr kissed the Prophet (ﷺ) after his death}}
\hadithdefcmd{bukhari}{4464}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، وَابْنِ، عَبَّاسٍ رضى الله عنهم أَنَّ النَّبِيَّ صلى الله عليه وسلم لَبِثَ بِمَكَّةَ عَشْرَ سِنِينَ يُنْزَلُ عَلَيْهِ الْقُرْآنُ، وَبِالْمَدِينَةِ عَشْرًا‏.‏\hadithno{4464}\hadithtrans{Narrated Aisha and Ibn `Abbas:The Prophet (ﷺ) stayed for ten years in Mecca with the Qur'an being revealed to him and he stayed in Medina for ten years}}
\hadithdefcmd{bukhari}{4513}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَتَاهُ رَجُلاَنِ فِي فِتْنَةِ ابْنِ الزُّبَيْرِ فَقَالاَ إِنَّ النَّاسَ قَدْ ضُيِّعُوا، وَأَنْتَ ابْنُ عُمَرَ وَصَاحِبُ النَّبِيِّ صلى الله عليه وسلم فَمَا يَمْنَعُكَ أَنْ تَخْرُجَ فَقَالَ يَمْنَعُنِي أَنَّ اللَّهَ حَرَّمَ دَمَ أَخِي‏.‏ فَقَالاَ أَلَمْ يَقُلِ اللَّهُ ‏\{‏وَقَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ ‏\}‏ فَقَالَ قَاتَلْنَا حَتَّى لَمْ تَكُنْ فِتْنَةٌ، وَكَانَ الدِّينُ لِلَّهِ، وَأَنْتُمْ تُرِيدُونَ أَنْ تُقَاتِلُوا حَتَّى تَكُونَ فِتْنَةٌ، وَيَكُونَ الدِّينُ لِغَيْرِ اللَّهِ‏.‏ وَزَادَ عُثْمَانُ بْنُ صَالِحٍ عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي فُلاَنٌ، وَحَيْوَةُ بْنُ شُرَيْحٍ، عَنْ بَكْرِ بْنِ عَمْرٍو الْمَعَافِرِيِّ، أَنَّ بُكَيْرَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُ عَنْ نَافِعٍ، أَنَّ رَجُلاً، أَتَى ابْنَ عُمَرَ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ مَا حَمَلَكَ عَلَى أَنْ تَحُجَّ عَامًا وَتَعْتَمِرَ عَامًا، وَتَتْرُكَ الْجِهَادَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ، وَقَدْ عَلِمْتَ مَا رَغَّبَ اللَّهُ فِيهِ قَالَ يَا ابْنَ أَخِي بُنِيَ الإِسْلاَمُ عَلَى خَمْسٍ إِيمَانٍ بِاللَّهِ وَرَسُولِهِ، وَالصَّلاَةِ الْخَمْسِ، وَصِيَامِ رَمَضَانَ، وَأَدَاءِ الزَّكَاةِ، وَحَجِّ الْبَيْتِ‏.‏ قَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ، أَلاَ تَسْمَعُ مَا ذَكَرَ اللَّهُ فِي كِتَابِهِ ‏\{‏وَإِنْ طَائِفَتَانِ مِنَ الْمُؤْمِنِينَ اقْتَتَلُوا فَأَصْلِحُوا بَيْنَهُمَا‏\}‏ ‏\{‏إِلَى أَمْرِ اللَّهِ‏\}‏ ‏\{‏قَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ‏\}‏ قَالَ فَعَلْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ الإِسْلاَمُ قَلِيلاً، فَكَانَ الرَّجُلُ يُفْتَنُ فِي دِينِهِ إِمَّا قَتَلُوهُ، وَإِمَّا يُعَذِّبُوهُ، حَتَّى كَثُرَ الإِسْلاَمُ فَلَمْ تَكُنْ فِتْنَةٌ‏.‏ قَالَ فَمَا قَوْلُكَ فِي عَلِيٍّ وَعُثْمَانَ قَالَ أَمَّا عُثْمَانُ فَكَأَنَّ اللَّهَ عَفَا عَنْهُ، وَأَمَّا أَنْتُمْ فَكَرِهْتُمْ أَنْ تَعْفُوا عَنْهُ، وَأَمَّا عَلِيٌّ فَابْنُ عَمِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَخَتَنُهُ‏.‏ وَأَشَارَ بِيَدِهِ فَقَالَ هَذَا بَيْتُهُ حَيْثُ تَرَوْنَ‏.‏\hadithno{4513}\hadithtrans{Narrated Nafi`:During the affliction of Ibn Az-Zubair, two men came to Ibn `Umar and said, "The people are lost, and you are the son of `Umar, and the companion of the Prophet, so what forbids you from coming out?" He said, "What forbids me is that Allah has prohibited the shedding of my brother's blood." They both said, "Didn't Allah say, 'And fight them until there is no more affliction?" He said "We fought until there was no more affliction and the worship is for Allah (Alone while you want to fight until there is affliction and until the worship becomes for other than Allah." Narrated Nafi` (through another group of sub-narrators): A man came to Ibn `Umar and said, "O Abu `Abdur Rahman! What made you perform Hajj in one year and Umra in another year and leave the Jihad for Allah' Cause though you know how much Allah recommends it?" Ibn `Umar replied, "O son of my brother! Islam is founded on five principles, i.e. believe in Allah and His Apostle, the five compulsory prayers, the fasting of the month of Ramadan, the payment of Zakat, and the Hajj to the House (of Allah)." The man said, "O Abu `Abdur Rahman! Won't you listen to what Allah has mentioned in His Book: 'If two groups of believers fight each other, then make peace between them, but if one of them transgresses beyond bounds against the other, then you all fight against the one that transgresses. (49.9) and:--"And fight them till there is no more affliction (i.e. no more worshiping of others along with Allah)." Ibn `Umar said, "We did it, during the lifetime of Allah's Messenger (ﷺ) when Islam had only a few followers. A man would be put to trial because of his religion; he would either be killed or tortured. But when the Muslims increased, there was no more afflictions or oppressions." The man said, "What is your opinion about `Uthman and `Ali?" Ibn `Umar said, "As for `Uthman, it seems that Allah has forgiven him, but you people dislike that he should be forgiven. And as for `Ali, he is the cousin of Allah's Messenger (ﷺ) and his son-in-law." Then he pointed with his hand and said, "That is his house which you see}}
\hadithdefcmd{bukhari}{4514}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَتَاهُ رَجُلاَنِ فِي فِتْنَةِ ابْنِ الزُّبَيْرِ فَقَالاَ إِنَّ النَّاسَ قَدْ ضُيِّعُوا، وَأَنْتَ ابْنُ عُمَرَ وَصَاحِبُ النَّبِيِّ صلى الله عليه وسلم فَمَا يَمْنَعُكَ أَنْ تَخْرُجَ فَقَالَ يَمْنَعُنِي أَنَّ اللَّهَ حَرَّمَ دَمَ أَخِي‏.‏ فَقَالاَ أَلَمْ يَقُلِ اللَّهُ ‏\{‏وَقَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ ‏\}‏ فَقَالَ قَاتَلْنَا حَتَّى لَمْ تَكُنْ فِتْنَةٌ، وَكَانَ الدِّينُ لِلَّهِ، وَأَنْتُمْ تُرِيدُونَ أَنْ تُقَاتِلُوا حَتَّى تَكُونَ فِتْنَةٌ، وَيَكُونَ الدِّينُ لِغَيْرِ اللَّهِ‏.‏ وَزَادَ عُثْمَانُ بْنُ صَالِحٍ عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي فُلاَنٌ، وَحَيْوَةُ بْنُ شُرَيْحٍ، عَنْ بَكْرِ بْنِ عَمْرٍو الْمَعَافِرِيِّ، أَنَّ بُكَيْرَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُ عَنْ نَافِعٍ، أَنَّ رَجُلاً، أَتَى ابْنَ عُمَرَ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ مَا حَمَلَكَ عَلَى أَنْ تَحُجَّ عَامًا وَتَعْتَمِرَ عَامًا، وَتَتْرُكَ الْجِهَادَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ، وَقَدْ عَلِمْتَ مَا رَغَّبَ اللَّهُ فِيهِ قَالَ يَا ابْنَ أَخِي بُنِيَ الإِسْلاَمُ عَلَى خَمْسٍ إِيمَانٍ بِاللَّهِ وَرَسُولِهِ، وَالصَّلاَةِ الْخَمْسِ، وَصِيَامِ رَمَضَانَ، وَأَدَاءِ الزَّكَاةِ، وَحَجِّ الْبَيْتِ‏.‏ قَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ، أَلاَ تَسْمَعُ مَا ذَكَرَ اللَّهُ فِي كِتَابِهِ ‏\{‏وَإِنْ طَائِفَتَانِ مِنَ الْمُؤْمِنِينَ اقْتَتَلُوا فَأَصْلِحُوا بَيْنَهُمَا‏\}‏ ‏\{‏إِلَى أَمْرِ اللَّهِ‏\}‏ ‏\{‏قَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ‏\}‏ قَالَ فَعَلْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ الإِسْلاَمُ قَلِيلاً، فَكَانَ الرَّجُلُ يُفْتَنُ فِي دِينِهِ إِمَّا قَتَلُوهُ، وَإِمَّا يُعَذِّبُوهُ، حَتَّى كَثُرَ الإِسْلاَمُ فَلَمْ تَكُنْ فِتْنَةٌ‏.‏ قَالَ فَمَا قَوْلُكَ فِي عَلِيٍّ وَعُثْمَانَ قَالَ أَمَّا عُثْمَانُ فَكَأَنَّ اللَّهَ عَفَا عَنْهُ، وَأَمَّا أَنْتُمْ فَكَرِهْتُمْ أَنْ تَعْفُوا عَنْهُ، وَأَمَّا عَلِيٌّ فَابْنُ عَمِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَخَتَنُهُ‏.‏ وَأَشَارَ بِيَدِهِ فَقَالَ هَذَا بَيْتُهُ حَيْثُ تَرَوْنَ‏.‏\hadithno{4514}\hadithtrans{Narrated Nafi`:During the affliction of Ibn Az-Zubair, two men came to Ibn `Umar and said, "The people are lost, and you are the son of `Umar, and the companion of the Prophet, so what forbids you from coming out?" He said, "What forbids me is that Allah has prohibited the shedding of my brother's blood." They both said, "Didn't Allah say, 'And fight them until there is no more affliction?" He said "We fought until there was no more affliction and the worship is for Allah (Alone while you want to fight until there is affliction and until the worship becomes for other than Allah." Narrated Nafi` (through another group of sub-narrators): A man came to Ibn `Umar and said, "O Abu `Abdur Rahman! What made you perform Hajj in one year and Umra in another year and leave the Jihad for Allah' Cause though you know how much Allah recommends it?" Ibn `Umar replied, "O son of my brother! Islam is founded on five principles, i.e. believe in Allah and His Apostle, the five compulsory prayers, the fasting of the month of Ramadan, the payment of Zakat, and the Hajj to the House (of Allah)." The man said, "O Abu `Abdur Rahman! Won't you listen to what Allah has mentioned in His Book: 'If two groups of believers fight each other, then make peace between them, but if one of them transgresses beyond bounds against the other, then you all fight against the one that transgresses. (49.9) and:--"And fight them till there is no more affliction (i.e. no more worshiping of others along with Allah)." Ibn `Umar said, "We did it, during the lifetime of Allah's Messenger (ﷺ) when Islam had only a few followers. A man would be put to trial because of his religion; he would either be killed or tortured. But when the Muslims increased, there was no more afflictions or oppressions." The man said, "What is your opinion about `Uthman and `Ali?" Ibn `Umar said, "As for `Uthman, it seems that Allah has forgiven him, but you people dislike that he should be forgiven. And as for `Ali, he is the cousin of Allah's Messenger (ﷺ) and his son-in-law." Then he pointed with his hand and said, "That is his house which you see}}
\hadithdefcmd{bukhari}{4524}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يَقُولُ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏حَتَّى إِذَا اسْتَيْأَسَ الرُّسُلُ وَظَنُّوا أَنَّهُمْ قَدْ كُذِبُوا‏\}‏ خَفِيفَةً، ذَهَبَ بِهَا هُنَاكَ، وَتَلاَ ‏\{‏حَتَّى يَقُولَ الرَّسُولُ وَالَّذِينَ آمَنُوا مَعَهُ مَتَى نَصْرُ اللَّهِ أَلاَ إِنَّ نَصْرَ اللَّهِ قَرِيبٌ‏\}‏ فَلَقِيتُ عُرْوَةَ بْنَ الزُّبَيْرِ فَذَكَرْتُ لَهُ ذَلِكَ فَقَالَ قَالَتْ عَائِشَةُ مَعَاذَ اللَّهِ، وَاللَّهِ مَا وَعَدَ اللَّهُ رَسُولَهُ مِنْ شَىْءٍ قَطُّ إِلاَّ عَلِمَ أَنَّهُ كَائِنٌ قَبْلَ أَنْ يَمُوتَ، وَلَكِنْ لَمْ يَزَلِ الْبَلاَءُ بِالرُّسُلِ حَتَّى خَافُوا أَنْ يَكُونَ مَنْ مَعَهُمْ يُكَذِّبُونَهُمْ، فَكَانَتْ تَقْرَؤُهَا ‏\{‏وَظَنُّوا أَنَّهُمْ قَدْ كُذِّبُوا‏\}‏ مُثَقَّلَةً‏.‏\hadithno{4524}\hadithtrans{Narrated Ibn Abu Mulaika:Ibn `Abbas recited: "(Respite will be granted) until when the Apostles gave up hope (of their people) and thought that they were denied (by their people). There came to them Our Help ...." (12.110) reading Kudhibu without doubling the sound 'dh', and that was what he understood of the Verse. Then he went on reciting: "..even the Apostle and those who believed along with him said: When (will come) Allah's Help? Yes, verily, Allah's Help is near." (2.214) Then I met `Urwa bin Az-Zubair and I mentioned that to him. He said, "Aisha said, 'Allah forbid! By Allah, Allah never promised His Apostle anything but he knew that it would certainly happen before he died. But trials were continuously presented before the Apostles till they were afraid that their followers would accuse them of telling lies. So I used to recite:-- "Till they (come to) think that they were treated as liars." reading 'Kudh-dhibu with double 'dh}}
\hadithdefcmd{bukhari}{4526}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ إِذَا قَرَأَ الْقُرْآنَ لَمْ يَتَكَلَّمْ حَتَّى يَفْرُغَ مِنْهُ، فَأَخَذْتُ عَلَيْهِ يَوْمًا، فَقَرَأَ سُورَةَ الْبَقَرَةِ حَتَّى انْتَهَى إِلَى مَكَانٍ قَالَ تَدْرِي فِيمَا أُنْزِلَتْ‏.‏ قُلْتُ لاَ‏.‏ قَالَ أُنْزِلَتْ فِي كَذَا وَكَذَا‏.‏ ثُمَّ مَضَى‏.‏ وَعَنْ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، حَدَّثَنِي أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ‏\{‏فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ‏\}‏ قَالَ يَأْتِيهَا فِي‏.‏ رَوَاهُ مُحَمَّدُ بْنُ يَحْيَى بْنِ سَعِيدٍ عَنْ أَبِيهِ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ‏.‏\hadithno{4526}\hadithtrans{Narrated Nafi`:Whenever Ibn `Umar recited the Qur'an, he would not speak to anyone till he had finished his recitation. Once I held the Qur'an and he recited Surat-al-Baqara from his memory and then stopped at a certain Verse and said, "Do you know in what connection this Verse was revealed? " I replied, "No." He said, "It was revealed in such-and-such connection." Ibn `Umar then resumed his recitation. Nafi` added regarding the Verse:--"So go to your tilth when or how you will" Ibn `Umar said, "It means one should approach his wife in}}
\hadithdefcmd{bukhari}{4549}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ يَمِينَ صَبْرٍ لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً أُولَئِكَ لاَ خَلاَقَ لَهُمْ فِي الآخِرَةِ‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏ قَالَ فَدَخَلَ الأَشْعَثُ بْنُ قَيْسٍ وَقَالَ مَا يُحَدِّثُكُمْ أَبُو عَبْدِ الرَّحْمَنِ قُلْنَا كَذَا وَكَذَا‏.‏ قَالَ فِيَّ أُنْزِلَتْ كَانَتْ لِي بِئْرٌ فِي أَرْضِ ابْنِ عَمٍّ لِي قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَيِّنَتُكَ أَوْ يَمِينُهُ ‏"‏ فَقُلْتُ إِذًا يَحْلِفَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينِ صَبْرٍ يَقْتَطِعُ بِهَا مَالَ امْرِئٍ مُسْلِمٍ وَهْوَ فِيهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانٌ ‏"‏‏.‏\hadithno{4549}\hadithtrans{Narrated Abu Wail:`Abdullah bin Masud said, "Allah's Messenger (ﷺ) said, 'Whoever takes an oath when asked to do so, in which he may deprive a Muslim of his property unlawfully, will meet Allah Who will be angry with him.' So Allah revealed in confirmation of this statement:--"Verily! Those who Purchase a small gain at the cost of Allah's Covenant and oaths, they shall have no portion in the Hereafter..." (3.77) Then entered Al-Ash'ath bin Qais and said, "What is Abu `Abdur-Rahman narrating to you?" We replied, 'So-and-so." Al-Ash'ath said, "This Verse was revealed in my connection. I had a well in the land of my cousin (and he denied my, possessing it). On that the Prophet (ﷺ) said to me, 'Either you bring forward a proof or he (i.e. your cousin) takes an oath (to confirm his claim)' I said, 'I am sure he would take a (false) oath, O Allah's Messenger (ﷺ).' He said, 'If somebody takes an oath when asked to do so through which he may deprive a Muslim of his property (unlawfully) and he is a liar in his oath, he will meet Allah Who will be angry with him}}
\hadithdefcmd{bukhari}{4828}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَاحِكًا حَتَّى أَرَى مِنْهُ لَهَوَاتِهِ، إِنَّمَا كَانَ يَتَبَسَّمُ‏.‏ قَالَتْ وَكَانَ إِذَا رَأَى غَيْمًا أَوْ رِيحًا عُرِفَ فِي وَجْهِهِ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ النَّاسَ إِذَا رَأَوُا الْغَيْمَ فَرِحُوا، رَجَاءَ أَنْ يَكُونَ فِيهِ الْمَطَرُ، وَأَرَاكَ إِذَا رَأَيْتَهُ عُرِفَ فِي وَجْهِكَ الْكَرَاهِيَةُ‏.‏ فَقَالَ ‏"‏ يَا عَائِشَةُ مَا يُؤْمِنِّي أَنْ يَكُونَ فِيهِ عَذَابٌ عُذِّبَ قَوْمٌ بِالرِّيحِ، وَقَدْ رَأَى قَوْمٌ الْعَذَابَ فَقَالُوا ‏\{‏هَذَا عَارِضٌ مُمْطِرُنَا‏\}‏‏"‏\hadithno{4828}\hadithtrans{Narrated `Aisha:(the wife of the Prophet), I never saw Allah's Messenger (ﷺ) laughing loudly enough to enable me to see his uvula, but he used to smile only. And whenever he saw clouds or winds, signs of deep concern would appear on his face. I said, "O Allah's Messenger (ﷺ)! When people see clouds they usually feel happy, hoping that it would rain, while I see that when you see clouds, one could notice signs of dissatisfaction on your face." He said, "O `Aisha! What is the guarantee for me that there will be no punishment in it, since some people were punished with a wind? Verily, some people saw (received) the punishment, but (while seeing the cloud) they said, 'This cloud will give us rain}}
\hadithdefcmd{bukhari}{4879}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ خَيْمَةً مِنْ لُؤْلُؤَةٍ مُجَوَّفَةٍ، عَرْضُهَا سِتُّونَ مِيلاً، فِي كُلِّ زَاوِيَةٍ مِنْهَا أَهْلٌ، مَا يَرَوْنَ الآخَرِينَ يَطُوفُ عَلَيْهِمُ الْمُؤْمِنُونَ ‏"‏‏.‏ ‏"‏ وَجَنَّتَانِ مِنْ فِضَّةٍ، آنِيَتُهُمَا وَمَا فِيهِمَا، وَجَنَّتَانِ مِنْ كَذَا آنِيَتُهُمَا، وَمَا فِيهِمَا، وَمَا بَيْنَ الْقَوْمِ وَبَيْنَ أَنْ يَنْظُرُوا إِلَى رَبِّهِمْ إِلاَّ رِدَاءُ الْكِبْرِ عَلَى وَجْهِهِ فِي جَنَّةِ عَدْنٍ ‏"‏‏.‏\hadithno{4879}\hadithtrans{Narrated `Abdullah bin Qais:Allah's Messenger (ﷺ) said, "In Paradise there is a pavilion made of a single hollow pearl sixty miles wide, in each corner of which there are wives who will not see those in the other corners; and the believers will visit and enjoy them. And there are two gardens, the utensils and contents of which are made of silver; and two other gardens, the utensils and contents of which are made of so-and-so (i.e. gold) and nothing will prevent the people staying in the Garden of Eden from seeing their Lord except the curtain of Majesty over His Face}}
\hadithdefcmd{bukhari}{4978}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ أَخْبَرَتْنِي عَائِشَةُ، وَابْنُ، عَبَّاسٍ رضى الله عنهم قَالاَ لَبِثَ النَّبِيُّ صلى الله عليه وسلم بِمَكَّةَ عَشْرَ سِنِينَ يُنْزَلُ عَلَيْهِ الْقُرْآنُ وَبِالْمَدِينَةِ عَشْرَ سِنِينَ\hadithno{4978}\hadithtrans{Narrated `Aisha and Ibn `Abbas:The Prophet (ﷺ) remained in Mecca for ten years, during which the Qur'an used to be revealed to him; and he stayed in Medina for ten years}}
\hadithdefcmd{bukhari}{5110}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي قَبِيصَةُ بْنُ ذُؤَيْبٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا وَالْمَرْأَةُ وَخَالَتُهَا‏.‏ فَنُرَى خَالَةَ أَبِيهَا بِتِلْكَ الْمَنْزِلَةِ‏.‏ لأَنَّ عُرْوَةَ حَدَّثَنِي عَنْ عَائِشَةَ، قَالَتْ حَرِّمُوا مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ النَّسَبِ‏.‏\hadithno{5110}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) forbade that a woman should be married to a man along with her paternal aunt or with her maternal aunt (at the same time). Az-Zuhri (the sub-narrator) said: There is a similar order for the paternal aunt of the father of one's wife, for 'Urwa told me that `Aisha said, "What is unlawful because of blood relations, is also unlawful because of the corresponding foster suckling relations}}
\hadithdefcmd{bukhari}{5117}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو عَنِ الْحَسَنِ بْنِ مُحَمَّدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، وَسَلَمَةَ بْنِ الأَكْوَعِ، قَالاَ كُنَّا فِي جَيْشٍ فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّهُ قَدْ أُذِنَ لَكُمْ أَنْ تَسْتَمْتِعُوا فَاسْتَمْتِعُوا ‏"‏‏.‏\hadithno{5117}\hadithtrans{Narrated Jabir bin `Abdullah and Salama bin Al-Akwa`:While we were in an army, Allah's Messenger (ﷺ) came to us and said, "You have been allowed to do the Mut'a (marriage), so do it}}
\hadithdefcmd{bukhari}{5143}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، قَالَ قَالَ أَبُو هُرَيْرَةَ يَأْثُرُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالظَّنَّ، فَإِنَّ الظَّنَّ أَكْذَبُ الْحَدِيثِ، وَلاَ تَجَسَّسُوا، وَلاَ تَحَسَّسُوا، وَلاَ تَبَاغَضُوا، وَكُونُوا إِخْوَانًا ‏"‏‏.‏ وَلَا يَخْطُبُ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ حَتَّى يَنْكِحَ أَوْ يَتْرُكَ\hadithno{5143}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Beware of suspicion (about others), as suspicion is the falsest talk, and do not spy upon each other, and do not listen to the evil talk of the people about others' affairs, and do not have enmity with one another, but be brothers. And none should ask for the hand of a girl who is already engaged to his (Muslim) brother, but one should wait till the first suitor marries her or leaves her}}
\hadithdefcmd{bukhari}{5185}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ مَيْسَرَةَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يُؤْذِي جَارَهُ ‏"‏‏.‏ وَاسْتَوْصُوا بِالنِّسَاءِ خَيْرًا فَإِنَّهُنَّ خُلِقْنَ مِنْ ضِلَعٍ وَإِنَّ أَعْوَجَ شَيْءٍ فِي الضِّلَعِ أَعْلَاهُ فَإِنْ ذَهَبْتَ تُقِيمُهُ كَسَرْتَهُ وَإِنْ تَرَكْتَهُ لَمْ يَزَلْ أَعْوَجَ فَاسْتَوْصُوا بِالنِّسَاءِ خَيْرًا\hadithno{5185}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever believes in Allah and the Last Day should not hurt (trouble) his neighbor. And I advise you to take care of the women, for they are created from a rib and the most crooked portion of the rib is its upper part; if you try to straighten it, it will break, and if you leave it, it will remain crooked, so I urge you to take care of the women}}
\hadithdefcmd{bukhari}{5208}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو أَخْبَرَنِي عَطَاءٌ، سَمِعَ جَابِرًا، رضى الله عنه قَالَ كُنَّا نَعْزِلُ وَالْقُرْآنُ يَنْزِلُ‏.‏ وَعَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَعْزِلُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَالْقُرْآنُ يَنْزِلُ‏.‏\hadithno{5208}\hadithtrans{Narrated Jabir:We used to practice coitus interruptus while the Qur'an was being revealed. Jabir added: We used to practice coitus interruptus during the lifetime of Allah's Messenger (ﷺ) while the Qur'an was being Revealed}}
\hadithdefcmd{bukhari}{5271}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ أَتَى رَجُلٌ مِنْ أَسْلَمَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي الْمَسْجِدِ فَنَادَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ الأَخِرَ قَدْ زَنَى ـ يَعْنِي نَفْسَهُ ـ فَأَعْرَضَ عَنْهُ فَتَنَحَّى لِشِقِّ وَجْهِهِ الَّذِي أَعْرَضَ قِبَلَهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ الأَخِرَ قَدْ زَنَى فَأَعْرَضَ عَنْهُ فَتَنَحَّى لِشِقِّ وَجْهِهِ الَّذِي أَعْرَضَ قِبَلَهُ فَقَالَ لَهُ ذَلِكَ فَأَعْرَضَ عَنْهُ فَتَنَحَّى لَهُ الرَّابِعَةَ، فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ دَعَاهُ فَقَالَ ‏"‏ هَلْ بِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اذْهَبُوا بِهِ فَارْجُمُوهُ ‏"‏‏.‏ وَكَانَ قَدْ أُحْصِنَ‏.‏ وَعَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي مَنْ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيَّ، قَالَ كُنْتُ فِيمَنْ رَجَمَهُ فَرَجَمْنَاهُ بِالْمُصَلَّى بِالْمَدِينَةِ، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ جَمَزَ حَتَّى أَدْرَكْنَاهُ بِالْحَرَّةِ، فَرَجَمْنَاهُ حَتَّى مَاتَ‏.‏\hadithno{5271}\hadithtrans{Narrated Abu Huraira:A man from Bani Aslam came to Allah's Messenger (ﷺ) while he was in the mosque and called (the Prophet (ﷺ) ) saying, "O Allah's Messenger (ﷺ)! I have committed illegal sexual intercourse." On that the Prophet (ﷺ) turned his face from him to the other side, whereupon the man moved to the side towards which the Prophet (ﷺ) had turned his face, and said, "O Allah's Messenger (ﷺ)! I have committed illegal sexual intercourse." The Prophet turned his face (from him) to the other side whereupon the man moved to the side towards which the Prophet (ﷺ) had turned his face, and repeated his statement. The Prophet (ﷺ) turned his face (from him) to the other side again. The man moved again (and repeated his statement) for the fourth time. So when the man had given witness four times against himself, the Prophet (ﷺ) called him and said, "Are you insane?" He replied, "No." The Prophet (ﷺ) then said (to his companions), "Go and stone him to death." The man was a married one. Jabir bin `Abdullah Al-Ansari said: I was one of those who stoned him. We stoned him at the Musalla (`Id praying place) in Medina. When the stones hit him with their sharp edges, he fled, but we caught him at Al-Harra and stoned him till he died}}
\hadithdefcmd{bukhari}{5321}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ سَمِعَهُ يَذْكُرُ، أَنَّ يَحْيَى بْنَ سَعِيدِ بْنِ الْعَاصِ، طَلَّقَ بِنْتَ عَبْدِ الرَّحْمَنِ بْنِ الْحَكَمِ، فَانْتَقَلَهَا عَبْدُ الرَّحْمَنِ، فَأَرْسَلَتْ عَائِشَةُ أُمُّ الْمُؤْمِنِينَ إِلَى مَرْوَانَ وَهْوَ أَمِيرُ الْمَدِينَةِ اتَّقِ اللَّهَ وَارْدُدْهَا إِلَى بَيْتِهَا‏.‏ قَالَ مَرْوَانُ فِي حَدِيثِ سُلَيْمَانَ إِنَّ عَبْدَ الرَّحْمَنِ بْنَ الْحَكَمِ غَلَبَنِي‏.‏ وَقَالَ الْقَاسِمُ بْنُ مُحَمَّدٍ أَوَمَا بَلَغَكِ شَأْنُ فَاطِمَةَ بِنْتِ قَيْسٍ قَالَتْ لاَ يَضُرُّكَ أَنْ لاَ تَذْكُرَ حَدِيثَ فَاطِمَةَ‏.‏ فَقَالَ مَرْوَانُ بْنُ الْحَكَمِ إِنْ كَانَ بِكِ شَرٌّ فَحَسْبُكِ مَا بَيْنَ هَذَيْنِ مِنَ الشَّرِّ‏.‏\hadithno{5321}\hadithtrans{(Narrated Qasim bin Muhammad and Sulaiman bin Yasar:that Yahya bin Sa`id bin Al-`As divorced the daughter of `Abdur-Rahman bin Al-Hakarn. `Abdur- Rahman took her to his house. On that `Aisha sent a message to Marwan bin Al-Hakam who was the ruler of Medina, saying, "Fear Allah, and urge your brother) to return her to her house." Marwan (in Sulaiman's version) said, "Abdur-Rahman bin Al-Hakam did not obey me (or had a convincing argument)." (In Al-Qasim's versions Marwan said, "Have you not heard of the case of Fatima bint Qais?" Aisha said, "The case of Fatima bint Qais is not in your favor.' Marwan bin Al-Hakam said to `Aisha, "The reason that made Fatima bint Qais go to her father's house is just applicable to the daughter of `Abdur-Rahman)}}
\hadithdefcmd{bukhari}{5323}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مَا لِفَاطِمَةَ أَلاَ تَتَّقِي اللَّهَ، يَعْنِي فِي قَوْلِهَا لاَ سُكْنَى وَلاَ نَفَقَةَ\hadithno{5323}\hadithtrans{Narrated Al-Qasim:Aisha said, "What is wrong with Fatima? Why doesn't she fear Allah?" by saying that a divorced lady is not entitled to be provided with residence and sustenance (by her husband)}}
\hadithdefcmd{bukhari}{5325}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، قَالَ عُرْوَةُ بْنُ الزُّبَيْرِ لِعَائِشَةَ أَلَمْ تَرَيْنَ إِلَى فُلاَنَةَ بِنْتِ الْحَكَمِ طَلَّقَهَا زَوْجُهَا الْبَتَّةَ فَخَرَجَتْ‏.‏ فَقَالَتْ بِئْسَ مَا صَنَعَتْ‏.‏ قَالَ أَلَمْ تَسْمَعِي فِي قَوْلِ فَاطِمَةَ قَالَتْ أَمَا إِنَّهُ لَيْسَ لَهَا خَيْرٌ فِي ذِكْرِ هَذَا الْحَدِيثِ‏.‏ وَزَادَ ابْنُ أَبِي الزِّنَادِ عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَابَتْ عَائِشَةُ أَشَدَّ الْعَيْبِ وَقَالَتْ إِنَّ فَاطِمَةَ كَانَتْ فِي مَكَانٍ وَحِشٍ فَخِيفَ عَلَى نَاحِيَتِهَا، فَلِذَلِكَ أَرْخَصَ لَهَا النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{5325}\hadithtrans{Narrated Qasim:Urwa said to Aisha, "Do you know so-and-so, the daughter of Al-Hakam? Her husband divorced her irrevocably and she left (her husband's house)." `Aisha said, "What a bad thing she has done!" 'Urwa said (to `Aisha), "Haven't you heard the statement of Fatima?" `Aisha replied, "It is not in her favor to mention." 'Urwa added, `Aisha reproached (Fatima) severely and said, "Fatima was in a lonely place, and she was prone to danger, so the Prophet (ﷺ) allowed her (to go out of her husband's house)}}
\hadithdefcmd{bukhari}{5327}{وَحَدَّثَنِي حِبَّانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَنْكَرَتْ ذَلِكَ عَلَى فَاطِمَةَ‏.‏\hadithno{5327}\hadithtrans{Narrated 'Urwa:Aisha disapproved of what Fatima used to say}}
\hadithdefcmd{bukhari}{5525}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي عَدِيٌّ، عَنِ الْبَرَاءِ، وَابْنِ أَبِي أَوْفَى، رضى الله عنهم قَالاَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ لُحُومِ الْحُمُرِ‏.‏\hadithno{5525}\hadithtrans{Narrated Al-Bara' and Ibn Abi `Aufa:The Prophet (ﷺ) prohibited the eating of donkey's meat}}
\hadithdefcmd{bukhari}{5641}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَعَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يُصِيبُ الْمُسْلِمَ مِنْ نَصَبٍ وَلاَ وَصَبٍ وَلاَ هَمٍّ وَلاَ حُزْنٍ وَلاَ أَذًى وَلاَ غَمٍّ حَتَّى الشَّوْكَةِ يُشَاكُهَا، إِلاَّ كَفَّرَ اللَّهُ بِهَا مِنْ خَطَايَاهُ ‏"‏‏.‏\hadithno{5641}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:The Prophet (ﷺ) said, "No fatigue, nor disease, nor sorrow, nor sadness, nor hurt, nor distress befalls a Muslim, even if it were the prick he receives from a thorn, but that Allah expiates some of his sins for that}}
\hadithdefcmd{bukhari}{5692}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، قَالَ سَمِعْتُ الزُّهْرِيَّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ عَلَيْكُمْ بِهَذَا الْعُودِ الْهِنْدِيِّ، فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ‏.‏ يُسْتَعَطُ بِهِ مِنَ الْعُذْرَةِ، وَيُلَدُّ بِهِ مِنْ ذَاتِ الْجَنْبِ ‏"‏‏.‏ وَدَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم بِابْنٍ لِي لَمْ يَأْكُلِ الطَّعَامَ فَبَالَ عَلَيْهِ، فَدَعَا بِمَاءٍ فَرَشَّ عَلَيْهِ‏.‏\hadithno{5692}\hadithtrans{Narrated Um Qais bint Mihsan:I heard the Prophet (ﷺ) saying, "Treat with the Indian incense, for it has healing for seven diseases; it is to be sniffed by one having throat trouble, and to be put into one side of the mouth of one suffering from pleurisy." Once I went to Allah's Messenger (ﷺ) with a son of mine who would not eat any food, and the boy passed urine on him whereupon he asked for some water and sprinkled it over the place of urine}}
\hadithdefcmd{bukhari}{5698}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ عَلْقَمَةَ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ الأَعْرَجَ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ ابْنَ بُحَيْنَةَ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ بِلَحْىِ جَمَلٍ مِنْ طَرِيقِ مَكَّةَ، وَهْوَ مُحْرِمٌ، فِي وَسَطِ رَأْسِهِ‏.‏ وَقَالَ الأَنْصَارِيُّ أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ فِي رَأْسِهِ‏.‏\hadithno{5698}\hadithtrans{Narrated `Abdullah bin Buhaina:Allah's Messenger (ﷺ) was cupped on the middle of his head at Lahl Jamal on his way to Mecca while he was in a state of Ihram. Narrated Ibn `Abbas: Allah's Messenger (ﷺ) was cupped on his head}}
\hadithdefcmd{bukhari}{5700}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم فِي رَأْسِهِ وَهْوَ مُحْرِمٌ مِنْ وَجَعٍ كَانَ بِهِ بِمَاءٍ يُقَالُ لَهُ لَحْىُ جَمَلٍ‏.‏ وَقَالَ مُحَمَّدُ بْنُ سَوَاءٍ أَخْبَرَنَا هِشَامٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهْوَ مُحْرِمٌ فِي رَأْسِهِ مِنْ شَقِيقَةٍ كَانَتْ بِهِ‏.‏\hadithno{5700}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was cupped on his head for an ailment he was suffering from while he was in a state of Ihram. at a water place called Lahl Jamal. Ibn `Abbas further said: Allah's Apostle was cupped on his head for unilateral headache while he was in a state of Ihram}}
\hadithdefcmd{bukhari}{5709}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مُوسَى بْنُ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، وَعَائِشَةَ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ قَبَّلَ النَّبِيَّ صلى الله عليه وسلم وَهْوَ مَيِّتٌ‏.‏ قَالَ وَقَالَتْ عَائِشَةُ لَدَدْنَاهُ فِي مَرَضِهِ، فَجَعَلَ يُشِيرُ إِلَيْنَا، أَنْ لاَ تَلُدُّونِي‏.‏ فَقُلْنَا كَرَاهِيَةُ الْمَرِيضِ لِلدَّوَاءِ‏.‏ فَلَمَّا أَفَاقَ قَالَ ‏"‏ أَلَمْ أَنْهَكُمْ أَنْ تَلُدُّونِي ‏"‏‏.‏ قُلْنَا كَرَاهِيَةَ الْمَرِيضِ لِلدَّوَاءِ‏.‏ فَقَالَ ‏"‏ لاَ يَبْقَى فِي الْبَيْتِ أَحَدٌ إِلاَّ لُدَّ ـ وَأَنَا أَنْظُرُ ـ إِلاَّ الْعَبَّاسَ فَإِنَّهُ لَمْ يَشْهَدْكُمْ ‏"‏‏.‏\hadithno{5709}\hadithtrans{Narrated Ibn `Abbas and `Aisha:Abu Bakr kissed (the forehead of) the Prophet (ﷺ) when he was dead. `Aisha added: We put medicine in one side of his mouth but he started waving us not to insert the medicine into his mouth. We said, "He dislikes the medicine as a patient usually does." But when he came to his senses he said, "Did I not forbid you to put medicine (by force) in the side of my mouth?" We said, "We thought it was just because a patient usually dislikes medicine." He said, "None of those who are in the house but will be forced to take medicine in the side of his mouth while I am watching, except Al-`Abbas, for he had not witnessed your deed}}
\hadithdefcmd{bukhari}{5710}{\hadithno{5710}\hadithtrans{}}
\hadithdefcmd{bukhari}{5711}{\hadithno{5711}\hadithtrans{}}
\hadithdefcmd{bukhari}{5719}{حَدَّثَنَا عَارِمٌ، حَدَّثَنَا حَمَّادٌ، قَالَ قُرِئَ عَلَى أَيُّوبَ مِنْ كُتُبِ أَبِي قِلاَبَةَ، مِنْهُ مَا حَدَّثَ بِهِ وَمِنْهُ مَا قُرِئَ عَلَيْهِ، وَكَانَ هَذَا فِي الْكِتَابِ عَنْ أَنَسٍ أَنَّ أَبَا طَلْحَةَ وَأَنَسَ بْنَ النَّضْرِ كَوَيَاهُ، وَكَوَاهُ أَبُو طَلْحَةَ بِيَدِهِ‏.‏ وَقَالَ عَبَّادُ بْنُ مَنْصُورٍ عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَذِنَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ بَيْتٍ مِنَ الأَنْصَارِ أَنْ يَرْقُوا مِنَ الْحُمَةِ وَالأُذُنِ‏.‏ قَالَ أَنَسٌ كُوِيتُ مِنْ ذَاتِ الْجَنْبِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حَىٌّ، وَشَهِدَنِي أَبُو طَلْحَةَ وَأَنَسُ بْنُ النَّضْرِ وَزَيْدُ بْنُ ثَابِتٍ، وَأَبُو طَلْحَةَ كَوَانِي‏.‏\hadithno{5719}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) allowed one of the Ansar families to treat persons who have taken poison and also who are suffering from ear ailment with Ruqya. Anas added: I got myself branded cauterized) for pleurisy, when Allah's Messenger (ﷺ) was still alive. Abu Talha, Anas bin An-Nadr and Zaid bin Thabit witnessed that, and it was Abu Talha who branded (cauterized) me}}
\hadithdefcmd{bukhari}{5720}{حَدَّثَنَا عَارِمٌ، حَدَّثَنَا حَمَّادٌ، قَالَ قُرِئَ عَلَى أَيُّوبَ مِنْ كُتُبِ أَبِي قِلاَبَةَ، مِنْهُ مَا حَدَّثَ بِهِ وَمِنْهُ مَا قُرِئَ عَلَيْهِ، وَكَانَ هَذَا فِي الْكِتَابِ عَنْ أَنَسٍ أَنَّ أَبَا طَلْحَةَ وَأَنَسَ بْنَ النَّضْرِ كَوَيَاهُ، وَكَوَاهُ أَبُو طَلْحَةَ بِيَدِهِ‏.‏ وَقَالَ عَبَّادُ بْنُ مَنْصُورٍ عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَذِنَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ بَيْتٍ مِنَ الأَنْصَارِ أَنْ يَرْقُوا مِنَ الْحُمَةِ وَالأُذُنِ‏.‏ قَالَ أَنَسٌ كُوِيتُ مِنْ ذَاتِ الْجَنْبِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حَىٌّ، وَشَهِدَنِي أَبُو طَلْحَةَ وَأَنَسُ بْنُ النَّضْرِ وَزَيْدُ بْنُ ثَابِتٍ، وَأَبُو طَلْحَةَ كَوَانِي‏.‏\hadithno{5720}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) allowed one of the Ansar families to treat persons who have taken poison and also who are suffering from ear ailment with Ruqya. Anas added: I got myself branded cauterized) for pleurisy, when Allah's Messenger (ﷺ) was still alive. Abu Talha, Anas bin An-Nadr and Zaid bin Thabit witnessed that, and it was Abu Talha who branded (cauterized) me}}
\hadithdefcmd{bukhari}{5759}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ امْرَأَتَيْنِ، رَمَتْ إِحْدَاهُمَا الأُخْرَى بِحَجَرٍ فَطَرَحَتْ جَنِينَهَا، فَقَضَى فِيهِ النَّبِيُّ صلى الله عليه وسلم بِغُرَّةٍ عَبْدٍ أَوْ وَلِيدَةٍ‏.‏ وَعَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي الْجَنِينِ يُقْتَلُ فِي بَطْنِ أُمِّهِ بِغُرَّةٍ عَبْدٍ أَوْ وَلِيدَةٍ‏.‏ فَقَالَ الَّذِي قُضِيَ عَلَيْهِ كَيْفَ أَغْرَمُ مَنْ لاَ أَكَلَ، وَلاَ شَرِبَ، وَلاَ نَطَقَ، وَلاَ اسْتَهَلَّ، وَمِثْلُ ذَلِكَ بَطَلْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هَذَا مِنْ إِخْوَانِ الْكُهَّانِ ‏"‏‏.‏\hadithno{5759}\hadithtrans{Narrated Abu Huraira:Two ladies (had a fight) and one of them hit the other with a stone on the `Abdomen and caused her to abort. The Prophet (ﷺ) judged that the victim be given either a slave or a female slave (as blood-money). Narrated Ibn Shihab: Sa`id bin Al-Musayyab said, "Allah's Messenger (ﷺ) judged that in case of child killed in the womb of its mother, the offender should give the mother a slave or a female slave in recompense The offender said, How can I be fined for killing one who neither ate nor drank, neither spoke nor cried: a case like that should be denied ' On that Allah's Messenger (ﷺ) said 'He is one of the brothers of the foretellers}}
\hadithdefcmd{bukhari}{5773}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى ‏"‏‏.‏ قَالَ أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُورِدُوا الْمُمْرِضَ عَلَى الْمُصِحِّ ‏"‏‏.‏ وَعَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سِنَانُ بْنُ أَبِي سِنَانٍ الدُّؤَلِيُّ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى ‏"‏‏.‏ فَقَامَ أَعْرَابِيٌّ فَقَالَ أَرَأَيْتَ الإِبِلَ تَكُونُ فِي الرِّمَالِ أَمْثَالَ الظِّبَاءِ فَيَأْتِيهِ الْبَعِيرُ الأَجْرَبُ فَتَجْرَبُ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَمَنْ أَعْدَى الأَوَّلَ ‏"‏‏.‏\hadithno{5773}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No 'Adwa." Abu Huraira also said: The Prophet (ﷺ) said, "The cattle suffering from a disease should not be mixed up with healthy cattle (or said "Do not put a patient with a healthy person as a precaution.") Abu Huraira also said: Allah's Messenger (ﷺ) said, "No 'Adwa." A bedouin got up and said, "Don't you see how camels on the sand look like deer but when a mangy camel mixes with them, they all get infected with mange?" On that the Prophet (ﷺ) said, "Then who conveyed the (mange) disease to the first camel?}}
\hadithdefcmd{bukhari}{5774}{\hadithno{5774}\hadithtrans{}}
\hadithdefcmd{bukhari}{5780}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، رضى الله عنه قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ‏.‏ قَالَ الزُّهْرِيُّ وَلَمْ أَسْمَعْهُ حَتَّى أَتَيْتُ الشَّأْمَ‏.‏ وَزَادَ اللَّيْثُ قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ وَسَأَلْتُهُ هَلْ نَتَوَضَّأُ أَوْ نَشْرَبُ أَلْبَانَ الأُتُنِ أَوْ مَرَارَةَ السَّبُعِ أَوْ أَبْوَالَ الإِبِلِ‏.‏ قَالَ قَدْ كَانَ الْمُسْلِمُونَ يَتَدَاوَوْنَ بِهَا، فَلاَ يَرَوْنَ بِذَلِكَ بَأْسًا، فَأَمَّا أَلْبَانُ الأُتُنِ فَقَدْ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُحُومِهَا، وَلَمْ يَبْلُغْنَا عَنْ أَلْبَانِهَا أَمْرٌ وَلاَ نَهْىٌ، وَأَمَّا مَرَارَةُ السَّبُعِ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ أَنَّ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ‏.‏\hadithno{5780}\hadithtrans{Narrated Abu Tha`laba Al-Khushani:The Prophet (ﷺ) forbade the eating of wild animals having fangs. (Az-Zuhri said: I did not hear this narration except when I went to Sham.) Al-Laith said: Narrated Yunus: I asked Ibn Shihab, "May we perform the ablution with the milk of she-asses or drink it, or drink the bile of wild animals or urine of camels?" He replied, "The Muslims used to treat themselves with that and did not see any harm in it. As for the milk of she-asses, we have learnt that Allah's Messenger (ﷺ) forbade the eating of their meat, but we have not received any information whether drinking of their milk is allowed or forbidden." As for the bile of wild animals, Ibn Shihab said, "Abu Idris Al-Khaulani told me that Allah's Messenger (ﷺ) forbade the eating of the flesh of every wild beast having fangs}}
\hadithdefcmd{bukhari}{5815}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَائِشَةَ، وَعَبْدَ اللَّهِ بْنَ عَبَّاسٍ، رضى الله عنهم قَالاَ لَمَّا نَزَلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم طَفِقَ يَطْرَحُ خَمِيصَةً لَهُ عَلَى وَجْهِهِ، فَإِذَا اغْتَمَّ كَشَفَهَا عَنْ وَجْهِهِ، فَقَالَ وَهْوَ كَذَلِكَ ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الْيَهُودِ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏‏.‏ يُحَذِّرُ مَا صَنَعُوا‏.‏\hadithno{5815}\hadithtrans{Narrated `Aisha and `Abdullah bin `Abbas:When the disease of Allah's Messenger (ﷺ) got aggravated, he covered his face with a Khamisa, but when he became short of breath, he would remove it from his face and say, "It is like that! May Allah curse the Jews Christians because they took the graves of their prophets as places of worship." By that he warned his follower of imitating them, by doing that which they did}}
\hadithdefcmd{bukhari}{5908}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا مُعَاذُ بْنُ هَانِئٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ،‏.‏ أَوْ عَنْ رَجُلٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم ضَخْمَ الْقَدَمَيْنِ، حَسَنَ الْوَجْهِ، لَمْ أَرَ بَعْدَهُ مِثْلَهُ‏.‏\hadithno{5908}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) had big feet and a good-looking face and I have not seen anybody like him after him}}
\hadithdefcmd{bukhari}{5911}{وَقَالَ أَبُو هِلاَلٍ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ،‏.‏ أَوْ جَابِرِ بْنِ عَبْدِ اللَّهِ كَانَ النَّبِيُّ صلى الله عليه وسلم ضَخْمَ الْكَفَّيْنِ وَالْقَدَمَيْنِ، لَمْ أَرَ بَعْدَهُ شَبَهًا لَهُ‏.‏\hadithno{5911}\hadithtrans{Narrated Anas or Jabir bin `Abdullah:The Prophet (ﷺ) had big hands and feet and I have not seen anybody like him after him}}
\hadithdefcmd{bukhari}{6026}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي بُرْدَةَ، بُرَيْدِ بْنِ أَبِي بُرْدَةَ قَالَ أَخْبَرَنِي جَدِّي أَبُو بُرْدَةَ، عَنْ أَبِيهِ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْمُؤْمِنُ لِلْمُؤْمِنِ كَالْبُنْيَانِ، يَشُدُّ بَعْضُهُ بَعْضًا ‏"‏‏.‏ ثُمَّ شَبَّكَ بَيْنَ أَصَابِعِهِ‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم جَالِسًا إِذْ جَاءَ رَجُلٌ يَسْأَلُ أَوْ طَالِبُ حَاجَةٍ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏"‏ اشْفَعُوا فَلْتُؤْجَرُوا، وَلْيَقْضِ اللَّهُ عَلَى لِسَانِ نَبِيِّهِ مَا شَاءَ ‏"‏‏.‏\hadithno{6026}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "A believer to another believer is like a building whose different parts enforce each other." The Prophet (ﷺ) then clasped his hands with the fingers interlaced. (At that time) the Prophet (ﷺ) was sitting and a man came and begged or asked for something. The Prophet (ﷺ) faced us and said, "Help and recommend him and you will receive the reward for it, and Allah will bring about what He will through His Prophet's tongue}}
\hadithdefcmd{bukhari}{6073}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَوْفُ بْنُ مَالِكِ بْنِ الطُّفَيْلِ ـ هُوَ ابْنُ الْحَارِثِ وَهْوَ ابْنُ أَخِي عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم لأُمِّهَا ـ أَنَّ عَائِشَةَ حُدِّثَتْ أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ قَالَ فِي بَيْعٍ أَوْ عَطَاءٍ أَعْطَتْهُ عَائِشَةُ وَاللَّهِ لَتَنْتَهِيَنَّ عَائِشَةُ، أَوْ لأَحْجُرَنَّ عَلَيْهَا‏.‏ فَقَالَتْ أَهُوَ قَالَ هَذَا قَالُوا نَعَمْ‏.‏ قَالَتْ هُوَ لِلَّهِ عَلَىَّ نَذْرٌ، أَنْ لاَ أُكَلِّمَ ابْنَ الزُّبَيْرِ أَبَدًا‏.‏ فَاسْتَشْفَعَ ابْنُ الزُّبَيْرِ إِلَيْهَا، حِينَ طَالَتِ الْهِجْرَةُ فَقَالَتْ لاَ وَاللَّهِ لاَ أُشَفِّعُ فِيهِ أَبَدًا، وَلاَ أَتَحَنَّثُ إِلَى نَذْرِي‏.‏ فَلَمَّا طَالَ ذَلِكَ عَلَى ابْنِ الزُّبَيْرِ كَلَّمَ الْمِسْوَرَ بْنَ مَخْرَمَةَ وَعَبْدَ الرَّحْمَنِ بْنَ الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ، وَهُمَا مِنْ بَنِي زُهْرَةَ، وَقَالَ لَهُمَا أَنْشُدُكُمَا بِاللَّهِ لَمَّا أَدْخَلْتُمَانِي عَلَى عَائِشَةَ، فَإِنَّهَا لاَ يَحِلُّ لَهَا أَنْ تَنْذُرَ قَطِيعَتِي‏.‏ فَأَقْبَلَ بِهِ الْمِسْوَرُ وَعَبْدُ الرَّحْمَنِ مُشْتَمِلَيْنِ بِأَرْدِيَتِهِمَا حَتَّى اسْتَأْذَنَا عَلَى عَائِشَةَ فَقَالاَ السَّلاَمُ عَلَيْكِ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، أَنَدْخُلُ قَالَتْ عَائِشَةُ ادْخُلُوا‏.‏ قَالُوا كُلُّنَا قَالَتْ نَعَمِ ادْخُلُوا كُلُّكُمْ‏.‏ وَلاَ تَعْلَمُ أَنَّ مَعَهُمَا ابْنَ الزُّبَيْرِ، فَلَمَّا دَخَلُوا دَخَلَ ابْنُ الزُّبَيْرِ الْحِجَابَ، فَاعْتَنَقَ عَائِشَةَ وَطَفِقَ يُنَاشِدُهَا وَيَبْكِي، وَطَفِقَ الْمِسْوَرُ وَعَبْدُ الرَّحْمَنِ يُنَاشِدَانِهَا إِلاَّ مَا كَلَّمَتْهُ وَقَبِلَتْ مِنْهُ، وَيَقُولاَنِ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَمَّا قَدْ عَلِمْتِ مِنَ الْهِجْرَةِ، فَإِنَّهُ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثِ لَيَالٍ‏.‏ فَلَمَّا أَكْثَرُوا عَلَى عَائِشَةَ مِنَ التَّذْكِرَةِ وَالتَّحْرِيجِ طَفِقَتْ تُذَكِّرُهُمَا نَذْرَهَا وَتَبْكِي وَتَقُولُ إِنِّي نَذَرْتُ، وَالنَّذْرُ شَدِيدٌ‏.‏ فَلَمْ يَزَالاَ بِهَا حَتَّى كَلَّمَتِ ابْنَ الزُّبَيْرِ، وَأَعْتَقَتْ فِي نَذْرِهَا ذَلِكَ أَرْبَعِينَ رَقَبَةً‏.‏ وَكَانَتْ تَذْكُرُ نَذْرَهَا بَعْدَ ذَلِكَ فَتَبْكِي، حَتَّى تَبُلَّ دُمُوعُهَا خِمَارَهَا‏.‏\hadithno{6073}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) that she was told that `Abdullah bin Az-Zubair (on hearing that she was selling or giving something as a gift) said, "By Allah, if `Aisha does not give up this, I will declare her incompetent to dispose of her wealth." I said, "Did he (`Abdullah bin Az-Zubair) say so?" They (people) said, "Yes." `Aisha said, "I vow to Allah that I will never speak to Ibn Az-Zubair." When this desertion lasted long, `Abdullah bin Az-Zubair sought intercession with her, but she said, "By Allah, I will not accept the intercession of anyone for him, and will not commit a sin by breaking my vow." When this state of affairs was prolonged on Ibn Az-Zubair (he felt it hard on him), he said to Al- Miswar bin Makhrama and `Abdur-Rahman bin Al-Aswad bin 'Abd Yaghuth, who were from the tribe of Bani Zahra, "I beseech you, by Allah, to let me enter upon `Aisha, for it is unlawful for her to vow to cut the relation with me." So Al-Miswar and `Abdur-Rahman, wrapping their sheets around themselves, asked `Aisha's permission saying, "Peace and Allah's Mercy and Blessings be upon you! Shall we come in?" `Aisha said, "Come in." They said, "All of us?" She said, "Yes, come in all of you," not knowing that Ibn Az-Zubair was also with them. So when they entered, Ibn Az-Zubair entered the screened place and got hold of `Aisha and started requesting her to excuse him, and wept. Al-Miswar and `Abdur Rahman also started requesting her to speak to him and to accept his repentance. They said (to her), "The Prophet (ﷺ) forbade what you know of deserting (not speaking to your Muslim Brethren), for it is unlawful for any Muslim not to talk to his brother for more than three nights (days)." So when they increased their reminding her (of the superiority of having good relation with Kith and kin, and of excusing others' sins), and brought her down to a critical situation, she started reminding them, and wept, saying, "I have made a vow, and (the question of) vow is a difficult one." They (Al-Miswar and `Abdur-Rahman) persisted in their appeal till she spoke with `Abdullah bin Az-Zubair and she manumitted forty slaves as an expiation for her vow. Later on, whenever she remembered her vow, she used to weep so much that her veil used to become wet with her tears}}
\hadithdefcmd{bukhari}{6074}{\hadithno{6074}\hadithtrans{}}
\hadithdefcmd{bukhari}{6089}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، قَالَ مَا حَجَبَنِي النَّبِيُّ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ، وَلاَ رَآنِي إِلاَّ تَبَسَّمَ فِي وَجْهِي‏.‏ وَلَقَدْ شَكَوْتُ إِلَيْهِ أَنِّي لاَ أَثْبُتُ عَلَى الْخَيْلِ، فَضَرَبَ بِيَدِهِ فِي صَدْرِي وَقَالَ ‏ "‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏‏.‏\hadithno{6089}\hadithtrans{Narrated Jarir:The Prophet (ﷺ) did not screen himself from me (had never prevented me from entering upon him) since I embraced Islam, and whenever he saw me, he would receive me with a smile. Once I told him that I could not sit firm on horses. He stroked me on the chest with his hand, and said, "O Allah! Make him firm and make him a guiding and a rightly guided man}}
\hadithdefcmd{bukhari}{6142}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، هُوَ ابْنُ زَيْدٍ ـ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، مَوْلَى الأَنْصَارِ عَنْ رَافِعِ بْنِ خَدِيجٍ، وَسَهْلَ بْنَ أَبِي حَثْمَةَ، أَنَّهُمَا حَدَّثَاهُ أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلٍ وَمُحَيِّصَةَ بْنَ مَسْعُودٍ أَتَيَا خَيْبَرَ فَتَفَرَّقَا فِي النَّخْلِ، فَقُتِلَ عَبْدُ اللَّهِ بْنُ سَهْلٍ، فَجَاءَ عَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ وَحُوَيِّصَةُ وَمُحَيِّصَةُ ابْنَا مَسْعُودٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَتَكَلَّمُوا فِي أَمْرِ صَاحِبِهِمْ فَبَدَأَ عَبْدُ الرَّحْمَنِ، وَكَانَ أَصْغَرَ الْقَوْمِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ كَبِّرِ الْكُبْرَ ‏"‏‏.‏ ـ قَالَ يَحْيَى لِيَلِيَ الْكَلاَمَ الأَكْبَرُ ـ فَتَكَلَّمُوا فِي أَمْرِ صَاحِبِهِمْ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَتَسْتَحِقُّونَ قَتِيلَكُمْ ـ أَوْ قَالَ صَاحِبَكُمْ ـ بِأَيْمَانِ خَمْسِينَ مِنْكُمْ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَمْرٌ لَمْ نَرَهُ‏.‏ قَالَ ‏"‏ فَتُبْرِئُكُمْ يَهُودُ فِي أَيْمَانِ خَمْسِينَ مِنْهُمْ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ قَوْمٌ كُفَّارٌ‏.‏ فَوَدَاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ قِبَلِهِ‏.‏ قَالَ سَهْلٌ فَأَدْرَكْتُ نَاقَةً مِنْ تِلْكَ الإِبِلِ، فَدَخَلَتْ مِرْبَدًا لَهُمْ فَرَكَضَتْنِي بِرِجْلِهَا‏.‏ قَالَ اللَّيْثُ حَدَّثَنِي يَحْيَى، عَنْ بُشَيْرٍ، عَنْ سَهْلٍ، قَالَ يَحْيَى حَسِبْتُ أَنَّهُ قَالَ مَعَ رَافِعِ بْنِ خَدِيجٍ، وَقَالَ ابْنُ عُيَيْنَةَ حَدَّثَنَا يَحْيَى عَنْ بُشَيْرٍ عَنْ سَهْلٍ وَحْدَهُ‏.‏\hadithno{6142}\hadithtrans{Narrated Rafi` bin Khadij and Sahl bin Abu Hathma:`Abdullah bin Sahl and Muhaiyisa bin Mas`ud went to Khaibar and they dispersed in the gardens of the date-palm trees. `Abdullah bin Sahl was murdered. Then `Abdur-Rahman bin Sahl, Huwaiyisa and Muhaiyisa, the two sons of Mas`ud, came to the Prophet (ﷺ) and spoke about the case of their (murdered) friend. `Abdur-Rahman who was the youngest of them all, started talking. The Prophet (ﷺ) said, "Let the older (among you) speak first." So they spoke about the case of their (murdered) friend. The Prophet (ﷺ) said, "Will fifty of you take an oath whereby you will have the right to receive the blood money of your murdered man," (or said, "..your companion"). They said, "O Allah's Messenger (ﷺ)! The murder was a thing we did not witness." The Prophet (ﷺ) said, "Then the Jews will release you from the oath, if fifty of them (the Jews) should take an oath to contradict your claim." They said, "O Allah's Messenger (ﷺ)! They are disbelievers (and they will take a false oath)." Then Allah's Messenger (ﷺ) himself paid the blood money to them}}
\hadithdefcmd{bukhari}{6173}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ انْطَلَقَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ مِنْ أَصْحَابِهِ قِبَلَ ابْنِ صَيَّادٍ، حَتَّى وَجَدَهُ يَلْعَبُ مَعَ الْغِلْمَانِ فِي أُطُمِ بَنِي مَغَالَةَ، وَقَدْ قَارَبَ ابْنُ صَيَّادٍ يَوْمَئِذٍ الْحُلُمَ، فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ظَهْرَهُ بِيَدِهِ ثُمَّ قَالَ ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏‏.‏ فَنَظَرَ إِلَيْهِ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ‏.‏ ثُمَّ قَالَ ابْنُ صَيَّادٍ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَرَضَّهُ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ آمَنْتُ بِاللَّهِ وَرُسُلِهِ ‏"‏‏.‏ ثُمَّ قَالَ لاِبْنِ صَيَّادٍ ‏"‏ مَاذَا تَرَى ‏"‏‏.‏ قَالَ يَأْتِينِي صَادِقٌ وَكَاذِبٌ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي خَبَأْتُ لَكَ خَبِيئًا ‏"‏‏.‏ قَالَ هُوَ الدُّخُّ‏.‏ قَالَ ‏"‏ اخْسَأْ، فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏‏.‏ قَالَ عُمَرُ يَا رَسُولَ اللَّهِ أَتَأْذَنُ لِي فِيهِ أَضْرِبْ عُنُقَهُ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْ هُوَ لاَ تُسَلَّطُ عَلَيْهِ، وَإِنْ لَمْ يَكُنْ هُوَ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏‏.‏ قَالَ سَالِمٌ فَسَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ انْطَلَقَ بَعْدَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ الأَنْصَارِيُّ يَؤُمَّانِ النَّخْلَ الَّتِي فِيهَا ابْنُ صَيَّادٍ، حَتَّى إِذَا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم طَفِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَّقِي بِجُذُوعِ النَّخْلِ، وَهْوَ يَخْتِلُ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ، وَابْنُ صَيَّادٍ مُضْطَجِعٌ عَلَى فِرَاشِهِ فِي قَطِيفَةٍ لَهُ فِيهَا رَمْرَمَةٌ أَوْ زَمْزَمَةٌ، فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ النَّبِيَّ صلى الله عليه وسلم وَهْوَ يَتَّقِي بِجُذُوعِ النَّخْلِ، فَقَالَتْ لاِبْنِ صَيَّادٍ أَىْ صَافِ ـ وَهْوَ اسْمُهُ ـ هَذَا مُحَمَّدٌ‏.‏ فَتَنَاهَى ابْنُ صَيَّادٍ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏‏.‏ قَالَ سَالِمٌ قَالَ عَبْدُ اللَّهِ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏"‏ إِنِّي أُنْذِرُكُمُوهُ، وَمَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَ قَوْمَهُ، لَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ، وَلَكِنِّي سَأَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ، تَعْلَمُونَ أَنَّهُ أَعْوَرُ، وَأَنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ‏"‏‏. قَالَ أَبُو عَبْد اللَّهِ خَسَأْتُ الْكَلْبَ بَعَّدْتُهُ خَاسِئِينَ مُبْعَدِينَ\hadithno{6173}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab set out with Allah's Messenger (ﷺ), and a group of his companions to Ibn Saiyad. They found him playing with the boys in the fort or near the Hillocks of Bani Maghala. Ibn Saiyad was nearing his puberty at that time, and he did not notice the arrival of the Prophet (ﷺ) till Allah's Apostle stroked him on the back with his hand and said, "Do you testify that I am Allah's Messenger (ﷺ)?" Ibn Saiyad looked at him and said, "I testify that you are the Apostle of the unlettered ones (illiterates)". Then Ibn Saiyad said to the Prophets . "Do you testify that I am Allah's Messenger (ﷺ)?" The Prophet denied that, saying, "I believe in Allah and all His Apostles," and then said to Ibn Saiyad, "What do you see?" Ibn Saiyad said, "True people and liars visit me." The Prophet (ﷺ) said, "You have been confused as to this matter." Allah's Messenger (ﷺ) added, "I have kept something for you (in my mind)." Ibn Saiyad said, "Ad-Dukh." The Prophet (ﷺ) said, "Ikhsa (you should be ashamed) for you can not cross your limits." `Umar said, "O Allah's Messenger (ﷺ)! Allow me to chop off h is neck." Allah's Apostle said (to `Umar). "Should this person be him (i.e. Ad-Dajjal) then you cannot over-power him; and should he be someone else, then it will be no use your killing him." `Abdullah bin `Umar added: Later on Allah's Messenger (ﷺ) and Ubai bin Ka`b Al-Ansari (once again) went to the garden in which Ibn Saiyad was present. When Allah's Messenger (ﷺ) entered the garden, he started hiding behind the trunks of the date-palms intending to hear something from Ibn Saiyad before the latter could see him. Ibn Saiyad was Lying on his bed, covered with a velvet sheet from where his mumur were heard. Ibn Saiyad's mother saw the Prophet and said, "O Saf (the nickname of Ibn Saiyad)! Here is Muhammad!" Ibn Saiyad stopped his murmuring. The Prophet (ﷺ) said, "If his mother had kept quiet, then I would have learnt more about him." `Abdullah added: Allah's Messenger (ﷺ) stood up before the people (delivering a sermon), and after praising and glorifying Allah as He deserved, he mentioned the Ad-Dajjal saying, "I warn you against him, and there has been no prophet but warned his followers against him. Noah warned his followers against him but I am telling you about him, something which no prophet has told his people of, and that is: Know that he is blind in one eye where as Allah is not so}}
\hadithdefcmd{bukhari}{6174}{\hadithno{6174}\hadithtrans{}}
\hadithdefcmd{bukhari}{6282}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَهَبَ إِلَى قُبَاءٍ يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ فَتُطْعِمُهُ، وَكَانَتْ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ، فَدَخَلَ يَوْمًا فَأَطْعَمَتْهُ، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ يَضْحَكُ‏.‏ قَالَتْ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ، يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ، مُلُوكًا عَلَى الأَسِرَّةِ ‏"‏‏.‏ ـ أَوْ قَالَ ‏"‏ مِثْلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ شَكَّ إِسْحَاقُ ـ قُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَدَعَا ثُمَّ وَضَعَ رَأْسَهُ فَنَامَ، ثُمَّ اسْتَيْقَظَ يَضْحَكُ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ، يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ، مُلُوكًا عَلَى الأَسِرَّةِ ‏"‏‏.‏ أَوْ ‏"‏ مِثْلَ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ فَقُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏‏.‏ فَرَكِبَتِ الْبَحْرَ زَمَانَ مُعَاوِيَةَ، فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ، فَهَلَكَتْ‏.‏\hadithno{6282}\hadithtrans{Narrated Anas bin Malik:Whenever Allah's Messenger (ﷺ) went to Quba, he used to visit Um Haram bint Milhan who would offer him meals; and she was the wife of 'Ubada bin As-samit. One day he went to her house and she offered him a meal, and after that he slept, and then woke up smiling. She (Um Haram) said, "I asked him, 'What makes you laugh, O Allah's Messenger (ﷺ)?' He said, 'Some people of my followers were displayed before me as warriors fighting for Allah's Cause and sailing over this sea, kings on thrones,' or said, 'like kings on thrones.' (The narrator, 'Is-haq is in doubt about it.) I (Um Haram) said, 'O Allah's Apostle! Invoke Allah that He may make me one of them.' He invoked (Allah) for her and then lay his head and slept again and then woke up smiling. I asked, 'What makes you laugh, O Allah's Messenger (ﷺ)?' He said, 'Some people of my followers were displayed before me as warriors fighting for Allah's Cause and sailing over this sea, kings on the thrones,' or said, 'like kings on the thrones.' I (Um Haram) said, 'O Allah's Messenger (ﷺ)! Invoke Allah that He may make me one of them.' He said, You will be amongst the first ones." It is said that Um Haram sailed over the sea at the time of Muawiya, and on coming out of the sea, she fell down from her riding animal and died}}
\hadithdefcmd{bukhari}{6285}{حَدَّثَنَا مُوسَى، عَنْ أَبِي عَوَانَةَ، حَدَّثَنَا فِرَاسٌ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، حَدَّثَتْنِي عَائِشَةُ أُمُّ الْمُؤْمِنِينَ، قَالَتْ إِنَّا كُنَّا أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم عِنْدَهُ جَمِيعًا، لَمْ تُغَادَرْ مِنَّا وَاحِدَةٌ، فَأَقْبَلَتْ فَاطِمَةُ ـ عَلَيْهَا السَّلاَمُ ـ تَمْشِي، لاَ وَاللَّهِ مَا تَخْفَى مِشْيَتُهَا مِنْ مِشْيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَآهَا رَحَّبَ قَالَ ‏"‏ مَرْحَبًا بِابْنَتِي ‏"‏‏.‏ ثُمَّ أَجْلَسَهَا عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ، ثُمَّ سَارَّهَا فَبَكَتْ بُكَاءً شَدِيدًا، فَلَمَّا رَأَى حُزْنَهَا سَارَّهَا الثَّانِيَةَ إِذَا هِيَ تَضْحَكُ‏.‏ فَقُلْتُ لَهَا أَنَا مِنْ بَيْنِ نِسَائِهِ خَصَّكِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالسِّرِّ مِنْ بَيْنِنَا، ثُمَّ أَنْتِ تَبْكِينَ، فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَأَلْتُهَا عَمَّا سَارَّكِ قَالَتْ مَا كُنْتُ لأُفْشِيَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سِرَّهُ‏.‏ فَلَمَّا تُوُفِّيَ قُلْتُ لَهَا عَزَمْتُ عَلَيْكِ بِمَا لِي عَلَيْكِ مِنَ الْحَقِّ لَمَّا أَخْبَرْتِنِي‏.‏ قَالَتْ أَمَّا الآنَ فَنَعَمْ‏.‏ فَأَخْبَرَتْنِي قَالَتْ أَمَّا حِينَ سَارَّنِي فِي الأَمْرِ الأَوَّلِ، فَإِنَّهُ أَخْبَرَنِي أَنَّ جِبْرِيلَ كَانَ يُعَارِضُهُ بِالْقُرْآنِ كُلَّ سَنَةٍ مَرَّةً ‏"‏ وَإِنَّهُ قَدْ عَارَضَنِي بِهِ الْعَامَ مَرَّتَيْنِ، وَلاَ أَرَى الأَجَلَ إِلاَّ قَدِ اقْتَرَبَ، فَاتَّقِي اللَّهَ وَاصْبِرِي، فَإِنِّي نِعْمَ السَّلَفُ أَنَا لَكَ ‏"‏‏.‏ قَالَتْ فَبَكَيْتُ بُكَائِي الَّذِي رَأَيْتِ، فَلَمَّا رَأَى جَزَعِي سَارَّنِي الثَّانِيَةَ قَالَ ‏"‏ يَا فَاطِمَةُ أَلاَ تَرْضَيْنَ أَنْ تَكُونِي سَيِّدَةَ نِسَاءِ الْمُؤْمِنِينَ ـ أَوْ ـ سَيِّدَةَ نِسَاءِ هَذِهِ الأُمَّةِ ‏"‏‏.‏\hadithno{6285}\hadithtrans{Narrated `Aisha:Mother of the Believers: We, the wives of the Prophet (ﷺ) were all sitting with the Prophet (ﷺ) and none of us had left when Fatima came walking, and by Allah, her gait was very similar to that of Allah's Messenger (ﷺ) .' When he saw her, he welcomed her, saying, "Welcome, O my daughter!" Then he made her sit on his right or his left, confided something to her, whereupon she wept bitterly. When he noticed her sorrow, he confided something else to her for the second time, and she started laughing. Only I from among the Prophet's wives said to her, "(O Fatima), Allah's Messenger (ﷺ) selected you from among us for the secret talk and still you weep?" When Allah's Messenger (ﷺ) got up (and went away), I asked her, "What did he confide to you?" She said, "I wouldn't disclose the secrets of Allah's Messenger (ﷺ)" But when he died I asked her, "I beseech you earnestly by what right I have on you, to tell me (that secret talk which the Prophet had with you)" She said, "As you ask me now, yes, (I will tell you)." She informed me, saying, "When he talked to me secretly the first time, he said that Gabriel used to review the Qur'an with him once every year. He added, 'But this year he reviewed it with me twice, and therefore I think that my time of death has approached. So, be afraid of Allah, and be patient, for I am the best predecessor for you (in the Hereafter).' " Fatima added, "So I wept as you (`Aisha) witnessed. And when the Prophet (ﷺ) saw me in this sorrowful state, he confided the second secret to me saying, 'O Fatima! Will you not be pleased that you will be chief of all the believing women (or chief of the women of this nation i.e. my followers?)}}
\hadithdefcmd{bukhari}{6378}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ أُمِّ سُلَيْمٍ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ أَنَسٌ خَادِمُكَ ادْعُ اللَّهَ لَهُ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ، وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏‏.‏ وَعَنْ هِشَامِ بْنِ زَيْدٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، مِثْلَهُ\hadithno{6378}\hadithtrans{Narrated Um Sulaim:that she said, "O Allah's Messenger (ﷺ)! Anas is your servant, so please invoke for Allah's blessing for him." The Prophet (ﷺ) said, "O Allah! Increase his wealth and offspring and bless (for him) whatever You give him}}
\hadithdefcmd{bukhari}{6380}{حَدَّثَنَا أَبُو زَيْدٍ، سَعِيدُ بْنُ الرَّبِيعِ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ قَالَ قَالَتْ أُمُّ سُلَيْمٍ أَنَسٌ خَادِمُكَ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ، وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏‏.‏\hadithno{6380}\hadithtrans{Narrated Anas:Um Sulaim said (to the Prophet), "Anas is your servant; so please invoke for Allah's blessings for him." He said "O Allah! Increase his wealth and offspring, and Bless (for him) whatever You give him}}
\hadithdefcmd{bukhari}{6567}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ أُمَّ حَارِثَةَ، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَدْ هَلَكَ حَارِثَةُ يَوْمَ بَدْرٍ، أَصَابَهُ غَرْبُ سَهْمٍ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ قَدْ عَلِمْتَ مَوْقِعَ حَارِثَةَ مِنْ قَلْبِي، فَإِنْ كَانَ فِي الْجَنَّةِ لَمْ أَبْكِ عَلَيْهِ، وَإِلاَّ سَوْفَ تَرَى مَا أَصْنَعُ‏.‏ فَقَالَ لَهَا ‏ "‏ هَبِلْتِ، أَجَنَّةٌ وَاحِدَةٌ هِيَ إِنَّهَا جِنَانٌ كَثِيرَةٌ، وَإِنَّهُ فِي الْفِرْدَوْسِ الأَعْلَى ‏"‏‏.‏ (وَقَالَ ‏:‏غَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا، وَلَقَابُ قَوْسِ أَحَدِكُمْ أَوْ مَوْضِعُ قَدَمٍ مِنَ الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا، وَلَوْ أَنَّ امْرَأَةً مِنْ نِسَاءِ أَهْلِ الْجَنَّةِ اطَّلَعَتْ إِلَى الأَرْضِ، لأَضَاءَتْ مَا بَيْنَهُمَا، وَلَمَلأَتْ مَا بَيْنَهُمَا رِيحًا، وَلَنَصِيفُهَا ـ يَعْنِي الْخِمَارَ ـ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا‏)‏‏.‏\hadithno{6567}\hadithtrans{Narrated Anas:Um (the mother of) Haritha came to Allah's Messenger (ﷺ) after Haritha had been martyred on the Day (of the battle) of Badr by an arrow thrown by an unknown person. She said, "O Allah's Messenger (ﷺ)! You know the position of Haritha in my heart (i.e. how dear to me he was), so if he is in Paradise, I will not weep for him, or otherwise, you will see what I will do." The Prophet (ﷺ) said, "Are you mad? Is there only one Paradise? There are many Paradises, and he is in the highest Paradise of Firdaus." The Prophet added, "A forenoon journey or an after noon journey in Allah's Cause is better than the whole world and whatever is in it; and a place equal to an arrow bow of anyone of you, or a place equal to a foot in Paradise is better than the whole world and whatever is in it; and if one of the women of Paradise looked at the earth, she would fill the whole space between them (the earth and the heaven) with light, and would fill whatever is in between them, with perfume, and the veil of her face is better than the whole world and whatever is in it}}
\hadithdefcmd{bukhari}{6599}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُولَدُ عَلَى الْفِطْرَةِ، فَأَبَوَاهُ يُهَوِّدَانِهِ وَيُنَصِّرَانِهِ، كَمَا تُنْتِجُونَ الْبَهِيمَةَ، هَلْ تَجِدُونَ فِيهَا مِنْ جَدْعَاءَ حَتَّى تَكُونُوا أَنْتُمْ تَجْدَعُونَهَا ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَفَرَأَيْتَ مَنْ يَمُوتُ وَهْوَ صَغِيرٌ قَالَ ‏\{‏اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ‏\}‏\hadithno{6599}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No child is born but has the Islamic Faith, but its parents turn it into a Jew or a Christian. It is as you help the animals give birth. Do you find among their offspring a mutilated one before you mutilate them yourself?" The people said, "O Allah's Messenger (ﷺ)! What do you think about those (of them) who die young?" The Prophet (ﷺ) said, "Allah knows what they would have done (were they to live)}}
\hadithdefcmd{bukhari}{6633}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ وَقَالَ الآخَرُ وَهْوَ أَفْقَهُهُمَا أَجَلْ يَا رَسُولَ اللَّهِ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَائْذَنْ لِي أَنْ أَتَكَلَّمَ‏.‏ قَالَ ‏"‏ تَكَلَّمْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا ـ قَالَ مَالِكٌ وَالْعَسِيفُ الأَجِيرُ ـ زَنَى بِامْرَأَتِهِ، فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَجَارِيَةٍ لِي، ثُمَّ إِنِّي سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّ مَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَإِنَّمَا الرَّجْمُ عَلَى امْرَأَتِهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا غَنَمُكَ وَجَارِيَتُكَ فَرَدٌّ عَلَيْكَ ‏"‏‏.‏ وَجَلَدَ ابْنَهُ مِائَةً وَغَرَّبَهُ عَامًا، وَأُمِرَ أُنَيْسٌ الأَسْلَمِيُّ أَنْ يَأْتِيَ امْرَأَةَ الآخَرِ، فَإِنِ اعْتَرَفَتْ رَجَمَهَا، فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏\hadithno{6633}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Two men had a dispute in the presence of Allah's Messenger (ﷺ). One of them said, "O Allah's Messenger (ﷺ)! Judge between us according to Allah's Laws." The other who was wiser, said, "Yes, O Allah's Apostle! Judge between us according to Allah's Laws and allow me to speak. The Prophet (ﷺ) said, "Speak." He said, "My son was a laborer serving this (person) and he committed illegal sexual intercourse with his wife, The people said that my son is to be stoned to death, but I ransomed him with one-hundred sheep and a slave girl. Then I asked the learned people, who informed me that my son should receive one hundred lashes and will be exiled for one year, and stoning will be the lot for the man's wife." Allah's Messenger (ﷺ) said, "Indeed, by Him in Whose Hand my soul is, I will judge between you according to Allah's Laws: As for your sheep and slave girl, they are to be returned to you." Then he scourged his son one hundred lashes and exiled him for one year. Then Unais Al- Aslami was ordered to go to the wife of the second man, and if she confessed (the crime), then stone her to death. She did confess, so he stoned her to death}}
\hadithdefcmd{bukhari}{6659}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، وَمَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ كَاذِبَةٍ، لِيَقْتَطِعَ بِهَا مَالَ رَجُلٍ مُسْلِمٍ أَوْ قَالَ أَخِيهِ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَهُ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ‏\}‏ قَالَ سُلَيْمَانُ فِي حَدِيثِهِ فَمَرَّ الأَشْعَثُ بْنُ قَيْسٍ فَقَالَ مَا يُحَدِّثُكُمْ عَبْدُ اللَّهِ قَالُوا لَهُ فَقَالَ الأَشْعَثُ نَزَلَتْ فِيَّ، وَفِي صَاحِبٍ لِي، فِي بِئْرٍ كَانَتْ بَيْنَنَا‏.‏\hadithno{6659}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Whoever swears falsely in order to grab the property of a Muslim (or of his brother), Allah will be angry with him when he meets Him." Allah then revealed in confirmation of the above statement:--'Verily those who purchase a small gain at the cost of Allah's Covenant and their own oaths.' (3.77) Al-Ash'ath said, "This Verse was revealed regarding me and a companion of mine when we had a dispute about a well}}
\hadithdefcmd{bukhari}{6676}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينِ صَبْرٍ، يَقْتَطِعُ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏ فَدَخَلَ الأَشْعَثُ بْنُ قَيْسٍ فَقَالَ مَا حَدَّثَكُمْ أَبُو عَبْدِ الرَّحْمَنِ، فَقَالُوا كَذَا وَكَذَا‏.‏ قَالَ فِيَّ أُنْزِلَتْ، كَانَتْ لِي بِئْرٌ فِي أَرْضِ ابْنِ عَمٍّ لِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ بَيِّنَتُكَ أَوْ يَمِينُهُ ‏"‏‏.‏ قُلْتُ إِذًا يَحْلِفُ عَلَيْهَا يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينِ صَبْرٍ، وَهْوَ فِيهَا فَاجِرٌ، يَقْتَطِعُ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ يَوْمَ الْقِيَامَةِ، وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏\hadithno{6676}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "If somebody is ordered (by the ruler or the judge) to take an oath, and he takes a false oath in order to grab the property of a Muslim, then he will incur Allah's Wrath when he will meet Him." And Allah revealed in its confirmation: 'Verily! Those who purchase a small gain at the cost of Allah's covenants and their own oaths.' (3.77) (The sub-narrator added:) Al-Ash'ath bin Qais entered, saying, "What did Abu `Abdur-Rahman narrate to you?" They said, "So-and-so," Al-Ash'ath said, "This verse was revealed in my connection. I had a well on the land of my cousin (and we had a dispute about it). I reported him to Allah's Apostle who said (to me). "You should give evidence (i.e. witness) otherwise the oath of your opponent will render your claim invalid." I said, "Then he (my opponent) will take the oath, O Allah's Messenger (ﷺ)." Allah's Messenger (ﷺ) said, "Whoever is ordered (by the ruler or the judge) to give an oath, and he takes a false oath in order to grab the property of a Muslim, then he will incur Allah's Wrath when he meets Him on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6725}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ، وَالْعَبَّاسَ ـ عَلَيْهِمَا السَّلاَمُ ـ أَتَيَا أَبَا بَكْرٍ يَلْتَمِسَانِ مِيرَاثَهُمَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُمَا حِينَئِذٍ يَطْلُبَانِ أَرْضَيْهِمَا مِنْ فَدَكَ، وَسَهْمَهُمَا مِنْ خَيْبَرَ‏.‏ فَقَالَ لَهُمَا أَبُو بَكْرٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ نُورَثُ، مَا تَرَكْنَا صَدَقَةٌ، إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ مِنْ هَذَا الْمَالِ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ وَاللَّهِ لاَ أَدَعُ أَمْرًا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُهُ فِيهِ إِلاَّ صَنَعْتُهُ‏.‏ قَالَ فَهَجَرَتْهُ فَاطِمَةُ، فَلَمْ تُكَلِّمْهُ حَتَّى مَاتَتْ‏.‏\hadithno{6725}\hadithtrans{Narrated `Aisha:Fatima and Al `Abbas came to Abu Bakr, seeking their share from the property of Allah's Messenger (ﷺ) and at that time, they were asking for their land at Fadak and their share from Khaibar. Abu Bakr said to them, " I have heard from Allah's Messenger (ﷺ) saying, 'Our property cannot be inherited, and whatever we leave is to be spent in charity, but the family of Muhammad may take their provisions from this property." Abu Bakr added, "By Allah, I will not leave the procedure I saw Allah's Messenger (ﷺ) following during his lifetime concerning this property." Therefore Fatima left Abu Bakr and did not speak to him till she died}}
\hadithdefcmd{bukhari}{6766}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ ـ هُوَ ابْنُ عَبْدِ اللَّهِ ـ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي عُثْمَانَ، عَنْ سَعْدٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ، وَهْوَ يَعْلَمُ أَنَّهُ غَيْرُ أَبِيهِ، فَالْجَنَّةُ عَلَيْهِ حَرَامٌ ‏"‏‏.‏ فَذَكَرْتُهُ لأَبِي بَكْرَةَ فَقَالَ وَأَنَا سَمِعَتْهُ أُذُنَاىَ، وَوَعَاهُ، قَلْبِي مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{6766}\hadithtrans{Narrated Sa`d:I heard the Prophet (ﷺ) saying, "Whoever claims to be the son of a person other than his father, and he knows that person is not his father, then Paradise will be forbidden for him." I mentioned that to Abu Bakra, and he said, "My ears heard that and my heart memorized it from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{6815}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي الْمَسْجِدِ فَنَادَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ‏.‏ فَأَعْرَضَ عَنْهُ، حَتَّى رَدَّدَ عَلَيْهِ أَرْبَعَ مَرَّاتٍ، فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ، دَعَاهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ أَحْصَنْتَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اذْهَبُوا بِهِ فَارْجُمُوهُ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي مَنْ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ فَكُنْتُ فِيمَنْ رَجَمَهُ فَرَجَمْنَاهُ بِالْمُصَلَّى، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ هَرَبَ، فَأَدْرَكْنَاهُ بِالْحَرَّةِ فَرَجَمْنَاهُ‏.‏\hadithno{6815}\hadithtrans{Narrated Abu Huraira:A man came to Allah's Messenger (ﷺ) while he was in the mosque, and he called him, saying, "O Allah's Apostle! I have committed illegal sexual intercourse.'" The Prophet (ﷺ) turned his face to the other side, but that man repeated his statement four times, and after he bore witness against himself four times, the Prophet (ﷺ) called him, saying, "Are you mad?" The man said, "No." The Prophet (ﷺ) said, "Are you married?" The man said, "Yes." Then the Prophet (ﷺ) said, 'Take him away and stone him to death." Jabir bin `Abdullah said: I was among the ones who participated in stoning him and we stoned him at the Musalla. When the stones troubled him, he fled, but we over took him at Al-Harra and stoned him to death}}
\hadithdefcmd{bukhari}{6826}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ أَنَّ أَبَا هُرَيْرَةَ، قَالَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلٌ مِنَ النَّاسِ وَهْوَ فِي الْمَسْجِدِ فَنَادَاهُ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ‏.‏ يُرِيدُ نَفْسَهُ، فَأَعْرَضَ عَنْهُ النَّبِيُّ صلى الله عليه وسلم فَتَنَحَّى لِشِقِّ وَجْهِهِ الَّذِي أَعْرَضَ قِبَلَهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ‏.‏ فَأَعْرَضَ عَنْهُ، فَجَاءَ لِشِقِّ وَجْهِ النَّبِيِّ صلى الله عليه وسلم الَّذِي أَعْرَضَ عَنْهُ، فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ دَعَاهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ أَحْصَنْتَ ‏"‏‏.‏ قَالَ نَعَمْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ اذْهَبُوا فَارْجُمُوهُ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي مَنْ، سَمِعَ جَابِرًا، قَالَ فَكُنْتُ فِيمَنْ رَجَمَهُ، فَرَجَمْنَاهُ بِالْمُصَلَّى، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ جَمَزَ حَتَّى أَدْرَكْنَاهُ بِالْحَرَّةِ فَرَجَمْنَاهُ‏.‏\hadithno{6826}\hadithtrans{Narrated Abu Huraira:A man from among the people, came to Allah's Messenger (ﷺ) while Allah's Messenger (ﷺ) was sitting in the mosque, and addressed him, saying, "O Allah's Messenger (ﷺ)! I have committed an illegal sexual intercourse." The Prophet (ﷺ) turned his face away from him. The man came to that side to which the Prophet had turned his face, and said, "O Allah's Messenger (ﷺ)! I have committed an illegal intercourse." The Prophet (ﷺ) turned his face to the other side, and the man came to that side, and when he confessed four times, the Prophet (ﷺ) called him and said, "Are you mad?" He said, "No, O Allah's Messenger (ﷺ)!" The Prophet said, "Are you married?" He said, "Yes, O Allah's Messenger (ﷺ)." The Prophet (ﷺ) said (to the people), "Take him away and stone him to death." Ibn Shihab added, "I was told by one who heard Jabir, that Jabir said, 'I was among those who stoned the man, and we stoned him at the Musalla (`Id praying Place), and when the stones troubled him, he jumped quickly and ran away, but we overtook him at Al-Harra and stoned him to death (there)}}
\hadithdefcmd{bukhari}{6827}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنْ فِي الزُّهْرِيِّ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ وَزَيْدَ بْنَ خَالِدٍ قَالاَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَامَ رَجُلٌ فَقَالَ أَنْشُدُكَ اللَّهَ إِلاَّ قَضَيْتَ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ ـ وَكَانَ أَفْقَهَ مِنْهُ ـ فَقَالَ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ وَأْذَنْ لِي‏.‏ قَالَ ‏"‏ قُلْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا، فَزَنَى بِامْرَأَتِهِ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَخَادِمٍ، ثُمَّ سَأَلْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ، فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ، وَعَلَى امْرَأَتِهِ الرَّجْمَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ جَلَّ ذِكْرُهُ، الْمِائَةُ شَاةٍ وَالْخَادِمُ رَدٌّ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَاغْدُ يَا أُنَيْسُ عَلَى امْرَأَةِ هَذَا، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا عَلَيْهَا فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏ قُلْتُ لِسُفْيَانَ لَمْ يَقُلْ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ‏.‏ فَقَالَ أَشُكُّ فِيهَا مِنَ الزُّهْرِيِّ، فَرُبَّمَا قُلْتُهَا وَرُبَّمَا سَكَتُّ‏.‏\hadithno{6827}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:While we were with the Prophet (ﷺ) , a man stood up and said (to the Prophet (ﷺ) ), "I beseech you by Allah, that you should judge us according to Allah's Laws." Then the man's opponent who was wiser than him, got up saying (to Allah's Messenger (ﷺ)) "Judge us according to Allah's Law and kindly allow me (to speak)." The Prophet (ﷺ) said, "'Speak." He said, "My son was a laborer working for this man and he committed an illegal sexual intercourse with his wife, and I gave one-hundred sheep and a slave as a ransom for my son's sin. Then I asked a learned man about this case and he informed me that my son should receive one hundred lashes and be exiled for one year, and the man's wife should be stoned to death." The Prophet (ﷺ) said, "By Him in Whose Hand my soul is, I will judge you according to the Laws of Allah. Your one-hundred sheep and the slave are to be returned to you, and your son has to receive one-hundred lashes and be exiled for one year. O Unais! Go to the wife of this man, and if she confesses, then stone her to death." Unais went to her and she confessed. He then stoned her to death}}
\hadithdefcmd{bukhari}{6831}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَأْمُرُ فِيمَنْ زَنَى وَلَمْ يُحْصَنْ جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ‏.‏ قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عُرْوَةَ بْنُ الزُّبَيْرِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، غَرَّبَ، ثُمَّ لَمْ تَزَلْ تِلْكَ السُّنَّةَ‏.‏\hadithno{6831}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:I heard the Prophet (ﷺ) ordering that an unmarried person guilty of illegal sexual intercourse be flogged one-hundred stripes and be exiled for one year. `Umar bin Al-Khattab also exiled such a person, and this tradition is still valid}}
\hadithdefcmd{bukhari}{6835}{حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، أَنَّ رَجُلاً، مِنَ الأَعْرَابِ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ جَالِسٌ فَقَالَ يَا رَسُولَ اللَّهِ اقْضِ بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ فَقَالَ صَدَقَ اقْضِ لَهُ يَا رَسُولَ اللَّهِ بِكِتَابِ اللَّهِ، إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَى بِامْرَأَتِهِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ بِمِائَةٍ مِنَ الْغَنَمِ وَوَلِيدَةٍ، ثُمَّ سَأَلْتُ أَهْلَ الْعِلْمِ، فَزَعَمُوا أَنَّ مَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ‏.‏ فَقَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا الْغَنَمُ وَالْوَلِيدَةُ فَرَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَأَمَّا أَنْتَ يَا أُنَيْسُ فَاغْدُ عَلَى امْرَأَةِ هَذَا فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا أُنَيْسٌ فَرَجَمَهَا‏.‏\hadithno{6835}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:A bedouin came to the Prophet (ﷺ) while he (the Prophet) was sitting, and said, "O Allah's Messenger (ﷺ)! Give your verdict according to Allah's Laws (in our case)." Then his opponent got up and said, "He has told the truth, O Allah's Messenger (ﷺ)! Decide his case according to Allah's Laws. My son was a laborer working for this person, and he committed illegal sexual intercourse with his wife, and the people told me that my son should be stoned to death, but I offered one-hundred sheep and a slave girl as a ransom for him. Then I asked the religious learned people, and they told me that my son should be flogged with one-hundred stripes and be exiled for one year." The Prophet (ﷺ) said, "By Him in Whose Hand my soul is, I will judge you according to Allah's Laws. The sheep and the slave girl will be returned to you and your son will be flogged one-hundred stripes and be exiled for one year. And you, O Unais! Go to the wife of this man (and if she confesses), stone her to death." So Unais went in the morning and stoned her to death (after she had confessed)}}
\hadithdefcmd{bukhari}{6837}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ إِذَا زَنَتْ وَلَمْ تُحْصَنْ قَالَ ‏ "‏ إِذَا زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ بِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ لاَ أَدْرِي بَعْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ‏.‏\hadithno{6837}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:The verdict of Allah's Messenger (ﷺ) was sought about an unmarried slave girl guilty of illegal intercourse. He replied, "If she commits illegal sexual intercourse, then flog her (fifty stripes), and if she commits illegal sexual intercourse (after that for the second time), then flog her (fifty stripes), and if she commits illegal sexual intercourse (for the third time), then flog her (fifty stripes) and sell her for even a hair rope." Ibn Shihab said, "I am not sure whether the Prophet (ﷺ) ordered that she be sold after the third or fourth time of committing illegal intercourse}}
\hadithdefcmd{bukhari}{6842}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ وَقَالَ الآخَرُ وَهْوَ أَفْقَهُهُمَا أَجَلْ يَا رَسُولَ اللَّهِ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَأْذَنْ لِي أَنْ أَتَكَلَّمَ‏.‏ قَالَ ‏"‏ تَكَلَّمْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا ـ قَالَ مَالِكٌ وَالْعَسِيفُ الأَجِيرُ ـ فَزَنَى بِامْرَأَتِهِ، فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَبِجَارِيَةٍ لِي، ثُمَّ إِنِّي سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّ مَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَإِنَّمَا الرَّجْمُ عَلَى امْرَأَتِهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا غَنَمُكَ وَجَارِيَتُكَ فَرَدٌّ عَلَيْكَ ‏"‏‏.‏ وَجَلَدَ ابْنَهُ مِائَةً وَغَرَّبَهُ عَامًا، وَأَمَرَ أُنَيْسًا الأَسْلَمِيَّ أَنْ يَأْتِيَ امْرَأَةَ الآخَرِ، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا، فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏\hadithno{6842}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Two men had a dispute in the presence of Allah's Messenger (ﷺ). One of them said, "Judge us according to Allah's Laws." The other who was more wise said, "Yes, Allah's Messenger (ﷺ), judge us according to Allah's Laws and allow me to speak (first)" The Prophet (ﷺ) said to him, 'Speak " He said, "My son was a laborer for this man, and he committed illegal sexual intercourse with his wife, and the people told me that my son should be stoned to death, but I have given one-hundred sheep and a slave girl as a ransom (expiation) for my son's sin. Then I asked the religious learned people (about It), and they told me that my son should he flogged one-hundred stripes and should be exiled for one year, and only the wife of this man should be stoned to death " Allah's Messenger (ﷺ) said, "By Him in Whose Hand my soul is, I will judge you according to Allah's Laws: O man, as for your sheep and slave girl, they are to be returned to you." Then the Prophet (ﷺ) had the man's son flogged one hundred stripes and exiled for one year, and ordered Unais Al-Aslami to go to the wife of the other man, and if she confessed, stone her to death. She confessed and was stoned to death}}
\hadithdefcmd{bukhari}{6859}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالاَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَنْشُدُكَ اللَّهَ إِلاَّ قَضَيْتَ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ وَكَانَ أَفْقَهَ مِنْهُ فَقَالَ صَدَقَ، اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَأْذَنْ لِي يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قُلْ ‏"‏‏.‏ فَقَالَ إِنَّ ابْنِي كَانَ عَسِيفًا فِي أَهْلِ، هَذَا فَزَنَى بِامْرَأَتِهِ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَخَادِمٍ وَإِنِّي سَأَلْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ، وَأَنَّ عَلَى امْرَأَةِ هَذَا الرَّجْمَ‏.‏ فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، الْمِائَةُ وَالْخَادِمُ رَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَيَا أُنَيْسُ اغْدُ عَلَى امْرَأَةِ هَذَا فَسَلْهَا، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏ فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏\hadithno{6859}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A man came to the Prophet (ﷺ) and said, "I beseech you to judge us according to Allah's Laws." Then his opponent who was wiser than he, got up and said, "He has spoken the truth. So judge us according to Allah's Laws and please allow me (to speak), O Allah's Messenger (ﷺ)." The Prophet (ﷺ) said, "Speak." He said, "My son was a laborer for the family of this man and he committed illegal sexual intercourse with his wife, and I gave one-hundred sheep and a slave as a ransom (for my son), but I asked the religious learned people (regarding this case), and they informed me that my son should be flogged onehundred stripes, and be exiled for one year, and the wife of this man should be stoned (to death)."The Prophet (ﷺ) said, "By Him in Whose Hand my soul is, I will Judge you (in this case) according to Allah's Laws. The one-hundred (sheep) and the slave shall be returned to you and your son shall be flogged one-hundred stripes and be exiled for one year. And O Unais! Go in the morning to the wife of this man and ask her, and if she confesses, stone her to death." She confessed and he stoned her to death}}
\hadithdefcmd{bukhari}{6865}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا عَطَاءُ بْنُ يَزِيدَ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَدِيٍّ، حَدَّثَهُ أَنَّ الْمِقْدَادَ بْنَ عَمْرٍو الْكِنْدِيَّ حَلِيفَ بَنِي زُهْرَةَ حَدَّثَهُ وَكَانَ، شَهِدَ بَدْرًا مَعَ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنْ لَقِيتُ كَافِرًا فَاقْتَتَلْنَا، فَضَرَبَ يَدِي بِالسَّيْفِ فَقَطَعَهَا، ثُمَّ لاَذَ بِشَجَرَةٍ وَقَالَ أَسْلَمْتُ لِلَّهِ‏.‏ آقْتُلُهُ بَعْدَ أَنْ قَالَهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقْتُلْهُ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَإِنَّهُ طَرَحَ إِحْدَى يَدَىَّ، ثُمَّ قَالَ بَعْدَ مَا قَطَعَهَا، آقْتُلُهُ قَالَ ‏"‏ لاَ تَقْتُلْهُ، فَإِنْ قَتَلْتَهُ فَإِنَّهُ بِمَنْزِلَتِكَ قَبْلَ أَنْ تَقْتُلَهُ، وَأَنْتَ بِمَنْزِلَتِهِ قَبْلَ أَنْ يَقُولَ كَلِمَتَهُ الَّتِي قَالَ ‏"‏‏.‏ وَقَالَ حَبِيبُ بْنُ أَبِي عَمْرَةَ عَنْ سَعِيدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لِلْمِقْدَادِ ‏"‏ إِذَا كَانَ رَجُلٌ مُؤْمِنٌ يُخْفِي إِيمَانَهُ مَعَ قَوْمٍ كُفَّارٍ، فَأَظْهَرَ إِيمَانَهُ، فَقَتَلْتَهُ، فَكَذَلِكَ كُنْتَ أَنْتَ تُخْفِي إِيمَانَكَ بِمَكَّةَ مِنْ قَبْلُ ‏"‏‏.‏\hadithno{6865}\hadithtrans{Narrated Al-Miqdad bin `Amr Al-Kindi:An ally of Bani Zuhra who took part in the battle of Badr with the Prophet, that he said, "O Allah's Apostle! If I meet an unbeliever and we have a fight, and he strikes my hand with the sword and cuts it off, and then takes refuge from me under a tree, and says, 'I have surrendered to Allah (i.e. embraced Islam),' may I kill him after he has said so?" Allah's Messenger (ﷺ) said, "Do not kill him." Al- Miqdad said, "But O Allah's Messenger (ﷺ)! He had chopped off one of my hands and he said that after he had cut it off. May I kill him?" The Prophet (ﷺ) said. "Do not kill him for if you kill him, he would be in the position in which you had been before you kill him, and you would be in the position in which he was before he said the sentence." The Prophet (ﷺ) also said to Al-Miqdad, "If a faithful believer conceals his faith (Islam) from the disbelievers, and then when he declares his Islam, you kill him, (you will be sinful). Remember that you were also concealing your faith (Islam) at Mecca before}}
\hadithdefcmd{bukhari}{6887}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ وَبِإِسْنَادِهِ ‏"‏ لَوِ اطَّلَعَ فِي بَيْتِكَ أَحَدٌ وَلَمْ تَأْذَنْ لَهُ، خَذَفْتَهُ بِحَصَاةٍ فَفَقَأْتَ عَيْنَهُ، مَا كَانَ عَلَيْكَ مِنْ جُنَاحٍ ‏"‏‏.‏\hadithno{6887}\hadithtrans{Narrated Abu Huraira:That he heard Allah's Messenger (ﷺ) saying, "We (Muslims) are the last (to come) but (will be) the foremost (on the Day of Resurrection)." And added, "If someone is peeping (looking secretly) into your house without your permission, and you throw a stone at him and destroy his eyes, there will be no blame on you}}
\hadithdefcmd{bukhari}{6905}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ عُمَرَ ـ رضى الله عنه ـ أَنَّهُ اسْتَشَارَهُمْ فِي إِمْلاَصِ الْمَرْأَةِ فَقَالَ الْمُغِيرَةُ قَضَى النَّبِيُّ صلى الله عليه وسلم بِالْغُرَّةِ عَبْدٍ أَوْ أَمَةٍ‏.‏ فَقَالَ ائْتِ مَنْ يَشْهَدُ مَعَكَ، فَشَهِدَ مُحَمَّدُ بْنُ مَسْلَمَةَ أَنَّهُ شَهِدَ النَّبِيَّ صلى الله عليه وسلم قَضَى بِهِ‏.‏\hadithno{6905}\hadithtrans{Narrated Hisham's father from Al-Mughira bin Shu'ba: 'Umar consulted the companions about the case of a woman's abortion (caused by somebody else). Al-Mughira said: The Prophet (ﷺ) gave the verdict that a male or female slave should be given (as a Diya). Then Muhammad bin Maslama testified that he had witnessed the Prophet (ﷺ) giving such a verdict}}
\hadithdefcmd{bukhari}{6907}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنْ عُمَرَ، نَشَدَ النَّاسَ مَنْ سَمِعَ النَّبِيَّ صلى الله عليه وسلم قَضَى فِي السِّقْطِ وَقَالَ الْمُغِيرَةُ أَنَا سَمِعْتُهُ قَضَى فِيهِ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ‏.‏ قَالَ ائْتِ مَنْ يَشْهَدُ مَعَكَ عَلَى هَذَا فَقَالَ مُحَمَّدُ بْنُ مَسْلَمَةَ أَنَا أَشْهَدُ عَلَى النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ هَذَا‏.‏\hadithno{6907}\hadithtrans{Narrated Hisham's father: 'Umar asked the people, "Who heard the Prophet (ﷺ) giving his verdict regarding abortions?" Al-Mughira said, "I heard him judging that a male or female slave should be given (as a Diya)." 'Umar said, "Present a witness to testify your statement." Muhammad bin Maslama said, "I testify that the Prophet (ﷺ) gave such a judgment}}
\hadithdefcmd{bukhari}{6924}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ، وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ، قَالَ عُمَرُ يَا أَبَا بَكْرٍ، كَيْفَ تُقَاتِلُ النَّاسَ، وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ، إِلاَّ بِحَقِّهِ، وَحِسَابُهُ عَلَى اللَّهِ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ، فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ، وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ أَنْ قَدْ شَرَحَ اللَّهُ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏\hadithno{6924}\hadithtrans{Narrated Abu Huraira:When the Prophet (ﷺ) died and Abu Bakr became his successor and some of the Arabs reverted to disbelief, `Umar said, "O Abu Bakr! How can you fight these people although Allah's Messenger (ﷺ) said, 'I have been ordered to fight the people till they say: 'None has the right to be worshipped but Allah, 'and whoever said, 'None has the right to be worshipped but Allah', Allah will save his property and his life from me, unless (he does something for which he receives legal punishment) justly, and his account will be with Allah?' "Abu Bakr said, "By Allah! I will fight whoever differentiates between prayers and Zakat as Zakat is the right to be taken from property (according to Allah's Orders). By Allah! If they refused to pay me even a kid they used to pay to Allah's Messenger (ﷺ), I would fight with them for withholding it." `Umar said, "By Allah: It was nothing, but I noticed that Allah opened Abu Bakr's chest towards the decision to fight, therefore I realized that his decision was right}}
\hadithdefcmd{bukhari}{6957}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَكُونُ كَنْزُ أَحَدِكُمْ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ، يَفِرُّ مِنْهُ صَاحِبُهُ فَيَطْلُبُهُ وَيَقُولُ أَنَا كَنْزُكَ‏.‏ قَالَ وَاللَّهِ لَنْ يَزَالَ يَطْلُبُهُ حَتَّى يَبْسُطَ يَدَهُ فَيُلْقِمَهَا فَاهُ ‏"‏‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا مَا رَبُّ النَّعَمِ لَمْ يُعْطِ حَقَّهَا، تُسَلَّطُ عَلَيْهِ يَوْمَ الْقِيَامَةِ، تَخْبِطُ وَجْهَهُ بِأَخْفَافِهَا ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ فِي رَجُلٍ لَهُ إِبِلٌ، فَخَافَ أَنْ تَجِبَ عَلَيْهِ الصَّدَقَةُ، فَبَاعَهَا بِإِبِلٍ مِثْلِهَا، أَوْ بِغَنَمٍ، أَوْ بِبَقَرٍ، أَوْ بِدَرَاهِمَ، فِرَارًا مِنَ الصَّدَقَةِ بِيَوْمٍ، احْتِيَالاً فَلاَ بَأْسَ عَلَيْهِ، وَهْوَ يَقُولُ إِنْ زَكَّى إِبِلَهُ قَبْلَ أَنْ يَحُولَ الْحَوْلُ بِيَوْمٍ أَوْ بِسَنَةٍ، جَازَتْ عَنْهُ‏.‏\hadithno{6957}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "On the Day of Resurrection the Kanz (Treasure or wealth of which, Zakat has not been paid) of anyone of you will appear in the shape of a huge bald headed poisonous male snake and its owner will run away from it, but it will follow him and say, 'I am your Kanz.'" The Prophet (ﷺ) added, "By Allah, that snake will keep on following him until he stretches out his hand and let the snake swallow it." Allah's Messenger (ﷺ) added, "If the owner of camels does not pay their Zakat, then, on the Day of Resurrection those camels will come to him and will strike his face with their hooves." Some people said: Concerning a man who has camels, and is afraid that Zakat will be due so he sells those camels for similar camels or for sheep or cows or money one day before Zakat becomes due in order to avoid payment of their Zakat cunningly! "He has not to pay anything." The same scholar said, "If one pays Zakat of his camels one day or one year prior to the end of the year (by the end of which Zakat becomes due), his Zakat will be valid}}
\hadithdefcmd{bukhari}{7001}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، وَكَانَتْ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ، فَدَخَلَ عَلَيْهَا يَوْمًا فَأَطْعَمَتْهُ، وَجَعَلَتْ تَفْلِي رَأْسَهُ، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ وَهْوَ يَضْحَكُ‏.‏ قَالَتْ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ، يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ، مُلُوكًا عَلَى الأَسِرَّةِ أَوْ مِثْلَ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ شَكَّ إِسْحَاقُ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ، فَدَعَا لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ وَضَعَ رَأْسَهُ ثُمَّ اسْتَيْقَظَ وَهْوَ يَضْحَكُ‏.‏ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ كَمَا قَالَ فِي الأُولَى‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏‏.‏ فَرَكِبَتِ الْبَحْرَ فِي زَمَانِ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ، فَهَلَكَتْ‏.‏\hadithno{7001}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) used to visit Um Haram bint Milhan she was the wife of 'Ubada bin As-Samit. One day the Prophet (ﷺ) visited her and she provided him with food and started looking for lice in his head. Then Allah's Messenger (ﷺ) slept and afterwards woke up smiling. Um Haram asked, "What makes you smile, O Allah's Messenger (ﷺ)?" He said, "Some of my followers were presented before me in my dream as fighters in Allah's Cause, sailing in the middle of the seas like kings on the thrones or like kings sitting on their thrones." (The narrator 'Is-haq is not sure as to which expression was correct). Um Haram added, 'I said, "O Allah's Messenger (ﷺ)! Invoke Allah, to make me one of them;" So Allah's Messenger (ﷺ) invoked Allah for her and then laid his head down (and slept). Then he woke up smiling (again). (Um Haram added): I said, "What makes you smile, O Allah's Messenger (ﷺ)?" He said, "Some people of my followers were presented before me (in a dream) as fighters in Allah's Cause." He said the same as he had said before. I said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me from them." He said, "You are among the first ones." Then Um Haram sailed over the sea during the Caliphate of Muawiya bin Abu Sufyan, and she fell down from her riding animal after coming ashore, and died}}
\hadithdefcmd{bukhari}{7015}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ فِي الْمَنَامِ كَأَنَّ فِي يَدِي سَرَقَةً مِنْ حَرِيرٍ لاَ أَهْوِي بِهَا إِلَى مَكَانٍ فِي الْجَنَّةِ إِلاَّ طَارَتْ بِي إِلَيْهِ، فَقَصَصْتُهَا عَلَى حَفْصَةَ‏.‏ فَقَصَّتْهَا حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ أَخَاكِ رَجُلٌ صَالِحٌ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ إِنَّ عَبْدَ اللَّهِ رَجُلٌ صَالِحٌ ‏"‏‏.‏\hadithno{7015}\hadithtrans{Narrated Ibn `Umar:I saw in a dream a piece of silken cloth in my hand, and in whatever direction in Paradise I waved it, it flew, carrying me there. I narrated this (dream) to (my sister) Hafsa and she told it to the Prophet (ﷺ) who said, (to Hafsa), "Indeed, your brother is a righteous man," or, "Indeed, `Abdullah is a righteous man}}
\hadithdefcmd{bukhari}{7028}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، حَدَّثَنَا نَافِعٌ، أَنَّ ابْنَ عُمَرَ، قَالَ إِنَّ رِجَالاً مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانُوا يَرَوْنَ الرُّؤْيَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَقُصُّونَهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَقُولُ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ، وَأَنَا غُلاَمٌ حَدِيثُ السِّنِّ وَبَيْتِي الْمَسْجِدُ قَبْلَ أَنْ أَنْكِحَ، فَقُلْتُ فِي نَفْسِي لَوْ كَانَ فِيكَ خَيْرٌ لَرَأَيْتَ مِثْلَ مَا يَرَى هَؤُلاَءِ‏.‏ فَلَمَّا اضْطَجَعْتُ لَيْلَةً قُلْتُ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ فِيَّ خَيْرًا فَأَرِنِي رُؤْيَا‏.‏ فَبَيْنَمَا أَنَا كَذَلِكَ إِذْ جَاءَنِي مَلَكَانِ فِي يَدِ كُلِّ وَاحِدٍ مِنْهُمَا مَقْمَعَةٌ مِنْ حَدِيدٍ، يُقْبِلاَ بِي إِلَى جَهَنَّمَ، وَأَنَا بَيْنَهُمَا أَدْعُو اللَّهَ اللَّهُمَّ أَعُوذُ بِكَ مِنْ جَهَنَّمَ‏.‏ ثُمَّ أُرَانِي لَقِيَنِي مَلَكٌ فِي يَدِهِ مِقْمَعَةٌ مِنْ حَدِيدٍ فَقَالَ لَنْ تُرَاعَ، نِعْمَ الرَّجُلُ أَنْتَ لَوْ تُكْثِرُ الصَّلاَةَ‏.‏ فَانْطَلَقُوا بِي حَتَّى وَقَفُوا بِي عَلَى شَفِيرِ جَهَنَّمَ فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ، لَهُ قُرُونٌ كَقَرْنِ الْبِئْرِ، بَيْنَ كُلِّ قَرْنَيْنِ مَلَكٌ بِيَدِهِ مِقْمَعَةٌ مِنْ حَدِيدٍ، وَأَرَى فِيهَا رِجَالاً مُعَلَّقِينَ بِالسَّلاَسِلِ، رُءُوسُهُمْ أَسْفَلَهُمْ، عَرَفْتُ فِيهَا رِجَالاً مِنْ قُرَيْشٍ، فَانْصَرَفُوا بِي عَنْ ذَاتِ الْيَمِينِ‏.‏ فَقَصَصْتُهَا عَلَى حَفْصَةَ فَقَصَّتْهَا حَفْصَةُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ عَبْدَ اللَّهِ رَجُلٌ صَالِحٌ ‏"‏‏.‏ فَقَالَ نَافِعٌ لَمْ يَزَلْ بَعْدَ ذَلِكَ يُكْثِرُ الصَّلاَةَ‏.‏\hadithno{7028}\hadithtrans{Narrated Ibn `Umar:Men from the companions of Allah's Messenger (ﷺ) used to see dreams during the lifetime of Allah's Messenger (ﷺ) and they used to narrate those dreams to Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) would interpret them as Allah wished. I was a young man and used to stay in the mosque before my wedlock. I said to myself, "If there were any good in myself, I too would see what these people see." So when I went to bed one night, I said, "O Allah! If you see any good in me, show me a good dream." So while I was in that state, there came to me (in a dream) two angels. In the hand of each of them, there was a mace of iron, and both of them were taking me to Hell, and I was between them, invoking Allah, "O Allah! I seek refuge with You from Hell." Then I saw myself being confronted by another angel holding a mace of iron in his hand. He said to me, "Do not be afraid, you will be an excellent man if you only pray more often." So they took me till they stopped me at the edge of Hell, and behold, it was built inside like a well and it had side posts like those of a well, and beside each post there was an angel carrying an iron mace. I saw therein many people hanging upside down with iron chains, and I recognized therein some men from the Quraish. Then (the angels) took me to the right side. I narrated this dream to (my sister) Hafsa and she told it to Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) said, "No doubt, `Abdullah is a good man." (Nafi` said, "Since then `Abdullah bin `Umar used to pray much)}}
\hadithdefcmd{bukhari}{7030}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنْتُ غُلاَمًا شَابًّا عَزَبًا فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَكُنْتُ أَبِيتُ فِي الْمَسْجِدِ، وَكَانَ مَنْ رَأَى مَنَامًا قَصَّهُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ اللَّهُمَّ إِنْ كَانَ لِي عِنْدَكَ خَيْرٌ فَأَرِنِي مَنَامًا يُعَبِّرُهُ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم، فَنِمْتُ فَرَأَيْتُ مَلَكَيْنِ أَتَيَانِي فَانْطَلَقَا بِي، فَلَقِيَهُمَا مَلَكٌ آخَرُ فَقَالَ لِي لَنْ تُرَاعَ، إِنَّكَ رَجُلٌ صَالِحٌ، فَانْطَلَقَا بِي إِلَى النَّارِ، فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ، وَإِذَا فِيهَا نَاسٌ قَدْ عَرَفْتُ بَعْضَهُمْ، فَأَخَذَا بِي ذَاتَ الْيَمِينِ، فَلَمَّا أَصْبَحْتُ ذَكَرْتُ ذَلِكَ لِحَفْصَةَ‏.‏ فَزَعَمَتْ حَفْصَةُ أَنَّهَا قَصَّتْهَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ عَبْدَ اللَّهِ رَجُلٌ صَالِحٌ لَوْ كَانَ يُكْثِرُ الصَّلاَةَ مِنَ اللَّيْلِ ‏"‏‏.‏ قَالَ الزُّهْرِيُّ وَكَانَ عَبْدُ اللَّهِ بَعْدَ ذَلِكَ يُكْثِرُ الصَّلاَةَ مِنَ اللَّيْلِ‏.‏\hadithno{7030}\hadithtrans{Narrated Ibn `Umar:I was a young unmarried man during the lifetime of the Prophet. I used to sleep in the mosque. Anyone who had a dream, would narrate it to the Prophet. I said, "O Allah! If there is any good for me with You, then show me a dream so that Allah's Messenger (ﷺ) may interpret it for me." So I slept and saw (in a dream) two angels came to me and took me along with them, and they met another angel who said to me, "Don't be afraid, you are a good man." They took me towards the Fire, and behold, it was built inside like a well, and therein I saw people some of whom I recognized, and then the angels took me to the right side. In the morning, I mentioned that dream to Hafsa. Hafsa told me that she had mentioned it to the Prophet (ﷺ) and he said, "`Abdullah is a righteous man if he only prays more at night." (Az-Zuhri said, "After that, `Abdullah used to pray more at night)}}
\hadithdefcmd{bukhari}{7036}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا بِهِ أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ ‏"‏‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَيْنَا أَنَا نَائِمٌ إِذْ أُوتِيتُ خَزَائِنَ الأَرْضِ، فَوُضِعَ فِي يَدَىَّ سِوَارَانِ مِنْ ذَهَبٍ، فَكَبُرَا عَلَىَّ وَأَهَمَّانِي، فَأُوحِيَ إِلَىَّ أَنِ انْفُخْهُمَا، فَنَفَخْتُهُمَا فَطَارَا، فَأَوَّلْتُهُمَا الْكَذَّابَيْنِ اللَّذَيْنِ أَنَا بَيْنَهُمَا صَاحِبَ صَنْعَاءَ وَصَاحِبَ الْيَمَامَةِ ‏"‏‏.‏\hadithno{7036}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "We (Muslims) are the last (to come) but (will be) the foremost (on the Day of Resurrection)." Allah's Messenger (ﷺ) further said, ''While sleeping, I was given the treasures of the world and two golden bangles were put in my hands, but I felt much annoyed, and those two bangles distressed me very much, but I was inspired that I should blow them off, so I blew them and they flew away. Then I interpreted that those two bangles were the liars between whom I was (i.e., the one of San`a' and the one of Yamama)}}
\hadithdefcmd{bukhari}{7055}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ عَمْرٍو، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، قَالَ دَخَلْنَا عَلَى عُبَادَةَ بْنِ الصَّامِتِ وَهْوَ مَرِيضٌ قُلْنَا أَصْلَحَكَ اللَّهُ حَدِّثْ بِحَدِيثٍ، يَنْفَعُكَ اللَّهُ بِهِ سَمِعْتَهُ مِنَ النَّبِيِّ، صلى الله عليه وسلم‏.‏ قَالَ دَعَانَا النَّبِيُّ صلى الله عليه وسلم فَبَايَعْنَاهُ فَقَالَ فِيمَا أَخَذَ عَلَيْنَا أَنْ بَايَعَنَا عَلَى السَّمْعِ وَالطَّاعَةِ، فِي مَنْشَطِنَا وَمَكْرَهِنَا، وَعُسْرِنَا، وَيُسْرِنَا، وَأَثَرَةٍ عَلَيْنَا، وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ، إِلاَّ أَنْ تَرَوْا كُفْرًا بَوَاحًا، عِنْدَكُمْ مِنَ اللَّهِ فِيهِ بُرْهَانٌ‏.‏\hadithno{7055}\hadithtrans{Narrated Junada bin Abi Umaiya:We entered upon 'Ubada bin As-Samit while he was sick. We said, "May Allah make you healthy. Will you tell us a Hadith you heard from the Prophet (ﷺ) and by which Allah may make you benefit?" He said, "The Prophet (ﷺ) called us and we gave him the Pledge of allegiance for Islam, and among the conditions on which he took the Pledge from us, was that we were to listen and obey (the orders) both at the time when we were active and at the time when we were tired, and at our difficult time and at our ease and to be obedient to the ruler and give him his right even if he did not give us our right, and not to fight against him unless we noticed him having open Kufr (disbelief) for which we would have a proof with us from Allah}}
\hadithdefcmd{bukhari}{7062}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ وَأَبِي مُوسَى فَقَالاَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ بَيْنَ يَدَىِ السَّاعَةِ لأَيَّامًا يَنْزِلُ فِيهَا الْجَهْلُ، وَيُرْفَعُ فِيهَا الْعِلْمُ، وَيَكْثُرُ فِيهَا الْهَرْجُ، وَالْهَرْجُ الْقَتْلُ ‏"‏‏.‏\hadithno{7062}\hadithtrans{Narrated `Abdullah and Abu Musa:The Prophet (ﷺ) said, "Near the establishment of the Hour there will be days during which Religious ignorance will spread, knowledge will be taken away (vanish) and there will be much Al-Harj, and Al- Harj means killing}}
\hadithdefcmd{bukhari}{7102}{حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي عَمْرٌو، سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ دَخَلَ أَبُو مُوسَى وَأَبُو مَسْعُودٍ عَلَى عَمَّارٍ حَيْثُ بَعَثَهُ عَلِيٌّ إِلَى أَهْلِ الْكُوفَةِ يَسْتَنْفِرُهُمْ فَقَالاَ مَا رَأَيْنَاكَ أَتَيْتَ أَمْرًا أَكْرَهَ عِنْدَنَا مِنْ إِسْرَاعِكَ فِي هَذَا الأَمْرِ مُنْذُ أَسْلَمْتَ‏.‏ فَقَالَ عَمَّارٌ مَا رَأَيْتُ مِنْكُمَا مُنْذُ أَسْلَمْتُمَا أَمْرًا أَكْرَهَ عِنْدِي مِنْ إِبْطَائِكُمَا عَنْ هَذَا الأَمْرِ‏.‏ وَكَسَاهُمَا حُلَّةً حُلَّةً، ثُمَّ رَاحُوا إِلَى الْمَسْجِدِ‏.‏\hadithno{7102}\hadithtrans{Narrated Abu Wail:Abu Musa and Abu Mas`ud went to `Ammar when `Ali had sent him to Kufa to exhort them to fight (on `Ali's side). They said to him, "Since you have become a Muslim, we have never seen you doing a deed more criticizable to us than your haste in this matter." `Ammar said, "Since you (both) became Muslims, I have never seen you doing a deed more criticizable to me than your keeping away from this matter." Then Abu Mas`ud provided `Ammar and Abu Musa with two-piece outfits to wear, and one of them went to the mosque (of Kufa)}}
\hadithdefcmd{bukhari}{7103}{حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي عَمْرٌو، سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ دَخَلَ أَبُو مُوسَى وَأَبُو مَسْعُودٍ عَلَى عَمَّارٍ حَيْثُ بَعَثَهُ عَلِيٌّ إِلَى أَهْلِ الْكُوفَةِ يَسْتَنْفِرُهُمْ فَقَالاَ مَا رَأَيْنَاكَ أَتَيْتَ أَمْرًا أَكْرَهَ عِنْدَنَا مِنْ إِسْرَاعِكَ فِي هَذَا الأَمْرِ مُنْذُ أَسْلَمْتَ‏.‏ فَقَالَ عَمَّارٌ مَا رَأَيْتُ مِنْكُمَا مُنْذُ أَسْلَمْتُمَا أَمْرًا أَكْرَهَ عِنْدِي مِنْ إِبْطَائِكُمَا عَنْ هَذَا الأَمْرِ‏.‏ وَكَسَاهُمَا حُلَّةً حُلَّةً، ثُمَّ رَاحُوا إِلَى الْمَسْجِدِ‏.‏\hadithno{7103}\hadithtrans{Narrated Abu Wail:Abu Musa and Abu Mas`ud went to `Ammar when `Ali had sent him to Kufa to exhort them to fight (on `Ali's side). They said to him, "Since you have become a Muslim, we have never seen you doing a deed more criticizable to us than your haste in this matter." `Ammar said, "Since you (both) became Muslims, I have never seen you doing a deed more criticizable to me than your keeping away from this matter." Then Abu Mas`ud provided `Ammar and Abu Musa with two-piece outfits to wear, and one of them went to the mosque (of Kufa)}}
\hadithdefcmd{bukhari}{7105}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، كُنْتُ جَالِسًا مَعَ أَبِي مَسْعُودٍ وَأَبِي مُوسَى وَعَمَّارٍ فَقَالَ أَبُو مَسْعُودٍ مَا مِنْ أَصْحَابِكَ أَحَدٌ إِلاَّ لَوْ شِئْتُ لَقُلْتُ فِيهِ غَيْرَكَ، وَمَا رَأَيْتُ مِنْكَ شَيْئًا مُنْذُ صَحِبْتَ النَّبِيَّ صلى الله عليه وسلم أَعْيَبَ عِنْدِي مِنِ اسْتِسْرَاعِكَ فِي هَذَا الأَمْرِ‏.‏ قَالَ عَمَّارٌ يَا أَبَا مَسْعُودٍ وَمَا رَأَيْتُ مِنْكَ وَلاَ مِنْ صَاحِبِكَ هَذَا شَيْئًا مُنْذُ صَحِبْتُمَا النَّبِيَّ صلى الله عليه وسلم أَعْيَبَ عِنْدِي مِنْ إِبْطَائِكُمَا فِي هَذَا الأَمْرِ‏.‏ فَقَالَ أَبُو مَسْعُودٍ وَكَانَ مُوسِرًا يَا غُلاَمُ هَاتِ حُلَّتَيْنِ‏.‏ فَأَعْطَى إِحْدَاهُمَا أَبَا مُوسَى وَالأُخْرَى عَمَّارًا وَقَالَ رُوحَا فِيهِ إِلَى الْجُمُعَةِ‏.‏\hadithno{7105}\hadithtrans{Narrated Shaqiq bin Salama:I was sitting with Abu Mas`ud and Abu Musa and `Ammar. Abu Mas`ud said (to `Ammar), "There is none of your companions but, if I wish, I could find fault with him except with you. Since you joined the company of the Prophet (ﷺ) I have never seen anything done by you more criticizable by me than your haste in this issue." `Ammar said, O Abu Mas`ud ! I have never seen anything done by you or by this companion of yours (i.e., Abu Musa) more criticizable by me than your keeping away from this issue since the time you both joined the company of the Prophet." Then Abu Mas`ud who was a rich man, said (to his servant), "O boy! Bring two suits." Then he gave one to Abu Musa and the other to `Ammar and said (to them), "Put on these suits before going for the Friday prayer}}
\hadithdefcmd{bukhari}{7106}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، كُنْتُ جَالِسًا مَعَ أَبِي مَسْعُودٍ وَأَبِي مُوسَى وَعَمَّارٍ فَقَالَ أَبُو مَسْعُودٍ مَا مِنْ أَصْحَابِكَ أَحَدٌ إِلاَّ لَوْ شِئْتُ لَقُلْتُ فِيهِ غَيْرَكَ، وَمَا رَأَيْتُ مِنْكَ شَيْئًا مُنْذُ صَحِبْتَ النَّبِيَّ صلى الله عليه وسلم أَعْيَبَ عِنْدِي مِنِ اسْتِسْرَاعِكَ فِي هَذَا الأَمْرِ‏.‏ قَالَ عَمَّارٌ يَا أَبَا مَسْعُودٍ وَمَا رَأَيْتُ مِنْكَ وَلاَ مِنْ صَاحِبِكَ هَذَا شَيْئًا مُنْذُ صَحِبْتُمَا النَّبِيَّ صلى الله عليه وسلم أَعْيَبَ عِنْدِي مِنْ إِبْطَائِكُمَا فِي هَذَا الأَمْرِ‏.‏ فَقَالَ أَبُو مَسْعُودٍ وَكَانَ مُوسِرًا يَا غُلاَمُ هَاتِ حُلَّتَيْنِ‏.‏ فَأَعْطَى إِحْدَاهُمَا أَبَا مُوسَى وَالأُخْرَى عَمَّارًا وَقَالَ رُوحَا فِيهِ إِلَى الْجُمُعَةِ‏.‏\hadithno{7106}\hadithtrans{Narrated Shaqiq bin Salama:I was sitting with Abu Mas`ud and Abu Musa and `Ammar. Abu Mas`ud said (to `Ammar), "There is none of your companions but, if I wish, I could find fault with him except with you. Since you joined the company of the Prophet (ﷺ) I have never seen anything done by you more criticizable by me than your haste in this issue." `Ammar said, O Abu Mas`ud ! I have never seen anything done by you or by this companion of yours (i.e., Abu Musa) more criticizable by me than your keeping away from this issue since the time you both joined the company of the Prophet." Then Abu Mas`ud who was a rich man, said (to his servant), "O boy! Bring two suits." Then he gave one to Abu Musa and the other to `Ammar and said (to them), "Put on these suits before going for the Friday prayer}}
\hadithdefcmd{bukhari}{7176}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عَمِّهِ، مُوسَى بْنِ عُقْبَةَ قَالَ ابْنُ شِهَابٍ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ حِينَ أَذِنَ لَهُمُ الْمُسْلِمُونَ فِي عِتْقِ سَبْىِ هَوَازِنَ ‏ "‏ إِنِّي لاَ أَدْرِي مَنْ أَذِنَ مِنْكُمْ مِمَّنْ لَمْ يَأْذَنْ، فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، فَرَجَعُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّ النَّاسَ قَدْ طَيَّبُوا وَأَذِنُوا‏.‏\hadithno{7176}\hadithtrans{Narrated `Urwa bin Az-Zubair:Marwan bin Al-Hakam and Al-Miswar bin Makhrama told him that when the Muslims were permitted to set free the captives of Hawazin, Allah's Messenger (ﷺ) said, "I do not know who amongst you has agreed (to it) and who has not. Go back so that your 'Urafa' may submit your decision to us." So the people returned and their 'Urafa' talked to them and then came back to Allah's Messenger (ﷺ) and told him that the people had given their consent happily and permitted (their captives to be freed)}}
\hadithdefcmd{bukhari}{7183}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ يَحْلِفُ عَلَى يَمِينِ صَبْرٍ، يَقْتَطِعُ مَالاً وَهْوَ فِيهَا فَاجِرٌ، إِلاَّ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ‏\}‏ الآيَةَ‏.‏ فَجَاءَ الأَشْعَثُ وَعَبْدُ اللَّهِ يُحَدِّثُهُمْ فَقَالَ فِيَّ نَزَلَتْ وَفِي رَجُلٍ خَاصَمْتُهُ فِي بِئْرٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏‏.‏ قُلْتُ لاَ‏.‏ قَالَ ‏"‏ فَلْيَحْلِفْ ‏"‏‏.‏ قُلْتُ إِذًا يَحْلِفُ‏.‏ فَنَزَلَتْ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ‏\}‏ الآيَةَ‏.‏\hadithno{7183}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "If somebody on the demand of a judge takes an oath to grab (a Muslim's) property and he is liar in it, he will meet Allah Who will be angry with him". So Allah revealed,:-- 'Verily! those who purchase a small gain at the cost of Allah's Covenant and their oaths..' (3.77) 'Al- Ashath came while `Abdullah was narrating (this) to the people. Al-Ashath said, "This verse was revealed regarding me and another man with whom I had a quarrel about a well. The Prophet (ﷺ) said (to me), "Do you have any evidence?' I replied, 'No.' He said, 'Let your opponent take an oath.' I said: I am sure he would take a (false) oath." Thereupon it was revealed: 'Verily! those who purchase a small gain at the cost of Allah's Covenant....' (3.77) (See Hadith No. 72, Vol)}}
\hadithdefcmd{bukhari}{7193}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالاَ جَاءَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ فَقَامَ خَصْمُهُ فَقَالَ صَدَقَ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَالَ الأَعْرَابِيُّ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَى بِامْرَأَتِهِ، فَقَالُوا لِي عَلَى ابْنِكَ الرَّجْمُ‏.‏ فَفَدَيْتُ ابْنِي مِنْهُ بِمِائَةٍ مِنَ الْغَنَمِ وَوَلِيدَةٍ، ثُمَّ سَأَلْتُ أَهْلَ الْعِلْمِ فَقَالُوا إِنَّمَا عَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا الْوَلِيدَةُ وَالْغَنَمُ فَرَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَأَمَّا أَنْتَ يَا أُنَيْسُ ـ لِرَجُلٍ ـ فَاغْدُ عَلَى امْرَأَةِ هَذَا فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا عَلَيْهَا أُنَيْسٌ فَرَجَمَهَا‏.‏\hadithno{7193}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A bedouin came and said, "O Allah's Messenger (ﷺ)! Judge between us according to Allah's Book (Laws)." His opponent stood up and said, "He has said the truth, so judge between us according to Allah's Laws." The bedouin said, "My son was a laborer for this man and committed illegal sexual intercourse with his wife. The people said to me, 'Your son is to be stoned to death,' so I ransomed my son for one hundred sheep and a slave girl. Then I asked the religious learned men and they said to me, 'Your son has to receive one hundred lashes plus one year of exile.' " The Prophet (ﷺ) said, "I shall judge between you according to Allah's Book (Laws)! As for the slave girl and the sheep, it shall be returned to you, and your son shall receive one-hundred lashes and be exiled for one year. O you, Unais!" The Prophet (ﷺ) addressed some man, "Go in the morning to the wife of this man and stone her to death." So Unais went to her the next morning and stoned her to death}}
\hadithdefcmd{bukhari}{7199}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي عُبَادَةُ بْنُ الْوَلِيدِ، أَخْبَرَنِي أَبِي، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ "بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْمَنْشَطِ وَالْمَكْرَهِ‏.‏ ‏‏وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ، وَأَنْ نَقُومَ ـ أَوْ نَقُولَ ـ بِالْحَقِّ حَيْثُمَا كُنَّا لاَ نَخَافُ فِي اللَّهِ لَوْمَةَ لاَئِمٍ ‏"‏‏.‏\hadithno{7199}\hadithtrans{Narrated 'Ubada bin As-Samit:We gave the oath of allegiance to Allah's Messenger (ﷺ) that we would listen to and obey him both at the time when we were active and at the time when we were tired and that we would not fight against the ruler or disobey him, and would stand firm for the truth or say the truth wherever we might be, and in the Way of Allah we would not be afraid of the blame of the blamers. (See Hadith No. 178 and)}}
\hadithdefcmd{bukhari}{7222}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَكُونُ اثْنَا عَشَرَ أَمِيرًا ـ فَقَالَ كَلِمَةً لَمْ أَسْمَعْهَا فَقَالَ أَبِي إِنَّهُ قَالَ ـ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏‏.‏\hadithno{7222}\hadithtrans{Narrated Jabir bin Samura:I heard the Prophet (ﷺ) saying, "There will be twelve Muslim rulers (who will rule all the Islamic world)." He then said a sentence which I did not hear. My father said, "All of them (those rulers) will be from Quraish}}
\hadithdefcmd{bukhari}{7258}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ وَزَيْدَ بْنَ خَالِدٍ أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7258}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Two men sued each other before the Prophet}}
\hadithdefcmd{bukhari}{7278}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، قَالاَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ ‏"‏‏.‏\hadithno{7278}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:We were with the Prophet (ﷺ) when he said (to two men), "I shall judge between you according to Allah's Book (Laws)}}
\hadithdefcmd{bukhari}{7284}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ بَعْدَهُ، وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ لأَبِي بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ، وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ، إِلاَّ بِحَقِّهِ، وَحِسَابُهُ عَلَى اللَّهِ ‏"‏‏.‏ فَقَالَ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ، فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ، وَاللَّهِ لَوْ مَنَعُونِي عِقَالاً كَانُوا يُؤَدُّونَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهِ‏.‏ فَقَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ اللَّهَ قَدْ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏ قَالَ ابْنُ بُكَيْرٍ وَعَبْدُ اللَّهِ عَنِ اللَّيْثِ عَنَاقًا‏.‏ وَهْوَ أَصَحُّ‏.‏\hadithno{7284}\hadithtrans{Narrated Abu Huraira:When Allah's Messenger (ﷺ) died and Abu Bakr was elected as a Caliph after him, some of the Arabs reverted to disbelief, `Umar said to Abu Bakr, "How dare you fight the people while Allah's Messenger (ﷺ) said, I have been ordered to fight the people till they say 'None has the right to be worshipped but Allah' And whoever says: None has the right to be worshipped but Allah.' waves his wealth and his life from me unless he deserves a legal punishment lusty, and his account will be with Allah! Abu Bakr said, "By Allah, I will fight him who discriminates between Zakat and prayers, for Zakat is the Compulsory right to be taken from the wealth By Allah, if they refuse to give me even a tying rope which they use to give to Allah's Messenger (ﷺ), I would fight them for withholding it." `Umar said, 'By Allah, It was nothing, except I saw that Allah had opened the chest of Abu Bakr to the fight, and I came to know for certain that was the truth}}
\hadithdefcmd{bukhari}{7317}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ سَأَلَ عُمَرُ بْنُ الْخَطَّابِ عَنْ إِمْلاَصِ الْمَرْأَةِ ـ هِيَ الَّتِي يُضْرَبُ بَطْنُهَا فَتُلْقِي جَنِينًا ـ فَقَالَ أَيُّكُمْ سَمِعَ مِنَ النَّبِيِّ صلى الله عليه وسلم فِيهِ شَيْئًا فَقُلْتُ أَنَا‏.‏ فَقَالَ مَا هُوَ قُلْتُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ فِيهِ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ ‏"‏‏.‏ فَقَالَ لاَ تَبْرَحْ حَتَّى تَجِيئَنِي بِالْمَخْرَجِ فِيمَا قُلْتَ‏.فَخَرَجْتُ فَوَجَدْتُ مُحَمَّدَ بْنَ مَسْلَمَةَ فَجِئْتُ بِهِ، فَشَهِدَ مَعِي أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ فِيهِ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ ‏"‏‏.‏ تَابَعَهُ ابْنُ أَبِي الزِّنَادِ عَنْ أَبِيهِ عَنْ عُرْوَةَ عَنِ الْمُغِيرَةِ‏.‏\hadithno{7317}\hadithtrans{Narrated Al-Mughira bin Shu`ba:`Umar bin Al-Khattab asked (the people) about the Imlas of a woman, i.e., a woman who has an abortion because of having been beaten on her `Abdomen, saying, "Who among you has heard anything about it from the Prophet?" I said, "I did.'' He said, "What is that?" I said, "I heard the Prophet saying, "Its Diya (blood money) is either a male or a female slave.' " `Umar said, "Do not leave till you present witness in support of your statement." So I went out, and found Muhammad bin Maslama. I brought him, and he bore witness with me that he had heard the Prophet (ﷺ) saying, "Its Diya (blood money) is either a male slave or a female slave}}
\hadithdefcmd{bukhari}{7327}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لِعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ادْفِنِّي مَعَ صَوَاحِبِي وَلاَ تَدْفِنِّي مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْبَيْتِ، فَإِنِّي أَكْرَهُ أَنْ أُزَكَّى‏.‏ وَعَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنَّ عُمَرَ، أَرْسَلَ إِلَى عَائِشَةَ ائْذَنِي لِي أَنْ أُدْفَنَ مَعَ صَاحِبَىَّ فَقَالَتْ إِي وَاللَّهِ‏.‏ قَالَ وَكَانَ الرَّجُلُ إِذَا أَرْسَلَ إِلَيْهَا مِنَ الصَّحَابَةِ قَالَتْ لاَ وَاللَّهِ لاَ أُوثِرُهُمْ بِأَحَدٍ أَبَدًا‏.‏\hadithno{7327}\hadithtrans{Narrated Hisham's father:`Aisha said to `Abdullah bin Az-Zubair, "Bury me with my female companions (i.e. the wives of the Prophet) and do not bury me with the Prophet (ﷺ) in the house, for I do not like to be regarded as sanctified (just for being buried there).'' Narrated Hisham's father: `Umar sent a message to `Aisha, saying, "Will you allow me to be buried with my two companions (the Prophet (ﷺ) and Abu Bakr) ?" She said, "Yes, by Allah." though it was her habit that if a man from among the companions (of the Prophet (ﷺ) ) sent her a message asking her to allow him to be buried there, she would say, "No, by Allah, I will never give permission to anyone to be buried with them}}
\hadithdefcmd{bukhari}{7340}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَنَسٍ، قَالَ حَالَفَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ الأَنْصَارِ وَقُرَيْشٍ فِي دَارِي الَّتِي بِالْمَدِينَةِ‏.‏ وَقَنَتَ شَهْرًا يَدْعُو عَلَى أَحْيَاءٍ مِنْ بَنِي سُلَيْمٍ\hadithno{7340}\hadithtrans{Narrated Anas:The Prophet (ﷺ) brought the Ansar and the Quraish people into alliance in my house at Medina, and he invoked Allah for one month against the tribe of Bani Sulaim in (the last rak`a of each compulsory) prayer}}
\hadithdefcmd{bukhari}{7350}{حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَخِيهِ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُحَدِّثُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، وَأَبَا، هُرَيْرَةَ حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَخَا بَنِي عَدِيٍّ الأَنْصَارِيَّ وَاسْتَعْمَلَهُ عَلَى خَيْبَرَ، فَقَدِمَ بِتَمْرٍ جَنِيبٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنَّا لَنَشْتَرِي الصَّاعَ بِالصَّاعَيْنِ مِنَ الْجَمْعِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَفْعَلُوا، وَلَكِنْ مِثْلاً بِمِثْلٍ، أَوْ بِيعُوا هَذَا وَاشْتَرُوا بِثَمَنِهِ مِنْ هَذَا وَكَذَلِكَ الْمِيزَانُ ‏"‏‏.‏\hadithno{7350}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:Allah's Messenger (ﷺ) sent the brother of the tribe of Bani Adi Al-Ansari as governor of Khaibar. Then the man returned, bringing Janib (a good kind of date). Allah's Messenger (ﷺ) asked him, "Are all the dates of Khaibar like that?" He replied, "No, by Allah, O Allah's Messenger (ﷺ)! We take one Sa' of these (good) dates for two Sas of mixed dates." Allah's Messenger (ﷺ) then said, "Do not do so. You should either take one Sa of this (kind) for one Sa' of the other; or sell one kind and then buy with its price the other kind (of dates), and you should do the same in weighing}}
\hadithdefcmd{bukhari}{7387}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ ـ رضى الله عنه ـ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي‏.‏ قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَثِيرًا، وَلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ، فَاغْفِرْ لِي مِنْ عِنْدِكَ مَغْفِرَةً، إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏‏.‏\hadithno{7387}\hadithtrans{Narrated `Abdullah bin `Amr:Abu Bakr As-Siddiq said to the Prophet (ﷺ) "O Allah's Messenger (ﷺ)! Teach me an invocation with which I may invoke Allah in my prayers." The Prophet (ﷺ) said, "Say: O Allah! I have wronged my soul very much (oppressed myself), and none forgives the sins but You; so please bestow Your Forgiveness upon me. No doubt, You are the Oft-Forgiving, Most Merciful}}
\hadithdefcmd{bukhari}{7412}{حَدَّثَنَا مُقَدَّمُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي عَمِّي الْقَاسِمُ بْنُ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنَّ اللَّهَ يَقْبِضُ يَوْمَ الْقِيَامَةِ الأَرْضَ وَتَكُونُ السَّمَوَاتُ بِيَمِينِهِ ثُمَّ يَقُولُ أَنَا الْمَلِكُ ‏"‏‏.‏ رَوَاهُ سَعِيدٌ عَنْ مَالِكٍ‏.‏ وَقَالَ عُمَرُ بْنُ حَمْزَةَ سَمِعْتُ سَالِمًا سَمِعْتُ ابْنَ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا‏.‏ وَقَالَ أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَقْبِضُ اللَّهُ الأَرْضَ ‏"‏‏.‏\hadithno{7412}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "On the Day of Resurrection, Allah will grasp the whole Earth by His Hand, and all the Heavens in His right, and then He will say, 'I am the King." Abu Huraira said, "Allah's Messenger (ﷺ) said," Allah will grasp the Earth}}
\hadithdefcmd{bukhari}{7427}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ النَّاسُ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ فَإِذَا أَنَا بِمُوسَى آخِذٌ بِقَائِمَةٍ مِنْ قَوَائِمِ الْعَرْشِ ‏"‏‏.‏ وَقَالَ الْمَاجِشُونُ عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فَأَكُونُ أَوَّلَ مَنْ بُعِثَ فَإِذَا مُوسَى آخِذٌ بِالْعَرْشِ ‏"‏‏.‏\hadithno{7427}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "The people will fall unconscious on the Day of Resurrection, then suddenly I will see Moses holding one of the pillars of the Throne." Abu Huraira said: The Prophet (ﷺ) said, "I will be the first person to be resurrected and will see Moses holding the Throne}}
\hadithdefcmd{bukhari}{7437}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّاسَ، قَالُوا يَا رَسُولَ اللَّهِ هَلْ نَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ تُضَارُّونَ فِي الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَهَلْ تُضَارُّونَ فِي الشَّمْسِ لَيْسَ دُونَهَا سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ تَرَوْنَهُ كَذَلِكَ، يَجْمَعُ اللَّهُ النَّاسَ يَوْمَ الْقِيَامَةِ فَيَقُولُ مَنْ كَانَ يَعْبُدُ شَيْئًا فَلْيَتَّبِعْهُ‏.‏ فَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الشَّمْسَ الشَّمْسَ، وَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الْقَمَرَ الْقَمَرَ، وَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الطَّوَاغِيتَ الطَّوَاغِيتَ، وَتَبْقَى هَذِهِ الأُمَّةُ فِيهَا شَافِعُوهَا ـ أَوْ مُنَافِقُوهَا شَكَّ إِبْرَاهِيمُ ـ فَيَأْتِيهِمُ اللَّهُ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ هَذَا مَكَانُنَا حَتَّى يَأْتِيَنَا رَبُّنَا فَإِذَا جَاءَنَا رَبُّنَا عَرَفْنَاهُ فَيَأْتِيهِمُ اللَّهُ فِي صُورَتِهِ الَّتِي يَعْرِفُونَ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ أَنْتَ رَبُّنَا‏.‏ فَيَتْبَعُونَهُ وَيُضْرَبُ الصِّرَاطُ بَيْنَ ظَهْرَىْ جَهَنَّمَ، فَأَكُونُ أَنَا وَأُمَّتِي أَوَّلَ مَنْ يُجِيزُهَا، وَلاَ يَتَكَلَّمُ يَوْمَئِذٍ إِلاَّ الرُّسُلُ، وَدَعْوَى الرُّسُلِ يَوْمَئِذٍ اللَّهُمَّ سَلِّمْ سَلِّمْ‏.‏ وَفِي جَهَنَّمَ كَلاَلِيبُ مِثْلُ شَوْكِ السَّعْدَانِ، هَلْ رَأَيْتُمُ السَّعْدَانَ ‏"‏‏.‏ قَالُوا نَعَمْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنَّهَا مِثْلُ شَوْكِ السَّعْدَانِ، غَيْرَ أَنَّهُ لاَ يَعْلَمُ مَا قَدْرُ عِظَمِهَا إِلاَّ اللَّهُ، تَخْطَفُ النَّاسَ بِأَعْمَالِهِمْ، فَمِنْهُمُ الْمُوبَقُ بَقِيَ بِعَمَلِهِ، أَوِ الْمُوثَقُ بِعَمَلِهِ، وَمِنْهُمُ الْمُخَرْدَلُ أَوِ الْمُجَازَى أَوْ نَحْوُهُ، ثُمَّ يَتَجَلَّى حَتَّى إِذَا فَرَغَ اللَّهُ مِنَ الْقَضَاءِ بَيْنَ الْعِبَادِ وَأَرَادَ أَنْ يُخْرِجَ بِرَحْمَتِهِ مَنْ أَرَادَ مِنْ أَهْلِ النَّارِ أَمَرَ الْمَلاَئِكَةَ أَنْ يُخْرِجُوا مِنَ النَّارِ مَنْ كَانَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا، مِمَّنْ أَرَادَ اللَّهُ أَنْ يَرْحَمَهُ مِمَّنْ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، فَيَعْرِفُونَهُمْ فِي النَّارِ بِأَثَرِ السُّجُودِ، تَأْكُلُ النَّارُ ابْنَ آدَمَ إِلاَّ أَثَرَ السُّجُودِ، حَرَّمَ اللَّهُ عَلَى النَّارِ أَنْ تَأْكُلَ أَثَرَ السُّجُودِ، فَيَخْرُجُونَ مِنَ النَّارِ قَدِ امْتُحِشُوا، فَيُصَبُّ عَلَيْهِمْ مَاءُ الْحَيَاةِ فَيَنْبُتُونَ تَحْتَهُ كَمَا تَنْبُتُ الْحِبَّةُ فِي حَمِيلِ السَّيْلِ، ثُمَّ يَفْرُغُ اللَّهُ مِنَ الْقَضَاءِ بَيْنَ الْعِبَادِ، وَيَبْقَى رَجُلٌ مُقْبِلٌ بِوَجْهِهِ عَلَى النَّارِ هُوَ آخِرُ أَهْلِ النَّارِ دُخُولاً الْجَنَّةَ فَيَقُولُ أَىْ رَبِّ اصْرِفْ وَجْهِي عَنِ النَّارِ، فَإِنَّهُ قَدْ قَشَبَنِي رِيحُهَا وَأَحْرَقَنِي ذَكَاؤُهَا‏.‏ فَيَدْعُو اللَّهَ بِمَا شَاءَ أَنْ يَدْعُوَهُ ثُمَّ يَقُولُ اللَّهُ هَلْ عَسَيْتَ إِنْ أُعْطِيتَ ذَلِكَ أَنْ تَسْأَلَنِي غَيْرَهُ‏.‏ فَيَقُولُ لاَ وَعِزَّتِكَ لاَ أَسْأَلُكَ غَيْرَهُ، وَيُعْطِي رَبَّهُ مِنْ عُهُودٍ وَمَوَاثِيقَ مَا شَاءَ، فَيَصْرِفُ اللَّهُ وَجْهَهُ عَنِ النَّارِ، فَإِذَا أَقْبَلَ عَلَى الْجَنَّةِ وَرَآهَا سَكَتَ مَا شَاءَ اللَّهُ أَنْ يَسْكُتَ ثُمَّ يَقُولُ أَىْ رَبِّ قَدِّمْنِي إِلَى باب الْجَنَّةِ‏.‏ فَيَقُولُ اللَّهُ لَهُ أَلَسْتَ قَدْ أَعْطَيْتَ عُهُودَكَ وَمَوَاثِيقَكَ أَنْ لاَ تَسْأَلَنِي غَيْرَ الَّذِي أُعْطِيتَ أَبَدًا، وَيْلَكَ يَا ابْنَ آدَمَ مَا أَغْدَرَكَ‏.‏ فَيَقُولُ أَىْ رَبِّ‏.‏ وَيَدْعُو اللَّهَ حَتَّى يَقُولَ هَلْ عَسَيْتَ إِنْ أُعْطِيتَ ذَلِكَ أَنْ تَسْأَلَ غَيْرَهُ‏.‏ فَيَقُولُ لاَ وَعِزَّتِكَ لاَ أَسْأَلُكَ غَيْرَهُ، وَيُعْطِي مَا شَاءَ مِنْ عُهُودٍ وَمَوَاثِيقَ، فَيُقَدِّمُهُ إِلَى باب الْجَنَّةِ، فَإِذَا قَامَ إِلَى باب الْجَنَّةِ انْفَهَقَتْ لَهُ الْجَنَّةُ فَرَأَى مَا فِيهَا مِنَ الْحَبْرَةِ وَالسُّرُورِ، فَيَسْكُتُ مَا شَاءَ اللَّهُ أَنْ يَسْكُتَ ثُمَّ يَقُولُ أَىْ رَبِّ أَدْخِلْنِي الْجَنَّةَ‏.‏ فَيَقُولُ اللَّهُ أَلَسْتَ قَدْ أَعْطَيْتَ عُهُودَكَ وَمَوَاثِيقَكَ أَنْ لاَ تَسْأَلَ غَيْرَ مَا أُعْطِيتَ ـ فَيَقُولُ ـ وَيْلَكَ يَا ابْنَ آدَمَ مَا أَغْدَرَكَ‏.‏ فَيَقُولُ أَىْ رَبِّ لاَ أَكُونَنَّ أَشْقَى خَلْقِكَ فَلاَ يَزَالُ يَدْعُو حَتَّى يَضْحَكَ اللَّهُ مِنْهُ فَإِذَا ضَحِكَ مِنْهُ قَالَ لَهُ ادْخُلِ الْجَنَّةَ‏.‏ فَإِذَا دَخَلَهَا قَالَ اللَّهُ لَهُ تَمَنَّهْ‏.‏ فَسَأَلَ رَبَّهُ وَتَمَنَّى حَتَّى إِنَّ اللَّهَ لَيُذَكِّرُهُ يَقُولُ كَذَا وَكَذَا، حَتَّى انْقَطَعَتْ بِهِ الأَمَانِيُّ قَالَ اللَّهُ ذَلِكَ لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ عَطَاءُ بْنُ يَزِيدَ وَأَبُو سَعِيدٍ الْخُدْرِيُّ مَعَ أَبِي هُرَيْرَةَ لاَ يَرُدُّ عَلَيْهِ مِنْ حَدِيثِهِ شَيْئًا حَتَّى إِذَا حَدَّثَ أَبُو هُرَيْرَةَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ ‏"‏ ذَلِكَ لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ ‏"‏ وَعَشَرَةُ أَمْثَالِهِ مَعَهُ ‏"‏‏.‏ يَا أَبَا هُرَيْرَةَ‏.‏ قَالَ أَبُو هُرَيْرَةَ مَا حَفِظْتُ إِلاَّ قَوْلَهُ ‏"‏ ذَلِكَ لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ أَشْهَدُ أَنِّي حَفِظْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَوْلَهُ ‏"‏ ذَلِكَ لَكَ وَعَشَرَةُ أَمْثَالِهِ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ فَذَلِكَ الرَّجُلُ آخِرُ أَهْلِ الْجَنَّةِ دُخُولاً الْجَنَّةَ‏.‏\hadithno{7437}\hadithtrans{Narrated 'Ata' bin Yazid Al-Laithi: On the authority of Abu Huraira: The people said, "O Allah's Messenger (ﷺ)! Shall we see our Lord on the Day of Resurrection?" The Prophet (ﷺ) said, "Do you have any difficulty in seeing the moon on a full moon night?" They said, "No, O Allah's Messenger (ﷺ)." He said, "Do you have any difficulty in seeing the sun when there are no clouds?" They said, "No, O Allah's Messenger (ﷺ)." He said, "So you will see Him, like that. Allah will gather all the people on the Day of Resurrection, and say, 'Whoever worshipped something (in the world) should follow (that thing),' so, whoever worshipped the sun will follow the sun, and whoever worshiped the moon will follow the moon, and whoever used to worship certain (other false) deities, he will follow those deities. And there will remain only this nation with its good people (or its hypocrites). (The sub-narrator, Ibrahim is in doubt.) Allah will come to them and say, 'I am your Lord.' They will (deny Him and) say, 'We will stay here till our Lord comes, for when our Lord comes, we will recognize Him.' So Allah will come to them in His appearance which they know, and will say, 'I am your Lord.' They will say, 'You are our Lord,' so they will follow Him. Then a bridge will be laid across Hell (Fire)' I and my followers will be the first ones to go across it and none will speak on that Day except the Apostles. And the invocation of the Apostles on that Day will be, 'O Allah, save! Save!' In Hell (or over The Bridge) there will be hooks like the thorns of As-Sa'dan (thorny plant). Have you seen As-Sa'dan? " They replied, "Yes, O Allah's Messenger (ﷺ)!" He said, "So those hooks look like the thorns of As-Sa'dan, but none knows how big they are except Allah. Those hooks will snap the people away according to their deeds. Some of the people will stay in Hell (be destroyed) because of their (evil) deeds, and some will be cut or torn by the hooks (and fall into Hell) and some will be punished and then relieved. When Allah has finished His Judgments among the people, He will take whomever He will out of Hell through His Mercy. He will then order the angels to take out of the Fire all those who used to worship none but Allah from among those whom Allah wanted to be merciful to and those who testified (in the world) that none has the right to be worshipped but Allah. The angels will recognize them in the Fire by the marks of prostration (on their foreheads), for the Fire will eat up all the human body except the mark caused by prostration as Allah has forbidden the Fire to eat the mark of prostration. They will come out of the (Hell) Fire, completely burnt and then the water of life will be poured over them and they will grow under it as does a seed that comes in the mud of the torrent. Then Allah will finish the judgments among the people, and there will remain one man facing the (Hell) Fire and he will be the last person among the people of Hell to enter Paradise. He will say, 'O my Lord! Please turn my face away from the fire because its air has hurt me and its severe heat has burnt me.' So he will invoke Allah in the way Allah will wish him to invoke, and then Allah will say to him, 'If I grant you that, will you then ask for anything else?' He will reply, 'No, by Your Power, (Honor) I will not ask You for anything else.' He will give his Lord whatever promises and covenants Allah will demand. So Allah will turn his face away from Hell (Fire). When he will face Paradise and will see it, he will remain quiet for as long as Allah will wish him to remain quiet, then he will say, 'O my Lord! Bring me near to the gate of Paradise.' Allah will say to him, 'Didn't you give your promises and covenants that you would never ask for anything more than what you had been given? Woe on you, O Adam's son! How treacherous you are!' He will say, 'O my lord,' and will keep on invoking Allah till He says to him, 'If I give what you are asking, will you then ask for anything else?' He will reply, 'No, by Your (Honor) Power, I will not ask for anything else.' Then he will give covenants and promises to Allah and then Allah will bring him near to the gate of Paradise. When he stands at the gate of Paradise, Paradise will be opened and spread before him, and he will see its splendor and pleasures whereupon he will remain quiet as long as Allah will wish him to remain quiet, and then he will say, O my Lord! Admit me into Paradise.' Allah will say, 'Didn't you give your covenants and promises that you would not ask for anything more than what you had been given?' Allah will say, 'Woe on you, O Adam's son! How treacherous you are! ' The man will say, 'O my Lord! Do not make me the most miserable of Your creation,' and he will keep on invoking Allah till Allah will laugh because of his sayings, and when Allah will laugh because of him, He will say to him, 'Enter Paradise,' and when he will enter it, Allah will say to him, 'Wish for anything.' So he will ask his Lord, and he will wish for a great number of things, for Allah Himself will remind him to wish for certain things by saying, '(Wish for) so-and-so.' When there is nothing more to wish for, Allah will say, 'This is for you, and its equal (is for you) as well." 'Ata' bin Yazid added: Abu Sa'id Al-Khudri who was present with Abu Huraira, did not deny whatever the latter said, but when Abu Huraira said that Allah had said, "That is for you and its equal as well," Abu Sa'id Al-Khudri said, "And ten times as much, O Abu Huraira!" Abu Huraira said, "I do not remember, except his saying, 'That is for you and its equal as well.'" Abu Sa'id Al-Khudri then said, "I testify that I remember the Prophet (ﷺ) saying, 'That is for you, and ten times as much.' ' Abu Huraira then added, "That man will be the last person of the people of Paradise to enter Paradise}}
\hadithdefcmd{bukhari}{7495}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ وَبِهَذَا الإِسْنَادِ ‏"‏ قَالَ اللَّهُ أَنْفِقْ أُنْفِقْ عَلَيْكَ ‏"‏‏.‏\hadithno{7495}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "We (Muslims) are the last (to come) but will be the foremost on the Day of Resurrection." The narrators of this Hadith said: Allah said (to man), 'Spend (in charity), for then I will compensate you (generously)}}
