% Auto-generated chapter 39 for muslim
% Hadiths in this chapter: 210

\hadithdefcmd{muslim}{5646}{حَدَّثَنِي عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ، مَرْزُوقٍ حَدَّثَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي زِيَادٌ، أَنَّ ثَابِتًا، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُسَلِّمُ الرَّاكِبُ عَلَى الْمَاشِي وَالْمَاشِي عَلَى الْقَاعِدِ وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏ ‏.‏\hadithno{5646}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The rider should first greet the pedestrian, and the pedestrian the one who is seated and a small group should greet a larger group (with as-Salam-u-'Alaikum)}}
\hadithdefcmd{muslim}{5647}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِيهِ، قَالَ قَالَ أَبُو طَلْحَةَ كُنَّا قُعُودًا بِالأَفْنِيَةِ نَتَحَدَّثُ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَامَ عَلَيْنَا فَقَالَ ‏"‏ مَا لَكُمْ وَلِمَجَالِسِ الصُّعُدَاتِ اجْتَنِبُوا مَجَالِسَ الصُّعُدَاتِ ‏"‏ ‏.‏ فَقُلْنَا إِنَّمَا قَعَدْنَا لِغَيْرِ مَا بَاسٍ قَعَدْنَا نَتَذَاكَرُ وَنَتَحَدَّثُ ‏.‏ قَالَ ‏"‏ إِمَّا لاَ فَأَدُّوا حَقَّهَا غَضُّ الْبَصَرِ وَرَدُّ السَّلاَمِ وَحُسْنُ الْكَلاَمِ ‏"‏ ‏.‏\hadithno{5647}\hadithtrans{Abu Talha reported:While we were sitting in front of the houses and talking amongst ourselves, Allah's Messenger (ﷺ) happened to come there. He stood by us and said: What about you and your meetings on the paths? Avoid these meetings on the paths. We said: We were sitting here without (any intention of doing harm to the passers-by) ; we are sitting to discuss matters and to hold conversation amongst ourselves. Thereupon he said: If there is no help (for you but to sit on these paths), then give the paths their rights and these are lowering of the gaze, exchanging of greetings and good conversation}}
\hadithdefcmd{muslim}{5648}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ، بْنِ يَسَارٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْجُلُوسَ بِالطُّرُقَاتِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا لَنَا بُدٌّ مِنْ مَجَالِسِنَا نَتَحَدَّثُ فِيهَا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَبَيْتُمْ إِلاَّ الْمَجْلِسَ فَأَعْطُوا الطَّرِيقَ حَقَّهُ ‏"‏ ‏.‏ قَالُوا وَمَا حَقُّهُ قَالَ ‏"‏ غَضُّ الْبَصَرِ وَكَفُّ الأَذَى وَرَدُّ السَّلاَمِ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏ ‏.‏\hadithno{5648}\hadithtrans{Abu Sa'id Khudri reported Allah's Apostle (ﷺ) as saying:Avoid sitting on the paths. They (the Companions) said: Allah's Messenger, we cannot help but holding our meetings (in these paths) and discuss matters (there). Thereupon Allah's Messenger (ﷺ) said: If you insist on holding meetings, then give the path its due right. They said: What are its due rights? Upon this he said: Lowering the gaze, refraining from doing harm, exchanging of greetings. commanding of good and forbidding from evil}}
\hadithdefcmd{muslim}{5649}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الْمَدَنِيُّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، رَافِعٍ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ هِشَامٍ، - يَعْنِي ابْنَ سَعْدٍ - كِلاَهُمَا عَنْ زَيْدِ بْنِ أَسْلَمَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5649}\hadithtrans{This hadith has been narrated on the authority of Zaid b. Aslam with the same chain of transmitters}}
\hadithdefcmd{muslim}{5650}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ حَقُّ الْمُسْلِمِ عَلَى الْمُسْلِمِ خَمْسٌ ‏"‏ ‏.‏ ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ، الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَمْسٌ تَجِبُ لِلْمُسْلِمِ عَلَى أَخِيهِ رَدُّ السَّلاَمِ وَتَشْمِيتُ الْعَاطِسِ وَإِجَابَةُ الدَّعْوَةِ وَعِيَادَةُ الْمَرِيضِ وَاتِّبَاعُ الْجَنَائِزِ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ كَانَ مَعْمَرٌ يُرْسِلُ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ وَأَسْنَدَهُ مَرَّةً عَنِ ابْنِ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{5650}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Five are the rights of a Muslim over his brother: responding to salutation, saying Yarhamuk Allah when anybody sneezes and says al-Hamdulillah, visiting the sick. following the bier. ' Abd al-Razzaq said that this hadith has been transmitted as mursal hadith from Zuhri and he then substantiated it on the authority of Ibn Musayyib}}
\hadithdefcmd{muslim}{5651}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ حَقُّ الْمُسْلِمِ عَلَى الْمُسْلِمِ سِتٌّ ‏"‏ ‏.‏ قِيلَ مَا هُنَّ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِذَا لَقِيتَهُ فَسَلِّمْ عَلَيْهِ وَإِذَا دَعَاكَ فَأَجِبْهُ وَإِذَا اسْتَنْصَحَكَ فَانْصَحْ لَهُ وَإِذَا عَطَسَ فَحَمِدَ اللَّهَ فَسَمِّتْهُ وَإِذَا مَرِضَ فَعُدْهُ وَإِذَا مَاتَ فَاتَّبِعْهُ ‏"‏ ‏.‏\hadithno{5651}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Six are the rights of a Muslim over another Muslim. It was said to him: Allah's Messenger, what are these? Thereupon he said: When you meet him, offer him greetings;when he invites you to a feast accept it. when he seeks your council give him, and when he sneezes and says:" All praise is due to Allah," you say Yarhamuk Allah (may Allah show mercy to you) ; and when he fails ill visit him; and when he dies follow his bier}}
\hadithdefcmd{muslim}{5652}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ح وَحَدَّثَنِي إِسْمَاعِيلُ بْنُ سَالِمٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ جَدِّهِ، أَنَسِ بْنِ مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَلَّمَ عَلَيْكُمْ أَهْلُ الْكِتَابِ فَقُولُوا وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{5652}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:When the People of the Book offer you salutations, you should say: The same to you}}
\hadithdefcmd{muslim}{5653}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - قَالاَ حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لَهُمَا - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسٍ، أَنَّعليه وسلم قَالُوا لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أَهْلَ الْكِتَابِ يُسَلِّمُونَ عَلَيْنَا فَكَيْفَ نَرُدُّ عَلَيْهِمْ قَالَ ‏ "‏ قُولُوا وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{5653}\hadithtrans{Anas reported that the Companions of Allah's Apostle (ﷺ) said to him:The People. of the Book offer us salutations (by saying as-Salamu- 'Alaikum). How should we reciprocate them? Thereupon he said: Say: Wa 'Alaikum (and upon you too)}}
\hadithdefcmd{muslim}{5654}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ - وَاللَّفْظُ لِيَحْيَى بْنِ يَحْيَى - قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْيَهُودَ إِذَا سَلَّمُوا عَلَيْكُمْ يَقُولُ أَحَدُهُمُ السَّامُ عَلَيْكُمْ فَقُلْ عَلَيْكَ ‏"‏ ‏.‏\hadithno{5654}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:When the Jews offer you salutations, some of them say as-Sam-u-'Alaikum (death be upon you). You should say (in response to it): Let it be upon you}}
\hadithdefcmd{muslim}{5655}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَقُولُوا وَعَلَيْكَ ‏"‏ ‏.‏\hadithno{5655}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through another chain of transmitters with a slight variation of wording}}
\hadithdefcmd{muslim}{5656}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتَأْذَنَ رَهْطٌ مِنَ الْيَهُودِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا السَّامُ عَلَيْكُمْ ‏.‏ فَقَالَتْ عَائِشَةُ بَلْ عَلَيْكُمُ السَّامُ وَاللَّعْنَةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَائِشَةُ إِنَّ اللَّهَ يُحِبُّ الرِّفْقَ فِي الأَمْرِ كُلِّهِ ‏"‏ ‏.‏ قَالَتْ أَلَمْ تَسْمَعْ مَا قَالُوا قَالَ ‏"‏ قَدْ قُلْتُ وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{5656}\hadithtrans{A'isha reported that a group of Jews came to Allah's Messenger (ﷺ) and sought his audience and said:As-Sam-u-'Alaikum. A'isha said in response: As-Sam-u-'Alaikum (death be upon you) and curse also, whereupon Allah's Messenger (ﷺ) said: 'A'isha, verily Allah loves kindness in every matter. She said: Did you bear what they said? Thereupon he said: Did you not hear that I said (to them): Wa 'Alaikum}}
\hadithdefcmd{muslim}{5657}{حَدَّثَنَاهُ حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ، بْنِ سَعْدٍ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمَا جَمِيعًا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ قُلْتُ عَلَيْكُمْ ‏"‏ ‏.‏ وَلَمْ يَذْكُرُوا الْوَاوَ ‏.‏\hadithno{5657}\hadithtrans{This hadith has been transmitted on the authority of Zuhri that Allah's Messenger (ﷺ) said:I said 'Alaikum, and the transmitter did not make mention of the word "and}}
\hadithdefcmd{muslim}{5658}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ أَتَى النَّبِيَّ صلى الله عليه وسلم أُنَاسٌ مِنَ الْيَهُودِ فَقَالُوا السَّامُ عَلَيْكَ يَا أَبَا الْقَاسِمِ ‏.‏ قَالَ ‏"‏ وَعَلَيْكُمْ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ قُلْتُ بَلْ عَلَيْكُمُ السَّامُ وَالذَّامُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَائِشَةُ لاَ تَكُونِي فَاحِشَةً ‏"‏ ‏.‏ فَقَالَتْ مَا سَمِعْتَ مَا قَالُوا فَقَالَ ‏"‏ أَوَلَيْسَ قَدْ رَدَدْتُ عَلَيْهِمُ الَّذِي قَالُوا قُلْتُ وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{5658}\hadithtrans{A'isha reported that some Jews came to Allah's Apostle (ﷺ) and they said:Abu'l-Qasim (the Kunya of the Holy Prophet), as-Sam-u-'Alaikum, whereupon he (the Holy Prophet) said: Wa 'Alaikum. A'isha reported: In response to these words of theirs, I said: But let there be death upon you and disgrace also, whereupon Allah's Messenger (ﷺ) said: 'A'isha, do not use harsh words. She said: Did you hear what they said? Thereupon he (the Holy Prophet) said: Did I not respond to them when they said that; I said to them: Wa 'Alaikum (let it be upon you)}}
\hadithdefcmd{muslim}{5659}{حَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَعْلَى بْنُ عُبَيْدٍ، حَدَّثَنَا الأَعْمَشُ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ فَفَطِنَتْ بِهِمْ عَائِشَةُ فَسَبَّتْهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَهْ يَا عَائِشَةُ فَإِنَّ اللَّهَ لاَ يُحِبُّ الْفُحْشَ وَالتَّفَحُّشَ ‏"‏ ‏.‏ وَزَادَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَإِذَا جَاءُوكَ حَيَّوْكَ بِمَا لَمْ يُحَيِّكَ بِهِ اللَّهُ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{5659}\hadithtrans{This hadith has been reported on the authority of A'znash with a slight variation of wording. 'A'isha understood their meaning and cursed them and Allah's Messenger (ﷺ) said:'A'isha. (do not do that) for Allah does not like the use of harsh words, and it was at this stage that this verse of Allah. the Exalt. ed and Glorious. was revealed:" And when they come to thee, they greet thee with a greeting with which Allah greets thee not" (Iviii. 8) to the end of the verse}}
\hadithdefcmd{muslim}{5660}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَلَّمَ نَاسٌ مِنْ يَهُودَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا السَّامُ عَلَيْكَ يَا أَبَا الْقَاسِمِ ‏.‏ فَقَالَ ‏"‏ وَعَلَيْكُمْ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ وَغَضِبَتْ أَلَمْ تَسْمَعْ مَا قَالُوا قَالَ ‏"‏ بَلَى قَدْ سَمِعْتُ فَرَدَدْتُ عَلَيْهِمْ وَإِنَّا نُجَابُ عَلَيْهِمْ وَلاَ يُجَابُونَ عَلَيْنَا ‏"‏ ‏.‏\hadithno{5660}\hadithtrans{Jabir b. Abdullah reported that some people from amongst the Jews said to Allah's Messenger (ﷺ) Abu'l-Qasim. as-Sam-u-'Alaikum, whereupon he said:Wa 'Alaikum, A'isha was enraged and asked him (Allah's Apostle) whether he had not heard what they had said. He said, I did hear and I retorted to them (and the curse that I invoked upon them would receive response from Allah), but (the curse that they invoked upon us) would not be responded}}
\hadithdefcmd{muslim}{5661}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبْدَءُوا الْيَهُودَ وَلاَ النَّصَارَى بِالسَّلاَمِ فَإِذَا لَقِيتُمْ أَحَدَهُمْ فِي طَرِيقٍ فَاضْطَرُّوهُ إِلَى أَضْيَقِهِ ‏"‏ ‏.‏\hadithno{5661}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Do not greet the Jews and the Christians before they greet you and when you meet any one of them on the roads force him to go to the narrowest part of it}}
\hadithdefcmd{muslim}{5662}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ، بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، كُلُّهُمْ عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ وَكِيعٍ ‏"‏ إِذَا لَقِيتُمُ الْيَهُودَ ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ جَعْفَرٍ عَنْ شُعْبَةَ قَالَ فِي أَهْلِ الْكِتَابِ ‏.‏ وَفِي حَدِيثِ جَرِيرٍ ‏"‏ إِذَا لَقِيتُمُوهُمْ ‏"‏ ‏.‏ وَلَمْ يُسَمِّ أَحَدًا مِنَ الْمُشْرِكِينَ ‏.‏\hadithno{5662}\hadithtrans{This hadith has been narrated on the authority of Suhail with the same chain of transmitters but with a slight variation of wording. The hadith transmitted on the authority of Waki', the words are 'When you meet the Jews." And in the hadith transmitted on the authority of Shu'ba, the words are:'When you meet the People of the Book." And in the hadith transmitted on the authority of Jarir the words are:" When you meet them," but none amongst the polytheists has been mentioned explicitly by name}}
\hadithdefcmd{muslim}{5663}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ سَيَّارٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ، بْنِ مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ عَلَى غِلْمَانٍ فَسَلَّمَ عَلَيْهِمْ ‏.‏\hadithno{5663}\hadithtrans{Anas b. Malik reported that when Allah's Messenger (ﷺ) happened to pass by young boys he would great them}}
\hadithdefcmd{muslim}{5664}{وَحَدَّثَنِيهِ إِسْمَاعِيلُ بْنُ سَالِمٍ، أَخْبَرَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5664}\hadithtrans{This hadith has been narrated on the authority of Sayyar with the same chain of transmitters}}
\hadithdefcmd{muslim}{5665}{وَحَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَيَّارٍ، قَالَ كُنْتُ أَمْشِي مَعَ ثَابِتٍ الْبُنَانِيِّ فَمَرَّ بِصِبْيَانٍ فَسَلَّمَ عَلَيْهِمْ ‏.‏ وَحَدَّثَ ثَابِتٌ أَنَّهُ كَانَ يَمْشِي مَعَ أَنَسٍ فَمَرَّ بِصِبْيَانٍ فَسَلَّمَ عَلَيْهِمْ ‏.‏ وَحَدَّثَ أَنَسٌ أَنَّهُ كَانَ يَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَّ بِصِبْيَانٍ فَسَلَّمَ عَلَيْهِمْ ‏.‏\hadithno{5665}\hadithtrans{Sayyar reported:I was walking with Thibit al-Bunani that he happened to pass by children and he greeted them. And Thibit reported that he walked with Anas and he happened to pass by children and he greeted them. and Anas reported that he walked with Allah's Apostle (may peace be upon. him) and he happened, to pass by children and he greeted them}}
\hadithdefcmd{muslim}{5666}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ عَبْدِ الْوَاحِدِ، - وَاللَّفْظُ لِقُتَيْبَةَ - حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْحَسَنُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سُوَيْدٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، قَالَ سَمِعْتُ ابْنَ مَسْعُودٍ، يَقُولُ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذْنُكَ عَلَىَّ أَنْ يُرْفَعَ الْحِجَابُ وَأَنْ تَسْتَمِعَ سِوَادِي حَتَّى أَنْهَاكَ ‏"‏ ‏.‏\hadithno{5666}\hadithtrans{Ibn Mas'ud reported:The Messenger of Allah (ﷺ) said to me: The sign that you have been permitted to come in is that the curtain is raised or that you hear me speaking quietly until I forbid you}}
\hadithdefcmd{muslim}{5667}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5667}\hadithtrans{This hadith has been narrated on the authority of 'Ubaidullah with the same chain of transmitters}}
\hadithdefcmd{muslim}{5668}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجَتْ سَوْدَةُ بَعْدَ مَا ضُرِبَ عَلَيْهَا الْحِجَابُ لِتَقْضِيَ حَاجَتَهَا وَكَانَتِ امْرَأَةً جَسِيمَةً تَفْرَعُ النِّسَاءَ جِسْمًا لاَ تَخْفَى عَلَى مَنْ يَعْرِفُهَا فَرَآهَا عُمَرُ بْنُ الْخَطَّابِ فَقَالَ يَا سَوْدَةُ وَاللَّهِ مَا تَخْفَيْنَ عَلَيْنَا فَانْظُرِي كَيْفَ تَخْرُجِينَ ‏.‏ قَالَتْ فَانْكَفَأَتْ رَاجِعَةً وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي وَإِنَّهُ لَيَتَعَشَّى وَفِي يَدِهِ عَرْقٌ فَدَخَلَتْ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي خَرَجْتُ فَقَالَ لِي عُمَرُ كَذَا وَكَذَا ‏.‏ قَالَتْ فَأُوحِيَ إِلَيْهِ ثُمَّ رُفِعَ عَنْهُ وَإِنَّ الْعَرْقَ فِي يَدِهِ مَا وَضَعَهُ فَقَالَ ‏ "‏ إِنَّهُ قَدْ أُذِنَ لَكُنَّ أَنْ تَخْرُجْنَ لِحَاجَتِكُنَّ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ يَفْرَعُ النِّسَاءَ جِسْمُهَا ‏.‏ زَادَ أَبُو بَكْرٍ فِي حَدِيثِهِ فَقَالَ هِشَامٌ يَعْنِي الْبَرَازَ ‏.‏\hadithno{5668}\hadithtrans{A'isha reported that Sauda (Allah he pleated with her) went out (in the fields) in order to answer the call of nature even after the time when veil had been prescribed for women. She had been a bulky lady, significant in height amongst the women, and she could not conceal herself from him who had known her. 'Umar b. Khattab saw her and said:Sauda, by Allah, you cannot conceal from us. Therefore, be careful when you go out. She ('A'isha) said: She turned back. Allah's Messenger (ﷺ) was at that time in my house having his evening meal and there was a bone in his hand. She (Sauda) cline and said: Allah's Messenger. I went out and 'Umar said to me so and so. She ('A'isha) reported: There came the revelation to him and then it was over; the bone was then in his hand and he had not thrown it and he said:" Permission has been granted to you that you may go out for your needs}}
\hadithdefcmd{muslim}{5671}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ أَزْوَاجَ، رَسُولِ اللَّهِ صلى الله عليه وسلم كُنَّ يَخْرُجْنَ بِاللَّيْلِ إِذَا تَبَرَّزْنَ إِلَى الْمَنَاصِعِ وَهُوَ صَعِيدٌ أَفْيَحُ وَكَانَ عُمَرُ بْنُ الْخَطَّابِ يَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم احْجُبْ نِسَاءَكَ ‏.‏ فَلَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَفْعَلُ فَخَرَجَتْ سَوْدَةُ بِنْتُ زَمْعَةَ زَوْجُ النَّبِيِّ صلى الله عليه وسلم لَيْلَةً مِنَ اللَّيَالِي عِشَاءً وَكَانَتِ امْرَأَةً طَوِيلَةً فَنَادَاهَا عُمَرُ أَلاَ قَدْ عَرَفْنَاكِ يَا سَوْدَةُ ‏.‏ حِرْصًا عَلَى أَنْ يُنْزِلَ الْحِجَابَ ‏.‏ قَالَتْ عَائِشَةُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ الْحِجَابَ ‏.‏\hadithno{5671}\hadithtrans{A'isha reported that the wives of Allah's Messenger (ﷺ) used to go out in the cover of night when they went to open fields (in the outskirts of Medina) for easing themselves. 'Umar b Khattab used to say:Allah's Messenger, ask your ladies to observe veil, but Allah's Messenger (ﷺ) did not do that. So there went out Sauda, daughter of Zarn'a, the wife of Allah's Messenger (ﷺ), during one of the nights when it was dark. She was a tall statured lady. 'Umar called her saying: Sauda, we recognise you. (He did this with the hope that the verses pertaining to veil would be revealed.) 'A'isha said: Allah, the Exalted and Glorious, then revealed the verses pertaining to veil}}
\hadithdefcmd{muslim}{5672}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{5672}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters}}
\hadithdefcmd{muslim}{5673}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَلِيُّ بْنُ حُجْرٍ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ ابْنُ حُجْرٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ لاَ يَبِيتَنَّ رَجُلٌ عِنْدَ امْرَأَةٍ ثَيِّبٍ إِلاَّ أَنْ يَكُونَ نَاكِحًا أَوْ ذَا مَحْرَمٍ ‏"‏ ‏.‏\hadithno{5673}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:Behold, no person should spend the night with a married woman, but only in case he is married to her or he is her Mahram}}
\hadithdefcmd{muslim}{5674}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالدُّخُولَ عَلَى النِّسَاءِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ يَا رَسُولَ اللَّهِ أَفَرَأَيْتَ الْحَمْوَ قَالَ ‏"‏ الْحَمْوُ الْمَوْتُ ‏"‏ ‏.‏\hadithno{5674}\hadithtrans{Uqba b. `Amir reported Allah's Messenger (ﷺ) as saying:Beware of getting, into the houses and meeting women (in seclusion). A person from the Ansar said: Allah's Messenger, what about husband's brother, whereupon he (ﷺ) said: Husband's brother is like death}}
\hadithdefcmd{muslim}{5675}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، وَاللَّيْثِ، بْنِ سَعْدٍ وَحَيْوَةَ بْنِ شُرَيْحٍ وَغَيْرِهِمْ أَنَّ يَزِيدَ بْنَ أَبِي حَبِيبٍ، حَدَّثَهُمْ بِهَذَا الإِسْنَادِ، مِثْلَهُ ‏.‏\hadithno{5675}\hadithtrans{This hadith has been narrated on the authority of Yazid b. Abu Habib with the same chain of transmitters}}
\hadithdefcmd{muslim}{5676}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ اللَّيْثَ بْنَ سَعْدٍ، يَقُولُ الْحَمْوُ أَخُ الزَّوْجِ وَمَا أَشْبَهَهُ مِنْ أَقَارِبِ الزَّوْجِ ابْنُ الْعَمِّ وَنَحْوُهُ ‏.‏\hadithno{5676}\hadithtrans{Ibn Wahb reported:I heard Laith b. Said as saying: Al-Hamv means the brother of husband or like it from amongst the relatives of the husband, for example, cousin, etc}}
\hadithdefcmd{muslim}{5677}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ بَكْرَ بْنَ سَوَادَةَ، حَدَّثَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ جُبَيْرٍ حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ حَدَّثَهُ أَنَّ نَفَرًا مِنْ بَنِي هَاشِمٍ دَخَلُوا عَلَى أَسْمَاءَ بِنْتِ عُمَيْسٍ فَدَخَلَ أَبُو بَكْرٍ الصِّدِّيقُ وَهِيَ تَحْتَهُ يَوْمَئِذٍ فَرَآهُمْ فَكَرِهَ ذَلِكَ فَذَكَرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالَ لَمْ أَرَ إِلاَّ خَيْرًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ قَدْ بَرَّأَهَا مِنْ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ لاَ يَدْخُلَنَّ رَجُلٌ بَعْدَ يَوْمِي هَذَا عَلَى مُغِيبَةٍ إِلاَّ وَمَعَهُ رَجُلٌ أَوِ اثْنَانِ ‏"‏ ‏.‏\hadithno{5677}\hadithtrans{Abdullah b. 'Amr. b. al-'As reported that some persons from Banu Hisham entered the house of Asma' daughter of 'Umais when Abu Bakr also entered (and she was at that time his wife). He (Abu Bakr) saw it and disapproved of it and he made a mention of that to Allah's Messenger (ﷺ) and said:I did not see but good only (in my wife). Thereupon Allah's Messenger (ﷺ) said: Verily Allah has made her immune from all this. Then Allah's Messenger (ﷺ) stood on the pulpit and said: After this day no man should enter the house of another person in his absence, but only when he is accompanied by one person or two persons}}
\hadithdefcmd{muslim}{5678}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ مَعَ إِحْدَى نِسَائِهِ فَمَرَّ بِهِ رَجُلٌ فَدَعَاهُ فَجَاءَ فَقَالَ ‏"‏ يَا فُلاَنُ هَذِهِ زَوْجَتِي فُلاَنَةُ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ مَنْ كُنْتُ أَظُنُّ بِهِ فَلَمْ أَكُنْ أَظُنُّ بِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنَ الإِنْسَانِ مَجْرَى الدَّمِ ‏"‏ ‏.‏\hadithno{5678}\hadithtrans{Anas reported that when Allah's Messenger (ﷺ) was in the company of one of his wives a person happened to pass by them. He called him and when he came, he said to him:0 so and so, she was my such and such wife. Thereupon he said, Allah's Messenger, if I were to doubt at all, I would have entertained no doubt about you at least. Thereupon Allah's Messenger (ﷺ) said: Verily Satan circulates in the body like blood}}
\hadithdefcmd{muslim}{5679}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ صَفِيَّةَ بِنْتِ حُيَىٍّ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم مُعْتَكِفًا فَأَتَيْتُهُ أَزُورُهُ لَيْلاً فَحَدَّثْتُهُ ثُمَّ قُمْتُ لأَنْقَلِبَ فَقَامَ مَعِيَ لِيَقْلِبَنِي ‏.‏ وَكَانَ مَسْكَنُهَا فِي دَارِ أُسَامَةَ بْنِ زَيْدٍ فَمَرَّ رَجُلاَنِ مِنَ الأَنْصَارِ فَلَمَّا رَأَيَا النَّبِيَّ صلى الله عليه وسلم أَسْرَعَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكُمَا إِنَّهَا صَفِيَّةُ بِنْتُ حُيَىٍّ ‏"‏ ‏.‏ فَقَالاَ سُبْحَانَ اللَّهِ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنَ الإِنْسَانِ مَجْرَى الدَّمِ وَإِنِّي خَشِيتُ أَنْ يَقْذِفَ فِي قُلُوبِكُمَا شَرًّا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ شَيْئًا ‏"‏ ‏.‏\hadithno{5679}\hadithtrans{Safiyya daughter of Huyyay (the wife of Allah's Apostle) reported that while Allah's Messenger (may peace be. upon him) had been observing I'tikaf, I came to visit him one night and talked with him for some time. Then I stood up to go back and he (Allah's Apostle) also stood up with me in order to bid me good-bye. She was at that time residing in the house of Usama b. Zaid. The two persons from the Ansar happened to pass by him. When they saw Allah's Apostle (ﷺ). they began to walk swiftly, thereupon Allah's Messenger (ﷺ) said to them:Walk calmy, she is Safiyya daughter of Huyyay... Both of them said: Messenger, hallowed be Allah, (we cannot conceive of ab., ug doubtful even in the remotest corners of our minds), whereupon he said: Satan circulates in the body of man like the circulation of blood and I was afraid lest it should instill any evil in your heart or anything}}
\hadithdefcmd{muslim}{5680}{وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنَا عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ صَفِيَّةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّهَا جَاءَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم تَزُورُهُ فِي اعْتِكَافِهِ فِي الْمَسْجِدِ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ فَتَحَدَّثَتْ عِنْدَهُ سَاعَةً ثُمَّ قَامَتْ تَنْقَلِبُ وَقَامَ النَّبِيُّ صلى الله عليه وسلم يَقْلِبُهَا ‏.‏ ثُمَّ ذَكَرَ بِمَعْنَى حَدِيثِ مَعْمَرٍ غَيْرَ أَنَّهُ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ الشَّيْطَانَ يَبْلُغُ مِنَ الإِنْسَانِ مَبْلَغَ الدَّمِ ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ يَجْرِي ‏"‏ ‏.‏\hadithno{5680}\hadithtrans{This hadith has been reported on the authority of Safiyya, the wife of Allah's Apostle (ﷺ), through another chain of transmitters (and the words) are:" She went to Allah's Apostle (ﷺ) to visit him as he was observing I'tikaf in the mosque during Ramadan. She talked with him for some time and then stood up to go back and Allikh's Apostle (ﷺ) stood up in order to bid her good-bye." The rest of the hadith is the same except with the variation of the words that Allah's Apostle (ﷺ) said:" Satan penetrates in man like the penetration of blood (in every part of body)}}
\hadithdefcmd{muslim}{5681}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ إِسْحَاقَ بْنِ عَبْدِ، اللَّهِ بْنِ أَبِي طَلْحَةَ أَنَّ أَبَا مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ أَخْبَرَهُ عَنْ أَبِي وَاقِدٍ اللَّيْثِيِّ، أَنَّالله عليه وسلم بَيْنَمَا هُوَ جَالِسٌ فِي الْمَسْجِدِ وَالنَّاسُ مَعَهُ إِذْ أَقْبَلَ نَفَرٌ ثَلاَثَةٌ فَأَقْبَلَ اثْنَانِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَهَبَ وَاحِدٌ ‏.‏ قَالَ فَوَقَفَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَّا أَحَدُهُمَا فَرَأَى فُرْجَةً فِي الْحَلْقَةِ فَجَلَسَ فِيهَا وَأَمَّا الآخَرُ فَجَلَسَ خَلْفَهُمْ وَأَمَّا الثَّالِثُ فَأَدْبَرَ ذَاهِبًا فَلَمَّا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ عَنِ النَّفَرِ الثَّلاَثَةِ أَمَّا أَحَدُهُمْ فَأَوَى إِلَى اللَّهِ فَآوَاهُ اللَّهُ وَأَمَّا الآخَرُ فَاسْتَحْيَا فَاسْتَحْيَا اللَّهُ مِنْهُ وَأَمَّا الآخَرُ فَأَعْرَضَ فَأَعْرَضَ اللَّهُ عَنْهُ ‏"‏ ‏.‏\hadithno{5681}\hadithtrans{Abu Waqid al-Laith reported that Allah's Messenger (ﷺ) was sitting in the mosque along wish tome people when there came to him three persons; two of them stepped forward to the direction of Allah's Messenger (ﷺ), and one of them went away. The two stood by the side of Allah's Messenger (ﷺ), and one of them found a space in his circle and he sat in that; and the other one sat behind him and the third one went away. When Allah's Messenger (ﷺ) had finished his work, he said. Should I not inform you about these three persons? One of them sought refuge with Allah and Allah gave him refuge and the second one felt shy and Allah showed kindness to has shyness (and so he was accommodated in that meeting), and the last one reverted and Allah turned away His attention from him}}
\hadithdefcmd{muslim}{5682}{وَحَدَّثَنَا أَحْمَدُ بْنُ الْمُنْذِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَرْبٌ، - وَهُوَ ابْنُ شَدَّادٍ - ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا أَبَانٌ، قَالاَ جَمِيعًا حَدَّثَنَا يَحْيَى بْنُ، أَبِي كَثِيرٍ أَنَّ إِسْحَاقَ بْنَ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، حَدَّثَهُ فِي، هَذَا الإِسْنَادِ بِمِثْلِهِ فِي الْمَعْنَى ‏.‏\hadithno{5682}\hadithtrans{This hadith has been reported on the authority of Ishaq b. 'Abdullah b. Talha with the same chain of transmitters}}
\hadithdefcmd{muslim}{5683}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقِيمَنَّ أَحَدُكُمُ الرَّجُلَ مِنْ مَجْلِسِهِ ثُمَّ يَجْلِسُ فِيهِ ‏"‏ ‏.‏\hadithno{5683}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) having said:None of you should make another one stand in the meeting and then occupy his place}}
\hadithdefcmd{muslim}{5684}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى، - وَهْوَ الْقَطَّانُ - ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، وَأَبُو أُسَامَةَ وَابْنُ نُمَيْرٍ قَالُوا حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقِيمُ الرَّجُلُ الرَّجُلَ مِنْ مَقْعَدِهِ ثُمَّ يَجْلِسُ فِيهِ وَلَكِنْ تَفَسَّحُوا وَتَوَسَّعُوا ‏"‏ ‏.‏\hadithno{5684}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:No person should ask another person to stand at his place and then he should himself sit there, but he should simply say: Make room and accommodate}}
\hadithdefcmd{muslim}{5685}{وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنِي يَحْيَى، بْنُ حَبِيبٍ حَدَّثَنَا رَوْحٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَحَدَّثَنَا عَبْدُ الرَّزَّاقِ، كِلاَهُمَا عَنِ ابْنِ، جُرَيْجٍ ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ اللَّيْثِ وَلَمْ يَذْكُرُوا فِي الْحَدِيثِ ‏ "‏ وَلَكِنْ تَفَسَّحُوا وَتَوَسَّعُوا ‏"‏ ‏.‏ وَزَادَ فِي حَدِيثِ ابْنِ جُرَيْجٍ قُلْتُ فِي يَوْمِ الْجُمُعَةِ قَالَ فِي يَوْمِ الْجُمُعَةِ وَغَيْرِهَا ‏.‏\hadithno{5685}\hadithtrans{This hadith has been reported on the authority of Ibn 'Umar through another chain of transmitters. but with a slight variation of wording}}
\hadithdefcmd{muslim}{5686}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقِيمَنَّ أَحَدُكُمْ أَخَاهُ ثُمَّ يَجْلِسُ فِي مَجْلِسِهِ ‏"‏ ‏.‏ وَكَانَ ابْنُ عُمَرَ إِذَا قَامَ لَهُ رَجُلٌ عَنْ مَجْلِسِهِ لَمْ يَجْلِسْ فِيهِ ‏.‏\hadithno{5686}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:None should make one'\& brother stand and then sit at his place (and it was common with) Ibn Umar that when any person stood in the company (with a view to making room for him) he did not sit there}}
\hadithdefcmd{muslim}{5687}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5687}\hadithtrans{This hadith hilt been reported on the authority of Ma'mar with the same chain of transmitters}}
\hadithdefcmd{muslim}{5688}{وَحَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - وَهُوَ ابْنُ عُبَيْدِ اللَّهِ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقِيمَنَّ أَحَدُكُمْ أَخَاهُ يَوْمَ الْجُمُعَةِ ثُمَّ لْيُخَالِفْ إِلَى مَقْعَدِهِ فَيَقْعُدَ فِيهِ وَلَكِنْ يَقُولُ افْسَحُوا ‏"‏ ‏.‏\hadithno{5688}\hadithtrans{Jabir reported Allah's Apostle (may peace he upon him) as saying:None amongst you should make his brother stand on Friday (during the congregational prayer) and then occupy his-place. but he should only say to him (Accommodate me)}}
\hadithdefcmd{muslim}{5689}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، وَقَالَ، قُتَيْبَةُ أَيْضًا حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - كِلاَهُمَا عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا قَامَ أَحَدُكُمْ ‏"‏ ‏.‏ وَفِي حَدِيثِ أَبِي عَوَانَةَ ‏"‏ مَنْ قَامَ مِنْ مَجْلِسِهِ ثُمَّ رَجَعَ إِلَيْهِ فَهُوَ أَحَقُّ بِهِ ‏"‏ ‏.‏\hadithno{5689}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When anyone amongst you stands up, and in the badltb transmitted on the authority of Abu 'Awina, the words are:" He who stands in his place and (goes away) and then comes back to it, he his the greatest right (to occupy that)}}
\hadithdefcmd{muslim}{5690}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كُلُّهُمْ عَنْ هِشَامٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، أَيْضًا - وَاللَّفْظُ هَذَا - حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ، بِنْتِ أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، أَنَّ مُخَنَّثًا، كَانَ عِنْدَهَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْبَيْتِ فَقَالَ لأَخِي أُمِّ سَلَمَةَ يَا عَبْدَ اللَّهِ بْنَ أَبِي أُمَيَّةَ إِنْ فَتَحَ اللَّهُ عَلَيْكُمُ الطَّائِفَ غَدًا فَإِنِّي أَدُلُّكَ عَلَى بِنْتِ غَيْلاَنَ فَإِنَّهَا تُقْبِلُ بِأَرْبَعٍ وَتُدْبِرُ بِثَمَانٍ ‏.‏ قَالَ فَسَمِعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ يَدْخُلْ هَؤُلاَءِ عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{5690}\hadithtrans{Umm Salama reported that she had a eunuch (as a slave) in her house. Allah's Messenger imay peace be upon him) was once in the house that he (the eunuch) said to the brother of Umm Salama:Abdullahb. Aba Umayya. if Allah grants you victory in Ta'if on the next day, I will show you the daughter of Ghailan for she has four folds (upon her body) on the front side of her stomach and eight folds on the back. Allah's Messenger (ﷺ) heard this and he said: Such (people) should not visit you}}
\hadithdefcmd{muslim}{5691}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ يَدْخُلُ عَلَى أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم مُخَنَّثٌ فَكَانُوا يَعُدُّونَهُ مِنْ غَيْرِ أُولِي الإِرْبَةِ - قَالَ - فَدَخَلَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا وَهُوَ عِنْدَ بَعْضِ نِسَائِهِ وَهُوَ يَنْعَتُ امْرَأَةً قَالَ إِذَا أَقْبَلَتْ أَقْبَلَتْ بِأَرْبَعٍ وَإِذَا أَدْبَرَتْ أَدْبَرَتْ بِثَمَانٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلاَ أَرَى هَذَا يَعْرِفُ مَا هَا هُنَا لاَ يَدْخُلَنَّ عَلَيْكُنَّ ‏"‏ ‏.‏ قَالَتْ فَحَجَبُوهُ ‏.‏\hadithno{5691}\hadithtrans{A'isha reported that a eunuch used to come to the wives of Allah's Apostle (ﷺ) and they did not And anything objectionable in his visit considering him to be a male without any sexual desire. Allah's Apostle (ﷺ) one day came as he was sitting with some of his wives and he was busy in describing the bodily characteristics of a lady and saying:As the comes in front tour folds appear on her front side and as she turns her back eight folds appear on the back side. Thereupon Allah's Apostle (ﷺ) said: I me that he knows these things; do not, therefore. allow him to cater. She (" A'isha) said: Then they began to observe veil from him}}
\hadithdefcmd{muslim}{5692}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ أَبُو كُرَيْبٍ الْهَمْدَانِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، أَخْبَرَنِي أَبِي، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ تَزَوَّجَنِي الزُّبَيْرُ وَمَا لَهُ فِي الأَرْضِ مِنْ مَالٍ وَلاَ مَمْلُوكٍ وَلاَ شَىْءٍ غَيْرَ فَرَسِهِ - قَالَتْ - فَكُنْتُ أَعْلِفُ فَرَسَهُ وَأَكْفِيهِ مَئُونَتَهُ وَأَسُوسُهُ وَأَدُقُّ النَّوَى لِنَاضِحِهِ وَأَعْلِفُهُ وَأَسْتَقِي الْمَاءَ وَأَخْرِزُ غَرْبَهُ وَأَعْجِنُ وَلَمْ أَكُنْ أُحْسِنُ أَخْبِزُ وَكَانَ يَخْبِزُ لِي جَارَاتٌ مِنَ الأَنْصَارِ وَكُنَّ نِسْوَةَ صِدْقٍ - قَالَتْ - وَكُنْتُ أَنْقُلُ النَّوَى مِنْ أَرْضِ الزُّبَيْرِ الَّتِي أَقْطَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَأْسِي وَهْىَ عَلَى ثُلُثَىْ فَرْسَخٍ - قَالَتْ - فَجِئْتُ يَوْمًا وَالنَّوَى عَلَى رَأْسِي فَلَقِيتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَعَهُ نَفَرٌ مِنْ أَصْحَابِهِ فَدَعَانِي ثُمَّ قَالَ ‏ "‏ إِخْ إِخْ ‏"‏ ‏.‏ لِيَحْمِلَنِي خَلْفَهُ - قَالَتْ - فَاسْتَحْيَيْتُ وَعَرَفْتُ غَيْرَتَكَ فَقَالَ وَاللَّهِ لَحَمْلُكِ النَّوَى عَلَى رَأْسِكِ أَشَدُّ مِنْ رُكُوبِكِ مَعَهُ ‏.‏ قَالَتْ حَتَّى أَرْسَلَ إِلَىَّ أَبُو بَكْرٍ بَعْدَ ذَلِكَ بِخَادِمٍ فَكَفَتْنِي سِيَاسَةَ الْفَرَسِ فَكَأَنَّمَا أَعْتَقَتْنِي ‏.‏\hadithno{5692}\hadithtrans{Asma' daughter of Abu Bakr reported that the was married to Zubair. He had neither land nor wealth nor slave nor anything else like it except a bom. She further said:I grazed his horse. provided fodder to it and looked after it, and ground dates for his camel. Besides this, I grazed the camel, made arrangements for providing it with water and patched up the leather bucket and kneaded the flour. But I was not proficient in baking the bread, so my female neighbours used to bake bread for me and they were sincere women. She further said: I was carrying on my head the stones of the dates from the land of Zubair which Allah's Messenger (ﷺ) had endowed him and it was at a distance of two miles (from Medina). She add: As I was one day carrying the atones of dates upon my head I happened to meet Allah's Messenger (ﷺ) along with a group of his Companions. He called me and said (to the camel) to sit down so that he should make cite ride behind hirn. (I told my husband: ) I felt shy and remembered your jealousy, whereupon he said: By Allah. the carrying of the stone dates upon your bead is more severe a burden than riding with him. She said: (I led the life of hardship) until Abu Bakr sent afterwards a female servant who took upon herself the responsibility of looking after the horse and I felt as it she had emancipated me}}
\hadithdefcmd{muslim}{5693}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ أَسْمَاءَ، قَالَتْ كُنْتُ أَخْدُمُ الزُّبَيْرَ خِدْمَةَ الْبَيْتِ وَكَانَ لَهُ فَرَسٌ وَكُنْتُ أَسُوسُهُ فَلَمْ يَكُنْ مِنَ الْخِدْمَةِ شَىْءٌ أَشَدَّ عَلَىَّ مِنْ سِيَاسَةِ الْفَرَسِ كُنْتُ أَحْتَشُّ لَهُ وَأَقُومُ عَلَيْهِ وَأَسُوسُهُ ‏.‏ قَالَ ثُمَّ إِنَّهَا أَصَابَتْ خَادِمًا جَاءَ النَّبِيَّ صلى الله عليه وسلم سَبْىٌ فَأَعْطَاهَا خَادِمًا ‏.‏ قَالَتْ كَفَتْنِي سِيَاسَةَ الْفَرَسِ فَأَلْقَتْ عَنِّي مَئُونَتَهُ فَجَاءَنِي رَجُلٌ فَقَالَ يَا أُمَّ عَبْدِ اللَّهِ إِنِّي رَجُلٌ فَقِيرٌ أَرَدْتُ أَنْ أَبِيعَ فِي ظِلِّ دَارِكِ ‏.‏ قَالَتْ إِنِّي إِنْ رَخَّصْتُ لَكَ أَبَى ذَاكَ الزُّبَيْرُ فَتَعَالَ فَاطْلُبْ إِلَىَّ وَالزُّبَيْرُ شَاهِدٌ فَجَاءَ فَقَالَ يَا أُمَّ عَبْدِ اللَّهِ إِنِّي رَجُلٌ فَقِيرٌ أَرَدْتُ أَنْ أَبِيعَ فِي ظِلِّ دَارِكِ ‏.‏ فَقَالَتْ مَا لَكَ بِالْمَدِينَةِ إِلاَّ دَارِي فَقَالَ لَهَا الزُّبَيْرُ مَا لَكِ أَنْ تَمْنَعِي رَجُلاً فَقِيرًا يَبِيعُ فَكَانَ يَبِيعُ إِلَى أَنْ كَسَبَ فَبِعْتُهُ الْجَارِيَةَ فَدَخَلَ عَلَىَّ الزُّبَيْرُ وَثَمَنُهَا فِي حَجْرِي ‏.‏ فَقَالَ هَبِيهَا لِي ‏.‏ قَالَتْ إِنِّي قَدْ تَصَدَّقْتُ بِهَا ‏.‏\hadithno{5693}\hadithtrans{Asma' reported:I performed the household duties of Zubair and he had a horse; I used to look after it. Nothing was more burdensome for me than looking after the horse I used to bring grass for it and looked after it, then I got a servant as Allah's Apustle (ﷺ) had some prisoners of war in his possession. He gave me a female servant. She (the female servant) then began to look after the horse and thus relieved me of this burden. A person came and he said: Mother of 'Abdullah, I am a destitute person and I intend that I should start business under the shadow of your house. I (Asma') said: If I grant you permission, Zubair may not agree to that, so you come and make a demand of it when Zubair is also present there. He came accordingly find said: Mother of 'Abdullah. I am a destitute person. I intend to start t mall business in the shadow of your house. I said: Is there not in Medina (any place for starting the business) except my house? Zubair said: Why is it that you prohibit the destitute man to start business here? So he started business and he (earned so much) that we sold our slave-girl to him There came Zubair to me while the money was in my lap. He said: Give this to me. I said: (I intend) to spend it as charity}}
\hadithdefcmd{muslim}{5694}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ ثَلاَثَةٌ فَلاَ يَتَنَاجَى اثْنَانِ دُونَ وَاحِدٍ ‏"‏ ‏.‏\hadithno{5694}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) as saying:When there are three (persons), two should not converse secretly between themselves to the exclusion of the (third) one}}
\hadithdefcmd{muslim}{5695}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، وَابْنُ، نُمَيْرٍ ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَيُّوبَ بْنَ مُوسَى، كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ مَالِكٍ ‏.‏\hadithno{5695}\hadithtrans{This hadith has been reported on the authority of lbn 'Umar through two different chains of transmitters}}
\hadithdefcmd{muslim}{5696}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا - جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كُنْتُمْ ثَلاَثَةً فَلاَ يَتَنَاجَى اثْنَانِ دُونَ الآخَرِ حَتَّى تَخْتَلِطُوا بِالنَّاسِ مِنْ أَجْلِ أَنْ يُحْزِنَهُ ‏"‏ ‏.‏\hadithno{5696}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:If you are three, two amongst you should not converse secretly between yourselves to the exclusion of the other (third one), unti some other people join him (and dispel his loneliness), for it may hurt his feelings}}
\hadithdefcmd{muslim}{5697}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَابْنُ نُمَيْرٍ وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كُنْتُمْ ثَلاَثَةً فَلاَ يَتَنَاجَى اثْنَانِ دُونَ صَاحِبِهِمَا فَإِنَّ ذَلِكَ يُحْزِنُهُ ‏"‏ ‏.‏\hadithno{5697}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:If you are three, two should not converse secretly to the exclusion of your companion for that hurts his feelings}}
\hadithdefcmd{muslim}{5698}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5698}\hadithtrans{This hadith has been reported on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{5699}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ - عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ إِذَا اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَقَاهُ جِبْرِيلُ قَالَ بِاسْمِ اللَّهِ يُبْرِيكَ وَمِنْ كُلِّ دَاءٍ يَشْفِيكَ وَمِنْ شَرِّ حَاسِدٍ إِذَا حَسَدَ وَشَرِّ كُلِّ ذِي عَيْنٍ ‏.‏\hadithno{5699}\hadithtrans{A'isha (the wife of Allah's Apostle) said:When Allah's Messenger (ﷺ) fell ill, Gabriel used to recite this: "In the name of Allah, may He cure you from all kinds of illnesses and safeguard you from the evil of a jealous one when he feels jealous and from the evil influence of eye}}
\hadithdefcmd{muslim}{5700}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ جِبْرِيلَ، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ اشْتَكَيْتَ فَقَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ بِاسْمِ اللَّهِ أَرْقِيكَ مِنْ كُلِّ شَىْءٍ يُؤْذِيكَ مِنْ شَرِّ كُلِّ نَفْسٍ أَوْ عَيْنِ حَاسِدٍ اللَّهُ يَشْفِيكَ بِاسْمِ اللَّهِ أَرْقِيكَ ‏.‏\hadithno{5700}\hadithtrans{Abu Sa'id reported that Gabriel came to Allah's Messenger (ﷺ) and said:Muhammad, have you fallen ill? Thereupon he said: Yes. He (Gabriel) said: "In the name of Allah I exorcise you from everything and safeguard you from every evil that may harm you and from the eye of a jealous one. Allah would cure you and I invoke the name of Allah for you}}
\hadithdefcmd{muslim}{5701}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعَيْنُ حَقٌّ ‏"‏ ‏.‏\hadithno{5701}\hadithtrans{Abu Huraira reported so many abidith from Allah's Messenger (ﷺ) and he reported Allah's Messenger (ﷺ) as saying:The influence of an evil eye is a fact}}
\hadithdefcmd{muslim}{5702}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، وَحَجَّاجُ بْنُ الشَّاعِرِ، وَأَحْمَدُ بْنُ خِرَاشٍ، قَالَ عَبْدُ اللَّهِ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ، طَاوُسٍ عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَيْنُ حَقٌّ وَلَوْ كَانَ شَىْءٌ سَابَقَ الْقَدَرَ سَبَقَتْهُ الْعَيْنُ وَإِذَا اسْتُغْسِلْتُمْ فَاغْسِلُوا ‏"‏ ‏.‏\hadithno{5702}\hadithtrans{Ibn 'Abbas reported Allah's Messenger (ﷺ) as saying:The influence of an evil eye is a fact; if anything would precede the destiny it would be the influence of an evil eye, and when you are asked to take bath (as a cure) from the influence of an evil eye, you should take bath}}
\hadithdefcmd{muslim}{5703}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سَحَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَهُودِيٌّ مِنْ يَهُودِ بَنِي زُرَيْقٍ يُقَالُ لَهُ لَبِيدُ بْنُ الأَعْصَمِ - قَالَتْ - حَتَّى كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُخَيَّلُ إِلَيْهِ أَنَّهُ يَفْعَلُ الشَّىْءَ وَمَا يَفْعَلُهُ حَتَّى إِذَا كَانَ ذَاتَ يَوْمٍ أَوْ ذَاتَ لَيْلَةٍ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ دَعَا ثُمَّ دَعَا ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ أَشَعَرْتِ أَنَّ اللَّهَ أَفْتَانِي فِيمَا اسْتَفْتَيْتُهُ فِيهِ جَاءَنِي رَجُلاَنِ فَقَعَدَ أَحَدُهُمَا عِنْدَ رَأْسِي وَالآخَرُ عِنْدَ رِجْلَىَّ ‏.‏ فَقَالَ الَّذِي عِنْدَ رَأْسِي لِلَّذِي عِنْدَ رِجْلَىَّ أَوِ الَّذِي عِنْدَ رِجْلَىَّ لِلَّذِي عِنْدَ رَأْسِي مَا وَجَعُ الرَّجُلِ قَالَ مَطْبُوبٌ ‏.‏ قَالَ مَنْ طَبَّهُ قَالَ لَبِيدُ بْنُ الأَعْصَمِ ‏.‏ قَالَ فِي أَىِّ شَىْءٍ قَالَ فِي مُشْطٍ وَمُشَاطَةٍ ‏.‏ قَالَ وَجُبِّ طَلْعَةِ ذَكَرٍ ‏.‏ قَالَ فَأَيْنَ هُوَ قَالَ فِي بِئْرِ ذِي أَرْوَانَ ‏"‏ ‏.‏ قَالَتْ فَأَتَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أُنَاسٍ مِنْ أَصْحَابِهِ ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ وَاللَّهِ لَكَأَنَّ مَاءَهَا نُقَاعَةُ الْحِنَّاءِ وَلَكَأَنَّ نَخْلَهَا رُءُوسُ الشَّيَاطِينِ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ أَحْرَقْتَهُ قَالَ ‏"‏ لاَ أَمَّا أَنَا فَقَدْ عَافَانِي اللَّهُ وَكَرِهْتُ أَنْ أُثِيرَ عَلَى النَّاسِ شَرًّا فَأَمَرْتُ بِهَا فَدُفِنَتْ ‏"‏ ‏.‏\hadithno{5703}\hadithtrans{A'isha reported:that a Jew from among the Jews of Banu Zuraiq who was called Labid b. al-A'sam cast a spell upon Allah's Messenger (ﷺ) with the result that he (under the influence of the spell) felt that he had been doing something whereas in fact he had not been doing that. (This state of affairs lasted) until one day or during one night Allah's Messenger (ﷺ) made supplication (to dispel its effects). He again made a supplication and he again did this and said to 'A'isha: "Do you know that Allah has told me what I had asked Him? There came to me two men and one amongst them sat near my head and the other one near my feet and he who sat near my head said to one who sat near my feet or one who sat near my feet said to one who sat near my head: What is the trouble with the man? He said: The spell has affected him. He said: Who has cast that? He (the other one) said: It was Labid b. A'sam (who has done it). He said: What is the thing by which he transmitted its effect? He said: By the comb and by the hair stuck to the comb and the spathe of the date-palm. He said: Where is that? He replied: In the well of Dhi Arwan." She said: Allah's Messenger (ﷺ) sent some of the persons from among his Companions there and then said: "'A'isha, by Allah, its water was yellow like henna and its trees were like heads of the devils." She said that she asked Allah's Messenger (ﷺ) as to why he did not burn that. He said: "No, Allah has cured me and I do not like that I should induce people to commit any high-handedness in regard (to one another), but I only commanded that it should be buried}}
\hadithdefcmd{muslim}{5704}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سُحِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَسَاقَ أَبُو كُرَيْبٍ الْحَدِيثَ بِقِصَّتِهِ نَحْوَ حَدِيثِ ابْنِ نُمَيْرٍ وَقَالَ فِيهِ فَذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْبِئْرِ فَنَظَرَ إِلَيْهَا وَعَلَيْهَا نَخْلٌ ‏.‏ وَقَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ فَأَخْرِجْهُ ‏.‏ وَلَمْ يَقُلْ أَفَلاَ أَحْرَقْتَهُ وَلَمْ يَذْكُرْ ‏ "‏ فَأَمَرْتُ بِهَا فَدُفِنَتْ ‏"‏ ‏.‏\hadithno{5704}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) was affected with a spell, the rest of the hadith is the same but with this variation of wording:" Allah's Messenger (ﷺ) went to the well and looked towards it and there were trees of date-palm near it. I ('A'isha) said: I asked Allah'\& Messenger (ﷺ) to bring it out, and 1 did not say: Why did not you burn it?" And there is no mention of these words:" I commanded (to bury them and they buried)}}
\hadithdefcmd{muslim}{5705}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ، بْنِ زَيْدٍ عَنْ أَنَسٍ، أَنَّ امْرَأَةً، يَهُودِيَّةً أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِشَاةٍ مَسْمُومَةٍ فَأَكَلَ مِنْهَا فَجِيءَ بِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهَا عَنْ ذَلِكَ فَقَالَتْ أَرَدْتُ لأَقْتُلَكَ ‏.‏ قَالَ ‏"‏ مَا كَانَ اللَّهُ لِيُسَلِّطَكِ عَلَى ذَاكِ ‏"‏ ‏.‏ قَالَ أَوْ قَالَ ‏"‏ عَلَىَّ ‏"‏ ‏.‏ قَالَ قَالُوا أَلاَ نَقْتُلُهَا قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَمَا زِلْتُ أَعْرِفُهَا فِي لَهَوَاتِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5705}\hadithtrans{Anas reported that a Jewess came to Allah's Messenger (ﷺ) with poisoned mutton and he took of that what had been brought to him (Allah's Messenger). (When the effect of this poison were felt by him) he called for her and asked her about that, whereupon she said:I had determined to kill you. Thereupon he said: Allah will never give you the power to do it. He (the narrator) said that they (the Companion's of the Holy Prophet) said: Should we not kill her? Thereupon he said: No. He (Anas) said: I felt (the affects of this poison) on the uvula of Allah's Messenger}}
\hadithdefcmd{muslim}{5706}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، - سَمِعْتُ هِشَامَ، بْنَ زَيْدٍ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يُحَدِّثُ أَنَّ يَهُودِيَّةً، جَعَلَتْ سَمًّا فِي لَحْمٍ ثُمَّ أَتَتْ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم بِنَحْوِ حَدِيثِ خَالِدٍ ‏.‏\hadithno{5706}\hadithtrans{Anas b. Malik reported that a Jewess brought poisoned meat and then served it to Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{5707}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، زُهَيْرٌ - وَاللَّفْظُ لَهُ - حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اشْتَكَى مِنَّا إِنْسَانٌ مَسَحَهُ بِيَمِينِهِ ثُمَّ قَالَ ‏"‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ وَاشْفِ أَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏ فَلَمَّا مَرِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَقُلَ أَخَذْتُ بِيَدِهِ لأَصْنَعَ بِهِ نَحْوَ مَا كَانَ يَصْنَعُ فَانْتَزَعَ يَدَهُ مِنْ يَدِي ثُمَّ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِي وَاجْعَلْنِي مَعَ الرَّفِيقِ الأَعْلَى ‏"‏ ‏.‏ قَالَتْ فَذَهَبْتُ أَنْظُرُ فَإِذَا هُوَ قَدْ قَضَى ‏.‏\hadithno{5707}\hadithtrans{A'isha reported:When any person amongst us fell ill, Allah's Messenger (may peace he upon him) used to rub him with his right band and then say: O Lord of the people, grant him health, heal him, for Thou art a Greet Healer. There is no healere, but with Thy healing Power one is healed and illness is removed. She further added: When Allah's Messenger (ﷺ) fell ill, and his illness took a serious turn I took hold of hie hand to that I should do with it what he ward to do with that (i. e. I would rub his body with his sacred hand). But he withdrew his hand from my hand and then said: O Allah, pardon me and make me join the companion. ship on She said. I was gazing at him constantly whereas he had passed away}}
\hadithdefcmd{muslim}{5708}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح حَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا ابْنُ، بَشَّارٍ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كِلاَهُمَا عَنْ شُعْبَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ سُفْيَانَ، كُلُّ هَؤُلاَءِ عَنِ الأَعْمَشِ، بِإِسْنَادِ جَرِيرٍ ‏.‏ فِي حَدِيثِ هُشَيْمٍ وَشُعْبَةَ مَسَحَهُ بِيَدِهِ ‏.‏ قَالَ وَفِي حَدِيثِ الثَّوْرِيِّ مَسَحَهُ بِيَمِينِهِ ‏.‏ وَقَالَ فِي عَقِبِ حَدِيثِ يَحْيَى عَنْ سُفْيَانَ عَنِ الأَعْمَشِ قَالَ فَحَدَّثْتُ بِهِ مَنْصُورًا فَحَدَّثَنِي عَنْ إِبْرَاهِيمَ عَنْ مَسْرُوقٍ عَنْ عَائِشَةَ بِنَحْوِهِ ‏.‏\hadithno{5708}\hadithtrans{This. hadith has been reported on the authority of Shu'ba through another chain of transmitters (and the words are):" He rubbed him with his hand" and (in) the hadith transmitted on the authority of Thauri (the words are)." He used to rub with his right hand." This hadith has been reported through another chain of transmitters}}
\hadithdefcmd{muslim}{5709}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا عَادَ مَرِيضًا يَقُولُ ‏ "‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ اشْفِهِ أَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏\hadithno{5709}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:When Allah's Messenger (ﷺ) visited the sick he would say: Lord of the people. remove the disease, cure him, for Thou art the great Curer, there is no cure but through Thine healing Power, which leaves nothing of the disease}}
\hadithdefcmd{muslim}{5710}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَى الْمَرِيضَ يَدْعُو لَهُ قَالَ ‏"‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ وَاشْفِ أَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ فَدَعَا لَهُ وَقَالَ ‏"‏ وَأَنْتَ الشَّافِي ‏"‏ ‏.‏\hadithno{5710}\hadithtrans{A'isha reported that when Allah's Messenger (ﷺ) came to visit any sick he supplicated for him and said:Lord of the people, remove the malady, cure him for Thou art a great Curer. There is no cure but through Thine healing Power which leaves no trouble, and in the narration transmitted on the authority of Abu Bakr there is a slight variation of wording}}
\hadithdefcmd{muslim}{5711}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، وَمُسْلِمُ بْنُ صُبَيْحٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ أَبِي عَوَانَةَ وَجَرِيرٍ ‏.‏\hadithno{5711}\hadithtrans{This hadith has been reported on the authority of 'A'isha through another chain of transmitters with a slight variation of wording}}
\hadithdefcmd{muslim}{5712}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَرْقِي بِهَذِهِ الرُّقْيَةِ ‏ "‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ بِيَدِكَ الشِّفَاءُ لاَ كَاشِفَ لَهُ إِلاَّ أَنْتَ ‏"‏ ‏.‏\hadithno{5712}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) used to recite (this supplication) as the words of incantation:" Lord of the people, remove the trouble for in Thine Hand is the cure; none is there to relieve him (the burden of disease) but only Thou}}
\hadithdefcmd{muslim}{5713}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5713}\hadithtrans{This hadith has been reported on the authority of Hisham with the same chain of transmitted}}
\hadithdefcmd{muslim}{5714}{حَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، وَيَحْيَى بْنُ أَيُّوبَ، قَالاَ حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، عَنْ هِشَامِ، بْنِ عُرْوَةَ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا مَرِضَ أَحَدٌ مِنْ أَهْلِهِ نَفَثَ عَلَيْهِ بِالْمُعَوِّذَاتِ فَلَمَّا مَرِضَ مَرَضَهُ الَّذِي مَاتَ فِيهِ جَعَلْتُ أَنْفُثُ عَلَيْهِ وَأَمْسَحُهُ بِيَدِ نَفْسِهِ لأَنَّهَا كَانَتْ أَعْظَمَ بَرَكَةً مِنْ يَدِي ‏.‏ وَفِي رِوَايَةِ يَحْيَى بْنِ أَيُّوبَ بِمُعَوِّذَاتٍ ‏.‏\hadithno{5714}\hadithtrans{A'isha reported that when any of the members of the household fell ill Allah's Messenger (ﷺ) used to blow over him by reciting Mu'awwidhatan, and when he suffered from illness of which he died I used to blow over him and rubbed his body with his hand for his hand had greater healing power than my hand}}
\hadithdefcmd{muslim}{5715}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا اشْتَكَى يَقْرَأُ عَلَى نَفْسِهِ بِالْمُعَوِّذَاتِ وَيَنْفُثُ فَلَمَّا اشْتَدَّ وَجَعُهُ كُنْتُ أَقْرَأُ عَلَيْهِ وَأَمْسَحُ عَنْهُ بِيَدِهِ رَجَاءَ بَرَكَتِهَا ‏.‏\hadithno{5715}\hadithtrans{A'isha reported that when Allah's Messenger (ﷺ) fell ill, he recited over his body Mu'awwidhatan and blew over him and when his sickness was aggravated I used to recite over him and rub him with his band with the hope that it was more blessed}}
\hadithdefcmd{muslim}{5716}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا رَوْحٌ، ح وَحَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، وَأَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي زِيَادٌ، كُلُّهُمْ عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِ مَالِكٍ ‏.‏ نَحْوَ حَدِيثِهِ ‏.‏ وَلَيْسَ فِي حَدِيثِ أَحَدٍ مِنْهُمْ رَجَاءَ بَرَكَتِهَا ‏.‏ إِلاَّ فِي حَدِيثِ مَالِكٍ وَفِي حَدِيثِ يُونُسَ وَزِيَادٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا اشْتَكَى نَفَثَ عَلَى نَفْسِهِ بَالْمُعَوِّذَاتِ وَمَسَحَ عَنْهُ بِيَدِهِ ‏.‏\hadithno{5716}\hadithtrans{This hadith has been narrated through some other chains of transmitters but with a slight variation of wording. In the hadith transmitted on the authority of Yanus and Ziyari (the words are):" When Allah's Apostle (ﷺ) fell ill, he blew over his body by reciting Mu'awwidhatan and rubbed him with his hand}}
\hadithdefcmd{muslim}{5717}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الأَسْوَدِ عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الرُّقْيَةِ، فَقَالَتْ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ بَيْتٍ مِنَ الأَنْصَارِ فِي الرُّقْيَةِ مِنْ كُلِّ ذِي حُمَةٍ ‏.‏\hadithno{5717}\hadithtrans{Abd al-Rahman b. al-Aswad reported on the authority of his father:I asked 'A'isha about incantation. She said: Allah's Messenger (ﷺ) had granted its sanction to the members of a family of the Ansar for incantation in curing every type of poison}}
\hadithdefcmd{muslim}{5718}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَهْلِ بَيْتٍ مِنَ الأَنْصَارِ فِي الرُّقْيَةِ مِنَ الْحُمَةِ ‏.‏\hadithno{5718}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) granted sanction to the members of a family of the Ansar for incantation (for removing the effects) of the poison of the scorpion}}
\hadithdefcmd{muslim}{5719}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اشْتَكَى الإِنْسَانُ الشَّىْءَ مِنْهُ أَوْ كَانَتْ بِهِ قَرْحَةٌ أَوْ جَرْحٌ قَالَ النَّبِيُّ صلى الله عليه وسلم بِإِصْبَعِهِ هَكَذَا وَوَضَعَ سُفْيَانُ سَبَّابَتَهُ بِالأَرْضِ ثُمَّ رَفَعَهَا ‏"‏ بِاسْمِ اللَّهِ تُرْبَةُ أَرْضِنَا بِرِيقَةِ بَعْضِنَا لِيُشْفَى بِهِ سَقِيمُنَا بِإِذْنِ رَبِّنَا ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي شَيْبَةَ ‏"‏ يُشْفَى ‏"‏ ‏.‏ وَقَالَ زُهَيْرٌ ‏"‏ لِيُشْفَى سَقِيمُنَا ‏"‏ ‏.‏\hadithno{5719}\hadithtrans{A'isha reported that when any person fell ill with a disease or he had any ailment or he had any injury, the Messenger of Allah (ﷺ) placed his forefinger upon the ground and then lifted it by reciting the name of Allah. (and said):The dust of our ground with the saliva of any one of us would serve as a means whereby our illness would be cured with the sanction of Allah. This hadith has been transmitted on the authority of Ibn Abu Shaiba and Zubair with a slight variation of wording}}
\hadithdefcmd{muslim}{5720}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ أَبُو بَكْرٍ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لَهُمَا - حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مِسْعَرٍ، حَدَّثَنَا مَعْبَدُ بْنُ خَالِدٍ، عَنِ ابْنِ شَدَّادٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُهَا أَنْ تَسْتَرْقِيَ مِنَ الْعَيْنِ ‏.‏\hadithno{5720}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) commanded the use of incantation for curing the influence of an evil eye}}
\hadithdefcmd{muslim}{5721}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالَ حَدَّثَنَا أَبِي، حَدَّثَنَا مِسْعَرٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5721}\hadithtrans{This hadith has been narrated on the authority of Mis'ar with the same chain of transmitters}}
\hadithdefcmd{muslim}{5722}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ، شَدَّادٍ عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنِي أَنْ أَسْتَرْقِيَ مِنَ الْعَيْنِ ‏.‏\hadithno{5722}\hadithtrans{A'isha reported:Allah's Messenger (may peace he upon him) commanded me that I should make use of incantation for curing the influence of an evil eye}}
\hadithdefcmd{muslim}{5723}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ يُوسُفَ بْنِ، عَبْدِ اللَّهِ عَنْ أَنَسِ بْنِ مَالِكٍ، فِي الرُّقَى قَالَ رُخِّصَ فِي الْحُمَةِ وَالنَّمْلَةِ وَالْعَيْنِ ‏.‏\hadithno{5723}\hadithtrans{Anas b. Malik reported in connection with incantation that he had been granted sanction (to use incantation as a remedy) for the sting of the scorpion and for curing small pustules and dispelling the influence of an evil eye}}
\hadithdefcmd{muslim}{5724}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، ح وَحَدَّثَنِي زُهَيْرُ، بْنُ حَرْبٍ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا حَسَنٌ، - وَهُوَ ابْنُ صَالِحٍ - كِلاَهُمَا عَنْ عَاصِمٍ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسٍ، قَالَ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الرُّقْيَةِ مِنَ الْعَيْنِ وَالْحُمَةِ وَالنَّمْلَةِ ‏.‏ وَفِي حَدِيثِ سُفْيَانَ يُوسُفُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَارِثِ ‏.‏\hadithno{5724}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) granted him sanction to use incantation (as a cure) for the, influence of an evil eye, the sting of the scorpion and small pustules}}
\hadithdefcmd{muslim}{5725}{حَدَّثَنِي أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنِي مُحَمَّدُ بْنُ الْوَلِيدِ، الزُّبَيْدِيُّ عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِجَارِيَةٍ فِي بَيْتِ أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم رَأَى بِوَجْهِهَا سَفْعَةً فَقَالَ ‏ "‏ بِهَا نَظْرَةٌ فَاسْتَرْقُوا لَهَا ‏"‏ ‏.‏ يَعْنِي بِوَجْهِهَا صُفْرَةً ‏.‏\hadithno{5725}\hadithtrans{Umm Salama, the wife of Allah's Apostle (ﷺ), reported that Allah's Messenger (ﷺ) said to a small girl in the house of Umm Salama that he had been seeing on her face black stains and told her that that was due to the infiluence of an evil eye, and he asked that she should be cured with the help of incantation (hoping) that her face should become spotles}}
\hadithdefcmd{muslim}{5726}{حَدَّثَنِي عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ وَأَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم لآلِ حَزْمٍ فِي رُقْيَةِ الْحَيَّةِ وَقَالَ لأَسْمَاءَ بِنْتِ عُمَيْسٍ ‏"‏ مَا لِي أَرَى أَجْسَامَ بَنِي أَخِي ضَارِعَةً تُصِيبُهُمُ الْحَاجَةُ ‏"‏ ‏.‏ قَالَتْ لاَ وَلَكِنِ الْعَيْنُ تُسْرِعُ إِلَيْهِمْ ‏.‏ قَالَ ‏"‏ ارْقِيهِمْ ‏"‏ ‏.‏ قَالَتْ فَعَرَضْتُ عَلَيْهِ فَقَالَ ‏"‏ ارْقِيهِمْ ‏"‏ ‏.‏\hadithno{5726}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Apostle (ﷺ) granted sanction to the family of Hazm for incantation (in mitigating the effect of the poison of) the snake, and, he said -to Asma' daughter of 'Umais:What is this that I see the children of my brother lean? Are they not fed properly? She said: No, but they fall under the influence of an evil eve. He said: Use incantation She recited (the words of incantation before him), whereupon he (by approving them) said: Yes, use this incantation for them}}
\hadithdefcmd{muslim}{5727}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَرْخَصَ النَّبِيُّ صلى الله عليه وسلم فِي رُقْيَةِ الْحَيَّةِ لِبَنِي عَمْرٍو ‏.‏ قَالَ أَبُو الزُّبَيْرِ وَسَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَدَغَتْ رَجُلاً مِنَّا عَقْرَبٌ وَنَحْنُ جُلُوسٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَرْقِي قَالَ ‏ "‏ مَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَنْفَعَ أَخَاهُ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{5727}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Apostle (ﷺ) granted a special sanction for incantation in case of the snake poison to a tribe of 'Amr. Abu Zubair said:I heard Jabir b. 'Abdullah as saying that the scorpion stung one of us as we were sitting with Allah's Messenger (may peace upon him). A person said: Allah's Messenger, I use incantation (for curing the effect. of sting), whereupon he said: He who is competent amongst you to benefit his brother should do so}}
\hadithdefcmd{muslim}{5728}{وَحَدَّثَنِي سَعِيدُ بْنُ يَحْيَى الأُمَوِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَرْقِيهِ يَا رَسُولَ اللَّهِ وَلَمْ يَقُلْ أَرْقِي ‏.‏\hadithno{5728}\hadithtrans{This hadith has been narrated on the authority of Ibn Juraij with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5729}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ كَانَ لِي خَالٌ يَرْقِي مِنَ الْعَقْرَبِ فَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرُّقَى - قَالَ - فَأَتَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّكَ نَهَيْتَ عَنِ الرُّقَى وَأَنَا أَرْقِي مِنَ الْعَقْرَبِ ‏.‏ فَقَالَ ‏ "‏ مَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَنْفَعَ أَخَاهُ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{5729}\hadithtrans{Jabir b. 'Abdullah reported I had a maternal uncle who treated the sting of the scorpion with the help of incantation. Allah's Messenger (ﷺ) forbade incantation. He came to him and said:Allah's Messenger, you forbade to practise incantation, whereas I employ it for curing the sting of the scorpion, whereupon he said: He who amongst you is capable of employing it as a means to do good should do that}}
\hadithdefcmd{muslim}{5730}{وَحَدَّثَنَاهُ عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5730}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{5731}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرُّقَى فَجَاءَ آلُ عَمْرِو بْنِ حَزْمٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهُ كَانَتْ عِنْدَنَا رُقْيَةٌ نَرْقِي بِهَا مِنَ الْعَقْرَبِ وَإِنَّكَ نَهَيْتَ عَنِ الرُّقَى ‏.‏ قَالَ فَعَرَضُوهَا عَلَيْهِ ‏.‏ فَقَالَ ‏ "‏ مَا أَرَى بَأْسًا مَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَنْفَعَ أَخَاهُ فَلْيَنْفَعْهُ ‏"‏ ‏.‏\hadithno{5731}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) prohibited incantation. Then the people of Amr b. Hazm came to Allah's Messenger (ﷺ) and said:We know an incantation which we use for curing the sting of the scorpion but you have prohibited it. They recited (the words of incantation) before him, whereupon he said: I do not see any harm (in it), so he who amongst you is competent to do good to his brother should do that}}
\hadithdefcmd{muslim}{5732}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ جُبَيْرٍ عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ كُنَّا نَرْقِي فِي الْجَاهِلِيَّةِ فَقُلْنَا يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي ذَلِكَ فَقَالَ ‏ "‏ اعْرِضُوا عَلَىَّ رُقَاكُمْ لاَ بَأْسَ بِالرُّقَى مَا لَمْ يَكُنْ فِيهِ شِرْكٌ ‏"‏ ‏.‏\hadithno{5732}\hadithtrans{Auf b. Malik Ashja'i reported We practised incantation in the pre-Islamic days and we said:Allah's Messenger. what is your opinion about it? He said: Let me know your incantation and said: There is no harm in the incantation which does not smack of polytheism}}
\hadithdefcmd{muslim}{5733}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ نَاسًا، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانُوا فى سَفَرٍ فَمَرُّوا بِحَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ فَاسْتَضَافُوهُمْ فَلَمْ يُضِيفُوهُمْ ‏.‏ فَقَالُوا لَهُمْ هَلْ فِيكُمْ رَاقٍ فَإِنَّ سَيِّدَ الْحَىِّ لَدِيغٌ أَوْ مُصَابٌ ‏.‏ فَقَالَ رَجُلٌ مِنْهُمْ نَعَمْ فَأَتَاهُ فَرَقَاهُ بِفَاتِحَةِ الْكِتَابِ فَبَرَأَ الرَّجُلُ فَأُعْطِيَ قَطِيعًا مِنْ غَنَمٍ فَأَبَى أَنْ يَقْبَلَهَا ‏.‏ وَقَالَ حَتَّى أَذْكُرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم ‏.‏ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا رَقَيْتُ إِلاَّ بِفَاتِحَةِ الْكِتَابِ ‏.‏ فَتَبَسَّمَ وَقَالَ ‏"‏ وَمَا أَدْرَاكَ أَنَّهَا رُقْيَةٌ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ خُذُوا مِنْهُمْ وَاضْرِبُوا لِي بِسَهْمٍ مَعَكُمْ ‏"‏ ‏.‏\hadithno{5733}\hadithtrans{Abu Sa'id Khudri reported that some persons amongst the Companions of Allah's Messenger (ﷺ) set out on a journey and they happened to pass by a tribe from the tribes of Arabia. They demanded hospitality from the members of that tribe, but they did not extend any hospitality to them. They said to them:Is there any incantator amongst you, at the chief of the tribe has bgen stung by a scorpion? A person amongst us said: 'Yes. So he came to him and he practised incan- tation with the help of Sura al-Fatiha and the person became all right. He was given a flock of sheep (as recompense), but he refused to accept that, saying: I shall make a mention of it to Allah's Apostle (ﷺ), and if he approves of it. then I shall accept it. So we came to Allah's Apostle (ﷺ) and made a mention of that to him and he (that person) said: Allah's Messenger by Allah, I did not practice incantation but with the help of Sura al-Fatiha of the Holy Book. He (the Holy Prophet) smiled and said: How did you come to know that it can be used (as incactation)? - and then said: Take out of that and allocate a share for me along with your share}}
\hadithdefcmd{muslim}{5734}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ كِلاَهُمَا عَنْ غُنْدَرٍ، مُحَمَّدِ بْنِ جَعْفَرٍ عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ فَجَعَلَ يَقْرَأُ أُمَّ الْقُرْآنِ وَيَجْمَعُ بُزَاقَهُ وَيَتْفُلُ فَبَرَأَ الرَّجُلُ ‏.‏\hadithno{5734}\hadithtrans{This hadith has been reported on the authority of Abu Bishr with the same the same chain of transmitters (with these words):That he recited Umm-ul-Qur'an (Sura Fatiha), and he collected his spittle and he applied that and the person became all right}}
\hadithdefcmd{muslim}{5735}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَخِيهِ، مَعْبَدِ بْنِ سِيرِينَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَزَلْنَا مَنْزِلاً فَأَتَتْنَا امْرَأَةٌ فَقَالَتْ إِنَّ سَيِّدَ الْحَىِّ سَلِيمٌ لُدِغَ فَهَلْ فِيكُمْ مِنْ رَاقٍ فَقَامَ مَعَهَا رَجُلٌ مِنَّا مَا كُنَّا نَظُنُّهُ يُحْسِنُ رُقْيَةً فَرَقَاهُ بِفَاتِحَةِ الْكِتَابِ فَبَرَأَ فَأَعْطَوْهُ غَنَمًا وَسَقَوْنَا لَبَنًا فَقُلْنَا أَكُنْتَ تُحْسِنُ رُقْيَةً فَقَالَ مَا رَقَيْتُهُ إِلاَّ بِفَاتِحَةِ الْكِتَابِ ‏.‏ قَالَ فَقُلْتُ لاَ تُحَرِّكُوهَا حَتَّى نَأْتِيَ النَّبِيَّ صلى الله عليه وسلم ‏.‏ فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَذَكَرْنَا ذَلِكَ لَهُ ‏.‏ فَقَالَ ‏ "‏ مَا كَانَ يُدْرِيهِ أَنَّهَا رُقْيَةٌ اقْسِمُوا وَاضْرِبُوا لِي بِسَهْمٍ مَعَكُمْ ‏"‏ ‏.‏\hadithno{5735}\hadithtrans{Abu Sa'id al-Khudri reported:We landed at a place where a woman came to us and said: A scorpion has bitten the chief of the tribe. Is there any incantator amongst you? A person amongst us stood up (and went with her). We had no idea that he had been a good incantator but he practiced incantation with the help of Sura al-Fatiha and the (the chief) was all right. They gave him a flock of sheep and served us milk. We said (to him): Are you a good incantator. Thereupon he said: I did not do it but by the help of Sura al-Fatiha. He said: Do not drive (these goats) until we go to Allah's Messenger (ﷺ) and find out (whether it is permissible to accept (this reward of incantation). So we came to Allah's Apostle (ﷺ) and made a mention of that to him, whereupon he said: How did you come to know that this (Sura al-Fatiha) could be used as an incantation? So distribute them (amongst those who had been present there with him) and allocate a share of mine also}}
\hadithdefcmd{muslim}{5736}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ فَقَامَ مَعَهَا رَجُلٌ مِنَّا مَا كُنَّا نَأْبِنُهُ بِرُقْيَةٍ ‏.‏\hadithno{5736}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters and he said:There stood up with her a person amongst us whom we did not know before as an incantator}}
\hadithdefcmd{muslim}{5737}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي نَافِعُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ الثَّقَفِيِّ، أَنَّهُ شَكَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَجَعًا يَجِدُهُ فِي جَسَدِهِ مُنْذُ أَسْلَمَ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ضَعْ يَدَكَ عَلَى الَّذِي تَأَلَّمَ مِنْ جَسَدِكَ وَقُلْ بِاسْمِ اللَّهِ ‏.‏ ثَلاَثًا ‏.‏ وَقُلْ سَبْعَ مَرَّاتٍ أَعُوذُ بِاللَّهِ وَقُدْرَتِهِ مِنْ شَرِّ مَا أَجِدُ وَأُحَاذِرُ ‏"‏ ‏.‏\hadithno{5737}\hadithtrans{Uthman b. Abu al-'As Al-Thaqafi reported that he made a complaint of pain to Allah's Messenger (ﷺ) that he felt in his body at the time he had become Muslim. Thereupon Allah's Messenger (ﷺ) said:Place your hand at the place where you feel pain in your body and say Bismillah (in the name of Allah) three times and seven times A'udhu billahi wa qudratihi min sharri ma ajidu wa uhadhiru (I seek refuge with Allah and with His Power from the evil that I find and that I fear)}}
\hadithdefcmd{muslim}{5738}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ الْبَاهِلِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي، الْعَلاَءِ أَنَّ عُثْمَانَ بْنَ أَبِي الْعَاصِ، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ الشَّيْطَانَ قَدْ حَالَ بَيْنِي وَبَيْنَ صَلاَتِي وَقِرَاءَتِي يَلْبِسُهَا عَلَىَّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَاكَ شَيْطَانٌ يُقَالُ لَهُ خِنْزِبٌ فَإِذَا أَحْسَسْتَهُ فَتَعَوَّذْ بِاللَّهِ مِنْهُ وَاتْفِلْ عَلَى يَسَارِكَ ثَلاَثًا ‏"‏ ‏.‏ قَالَ فَفَعَلْتُ ذَلِكَ فَأَذْهَبَهُ اللَّهُ عَنِّي ‏.‏\hadithno{5738}\hadithtrans{Uthman b. Abu al-'As reported that he came to Allah's Messenger (ﷺ) and said:Allah's Messenger, the Satan intervenes between me and my prayer and my reciting of the Qur'an and he confounds me. Thereupon Allah's Messenger (ﷺ) said:, That is (the doing of a) Satan (devil) who is known as Khinzab, and when you perceive its effect, seek refuge with Allah from it and spit three times to your left. I did that and Allah dispelled that from me}}
\hadithdefcmd{muslim}{5739}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، كِلاَهُمَا عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِهِ وَلَمْ يَذْكُرْ فِي حَدِيثِ سَالِمِ بْنِ نُوحٍ ثَلاَثًا ‏.‏\hadithno{5739}\hadithtrans{Uthman b. Abu al-'As reported that he came to Allah's Apostle (ﷺ) and he narrated like this. In the hadith transmitted on the authority of Salam b. Nuh there is no mention of three times}}
\hadithdefcmd{muslim}{5740}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ الثَّقَفِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{5740}\hadithtrans{This hadith has been transmitted on the authority of 'Uthman b. Abu al-'As with a slight variation of wording}}
\hadithdefcmd{muslim}{5741}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَأَبُو الطَّاهِرِ، وَأَحْمَدُ بْنُ عِيسَى، قَالُوا حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لِكُلِّ دَاءٍ دَوَاءٌ فَإِذَا أُصِيبَ دَوَاءُ الدَّاءِ بَرَأَ بِإِذْنِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{5741}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:There is a remedy for every malady, and when the remedy is applied to the disease it is cured with the permission of Allah, the Exalted and Glorious}}
\hadithdefcmd{muslim}{5742}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَأَبُو الطَّاهِرِ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ عَاصِمَ بْنَ عُمَرَ بْنِ قَتَادَةَ حَدَّثَهُ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ عَادَ الْمُقَنَّعَ ثُمَّ قَالَ لاَ أَبْرَحُ حَتَّى تَحْتَجِمَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ فِيهِ شِفَاءً ‏"‏ ‏.‏\hadithno{5742}\hadithtrans{Jabir reported that he visited Muqanna' and then said:I will not go away unless you get yourself cupped, for I heard Allah's Messenger (ﷺ) say: It is a remedy}}
\hadithdefcmd{muslim}{5743}{حَدَّثَنِي نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سُلَيْمَانَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، قَالَ جَاءَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ فِي أَهْلِنَا وَرَجُلٌ يَشْتَكِي خُرَاجًا بِهِ أَوْ جِرَاحًا فَقَالَ مَا تَشْتَكِي قَالَ خُرَاجٌ بِي قَدْ شَقَّ عَلَىَّ ‏.‏ فَقَالَ يَا غُلاَمُ ائْتِنِي بِحَجَّامٍ ‏.‏ فَقَالَ لَهُ مَا تَصْنَعُ بِالْحَجَّامِ يَا أَبَا عَبْدِ اللَّهِ قَالَ أُرِيدُ أَنْ أُعَلِّقَ فِيهِ مِحْجَمًا ‏.‏ قَالَ وَاللَّهِ إِنَّ الذُّبَابَ لَيُصِيبُنِي أَوْ يُصِيبُنِي الثَّوْبُ فَيُؤْذِينِي وَيَشُقُّ عَلَىَّ ‏.‏ فَلَمَّا رَأَى تَبَرُّمَهُ مِنْ ذَلِكَ قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنْ كَانَ فِي شَىْءٍ مِنْ أَدْوِيَتِكُمْ خَيْرٌ فَفِي شَرْطَةِ مَحْجَمٍ أَوْ شَرْبَةٍ مِنْ عَسَلٍ أَوْ لَذْعَةٍ بِنَارٍ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا أُحِبُّ أَنْ أَكْتَوِيَ ‏"‏ ‏.‏ قَالَ فَجَاءَ بِحَجَّامٍ فَشَرَطَهُ فَذَهَبَ عَنْهُ مَا يَجِدُ ‏.‏\hadithno{5743}\hadithtrans{Asim b. 'Umar b. Qatada reported:There came to our house 'Abdullah and another person from amongst the members of the household who complained of a wound. Jabir said: What ails you? He said: There is a wound which is very painful for me, whereupon he said: Boy, bring to me a cupper. He said: 'Abdullah, what do you intend to do with the cupper? I said: I would get this wound cupped. He said: By Allah. oven the touch of fly or cloth causes me pain (and cupping) would thus cause me (unbearable) pain. And when he saw him feeling pain (at the idea of cupping), he said: I heard Allah's Messenger (ﷺ) as saying: If there is any effective remedy amongst your remedies, these are (three): Cupping, drinking of honey and cauterisation with the help of fire. Allah's Messenger (ﷺ) had said: As for myself I do not like cauterisation. The cupper was called and he cupped him and he was all right}}
\hadithdefcmd{muslim}{5744}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ أُمَّ سَلَمَةَ، اسْتَأْذَنَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْحِجَامَةِ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَبَا طَيْبَةَ أَنْ يَحْجُمَهَا ‏.‏ قَالَ حَسِبْتُ أَنَّهُ قَالَ كَانَ أَخَاهَا مِنَ الرَّضَاعَةِ أَوْ غُلاَمًا لَمْ يَحْتَلِمْ ‏.‏\hadithno{5744}\hadithtrans{Jabir reported that Umm Salama sought permission from Allah's messenger (may Allah's peace upon him) tor getting herself cupped. The Apostle of Allah (ﷺ) asked Abu Taiba to cup her. He (Jabir) said:I think he (Abu Taiba) was her faster brother or a young boy before entering upon the adolescent period}}
\hadithdefcmd{muslim}{5745}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى - وَاللَّفْظُ لَهُ - أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أُبَىِّ بْنِ كَعْبٍ طَبِيبًا فَقَطَعَ مِنْهُ عِرْقًا ثُمَّ كَوَاهُ عَلَيْهِ ‏.‏\hadithno{5745}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) sent a phystian to Ubayy b. Ka'b. He cut the vein and then cauterised it}}
\hadithdefcmd{muslim}{5746}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ، أَخْبَرَنَا سُفْيَانُ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرَا فَقَطَعَ مِنْهُ عِرْقًا ‏.‏\hadithno{5746}\hadithtrans{A'mash reported this with the same chain of transmitters and he made no mention of the fact that he cut one of his veins}}
\hadithdefcmd{muslim}{5747}{وَحَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ شُعْبَةَ، قَالَ سَمِعْتُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا سُفْيَانَ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ رُمِيَ أُبَىٌّ يَوْمَ الأَحْزَابِ عَلَى أَكْحَلِهِ فَكَوَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5747}\hadithtrans{Jabir b. 'Abdillah reported that on the day of Ahzab Ubayy received the wound of an arrow in his medial arm vein. Allah's Messenger (ﷺ) cauterised it}}
\hadithdefcmd{muslim}{5748}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَا يَحْيَى، بْنُ يَحْيَى أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رُمِيَ سَعْدُ بْنُ مُعَاذٍ فِي أَكْحَلِهِ - قَالَ - فَحَسَمَهُ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ بِمِشْقَصٍ ثُمَّ وَرِمَتْ فَحَسَمَهُ الثَّانِيَةَ ‏.‏\hadithno{5748}\hadithtrans{Jabir reported that Sa'd b. Mu'adh received a wound of the arrow in his vein. Allah's Messenger (ﷺ) cauterised it with a rod and it was swollen, to the Messenger of Allah (ﷺ) did it for the second time}}
\hadithdefcmd{muslim}{5749}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ صَخْرٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ وَأَعْطَى الْحَجَّامَ أَجْرَهُ وَاسْتَعَطَ ‏.‏\hadithno{5749}\hadithtrans{Ibn 'Abbas reported that Allah's Apostle (ﷺ) got himself cupped and gave to the cupper his wages and he put the medicine in the nostril}}
\hadithdefcmd{muslim}{5750}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَكِيعٌ، وَقَالَ، أَبُو كُرَيْبٍ - وَاللَّفْظُ لَهُ - أَخْبَرَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ عَمْرِو بْنِ عَامِرٍ الأَنْصَارِيِّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ لاَ يَظْلِمُ أَحَدًا أَجْرَهُ ‏.‏\hadithno{5750}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) got himself cupped and never withheld the wages of anyone}}
\hadithdefcmd{muslim}{5751}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{5751}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) as saying:The fever from the vehement raging of the (heat of Hell), so cool it with the help of water}}
\hadithdefcmd{muslim}{5752}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ شِدَّةَ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{5752}\hadithtrans{Ibn Umar reported Allah's Apostle (ﷺ) as saying:Fever is due to vehemence of the heat of Hell, so cool it with water}}
\hadithdefcmd{muslim}{5753}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مَالِكٌ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ رَافِعٍ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَأَطْفِئُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{5753}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) as saying:Fever is from the vehement raging of the fire of Hell, so extinguish it with water}}
\hadithdefcmd{muslim}{5754}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عُمَرَ بْنِ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَأَطْفِئُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{5754}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:Fever is from the vehement Paging of the Hell-fire, so cool it with water}}
\hadithdefcmd{muslim}{5755}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{5755}\hadithtrans{A'isha reported Allah's messenger (ﷺ) as saying:Fever is from the vehement raging of the Hell-fire, so cool it with water}}
\hadithdefcmd{muslim}{5756}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا خَالِدُ بْنُ الْحَارِثِ، وَعَبْدَةُ بْنُ سُلَيْمَانَ، جَمِيعًا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5756}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{5757}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، أَنَّهَا كَانَتْ تُؤْتَى بِالْمَرْأَةِ الْمَوْعُوكَةِ فَتَدْعُو بِالْمَاءِ فَتَصُبُّهُ فِي جَيْبِهَا وَتَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ ابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِنَّهَا مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{5757}\hadithtrans{Asma' reported that a woman running high fever was brought to her. She asked water to be brought and then sprinkled it in the opening of a shirt at the uppermost part of the chest and said that Allah's Messenger (ﷺ) had said:Cool (the fever) with water. for it is because of the vehemence of the beat of Hell}}
\hadithdefcmd{muslim}{5758}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ ابْنِ نُمَيْرٍ صَبَّتِ الْمَاءَ بَيْنَهَا وَبَيْنَ جَيْبِهَا ‏.‏ وَلَمْ يَذْكُرْ فِي حَدِيثِ أَبِي أُسَامَةَ ‏ "‏ أَنَّهَا مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏ قَالَ أَبُو أَحْمَدَ قَالَ إِبْرَاهِيمُ حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ حَدَّثَنَا أَبُو أُسَامَةَ بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5758}\hadithtrans{Hisham reported this hadith with the same chain of transmitters. In the hadith transmitted on the authority of Ibn Numair (the words are):" She poured water on her sides and in the opening of the shirt at the uppermost part of the chest." There is no mention of these words:" It is from the vehemence of the heat of the Hell." This hadith has been narrated on the authority of Abu Usama with the same chain of transmitters}}
\hadithdefcmd{muslim}{5759}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ، بْنِ رِفَاعَةَ عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْحُمَّى فَوْرٌ مِنْ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{5759}\hadithtrans{Rafi' b. Khadij reported:I heard Allah's messenger (ﷺ) as saying: The fever is due to the intense heat of the Hell, so cool it with water}}
\hadithdefcmd{muslim}{5760}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ حَاتِمٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالُوا حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، حَدَّثَنِي رَافِعُ بْنُ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الْحُمَّى مِنْ فَوْرِ جَهَنَّمَ فَابْرُدُوهَا عَنْكُمْ بِالْمَاءِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ أَبُو بَكْرٍ ‏"‏ عَنْكُمْ ‏"‏ ‏.‏ وَقَالَ قَالَ أَخْبَرَنِي رَافِعُ بْنُ خَدِيجٍ ‏.‏\hadithno{5760}\hadithtrans{Rafi' b. Khadij reported:I heard Allah's Messenger (ﷺ) as saying: The fever is due to the intense heat of Hell, so cool it down in your (bodies) with water. Aba Bakr has made no mention of the word" from you" ('ankum), but he said that Rafi' b. Khadij had informed him of it}}
\hadithdefcmd{muslim}{5761}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، حَدَّثَنِي مُوسَى بْنُ أَبِي، عَائِشَةَ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَائِشَةَ، قَالَتْ لَدَدْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ فَأَشَارَ أَنْ لاَ تَلُدُّونِي ‏.‏ فَقُلْنَا كَرَاهِيَةُ الْمَرِيضِ لِلدَّوَاءِ ‏.‏ فَلَمَّا أَفَاقَ قَالَ ‏ "‏ لاَ يَبْقَى أَحَدٌ مِنْكُمْ إِلاَّ لُدَّ غَيْرُ الْعَبَّاسِ فَإِنَّهُ لَمْ يَشْهَدْكُمْ ‏"‏ ‏.‏\hadithno{5761}\hadithtrans{A'isha reported:we (intended to pour) medicine in the mouth of Allah's Messenger (ﷺ) in his illness, but he pointed out (with the gesture of his hand) that it should not be poured into the mouth against his will. We said: (It was perhaps due to the natural) aversion of the patient against medicine. When he recovered, he said: Medicine should be poured into the mouth of every one of you except Ibn 'Abbas, for he was not present amongst you}}
\hadithdefcmd{muslim}{5763}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ وَابْنُ أَبِي عُمَرَ - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، أُخْتِ عُكَّاشَةَ بْنِ مِحْصَنٍ قَالَتْ دَخَلْتُ بِابْنٍ لِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَمْ يَأْكُلِ الطَّعَامَ فَبَالَ عَلَيْهِ فَدَعَا بِمَاءٍ فَرَشَّهُ ‏.‏ قَالَتْ وَدَخَلْتُ عَلَيْهِ بِابْنٍ لِي قَدْ أَعْلَقْتُ عَلَيْهِ مِنَ الْعُذْرَةِ فَقَالَ ‏ "‏ عَلاَمَهْ تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الْعِلاَقِ عَلَيْكُنَّ بِهَذَا الْعُودِ الْهِنْدِيِّ فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ مِنْهَا ذَاتُ الْجَنْبِ يُسْعَطُ مِنَ الْعُذْرَةِ وَيُلَدُّ مِنْ ذَاتِ الْجَنْبِ ‏"‏ ‏.‏\hadithno{5763}\hadithtrans{Umm Qais, daughter of Mihsan, the sister of 'Ukasha b. Mihsan said:I visited Allah's Messenger (ﷺ) along with my son who had not, by that time, been weaned and he urinated over his (clothes). He ordered water to be brought and sprinkled (it) over them. She (further) said: I visited him (Allah's Apostle) along with my son and I had squeezed the swelling in the uvula, whereupon he said: Why do you afflict your children by compressing like this? Use this Indian aloeswood, for it contains seven types of remedies, one among them being a remedy for pleurisy. It is applied through the nose for a swelling of the uvula and poured into the side of the mouth for pleurisy}}
\hadithdefcmd{muslim}{5765}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أُمَّ قَيْسٍ بِنْتَ مِحْصَنٍ، - وَكَانَتْ مِنَ الْمُهَاجِرَاتِ الأُوَلِ اللاَّتِي بَايَعْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهِيَ أُخْتُ عُكَّاشَةَ بْنِ مِحْصَنٍ أَحَدِ بَنِي أَسَدِ بْنِ خُزَيْمَةَ - قَالَ أَخْبَرَتْنِي أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِابْنٍ لَهَا لَمْ يَبْلُغْ أَنْ يَأْكُلَ الطَّعَامَ وَقَدْ أَعْلَقَتْ عَلَيْهِ مِنَ الْعُذْرَةِ - قَالَ يُونُسُ أَعْلَقَتْ غَمَزَتْ فَهِيَ تَخَافُ أَنْ يَكُونَ بِهِ عُذْرَةٌ - قَالَتْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلاَمَهْ تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الإِعْلاَقِ عَلَيْكُمْ بِهَذَا الْعُودِ الْهِنْدِيِّ - يَعْنِي بِهِ الْكُسْتَ - فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ مِنْهَا ذَاتُ الْجَنْبِ ‏"‏ ‏.‏ قَالَ عُبَيْدُ اللَّهِ وَأَخْبَرَتْنِي أَنَّ ابْنَهَا ذَاكَ بَالَ فِي حَجْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَاءٍ فَنَضَحَهُ عَلَى بَوْلِهِ وَلَمْ يَغْسِلْهُ غَسْلاً ‏.‏\hadithno{5765}\hadithtrans{Umm Qais, daughter of Mihsan, was one of the earlier female emigrants who had pledged allegiance to Allah's Messenger (ﷺ). She was the sister of Ukasha b. Mihsan, one of the posterity of Asad b. Khuzaima. She reported that she came to Allah's messenger (ﷺ) along with her son who had not attained the age of weaning and she had compressed the swelling of his uvula. (Yunus said:She compressed the uvula because she was afraid that there might be swelling of uvula.) Thereupon Allah's Messenger (ﷺ) said: Why do you afflict your children by compressing in this way? You should use Indian aloeswood, for it has seven remedies in it, one of them being the remedy for pleurisy. Ubaidullah reported that she had told that that was the child who had urinated in the lap of Allah's Messenger (ﷺ), and Allah's Messenger (ﷺ) called for water and sprinkled it on his urine, but he did not wash it well}}
\hadithdefcmd{muslim}{5766}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُمَا أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ فِي الْحَبَّةِ السَّوْدَاءِ شِفَاءً مِنْ كُلِّ دَاءٍ إِلاَّ السَّامَ ‏"‏ ‏.‏ وَالسَّامُ الْمَوْتُ ‏.‏ وَالْحَبَّةُ السَّوْدَاءُ الشُّونِيزُ ‏.‏\hadithno{5766}\hadithtrans{Abu Huraira reported that he heard Allah's Messenger (ﷺ) as saying:Nigella seed is a remedy for every disease except death}}
\hadithdefcmd{muslim}{5767}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ عُقَيْلٍ وَفِي حَدِيثِ سُفْيَانَ وَيُونُسَ الْحَبَّةُ السَّوْدَاءُ ‏.‏ وَلَمْ يَقُلِ الشُّونِيزُ ‏.‏\hadithno{5767}\hadithtrans{This hadith has been narrated through other chains of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5768}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ دَاءٍ إِلاَّ فِي الْحَبَّةِ السَّوْدَاءِ مِنْهُ شِفَاءٌ إِلاَّ السَّامَ ‏"‏ ‏.‏\hadithno{5768}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no disease for which Nigella seed does not provide remedy}}
\hadithdefcmd{muslim}{5769}{وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ إِذَا مَاتَ الْمَيِّتُ مِنْ أَهْلِهَا فَاجْتَمَعَ لِذَلِكَ النِّسَاءُ ثُمَّ تَفَرَّقْنَ إِلاَّ أَهْلَهَا وَخَاصَّتَهَا - أَمَرَتْ بِبُرْمَةٍ مِنْ تَلْبِينَةٍ فَطُبِخَتْ ثُمَّ صُنِعَ ثَرِيدٌ فَصُبَّتِ التَّلْبِينَةُ عَلَيْهَا ثُمَّ قَالَتْ كُلْنَ مِنْهَا فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ التَّلْبِينَةُ مَجَمَّةٌ لِفُؤَادِ الْمَرِيضِ تُذْهِبُ بَعْضَ الْحُزْنِ ‏"‏ ‏.‏\hadithno{5769}\hadithtrans{A'isha the wife of Allah's Apostle (ﷺ) said:When there was any bereavement in her family the women gathered there for condolence and they departed except the members of the family and some selected persons. She asked to prepare talbina in a small couldron and it was cooked and then tharid was prepared and it was poured over talbina, then she said: Eat it, for I heard Allah's Messenger (may peade be upon him) as saying: Talbina gives comfort to the aggrieved heart and it lessens grief}}
\hadithdefcmd{muslim}{5770}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ أَخِي اسْتَطْلَقَ بَطْنُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْقِهِ عَسَلاً ‏"‏ ‏.‏ فَسَقَاهُ ثُمَّ جَاءَهُ فَقَالَ إِنِّي سَقَيْت��هُ عَسَلاً فَلَمْ يَزِدْهُ إِلاَّ اسْتِطْلاَقًا ‏.‏ فَقَالَ لَهُ ثَلاَثَ مَرَّاتٍ ثُمَّ جَاءَ الرَّابِعَةَ فَقَالَ ‏"‏ اسْقِهِ عَسَلاً ‏"‏ ‏.‏ فَقَالَ لَقَدْ سَقَيْتُهُ فَلَمْ يَزِدْهُ إِلاَّ اسْتِطْلاَقًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقَ اللَّهُ وَكَذَبَ بَطْنُ أَخِيكَ ‏"‏ ‏.‏ فَسَقَاهُ فَبَرَأَ ‏.‏\hadithno{5770}\hadithtrans{Abu Sa'id Khudri reported that a person came to Allah's Apostle (ﷺ) and told him that his brother's bowels were loose. Thereupon Allah's Messenger (ﷺ) said:Give him honey. So he gave him that and then came and said: I gave him honey but it has only made his bowels more loose. He said this three times; and then he came the fourth time, and he (the Holy Prophet) said: Give him honey. He said: I did give him, but it has only made his bowels more loose, whereupon Allah's Messenger (ﷺ) said: Allah has spoken the truth and your brother's bowels are in the wrong. So he made him drink (honey) and he was recovered}}
\hadithdefcmd{muslim}{5771}{وَحَدَّثَنِيهِ عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي ابْنَ عَطَاءٍ - عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمُتَوَكِّلِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ أَخِي عَرِبَ بَطْنُهُ ‏.‏ فَقَالَ لَهُ ‏ "‏ اسْقِهِ عَسَلاً ‏"‏ ‏.‏ بِمَعْنَى حَدِيثِ شُعْبَةَ ‏.‏\hadithno{5771}\hadithtrans{This hadith has been narrated on the authority of Abu Sa'id Khudri through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5772}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَأَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَهُ يَسْأَلُ، أُسَامَةَ بْنَ زَيْدٍ مَاذَا سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الطَّاعُونِ فَقَالَ أُسَامَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الطَّاعُونُ رِجْزٌ أَوْ عَذَابٌ أُرْسِلَ عَلَى بَنِي إِسْرَائِيلَ أَوْ عَلَى مَنْ كَانَ قَبْلَكُمْ فَإِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏ ‏.‏ وَقَالَ أَبُو النَّضْرِ ‏"‏ لاَ يُخْرِجُكُمْ إِلاَّ فِرَارٌ مِنْهُ ‏"‏ ‏.‏\hadithno{5772}\hadithtrans{Amir b. Sa'd b. Abu Waqqas reported on the authority of his father that he asked Usama b. Zaid:What have you heard from Allah's Messenger (ﷺ) about plague? Thereupon Usama said: Allah's Messenger (ﷺ) said: Plague is a calamity which was sent to Bani Isra'il or upon those who were before you. So when you hear that it has broken out in a land, don't go to it, and when it has broken out in the land where you are, don't run out of it. In the narration transmitted on the authority of Abu Nadr there is a slight variation of wording}}
\hadithdefcmd{muslim}{5773}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ أَخْبَرَنَا الْمُغِيرَةُ، - وَنَسَبَهُ ابْنُ قَعْنَبٍ فَقَالَ ابْنُ عَبْدِ الرَّحْمَنِ الْقُرَشِيُّ - عَنْ أَبِي النَّضْرِ، عَنْ عَامِرِ بْنِ سَعْدِ، بْنِ أَبِي وَقَّاصٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الطَّاعُونُ آيَةُ الرِّجْزِ ابْتَلَى اللَّهُ عَزَّ وَجَلَّ بِهِ نَاسًا مِنْ عِبَادِهِ فَإِذَا سَمِعْتُمْ بِهِ فَلاَ تَدْخُلُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَفِرُّوا مِنْهُ ‏"‏ ‏.‏ هَذَا حَدِيثُ الْقَعْنَبِيِّ وَقُتَيْبَةَ نَحْوَهُ ‏.‏\hadithno{5773}\hadithtrans{Usama b. Zaid reported that Allah's Messenger (ﷺ) had said:Plague is the sign of a calamity with which Allah, the Exalted and Glorious, affects people from His servants. So when you hear about it, don't enter there (where it has broken out), and when it has broken out in a land and you are there, then don't run away from it}}
\hadithdefcmd{muslim}{5774}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أُسَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذَا الطَّاعُونَ رِجْزٌ سُلِّطَ عَلَى مَنْ كَانَ قَبْلَكُمْ أَوْ عَلَى بَنِي إِسْرَائِيلَ فَإِذَا كَانَ بِأَرْضٍ فَلاَ تَخْرُجُوا مِنْهَا فِرَارًا مِنْهُ وَإِذَا كَانَ بِأَرْضٍ فَلاَ تَدْخُلُوهَا ‏"‏ ‏.‏\hadithno{5774}\hadithtrans{Usama reported Allah's Messenger (ﷺ) as saying:Plague is a calamity which was inflicted on those who were before you, or upon Bani Isra'il. So when it has broken out in a land, don't run out of it, and when it has spread in a land, then don't enter it}}
\hadithdefcmd{muslim}{5775}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو، بْنُ دِينَارٍ أَنَّ عَامِرَ بْنَ سَعْدٍ، أَخْبَرَهُ أَنَّ رَجُلاً سَأَلَ سَعْدَ بْنَ أَبِي وَقَّاصٍ عَنِ الطَّاعُونِ، فَقَالَ أُسَامَةُ بْنُ زَيْدٍ أَنَا أُخْبِرُكَ عَنْهُ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ عَذَابٌ أَوْ رِجْزٌ أَرْسَلَهُ اللَّهُ عَلَى طَائِفَةٍ مِنْ بَنِي إِسْرَائِيلَ أَوْ نَاسٍ كَانُوا قَبْلَكُمْ فَإِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَدْخُلُوهَا عَلَيْهِ وَإِذَا دَخَلَهَا عَلَيْكُمْ فَلاَ تَخْرُجُوا مِنْهَا فِرَارًا ‏"‏ ‏.‏\hadithno{5775}\hadithtrans{Amir b. Sa'd reported that a person asked Sa'd b. Abu Waqqas about the plague, whereupon Usama b. Zaid said:I would inform you about it. The Messenger of Allah (ﷺ) said: It is a calamity or a disease which Allah sent to a group of Bani Isra'il, or to the people who were before you; so when you hear of it in land, don't enter it and when it has broken out in your land, don't run away from it}}
\hadithdefcmd{muslim}{5776}{وَحَدَّثَنَا أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ وَقُتَيْبَةُ بْنُ سَعِيدٍ قَالاَ حَدَّثَنَا حَمَّادٌ، وَهُوَ ابْنُ زَيْدٍ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، كِلاَهُمَا عَنْ عَمْرِو بْنِ، دِينَارٍ بِإِسْنَادِ ابْنِ جُرَيْجٍ نَحْوَ حَدِيثِهِ ‏.‏\hadithno{5776}\hadithtrans{This hadith has been narrated on the authority of Ibn Juraij through another chain of transmitters}}
\hadithdefcmd{muslim}{5777}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرٍو وَحَرْمَلَةُ بْنُ يَحْيَى قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ هَذَا الْوَجَعَ أَوِ السَّقَمَ رِجْزٌ عُذِّبَ بِهِ بَعْضُ الأُمَمِ قَبْلَكُمْ ثُمَّ بَقِيَ بَعْدُ بِالأَرْضِ فَيَذْهَبُ الْمَرَّةَ وَيَأْتِي الأُخْرَى فَمَنْ سَمِعَ بِهِ بِأَرْضٍ فَلاَ يَقْدَمَنَّ عَلَيْهِ وَمَنْ وَقَعَ بِأَرْضٍ وَهُوَ بِهَا فَلاَ يُخْرِجَنَّهُ الْفِرَارُ مِنْهُ ‏"‏ ‏.‏\hadithno{5777}\hadithtrans{Usama b. Zaid reported Allah's Messenger (ﷺ) having said this:This calamity or illness was a punishment with which were punished some of the nations before you. Then it was left upon the earth. It goes away once and comes back again. He who heard of its presence in a land should not go towards it, and he who happened to be in a land where it had broken out should not fly from it}}
\hadithdefcmd{muslim}{5778}{وَحَدَّثَنَاهُ أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِإِسْنَادِ يُونُسَ نَحْوَ حَدِيثِهِ ‏.‏\hadithno{5778}\hadithtrans{This hadith has been narrated on the authority of Zuhri with a different chain of transmitters}}
\hadithdefcmd{muslim}{5779}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ حَبِيبٍ، قَالَ كُنَّا بِالْمَدِينَةِ فَبَلَغَنِي أَنَّ الطَّاعُونَ قَدْ وَقَعَ بِالْكُوفَةِ فَقَالَ لِي عَطَاءُ بْنُ يَسَارٍ وَغَيْرُهُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا كُنْتَ بِأَرْضٍ فَوَقَعَ بِهَا فَلاَ تَخْرُجْ مِنْهَا وَإِذَا بَلَغَكَ أَنَّهُ بِأَرْضٍ فَلاَ تَدْخُلْهَا ‏"‏ ‏.‏ قَالَ قُلْتُ عَمَّنْ قَالُوا عَنْ عَامِرِ بْنِ سَعْدٍ يُحَدِّثُ بِهِ ‏.‏ قَالَ فَأَتَيْتُهُ فَقَالُوا غَائِبٌ - قَالَ - فَلَقِيتُ أَخَاهُ إِبْرَاهِيمَ بْنَ سَعْدٍ فَسَأَلْتُهُ فَقَالَ شَهِدْتُ أُسَامَةَ يُحَدِّثُ سَعْدًا قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ هَذَا الْوَجَعَ رِجْزٌ أَوْ عَذَابٌ أَوْ بَقِيَّةُ عَذَابٍ عُذِّبَ بِهِ أُنَاسٌ مِنْ قَبْلِكُمْ فَإِذَا كَانَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا مِنْهَا وَإِذَا بَلَغَكُمْ أَنَّهُ بِأَرْضٍ فَلاَ تَدْخُلُوهَا ‏"‏ ‏.‏ قَالَ حَبِيبٌ فَقُلْتُ لإِبْرَاهِيمَ آنْتَ سَمِعْتَ أُسَامَةَ يُحَدِّثُ سَعْدًا وَهُوَ لاَ يُنْكِرُ قَالَ نَعَمْ ‏.‏\hadithno{5779}\hadithtrans{Shu'ba reported from Habib:While we were in Medina we heard of plague having broken out in Kufa. 'Ata b. Yasir and others said to me that Allah's Messenger (ﷺ) had said. If you are in a land where it (this scourge) has broken out, don't get out of it, and if you were to know that it had broken (in another land, then don't enter it. I said to him: From whom (did you hear it)? They said: 'Amir b. Sa'd has narrated it. So I came to him. They said that he was not present there. So I met his brother Ibrahim b. Sa'd and asked him. He said: I bear testimony to the fact that Usama narrated it to Sa'd saying: I heard Allah's Messenger (ﷺ) as saying that it is a God-sent punishment from the calamity or from the remnant of the calamity with which people were afflicted before you. So when it is in a land and you are there, don't get out of it, and if (this news reaches you) that it has broken out in a land, then don't enter therein. Habib said: I said to Ibrahim: Did you hear Usama narrating it to Sa'd and he was not denying it. He said: Yes}}
\hadithdefcmd{muslim}{5780}{وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ قِصَّةَ عَطَاءِ بْنِ يَسَارٍ فِي أَوَّلِ الْحَدِيثِ ‏.‏\hadithno{5780}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters except for the fact that no mention has been made of the account of 'Ata b. Yasir as in the previous hadith}}
\hadithdefcmd{muslim}{5781}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبٍ، عَنْ إِبْرَاهِيمَ، بْنِ سَعْدٍ عَنْ سَعْدِ بْنِ مَالِكٍ، وَخُزَيْمَةَ بْنِ ثَابِتٍ، وَأُسَامَةَ بْنِ زَيْدٍ، قَالُوا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ شُعْبَةَ ‏.‏\hadithno{5781}\hadithtrans{This hadith has been transmitted on the authority of Sa'd b. Malik, Khuzaima b. Thabit and Usama b. Zaid}}
\hadithdefcmd{muslim}{5782}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرٍ، عَنِ الأَعْمَشِ، عَنْ حَبِيبٍ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ كَانَ أُسَامَةُ بْنُ زَيْدٍ وَسَعْدٌ جَالِسَيْنِ يَتَحَدَّثَانِ فَقَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{5782}\hadithtrans{Ibrahim b. Sa'd b. Abu Waqqas reported:Usama b. Zaid and Sa'd had been sitting and they had been conversing and they said this hadith}}
\hadithdefcmd{muslim}{5783}{وَحَدَّثَنِيهِ وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، - يَعْنِي الطَّحَّانَ - عَنِ الشَّيْبَانِيِّ، عَنْ حَبِيبِ، بْنِ أَبِي ثَابِتٍ عَنْ إِبْرَاهِيمَ بْنِ سَعْدِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{5783}\hadithtrans{This hadith has been transmitted by Ibrahim b. Sa'd b. Malik on the authority of his father}}
\hadithdefcmd{muslim}{5784}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ، الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَرَجَ إِلَى الشَّامِ حَتَّى إِذَا كَانَ بِسَرْغَ لَقِيَهُ أَهْلُ الأَجْنَادِ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ وَأَصْحَابُهُ فَأَخْبَرُوهُ أَنَّ الْوَبَاءَ قَدْ وَقَعَ بِالشَّامِ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَقَالَ عُمَرُ ادْعُ لِيَ الْمُهَاجِرِينَ الأَوَّلِينَ ‏.‏ فَدَعَوْتُهُمْ فَاسْتَشَارَهُمْ وَأَخْبَرَهُمْ أَنَّ الْوَبَاءَ قَدْ وَقَعَ بِالشَّامِ فَاخْتَلَفُوا فَقَالَ بَعْضُهُمْ قَدْ خَرَجْتَ لأَمْرٍ وَلاَ نَرَى أَنْ تَرْجِعَ عَنْهُ ‏.‏ وَقَالَ بَعْضُهُمْ مَعَكَ بَقِيَّةُ النَّاسِ وَأَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ نَرَى أَنْ تُقْدِمَهُمْ عَلَى هَذَا الْوَبَاءِ ‏.‏ فَقَالَ ارْتَفِعُوا عَنِّي ‏.‏ ثُمَّ قَالَ ادْعُ لِيَ الأَنْصَارَ فَدَعَوْتُهُمْ لَهُ فَاسْتَشَارَهُمْ فَسَلَكُوا سَبِيلَ الْمُهَاجِرِينَ وَاخْتَلَفُوا كَاخْتِلاَفِهِمْ ‏.‏ فَقَالَ ارْتَفِعُوا عَنِّي ‏.‏ ثُمَّ قَالَ ادْعُ لِي مَنْ كَانَ هَا هُنَا مِنْ مَشْيَخَةِ قُرَيْشٍ مِنْ مُهَاجِرَةِ الْفَتْحِ ‏.‏ فَدَعَوْتُهُمْ فَلَمْ يَخْتَلِفْ عَلَيْهِ رَجُلاَنِ فَقَالُوا نَرَى أَنْ تَرْجِعَ بِالنَّاسِ وَلاَ تُقْدِمْهُمْ عَلَى هَذَا الْوَبَاءِ ‏.‏ فَنَادَى عُمَرُ فِي النَّاسِ إِنِّي مُصْبِحٌ عَلَى ظَهْرٍ فَأَصْبِحُوا عَلَيْهِ ‏.‏ فَقَالَ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ أَفِرَارًا مِنْ قَدَرِ اللَّهِ فَقَالَ عُمَرُ لَوْ غَيْرُكَ قَالَهَا يَا أَبَا عُبَيْدَةَ - وَكَانَ عُمَرُ يَكْرَهُ خِلاَفَهُ - نَعَمْ نَفِرُّ مِنْ قَدَرِ اللَّهِ إِلَى قَدَرِ اللَّهِ أَرَأَيْتَ لَوْ كَانَتْ لَكَ إِبِلٌ فَهَبَطْتَ وَادِيًا لَهُ عِدْوَتَانِ إِحْدَاهُمَا خَصْبَةٌ وَالأُخْرَى جَدْبَةٌ أَلَيْسَ إِنْ رَعَيْتَ الْخَصْبَةَ رَعَيْتَهَا بِقَدَرِ اللَّهِ وَإِنْ رَعَيْتَ الْجَدْبَةَ رَعَيْتَهَا بِقَدَرِ اللَّهِ قَالَ فَجَاءَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ وَكَانَ مُتَغَيِّبًا فِي بَعْضِ حَاجَتِهِ فَقَالَ إِنَّ عِنْدِي مِنْ هَذَا عِلْمًا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏ ‏.‏ قَالَ فَحَمِدَ اللَّهَ عُمَرُ بْنُ الْخَطَّابِ ثُمَّ انْصَرَفَ ‏.‏\hadithno{5784}\hadithtrans{Abdullah b. 'Abbas reported:Umar b. Khattab set out for Syria. As he came at Sargh (a town by the side of Hijaz on the way to Syria), there met him the commander of the forces, Abu Ubaida b. Jandb, and his companions. They informed him that a scourge had broken out in Syria. Ibn 'Abbas further reported that 'Umar said: Call to me tile earliest emigrants. So I called them. He (Hadrat 'Umar) sought their advice, and they told him that the scourge had broker, out in Syria. There was a difference of opinion (whether they should proceed further or go back to their homes in such a situation). Some of them said: You ('Umar) have set forth for a task, and, therefore, we would not advise you to go back, whereas some of them said: You have along with you the remnants (of the sacred galaxy) of men and (the blessed) Companions of Allah's Messenger (ﷺ), so we would not advise you to go forth towards this calamity (with such eminent persons and thus expose them deliberately to a danger). He (Hadrat 'Umar) said: You can now go away. He said: Call to me the Ansar. So I called them to him, and he consulted them, and they trod the same path as was trodden by the Muhajirin, and they differed in their opinions as they had differed. He said: Now, you can go. He again said: Call to me the old persons of the Quraish who had migrated before the Victory (that is the Victory of Mecca), so I called them (and Hadrat 'Umar consulted them) and not even two persons differed (from the opinion held by the earlier delegates). They said: Our opinion is that you better go back along with the people and do not make them go to this scourge, So 'Umar made announcement to the people: In the morning I would be on the back of my side. So they (set forth in the morning), whereupon Abu 'Ubaida b. Jarrah said: Are you going to run away from the Divine Decree? Thereupon 'Umar said: Had it been someone else to say this besides you! 'Umar (in fact) did not approve of his opposing (this decision) and he said: Yes, we are running from the Divine Decree (to the) Divine Decree. You should think if there had been camels for you and you happened to get down in a valley having two sides, one of them covered with verdure and the other being barren, would you not (be doing) according to the Divine Decree if you graze them in verdure? And in case you graze them in the barren land (even then you would be grazing them) according to the Divine Decree. There happened to come 'Abd al-Rahman b. 'Auf and he had been absent in connection with some of his needs. He said: I have with me a knowledge of it, that I heard Allah's Messenger (ﷺ) as saying: If you hear of its presence (the presence of plague) in a land, don't enter it, but if it spreads in the land where you are, don't fly from it. Thereupon 'Umar b. Khattab praised Allah and then went back?}}
\hadithdefcmd{muslim}{5785}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ مَالِكٍ وَزَادَ فِي حَدِيثِ مَعْمَرٍ قَالَ وَقَالَ لَهُ أَيْضًا أَرَأَيْتَ أَنَّهُ لَوْ رَعَى الْجَدْبَةَ وَتَرَكَ الْخَصْبَةَ أَكُنْتَ مُعَجِّزَهُ قَالَ نَعَمْ ‏.‏ قَالَ فَسِرْ إِذًا ‏.‏ قَالَ فَسَارَ حَتَّى أَتَى الْمَدِينَةَ فَقَالَ هَذَا الْمَحِلُّ ‏.‏ أَوْ قَالَ هَذَا الْمَنْزِلُ إِنْ شَاءَ اللَّهُ ‏.‏\hadithno{5785}\hadithtrans{This hadith has been reported on the authority of Ma'mar with the same chain of transmitters but with this addition:" Do you think that he would graze in the barren land but would abandon the green land? Would you not attribute it to be a failing on his part? He said: Yes. He said: Then proceed. And he moved on until he came to Medina. And he said to me: This is the right place, or he said: That is the destination if Allah so wills}}
\hadithdefcmd{muslim}{5786}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ إِنَّ عَبْدَ اللَّهِ بْنَ الْحَارِثِ حَدَّثَهُ ‏.‏ وَلَمْ يَقُلْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ ‏.‏\hadithno{5786}\hadithtrans{This hadith has been transmitted on the authority of 'Abdullah b. Harith with a slight variation of wording}}
\hadithdefcmd{muslim}{5787}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ، عَامِرِ بْنِ رَبِيعَةَ أَنَّ عُمَرَ، خَرَجَ إِلَى الشَّامِ فَلَمَّا جَاءَ سَرْغَ بَلَغَهُ أَنَّ الْوَبَاءَ قَدْ وَقَعَ بِالشَّامِ ‏.‏ فَأَخْبَرَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ ‏.‏ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏ ‏.‏ فَرَجَعَ عُمَرُ بْنُ الْخَطَّابِ مِنْ سَرْغَ ‏.‏ وَعَنِ ابْنِ شِهَابٍ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ أَنَّ عُمَرَ إِنَّمَا انْصَرَفَ بِالنَّاسِ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ‏.‏\hadithno{5787}\hadithtrans{Amir b. Rabi'ah reported:'Umar went to Syria and as he came to Sargh, information was given to him that an epidemic had broken out in Syria. 'Abd al-Rahman b. 'Auf narrated to him that Allah's Messenger (ﷺ) had said: When you hear of its presence in a land, don't move towards it, and when it breaks out in a land and you are therein, then don't run away from it. So 'Umar b. Khattab came back from Sargh. Salim b. 'Abdullah reported that 'Umar went back, along with people on hearing the hadith reported on the authority of 'Abd al-Rahman b. 'Auf}}
\hadithdefcmd{muslim}{5788}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لأَبِي الطَّاهِرِ - قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، قَالَ ابْنُ شِهَابٍ فَحَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي، هُرَيْرَةَ حِينَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ عَدْوَى وَلاَ صَفَرَ وَلاَ هَامَةَ ‏"‏ ‏.‏ فَقَالَ أَعْرَابِيٌّ يَا رَسُولَ اللَّهِ فَمَا بَالُ الإِبِلِ تَكُونُ فِي الرَّمْلِ كَأَنَّهَا الظِّبَاءُ فَيَجِيءُ الْبَعِيرُ الأَجْرَبُ فَيَدْخُلُ فِيهَا فَيُجْرِبُهَا كُلَّهَا قَالَ ‏"‏ فَمَنْ أَعْدَى الأَوَّلَ ‏"‏ ‏.‏\hadithno{5788}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no infection, no safar, no hama. A desert Arab said: Allah's Messenger, how is it that when the camel is in the sand it is like a deer-then a camel afflicted with scab mixes with it and it is affected by sub? He (the Holy Prophet) said: Who infected the first one? Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{muslim}{5789}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَحَسَنٌ الْحُلْوَانِيُّ، قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَغَيْرُهُ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَلاَ صَفَرَ وَلاَ هَامَةَ ‏"‏ ‏.‏ فَقَالَ أَعْرَابِيٌّ يَا رَسُولَ اللَّهِ ‏.‏ بِمِثْلِ حَدِيثِ يُونُسَ ‏.‏\hadithno{5789}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no evil omen, no safar, no hama. A desert Arab said: Allah's, Messenger.... The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5790}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سِنَانُ بْنُ أَبِي سِنَانٍ الدُّؤَلِيُّ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ عَدْوَى ‏"‏ ‏.‏ فَقَامَ أَعْرَابِيٌّ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ يُونُسَ وَصَالِحٍ ‏.‏ وَعَنْ شُعَيْبٍ عَنِ الزُّهْرِيِّ قَالَ حَدَّثَنِي السَّائِبُ بْنُ يَزِيدَ ابْنُ أُخْتِ نَمِرٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى وَلاَ صَفَرَ وَلاَ هَامَةَ ‏"‏ ‏.‏\hadithno{5790}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no trahsitive disease. Thereupon a desert Arab stood up. The rest of the hadith is the same and in the hadith transmitted on the authority of Zuhri' the Prophet (ﷺ) is reported to have said: There is no transitive disease, no safar, no hama}}
\hadithdefcmd{muslim}{5791}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى ‏"‏ ‏.‏ وَيُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يُورِدُ مُمْرِضٌ عَلَى مُصِحٍّ ‏"‏ ‏.‏ قَالَ أَبُو سَلَمَةَ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُهُمَا كِلْتَيْهِمَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ صَمَتَ أَبُو هُرَيْرَةَ بَعْدَ ذَلِكَ عَنْ قَوْلِهِ ‏"‏ لاَ عَدْوَى ‏"‏ ‏.‏ وَأَقَامَ عَلَى ‏"‏ أَنْ لاَ يُورِدُ مُمْرِضٌ عَلَى مُصِحٍّ ‏"‏ ‏.‏ قَالَ فَقَالَ الْحَارِثُ بْنُ أَبِي ذُبَابٍ - وَهُوَ ابْنُ عَمِّ أَبِي هُرَيْرَةَ - قَدْ كُنْتُ أَسْمَعُكَ يَا أَبَا هُرَيْرَةَ تُحَدِّثَنَا مَعَ هَذَا الْحَدِيثِ حَدِيثًا آخَرَ قَدْ سَكَتَّ عَنْهُ كُنْتَ تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ عَدْوَى ‏"‏ ‏.‏ فَأَبَى أَبُو هُرَيْرَةَ أَنْ يَعْرِفَ ذَلِكَ وَقَالَ ‏"‏ لاَ يُورِدُ مُمْرِضٌ عَلَى مُصِحٍّ ‏"‏ ‏.‏ فَمَا رَآهُ الْحَارِثُ فِي ذَلِكَ حَتَّى غَضِبَ أَبُو هُرَيْرَةَ فَرَطَنَ بِالْحَبَشِيَّةِ فَقَالَ لِلْحَارِثِ أَتَدْرِي مَاذَا قُلْتُ قَالَ لاَ ‏.‏ قَالَ أَبُو هُرَيْرَةَ ‏.‏ قُلْتُ أَبَيْتُ ‏.‏ قَالَ أَبُو سَلَمَةَ وَلَعَمْرِي لَقَدْ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى ‏"‏ ‏.‏ فَلاَ أَدْرِي أَنَسِيَ أَبُو هُرَيْرَةَ أَوْ نَسَخَ أَحَدُ الْقَوْلَيْنِ الآخَرَ\hadithno{5791}\hadithtrans{Abu Salama h. 'Abd al-Rahman b. 'Auf reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, but he is also reported to have said: A sick person should not be taken to one who is healthy. Abu Salama said that Abu Huraira used to narrate these two (different ahadith) from Allah's Messenger (ﷺ), but afterwards Abu Huraira became silent on these words:" There is no transitive disease," but he stuck to this that the sick person should not be taken to one who is healthy. Harith b. Abu Dhubab (and he was the first cousin of Abu Huraira) said: Abu Huraira, I used to hear from you that you narrated to us along with this hadith and the other one also (there is no transitive disease), but now you observe silence about it. You used to say that Allah's Messenger (ﷺ) said: There is no transitive disease. Abu Huraira denied having any knowledge of that, but he said that the sick camel should not be taken to the healthy one. Harith, however, did not agree with him, which irritated Abu Huraira and he said to him some words in the Abyssinian language. He said to Harith: Do you know what I said to you? He said: No. Abu Huraira said: I simply denied having said it. Abu Salama sad: By my life, Abu Huraira in fact used to report Allah's Messenger (ﷺ) having said: There is no transitive disease. I do not know whether Abu Huraira has forgotten it or he deemed it an abrogated statement in the light of the other one}}
\hadithdefcmd{muslim}{5792}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ حَدَّثَنِي وَقَالَ، الآخَرَانِ حَدَّثَنَا يَعْقُوبُ، - يَعْنُونَ ابْنَ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ، شِهَابٍ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى ‏"‏ ‏.‏ وَيُحَدِّثُ مَعَ ذَلِكَ ‏"‏ لاَ يُورِدُ الْمُمْرِضُ عَلَى الْمُصِحِّ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ يُونُسَ ‏.‏\hadithno{5792}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no transitive disease and he also reported along with it: The ill should not be taken to the healthy}}
\hadithdefcmd{muslim}{5793}{حَدَّثَنَاهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{5793}\hadithtrans{This hadith has been reported on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{5794}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى وَلاَ هَامَةَ وَلاَ نَوْءَ وَلاَ صَفَرَ ‏"‏ ‏.‏\hadithno{5794}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no huma, no star promising rain, no safar}}
\hadithdefcmd{muslim}{5795}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَلاَ غُولَ ‏"‏ ‏.‏\hadithno{5795}\hadithtrans{Jabir reported Allal's Messenger (ﷺ) as saying:There is no transitive disease, no ill omen, no ghoul. Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{muslim}{5796}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمِ بْنِ حَيَّانَ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا يَزِيدُ، - وَهُوَ التُّسْتَرِيُّ - حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَدْوَى وَلاَ غُولَ وَلاَ صَفَرَ ‏"‏ ‏.‏\hadithno{5796}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no ghoul, no safar}}
\hadithdefcmd{muslim}{5797}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ عَدْوَى وَلاَ صَفَرَ وَلاَ غُولَ ‏"‏ ‏.‏ وَسَمِعْتُ أَبَا الزُّبَيْرِ يَذْكُرُ أَنَّ جَابِرًا فَسَّرَ لَهُمْ قَوْلَهُ ‏"‏ وَلاَ صَفَرَ ‏"‏ ‏.‏ فَقَالَ أَبُو الزُّبَيْرِ الصَّفَرُ الْبَطْنُ ‏.‏ فَقِيلَ لِجَابِرٍ كَيْفَ قَالَ كَانَ يُقَالُ دَوَابُّ الْبَطْنِ ‏.‏ قَالَ وَلَمْ يُفَسِّرِ الْغُولَ ‏.‏ قَالَ أَبُو الزُّبَيْرِ هَذِهِ الْغُولُ الَّتِي تَغَوَّلُ ‏.‏\hadithno{5797}\hadithtrans{Jabir b. 'Abdullah reported Allah's Apostle (ﷺ) as saying:There is no transitive disease, no safar, no ghoul. He (the narrator) said: I heard Abu Zubair say: Jabir explained for them the word safar. Abu Zubair said: safar means belly. It was said to Jabir: Why is it so? He said that it was held that safar implied the worms of the belly, but he gave no explanation of ghoul. Abu Zubair said: Ghoul is that which kills the travellers}}
\hadithdefcmd{muslim}{5798}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ، اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ طِيَرَةَ وَخَيْرُهَا الْفَأْلُ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا الْفَأْلُ قَالَ ‏"‏ الْكَلِمَةُ الصَّالِحَةُ يَسْمَعُهَا أَحَدُكُمْ ‏"‏ ‏.‏\hadithno{5798}\hadithtrans{Abu Huraira reported:I heard Allah's Messenger (ﷺ) as saying: There is no divination but the best type is the good omen. It was said to Allah's Messenger (ﷺ): What is good omen? Thereupon he said: A good word which one of you hears}}
\hadithdefcmd{muslim}{5799}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ ح وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ وَفِي حَدِيثِ عُقَيْلٍ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَلَمْ يَقُلْ سَمِعْتُ ‏.‏ وَفِي حَدِيثِ شُعَيْبٍ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم كَمَا قَالَ مَعْمَرٌ ‏.‏\hadithno{5799}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5800}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَيُعْجِبُنِي الْفَأْلُ الْكَلِمَةُ الْحَسَنَةُ الْكَلِمَةُ الطَّيِّبَةُ ‏"‏ ‏.‏\hadithno{5800}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no divination, but good omen pleases me, i. e. the good word or a good word. Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{muslim}{5801}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَيُعْجِبُنِي الْفَأْلُ ‏"‏ ‏.‏ قَالَ قِيلَ وَمَا الْفَأْلُ قَالَ ‏"‏ الْكَلِمَةُ الطَّيِّبَةُ ‏"‏ ‏.‏\hadithno{5801}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no divination, but good omen pleases me. It was said: What is good omen? He said: Sacred words}}
\hadithdefcmd{muslim}{5802}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنِي مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُخْتَارٍ، حَدَّثَنَا يَحْيَى بْنُ عَتِيقٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَأُحِبُّ الْفَأْلَ الصَّالِحَ ‏"‏ ‏.‏\hadithno{5802}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no divination, but I like good words}}
\hadithdefcmd{muslim}{5803}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَدْوَى وَلاَ هَامَةَ وَلاَ طِيَرَةَ وَأُحِبُّ الْفَأْلَ الصَّالِحَ ‏"‏ ‏.‏\hadithno{5803}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no hama, no divination, but I like good omen}}
\hadithdefcmd{muslim}{5804}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، ح وَحَدَّثَنَا يَحْيَى، بْنُ يَحْيَى قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ، وَسَالِمٍ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّؤْمُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏\hadithno{5804}\hadithtrans{Abdullah b. 'Umar reported Allah's Messenger (ﷺ) as saying:If there be bad luck, it is in the house, and the wife, and the horse}}
\hadithdefcmd{muslim}{5805}{وَحَدَّثَنَا أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ، وَسَالِمٍ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَإِنَّمَا الشُّؤْمُ فِي ثَلاَثَةٍ الْمَرْأَةِ وَالْفَرَسِ وَالدَّارِ ‏"‏ ‏.‏\hadithno{5805}\hadithtrans{Abdullah b. 'Umar reported Allah's Messenger (ﷺ) as saying:There is no transitive disease, no ill omen, and bad luck is lound in the house, or wife or horse. Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{muslim}{5806}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، وَحَمْزَةَ، ابْنَىْ عَبْدِ اللَّهِ عَنْ أَبِيهِمَا، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، وَحَمْزَةَ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، ح وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ، إِسْحَاقَ ح وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الشُّؤْمِ ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ لاَ يَذْكُرُ أَحَدٌ مِنْهُمْ فِي حَدِيثِ ابْنِ عُمَرَ الْعَدْوَى وَالْطِّيَرَةَ غَيْرُ يُونُسَ بْنِ يَزِيدَ ‏.‏\hadithno{5806}\hadithtrans{This hadith has been reported on the authority of Zuhri with other chains of transmitters but with slight variations of wording}}
\hadithdefcmd{muslim}{5807}{وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عُمَرَ بْنِ مُحَمَّدِ بْنِ زَيْدٍ، أَنَّهُ سَمِعَ أَبَاهُ، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنْ يَكُنْ مِنَ الشُّؤْمِ شَىْءٌ حَقٌّ فَفِي الْفَرَسِ وَالْمَرْأَةِ وَالدَّارِ ‏"‏ ‏.‏\hadithno{5807}\hadithtrans{Umar b. Muhammad b. Zaid reported that he heard his father narrating from Ibn 'Umar that Allah's Messenger (ﷺ) had said. If bad luck is a fact, then it is in the horse, the woman and the house}}
\hadithdefcmd{muslim}{5808}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَلَمْ يَقُلْ ‏ "‏ حَقٌّ ‏"‏ ‏.‏\hadithno{5808}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters but there is no mention of the word" Haqq"" (fact)}}
\hadithdefcmd{muslim}{5809}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي عُتْبَةُ بْنُ مُسْلِمٍ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ الشُّؤْمُ فِي شَىْءٍ فَفِي الْفَرَسِ وَالْمَسْكَنِ وَالْمَرْأَةِ ‏"‏ ‏.‏\hadithno{5809}\hadithtrans{Abdullah b. 'Umar reported on the authority of his father that Allah's Messenger (ﷺ) said:If there is bad luck in anything, it is the horse, the abode and the woman}}
\hadithdefcmd{muslim}{5810}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ، سَعْدٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ كَانَ فَفِي الْمَرْأَةِ وَالْفَرَسِ وَالْمَسْكَنِ ‏"‏ ‏.‏ يَعْنِي الشُّؤْمَ ‏.‏\hadithno{5810}\hadithtrans{Sahl b. Sa'd reported Allah's Messenger (ﷺ) as saying:If bad luck were to be in anything, it is found in the woman, the horse and the abode}}
\hadithdefcmd{muslim}{5811}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{5811}\hadithtrans{This hadith has been narrated on the authority of Sahl b. Sa'd with a different chain of transmitters}}
\hadithdefcmd{muslim}{5812}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ، عَنِ ابْنِ، جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يُخْبِرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ فَفِي الرَّبْعِ وَالْخَادِمِ وَالْفَرَسِ ‏"‏ ‏.‏\hadithno{5812}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:If bad luck were to be in anything, it is found in the land, in the servant and in the horse}}
\hadithdefcmd{muslim}{5813}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ مُعَاوِيَةَ بْنِ الْحَكَمِ السُّلَمِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أُمُورًا كُنَّا نَصْنَعُهَا فِي الْجَاهِلِيَّةِ كُنَّا نَأْتِي الْكُهَّانَ ‏.‏ قَالَ ‏"‏ فَلاَ تَأْتُوا الْكُهَّانَ ‏"‏ ‏.‏ قَالَ قُلْتُ كُنَّا نَتَطَيَّرُ ‏.‏ قَالَ ‏"‏ ذَاكَ شَىْءٌ يَجِدُهُ أَحَدُكُمْ فِي نَفْسِهِ فَلاَ يَصُدَّنَّكُمْ ‏"‏ ‏.‏\hadithno{5813}\hadithtrans{Mu'awiya b. al-Hakam as-Sulami reported:I said: Messenger of Allah, there were things we used to do in the pre-Islamic days. We used to visit Kahins, whereupon he said: Don't visit Kahins. I said: We used to take omens. He said: That is a sort of personal whim of yours, so let it not prevent you (from doing a thing)}}
\hadithdefcmd{muslim}{5814}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنِي حُجَيْنٌ، - يَعْنِي ابْنَ الْمُثَنَّى - حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، أَخْبَرَنَا إِسْحَاقُ بْنُ عِيسَى، أَخْبَرَنَا مَالِكٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ مَعْنَى حَدِيثِ يُونُسَ غَيْرَ أَنَّ مَالِكًا فِي حَدِيثِهِ ذَكَرَ الطِّيَرَةَ وَلَيْسَ فِيهِ ذِكْرُ الْكُهَّانِ ‏.‏\hadithno{5814}\hadithtrans{This hadith has been transmitted on the authority of Zuhri with a slight variation of wording}}
\hadithdefcmd{muslim}{5815}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ حَجَّاجٍ الصَّوَّافِ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَوْزَاعِيُّ، كِلاَهُمَا عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ، يَسَارٍ عَنْ مُعَاوِيَةَ بْنِ الْحَكَمِ السُّلَمِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمَعْنَى حَدِيثِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ مُعَاوِيَةَ وَزَادَ فِي حَدِيثِ يَحْيَى بْنِ أَبِي كَثِيرٍ قَالَ قُلْتُ وَمِنَّا رِجَالٌ يَخُطُّونَ قَالَ ‏ "‏ كَانَ نَبِيٌّ مِنَ الأَنْبِيَاءِ يَخُطُّ فَمَنْ وَافَقَ خَطُّهُ فَذَاكَ ‏"‏ ‏.‏\hadithno{5815}\hadithtrans{This hadith has been narrated on the authority of Mu'awiya b. Hakam as-Sulami through another chain of transmitters. The hadith transmitted on the authority of Yahya b. Abu Kathir (there is an addition of these words):I said: Among us there are men who draw lines and thus make divination. What about this? Thereupon he (the Holy Prophet) said: There was a Prophet who drew lines, so whose lines agree with his line for him it is allowable}}
\hadithdefcmd{muslim}{5816}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ يَحْيَى، بْنِ عُرْوَةَ بْنِ الزُّبَيْرِ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ الْكُهَّانَ كَانُوا يُحَدِّثُونَنَا بِالشَّىْءِ فَنَجِدُهُ حَقًّا قَالَ ‏ "‏ تِلْكَ الْكَلِمَةُ الْحَقُّ يَخْطَفُهَا الْجِنِّيُّ فَيَقْذِفُهَا فِي أُذُنِ وَلِيِّهِ وَيَزِيدُ فِيهَا مِائَةَ كَذْبَةٍ ‏"‏ ‏.‏\hadithno{5816}\hadithtrans{A'isha reported:I said: Allah's Messenger, the kahins used to tell us about things (unseen) and we found them to be true. Thereupon he said: That is a word pertaining to truth which a jinn snatches and throws into the ear of his friend, and makes an addition of one hundred lies to it}}
\hadithdefcmd{muslim}{5817}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - وَهْوَ ابْنُ عُبَيْدِ اللَّهِ - عَنِ الزُّهْرِيِّ، أَخْبَرَنِي يَحْيَى بْنُ عُرْوَةَ، أَنَّهُ سَمِعَ عُرْوَةَ، يَقُولُ قَالَتْ عَائِشَةُ سَأَلَ أُنَاسٌ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْكُهَّانِ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسُوا بِشَىْءٍ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَإِنَّهُمْ يُحَدِّثُونَ أَحْيَانًا الشَّىْءَ يَكُونُ حَقًّا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ الْكَلِمَةُ مِنَ الْجِنِّ يَخْطَفُهَا الْجِنِّيُّ فَيَقُرُّهَا فِي أُذُنِ وَلِيِّهِ قَرَّ الدَّجَاجَةِ فَيَخْلِطُونَ فِيهَا أَكْثَرَ مِنْ مِائَةِ كَذْبَةٍ ‏"‏ ‏.‏\hadithno{5817}\hadithtrans{Urwa reported from 'A'isha that she said that people asked Allah's Messenger (ﷺ) about the kahins. Allah's Messenger (ﷺ) said to them:It is nothing (i. e. it is a mere superstition). They said: Allah's Messenger, they at times narrate to us things which we find true. Thereupon Allah's Messenger (ﷺ) said: That is a word pertaining to truth which a jinn snatches away and then cackles into the ear of his friend as the hen does. And then they mix in it more than one hundred lies}}
\hadithdefcmd{muslim}{5818}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مُحَمَّدُ بْنُ عَمْرٍو، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ نَحْوَ رِوَايَةِ مَعْقِلٍ عَنِ الزُّهْرِيِّ، ‏.‏\hadithno{5818}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{5819}{حَدَّثَنَا حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ حَسَنٌ حَدَّثَنَا يَعْقُوبُ، وَقَالَ، عَبْدٌ حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالَ أَخْبَرَنِي رَجُلٌ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنَ الأَنْصَارِ أَنَّهُمْ بَيْنَمَا هُمْ جُلُوسٌ لَيْلَةً مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رُمِيَ بِنَجْمٍ فَاسْتَنَارَ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَاذَا كُنْتُمْ تَقُولُونَ فِي الْجَاهِلِيَّةِ إِذَا رُمِيَ بِمِثْلِ هَذَا ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ كُنَّا نَقُولُ وُلِدَ اللَّيْلَةَ رَجُلٌ عَظِيمٌ وَمَاتَ رَجُلٌ عَظِيمٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّهَا لاَ يُرْمَى بِهَا لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنْ رَبُّنَا تَبَارَكَ وَتَعَالَى اسْمُهُ إِذَا قَضَى أَمْرًا سَبَّحَ حَمَلَةُ الْعَرْشِ ثُمَّ سَبَّحَ أَهْلُ السَّمَاءِ الَّذِينَ يَلُونَهُمْ حَتَّى يَبْلُغَ التَّسْبِيحُ أَهْلَ هَذِهِ السَّمَاءِ الدُّنْيَا ثُمَّ قَالَ الَّذِينَ يَلُونَ حَمَلَةَ الْعَرْشِ لِحَمَلَةِ الْعَرْشِ مَاذَا قَالَ رَبُّكُمْ فَيُخْبِرُونَهُمْ مَاذَا قَالَ - قَالَ - فَيَسْتَخْبِرُ بَعْضُ أَهْلِ السَّمَوَاتِ بَعْضًا حَتَّى يَبْلُغَ الْخَبَرُ هَذِهِ السَّمَاءَ الدُّنْيَا فَتَخْطَفُ الْجِنُّ السَّمْعَ فَيَقْذِفُونَ إِلَى أَوْلِيَائِهِمْ وَيُرْمَوْنَ بِهِ فَمَا جَاءُوا بِهِ عَلَى وَجْهِهِ فَهُوَ حَقٌّ وَلَكِنَّهُمْ يَقْرِفُونَ فِيهِ وَيَزِيدُونَ ‏"‏ ‏.‏\hadithno{5819}\hadithtrans{Abdullah. Ibn 'Abbas reported:A person from the Ansar who was amongst the Companions of Allah's Messenger (ﷺ) reported to me: As we were sitting during the night with Allah's Messenger (ﷺ), a meteor shot gave a dazzling light. Allah's Messenger (ﷺ) said: What did you say in the pre-Islamic days when there was such a shot (of meteor)? They said: Allah and His Messenger know best (the actual position), but we, however, used to say that that very night a great man had been born and a great man had died, whereupon Allah's Messenger (ﷺ) said: (These meteors) are shot neither at the death of anyone nor on the birth of anyone. Allah, the Exalted and Glorious, issues Command when He decides to do a thing. Then (the Angels) supporting the Throne sing His glory, then sing the dwellers of heaven who are near to them until this glory of God reaches them who are in the heaven of this world. Then those who are near the supporters of the Throne ask these supporters of the Throne: What your Lord has said? And they accordingly inform them what He says. Then the dwellers of heaven seek information from them until this information reaches the heaven of the world. In this process of transmission (the jinn snatches) what he manages to overhear and he carries it to his friends. And when the Angels see the jinn they attack them with meteors. If they narrate only which they manage to snatch that is correct but they alloy it with lies and make additions to it}}
\hadithdefcmd{muslim}{5820}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو عَمْرٍو الأَوْزَاعِيُّ، ح وَحَدَّثَنَا أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي سَلَمَةُ بْنُ، شَبِيبٍ حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - يَعْنِي ابْنَ عُبَيْدِ اللَّهِ - كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ يُونُسَ، قَالَ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ أَخْبَرَنِي رِجَالٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ مِنَ الأَنْصَارِ وَفِي حَدِيثِ الأَوْزَاعِيِّ ‏"‏ وَلَكِنْ يَقْرِفُونَ فِيهِ وَيَزِيدُونَ ‏"‏ ‏.‏ وَفِي حَدِيثِ يُونُسَ ‏"‏ وَلَكِنَّهُمْ يَرْقَوْنَ فِيهِ وَيَزِيدُونَ ‏"‏ ‏.‏ وَزَادَ فِي حَدِيثِ يُونُسَ وَقَالَ اللَّهُ ‏"‏ حَتَّى إِذَا فُزِّعَ عَنْ قُلُوبِهِمْ قَالُوا مَاذَا قَالَ رَبُّكُمْ قَالُوا الْحَقَّ ‏"‏ ‏.‏ وَفِي حَدِيثِ مَعْقِلٍ كَمَا قَالَ الأَوْزَاعِيُّ ‏"‏ وَلَكِنَّهُمْ يَقْرِفُونَ فِيهِ وَيَزِيدُونَ ‏"‏ ‏.‏\hadithno{5820}\hadithtrans{The hadith has been narrated on the authority of Zuhri through the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5821}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ صَفِيَّةَ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَتَى عَرَّافًا فَسَأَلَهُ عَنْ شَىْءٍ لَمْ تُقْبَلْ لَهُ صَلاَةٌ أَرْبَعِينَ لَيْلَةً ‏"‏ ‏.‏\hadithno{5821}\hadithtrans{Safiyya reported from some of the wives of Allah's Apostle (ﷺ) Allah's Apostle (ﷺ) having said:He who visits a diviner ('Arraf) and asks him about anything, his prayers extending to forty nights will not be accepted}}
\hadithdefcmd{muslim}{5822}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، وَهُشَيْمُ بْنُ بَشِيرٍ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، قَالَ كَانَ فِي وَفْدِ ثَقِيفٍ رَجُلٌ مَجْذُومٌ فَأَرْسَلَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّا قَدْ بَايَعْنَاكَ فَارْجِعْ ‏"‏ ‏.‏\hadithno{5822}\hadithtrans{Amr b. Sharid reported on the authority of his father that there was in the delegation of Thaqif a leper. Allah's Apostle (ﷺ) sent a message to him:We have accepted your allegiance, so you may go}}
\hadithdefcmd{muslim}{5823}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَابْنُ، نُمَيْرٍ عَنْ هِشَامٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ ذِي الطُّفْيَتَيْنِ فَإِنَّهُ يَلْتَمِسُ الْبَصَرَ وَيُصِيبُ الْحَبَلَ ‏.‏\hadithno{5823}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) commanded the killing of a snake having stripes over it, for it affects eyesight and miscarries pregnancy}}
\hadithdefcmd{muslim}{5824}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، أَخْبَرَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ وَقَالَ الأَبْتَرُ وَذُو الطُّفْيَتَيْنِ ‏.‏\hadithno{5824}\hadithtrans{This hadith has been transmitted on the authority of Hisham. He said:The short-tailed snake and the snake having stripes over it should be killed}}
\hadithdefcmd{muslim}{5825}{وَحَدَّثَنِي عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ اقْتُلُوا الْحَيَّاتِ وَذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَسْتَسْقِطَانِ الْحَبَلَ وَيَلْتَمِسَانِ الْبَصَرَ ‏"‏ ‏.‏ قَالَ فَكَانَ ابْنُ عُمَرَ يَقْتُلُ كُلَّ حَيَّةٍ وَجَدَهَا فَأَبْصَرَهُ أَبُو لُبَابَةَ بْنُ عَبْدِ الْمُنْذِرِ أَوْ زَيْدُ بْنُ الْخَطَّابِ وَهُوَ يُطَارِدُ حَيَّةً فَقَالَ إِنَّهُ قَدْ نَهَى عَنْ ذَوَاتِ الْبُيُوتِ ‏.‏\hadithno{5825}\hadithtrans{Salim, on the authority of his father. reported Allah's Apostle (ﷺ) as saying:Kill the snakes having stripes over them and short-tailed snakes, for these two types cause miscarriage (of a pregnant woman) and they affect the eyesight adversely. So Ibn 'Umar used to kill every snake that he found. Abu Lubaba b. 'Abd al-Mundhir and Zaid b. Khattab saw him pursuing a snake, whereupon he said: They were forbidden (to kill) those snakes who live in houses}}
\hadithdefcmd{muslim}{5828}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَاللَّفْظُ، لَهُ حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، أَنَّ أَبَا لُبَابَةَ، كَلَّمَ ابْنَ عُمَرَ لِيَفْتَحَ لَهُ بَابًا فِي دَارِهِ يَسْتَقْرِبُ بِهِ إِلَى الْمَسْجِدِ فَوَجَدَ الْغِلْمَةُ جِلْدَ جَانٍّ فَقَالَ عَبْدُ اللَّهِ الْتَمِسُوهُ فَاقْتُلُوهُ ‏.‏ فَقَالَ أَبُو لُبَابَةَ لاَ تَقْتُلُوهُ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ الْجِنَّانِ الَّتِي فِي الْبُيُوتِ ‏.‏\hadithno{5828}\hadithtrans{Nafi' reported that Abu Lubaba talked to Ibn 'Umar to open a door in his house which would bring them nearer to the mosque and they found a fresh slough of the snake, whereupon 'Abdullah said:Find it out and kill it. Abu Lubaba said: Don't kill them, for Allah's Messenger (ﷺ) forbade the killing of the snakes found in houses}}
\hadithdefcmd{muslim}{5829}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا نَافِعٌ، قَالَ كَانَ ابْنُ عُمَرَ يَقْتُلُ الْحَيَّاتِ كُلَّهُنَّ حَتَّى حَدَّثَنَا أَبُو لُبَابَةَ بْنُ عَبْدِ الْمُنْذِرِ الْبَدْرِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ جِنَّانِ الْبُيُوتِ فَأَمْسَكَ ‏.‏\hadithno{5829}\hadithtrans{Nafi' reported that Ibn 'Urnar used to kill all types of snakes until Abu Lubaba b. 'Abd al-Mundhir Badri reported that Allah's Messenger (ﷺ) had forbidden the killing of the snakes of the houses, and so he abstained from it}}
\hadithdefcmd{muslim}{5830}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، أَنَّهُ سَمِعَ أَبَا لُبَابَةَ، يُخْبِرُ ابْنَ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ الْجِنَّانِ ‏\hadithno{5830}\hadithtrans{Nafi' reported that he heard Abu Lubaba informing Ibn 'Umar that Allah's Messenger (ﷺ) had forbidden the killing of domestic snakes}}
\hadithdefcmd{muslim}{5831}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا عُبَيْدُ، اللَّهِ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِي لُبَابَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ أَبَا لُبَابَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ الْجِنَّانِ الَّتِي فِي الْبُيُوتِ ‏\hadithno{5831}\hadithtrans{Abdullah reported that Abu Lubaba had informed him that Allah's Messenger (ﷺ) had forbidden the killing of the snakes found in the house}}
\hadithdefcmd{muslim}{5832}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - قَالَ سَمِعْتُ يَحْيَى، بْنَ سَعِيدٍ يَقُولُ أَخْبَرَنِي نَافِعٌ، أَنَّ أَبَا لُبَابَةَ بْنَ عَبْدِ الْمُنْذِرِ الأَنْصَارِيَّ، - وَكَانَ مَسْكَنُهُ بِقُبَاءٍ فَانْتَقَلَ إِلَى الْمَدِينَةِ - فَبَيْنَمَا عَبْدُ اللَّهِ بْنُ عُمَرَ جَالِسًا مَعَهُ يَفْتَحُ خَوْخَةً لَهُ إِذَا هُمْ بِحَيَّةٍ مِنْ عَوَامِرِ الْبُيُوتِ فَأَرَادُوا قَتْلَهَا فَقَالَ أَبُو لُبَابَةَ إِنَّهُ قَدْ نُهِيَ عَنْهُنَّ - يُرِيدُ عَوَامِرَ الْبُيُوتِ - وَأُمِرَ بِقَتْلِ الأَبْتَرِ وَذِي الطُّفْيَتَيْنِ وَقِيلَ هُمَا اللَّذَانِ يَلْتَمِعَانِ الْبَصَرَ وَيَطْرَحَانِ أَوْلاَدَ النِّسَاءِ ‏.‏\hadithno{5832}\hadithtrans{Nafi' reported that Abu Lubaba b. 'Abd al-Mundhir al-Ansari (first) lived in Quba. He then shifted to Medina and as he was in the company of 'Abdullah b. 'Umar opening a window for him, he suddenly saw a snake in the house. They (the inmates of the house) attempted to kill that. Thereupon Abu Lubaba said:They had been forbidden to make an attempt to kill house snakes and they had been commanded to kill the snakes having small tails, small snakes and those having streaks over them, and it was said: Both of them affect the eyes and cause miscarriage to women}}
\hadithdefcmd{muslim}{5833}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَهْضَمٍ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ عِنْدَنَا ابْنُ جَعْفَرٍ - عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ أَبِيهِ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَوْمًا عِنْدَ هَدْمٍ لَهُ فَرَأَى وَبِيصَ جَانٍّ فَقَالَ اتَّبِعُوا هَذَا الْجَانَّ فَاقْتُلُوهُ ‏.‏ قَالَ أَبُو لُبَابَةَ الأَنْصَارِيُّ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ الْجِنَّانِ الَّتِي تَكُونُ فِي الْبُيُوتِ إِلاَّ الأَبْتَرَ وَذَا الطُّفْيَتَيْنِ فَإِنَّهُمَا اللَّذَانِ يَخْطِفَانِ الْبَصَرَ وَيَتَتَبَّعَانِ مَا فِي بُطُونِ النِّسَاءِ ‏.‏\hadithno{5833}\hadithtrans{Nafi' reported on the authority of his father that as 'Abdullah b. 'Umar saw one day (standing) near the ruin (of his house) the slough of a snake and said (to the people around him):Pursue this snake and kill it. Abu Lubaba Ansari said: I heard Allah's Messenger (ﷺ). He forbade the killing of snakes found in the houses except the short-tailed snakes and those having streaks upon them, for both of them obliterate eyesight and affect that which is in the wombs of (pregnant) women}}
\hadithdefcmd{muslim}{5834}{وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، أَنَّ نَافِعًا، حَدَّثَهُ أَنَّ أَبَا لُبَابَةَ مَرَّ بِابْنِ عُمَرَ وَهُوَ عِنْدَ الأُطُمِ الَّذِي عِنْدَ دَارِ عُمَرَ بْنِ الْخَطَّابِ يَرْصُدُ حَيَّةً بِنَحْوِ حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ ‏.‏\hadithno{5834}\hadithtrans{Nafi' reported that Abu Lubaba happened to pass by Ibn 'Umar who lived in the fortified place near the house of 'Umar b. Khattab and was busy in keeping his eyes upon a snake and killing it, the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5835}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى وَإِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَارٍ وَقَدْ أُنْزِلَتْ عَلَيْهِ ‏\{‏ وَالْمُرْسَلاَتِ عُرْفًا‏\}‏ ‏.‏ فَنَحْنُ نَأْخُذُهَا مِنْ فِيهِ رَطْبَةً إِذْ خَرَجَتْ عَلَيْنَا حَيَّةٌ فَقَالَ ‏"‏ اقْتُلُوهَا ‏"‏ ‏.‏ فَابْتَدَرْنَاهَا لِنَقْتُلَهَا فَسَبَقَتْنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَقَاهَا اللَّهُ شَرَّكُمْ كَمَا وَقَاكُمْ شَرَّهَا ‏"‏ ‏.‏\hadithno{5835}\hadithtrans{Abdullah reported:We were with Allah's Messenger (ﷺ) in a cave when there was revealed to him (the Sura al-Mursalat, i. e. Sura lxxvii.:" By those sent forth to spread goodness" ) and we had just heard (it) from his lips that there appeared before us a snake. He said: Kill it. We hastened to kill it, but it slipped away from us, thereupon Allah's Messenger (ﷺ) said: Allah saved it from your harm just as he saved you from its evil}}
\hadithdefcmd{muslim}{5836}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{5836}\hadithtrans{This hadith has been narrated on the authority of al-A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{5837}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ مُحْرِمًا بِقَتْلِ حَيَّةٍ بِمِنًى ‏.‏\hadithno{5837}\hadithtrans{Abdullah reported that Allah's Messenger (ﷺ) commanded a Muhrim (one who is in the state of pilgrimage) to kill the snake at Mina}}
\hadithdefcmd{muslim}{5838}{وَحَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ بَيْنَمَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَارٍ ‏.‏ بِمِثْلِ حَدِيثِ جَرِيرٍ وَأَبِي مُعَاوِيَةَ ‏.‏\hadithno{5838}\hadithtrans{Abdullah reported:While we were with the Messenger of Allah (ﷺ) in the cave, the rest of the hadith is the same as the one narrated above}}
\hadithdefcmd{muslim}{5839}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ صَيْفِيٍّ، - وَهُوَ عِنْدَنَا مَوْلَى ابْنِ أَفْلَحَ - أَخْبَرَنِي أَبُو السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ أَنَّهُ دَخَلَ عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ فِي بَيْتِهِ قَالَ فَوَجَدْتُهُ يُصَلِّي فَجَلَسْتُ أَنْتَظِرُهُ حَتَّى يَقْضِيَ صَلاَتَهُ فَسَمِعْتُ تَحْرِيكًا فِي عَرَاجِينَ فِي نَاحِيَةِ الْبَيْتِ فَالْتَفَتُّ فَإِذَا حَيَّةٌ فَوَثَبْتُ لأَقْتُلَهَا فَأَشَارَ إِلَىَّ أَنِ اجْلِسْ ‏.‏ فَجَلَسْتُ فَلَمَّا انْصَرَفَ أَشَارَ إِلَى بَيْتٍ فِي الدَّارِ فَقَالَ أَتَرَى هَذَا الْبَيْتَ فَقُلْتُ نَعَمْ ‏.‏ قَالَ كَانَ فِيهِ فَتًى مِنَّا حَدِيثُ عَهْدٍ بِعُرْسٍ - قَالَ - فَخَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى الْخَنْدَقِ فَكَانَ ذَلِكَ الْفَتَى يَسْتَأْذِنُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأَنْصَافِ النَّهَارِ فَيَرْجِعُ إِلَى أَهْلِهِ فَاسْتَأْذَنَهُ يَوْمًا فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُذْ عَلَيْكَ سِلاَحَكَ فَإِنِّي أَخْشَى عَلَيْكَ قُرَيْظَةَ ‏"‏ ‏.‏ فَأَخَذَ الرَّجُلُ سِلاَحَهُ ثُمَّ رَجَعَ فَإِذَا امْرَأَتُهُ بَيْنَ الْبَابَيْنِ قَائِمَةً فَأَهْوَى إِلَيْهَا الرُّمْحَ لِيَطْعُنَهَا بِهِ وَأَصَابَتْهُ غَيْرَةٌ فَقَالَتْ لَهُ اكْفُفْ عَلَيْكَ رُمْحَكَ وَادْخُلِ الْبَيْتَ حَتَّى تَنْظُرَ مَا الَّذِي أَخْرَجَنِي ‏.‏ فَدَخَلَ فَإِذَا بِحَيَّةٍ عَظِيمَةٍ مُنْطَوِيَةٍ عَلَى الْفِرَاشِ فَأَهْوَى إِلَيْهَا بِالرُّمْحِ فَانْتَظَمَهَا بِهِ ثُمَّ خَرَجَ فَرَكَزَهُ فِي الدَّارِ فَاضْطَرَبَتْ عَلَيْهِ فَمَا يُدْرَى أَيُّهُمَا كَانَ أَسْرَعَ مَوْتًا الْحَيَّةُ أَمِ الْفَتَى قَالَ فَجِئْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرْنَا ذَلِكَ لَهُ وَقُلْنَا ادْعُ اللَّهَ يُحْيِيهِ لَنَا ‏.‏ فَقَالَ ‏"‏ اسْتَغْفِرُوا لِصَاحِبِكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ بِالْمَدِينَةِ جِنًّا قَدْ أَسْلَمُوا فَإِذَا رَأَيْتُمْ مِنْهُمْ شَيْئًا فَآذِنُوهُ ثَلاَثَةَ أَيَّامٍ فَإِنْ بَدَا لَكُمْ بَعْدَ ذَلِكَ فَاقْتُلُوهُ فَإِنَّمَا هُوَ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{5839}\hadithtrans{Abu as-Sa'ib, the freed slaved of Hisham b. Zuhra, said that he visited Abu Sa'id Khudri in his house, (and he further) said:I found him saying his prayer, so I sat down waiting for him to finish his prayer when I heard a stir in the bundles (of wood) lying in a comer of the house. I looked towards it and found a snake. I jumped up in order to kill it, but he (Abu Sa'id Khudri) made a gesture that I should sit down. So I sat down and as he finished (the prayer) he pointed to a room in the house and said: Do you see this room? I said: Yes. He said: There was a young man amongst us who had been newly wedded. We went with Allah's Messenger (ﷺ) (to participate in the Battle) of Trench when a young man in the midday used to seek permission from Allah's Messenger (ﷺ) to return to his family. One day he sought permission from him and Allah's Messenger (ﷺ) (after granting him the permission) said to him: Carry your weapons with you for I fear the tribe of Quraiza (may harm you). The man carried the weapons and then came back and found his wife standing between the two doors. He bent towards her smitten by jealousy and made a dash towards her with a spear in order to stab her. She said: Keep your spear away and enter the house until you see that which has made me come out. He entered and found a big snake coiled on the bedding. He darted with the spear and pierced it and then went out having fixed it in the house, but the snake quivered and attacked him and no one knew which of them died first, the snake or the young man. We came to Allah's Apostle (ﷺ) and made a mention to him and said: Supplicate to Allah that that (man) may be brought back to life. Thereupon he said: Ask forgiveness for your companion and then said: There are in Medina jinns who have accepted Islam, so when you see any one of them, pronounce a warning to it for three days, and if they appear before you after that, then kill it for that is a devil}}
\hadithdefcmd{muslim}{5840}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرِ بْنِ حَازِمٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ أَسْمَاءَ بْنَ عُبَيْدٍ، يُحَدِّثُ عَنْ رَجُلٍ، يُقَالُ لَهُ السَّائِبُ - وَهُوَ عِنْدَنَا أَبُو السَّائِبِ - قَالَ دَخَلْنَا عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ فَبَيْنَمَا نَحْنُ جُلُوسٌ إِذْ سَمِعْنَا تَحْتَ، سَرِيرِهِ حَرَكَةً فَنَظَرْنَا فَإِذَا حَيَّةٌ ‏.‏ وَسَاقَ الْحَدِيثَ بِقِصَّتِهِ نَحْوَ حَدِيثِ مَالِكٍ عَنْ صَيْفِيٍّ وَقَالَ فِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ لِهَذِهِ الْبُيُوتِ عَوَامِرَ فَإِذَا رَأَيْتُمْ شَيْئًا مِنْهَا فَحَرِّجُوا عَلَيْهَا ثَلاَثًا فَإِنْ ذَهَبَ وَإِلاَّ فَاقْتُلُوهُ فَإِنَّهُ كَافِرٌ ‏"‏ ‏.‏ وَقَالَ لَهُمُ ‏"‏ اذْهَبُوا فَادْفِنُوا صَاحِبَكُمْ ‏"‏ ‏.‏\hadithno{5840}\hadithtrans{Asma' b. 'Ubaid reported about a person who was called as-Sa'ib having said:We visited Abu Sa'id Khudri. When we had been sitting (with him) we heard a stir under his bed. When we looked we found a big snake, the rest of the hadith is the same. And in this Allah's Messenger (ﷺ) is reported to have said: Verily in these houses there live aged (snakes), so when you see one of them, make life hard for it for three days, and if it goes away (well and good), otherwise kill it for (in that case) it would be a nonbeliever. And he (the Holy Prophet) said (to his Companions): Go and bury your companion (who had died by the snake bite)}}
\hadithdefcmd{muslim}{5841}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ عَجْلاَنَ، حَدَّثَنِي صَيْفِيٌّ، عَنْ أَبِي السَّائِبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سَمِعْتُهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ بِالْمَدِينَةِ نَفَرًا مِنَ الْجِنِّ قَدْ أَسْلَمُوا فَمَنْ رَأَى شَيْئًا مِنْ هَذِهِ الْعَوَامِرِ فَلْيُؤْذِنْهُ ثَلاَثًا فَإِنْ بَدَا لَهُ بَعْدُ فَلْيَقْتُلْهُ فَإِنَّهُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{5841}\hadithtrans{Abu Sa'id Khudri reported Allah's Messenger having said:There is a group of jinns in Medina who accepted Islam, so he who would see anything from these occupants should warn him three times; and if he appears after that, he should kill him for he is a satan}}
\hadithdefcmd{muslim}{5842}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرِ، بْنِ شَيْبَةَ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ شَرِيكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهَا بِقَتْلِ الأَوْزَاغِ ‏.‏ وَفِي حَدِيثِ ابْنِ أَبِي شَيْبَةَ أَمَرَ ‏.‏\hadithno{5842}\hadithtrans{Umm Sharik reported that Allah's Messenger (ﷺ) commanded her to kill geckos. This hadith has been transmitted on the authority of Ibn Abi Shaiba with a slight variation of wording}}
\hadithdefcmd{muslim}{5843}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ حَدَّثَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ الْحَمِيدِ بْنُ جُبَيْرِ بْنِ شَيْبَةَ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، أَخْبَرَهُ أَنَّ أُمَّ شَرِيكٍ أَخْبَرَتْهُ أَنَّهَا، اسْتَأْمَرَتِ النَّبِيَّ صلى الله عليه وسلم فِي قَتْلِ الْوِزْغَانِ فَأَمَرَ بِقَتْلِهَا ‏.‏ وَأُمُّ شَرِيكٍ إِحْدَى نِسَاءِ بَنِي عَامِرِ بْنِ لُؤَىٍّ ‏.‏ اتَّفَقَ لَفْظُ حَدِيثِ ابْنِ أَبِي خَلَفٍ وَعَبْدِ بْنِ حُمَيْدٍ وَحَدِيثُ ابْنِ وَهْبٍ قَرِيبٌ مِنْهُ ‏.‏\hadithno{5843}\hadithtrans{Umm Sharik reported that she consulted Allah's Apostle (ﷺ) in regard to killing of geckos, and he commanded to kill them and Umm Sharik is one of the women of Bani 'Amir b. Luwayy. This hadith has been reported through another chain of transmitters with the same meaning}}
\hadithdefcmd{muslim}{5844}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْوَزَغِ وَسَمَّاهُ فُوَيْسِقًا ‏.‏\hadithno{5844}\hadithtrans{Amir b. Sa'd reported on the authority of his father that Allah's Apostle (ﷺ) commanded the killing of geckos, and he called them little noxious creatures}}
\hadithdefcmd{muslim}{5845}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِلْوَزَغِ ‏ "‏ الْفُوَيْسِقُ ‏"‏ ‏.‏ زَادَ حَرْمَلَةُ قَالَتْ وَلَمْ أَسْمَعْهُ أَمَرَ بِقَتْلِهِ ‏.‏\hadithno{5845}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) said about the gecko as a noxious creature". Harmala made this addition that she said:I did not hear that he had commanded to kill them}}
\hadithdefcmd{muslim}{5846}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ وَزَغَةً فِي أَوَّلِ ضَرْبَةٍ فَلَهُ كَذَا وَكَذَا حَسَنَةً وَمَنْ قَتَلَهَا فِي الضَّرْبَةِ الثَّانِيَةِ فَلَهُ كَذَا وَكَذَا حَسَنَةً لِدُونِ الأُولَى وَإِنْ قَتَلَهَا فِي الضَّرْبَةِ الثَّالِثَةِ فَلَهُ كَذَا وَكَذَا حَسَنَةً لِدُونِ الثَّانِيَةِ ‏"‏ ‏.‏\hadithno{5846}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who killed a gecko with the first stroke for him is such and such a reward, and he who killed it with a second stroke for him is such and such reward less than the first one, and he who killed it with the third stroke for him is such and such a reward less than the second one}}
\hadithdefcmd{muslim}{5847}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ يَعْنِي ابْنَ زَكَرِيَّاءَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، كُلُّهُمْ عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمَعْنَى حَدِيثِ خَالِدٍ عَنْ سُهَيْلٍ إِلاَّ جَرِيرًا وَحْدَهُ فَإِنَّ فِي حَدِيثِهِ ‏ "‏ مَنْ قَتَلَ وَزَغًا فِي أَوَّلِ ضَرْبَةٍ كُتِبَتْ لَهُ مِائَةُ حَسَنَةٍ وَفِي الثَّانِيَةِ دُونَ ذَلِكَ وَفِي الثَّالِثَةِ دُونَ ذَلِكَ ‏"‏ ‏.‏\hadithno{5847}\hadithtrans{This hadith has been reported on the authority of Abu Huraira through another chain of transmitters (and the words are):- He who killed a gecko with the first stroke for him are ordained one hundred virtues, and with the second one less than that and with the third one less than that}}
\hadithdefcmd{muslim}{5848}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ يَعْنِي ابْنَ زَكَرِيَّاءَ، عَنْ سُهَيْلٍ، حَدَّثَتْنِي أُخْتِي، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ فِي أَوَّلِ ضَرْبَةٍ سَبْعِينَ حَسَنَةً ‏"‏ ‏.‏\hadithno{5848}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying (that he who kills a gecko) with the first stroke there are seventy rewards for him}}
\hadithdefcmd{muslim}{5849}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّ نَمْلَةً قَرَصَتْ نَبِيًّا مِنَ الأَنْبِيَاءِ فَأَمَرَ بِقَرْيَةِ النَّمْلِ فَأُحْرِقَتْ فَأَوْحَى اللَّهُ إِلَيْهِ أَفِي أَنْ قَرَصَتْكَ نَمْلَةٌ أَهْلَكْتَ أُمَّةً مِنَ الأُمَمِ تُسَبِّحُ ‏"‏ ‏.‏\hadithno{5849}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:An ant had bitten a Prophet (one amongst the earlier Prophets) and he ordered that the colony of the ants should be burnt. And Allah revealed to him:" Because of an ant's bite you have burnt a community from amongst the communities which sings My glory}}
\hadithdefcmd{muslim}{5850}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ نَزَلَ نَبِيٌّ مِنَ الأَنْبِيَاءِ تَحْتَ شَجَرَةٍ فَلَدَغَتْهُ نَمْلَةٌ فَأَمَرَ بِجِهَازِهِ فَأُخْرِجَ مِنْ تَحْتِهَا ثُمَّ أَمَرَ بِهَا فَأُحْرِقَتْ فَأَوْحَى اللَّهُ إِلَيْهِ فَهَلاَّ نَمْلَةً وَاحِدَةً ‏"‏ ‏.‏\hadithno{5850}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:An Apostle from amongst the Apostles of Allah encamped under a tree, and an ant bit him, and he commanded his belongings to be removed from underneath the tree. He then commanded and it was burnt, and Allah revealed to bin):" Why one ant (which had bitten you) was not killed?}}
\hadithdefcmd{muslim}{5851}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَزَلَ نَبِيٌّ مِنَ الأَنْبِيَاءِ تَحْتَ شَجَرَةٍ فَلَدَغَتْهُ نَمْلَةٌ فَأَمَرَ بِجِهَازِهِ فَأُخْرِجَ مِنْ تَحْتِهَا وَأَمَرَ بِهَا فَأُحْرِقَتْ فِي النَّارِ - قَالَ - فَأَوْحَى اللَّهُ إِلَيْهِ فَهَلاَّ نَمْلَةً وَاحِدَةً ‏"‏ ‏.‏\hadithno{5851}\hadithtrans{Abu Huraira reported so many ahadith and one of them was this that Allah' Messenger (ﷺ) said:When an Apostle from amongst the Apostles of Allah came to sit under a tree an ant bit him. He commanded his luggage to be removed from under the tree and he commanded it to be burnt in the fire and Allah revealed to him:" Why one ant (which had bitten you) was not killed (and why did you burn the others)?}}
\hadithdefcmd{muslim}{5852}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُذِّبَتِ امْرَأَةٌ فِي هِرَّةٍ سَجَنَتْهَا حَتَّى مَاتَتْ فَدَخَلَتْ فِيهَا النَّارَ لاَ هِيَ أَطْعَمَتْهَا وَسَقَتْهَا إِذْ حَبَسَتْهَا وَلاَ هِيَ تَرَكَتْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ ‏"‏ ‏.‏\hadithno{5852}\hadithtrans{Nafi' reported from 'Abdullah that Allah's Messenger (ﷺ) said:A woman was punished because she had kept a cat tied until it died, and (as a punishment of this offence) she was thrown into the Hell. She had not provided it with food, or drink, and had not freed her so that she could eat the vermin of the earth}}
\hadithdefcmd{muslim}{5853}{وَحَدَّثَنِي نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، وَعَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ مَعْنَاهُ ‏.‏\hadithno{5853}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{5854}{وَحَدَّثَنَاهُ هَارُونُ بْنُ عَبْدِ اللَّهِ، وَعَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ مَعْنِ بْنِ عِيسَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِذَلِكَ ‏.‏\hadithno{5854}\hadithtrans{This hadith has been transmitted on the authority of Ibn 'Umar also}}
\hadithdefcmd{muslim}{5855}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُذِّبَتِ امْرَأَةٌ فِي هِرَّةٍ لَمْ تُطْعِمْهَا وَلَمْ تَسْقِهَا وَلَمْ تَتْرُكْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ ‏"‏ ‏.‏\hadithno{5855}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A woman was punished because of a cat. She had neither provided her with food nor drink, nor set her free so that she might eat the vermin of the earth}}
\hadithdefcmd{muslim}{5856}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ، بْنُ الْحَارِثِ حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِهِمَا ‏"‏ رَبَطَتْهَا ‏"‏ ‏.‏ وَفِي حَدِيثِ أَبِي مُعَاوِيَةَ ‏"‏ حَشَرَاتِ الأَرْضِ ‏"‏ ‏.‏\hadithno{5856}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters, but with a slight variation of wording}}
\hadithdefcmd{muslim}{5857}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ قَالَ الزُّهْرِيُّ وَحَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ هِشَامِ بْنِ عُرْوَةَ ‏.‏\hadithno{5857}\hadithtrans{Abu Huraira reported this hadith through another chain of transmitters}}
\hadithdefcmd{muslim}{5858}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{5858}\hadithtrans{Hammam b. Manabbih reported this hadith on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{5859}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ اشْتَدَّ عَلَيْهِ الْعَطَشُ فَوَجَدَ بِئْرًا فَنَزَلَ فِيهَا فَشَرِبَ ثُمَّ خَرَجَ فَإِذَا كَلْبٌ يَلْهَثُ يَأْكُلُ الثَّرَى مِنَ الْعَطَشِ فَقَالَ الرَّجُلُ لَقَدْ بَلَغَ هَذَا الْكَلْبَ مِنَ الْعَطَشِ مِثْلُ الَّذِي كَانَ بَلَغَ مِنِّي ‏.‏ فَنَزَلَ الْبِئْرَ فَمَلأَ خُفَّهُ مَاءً ثُمَّ أَمْسَكَهُ بِفِيهِ حَتَّى رَقِيَ فَسَقَى الْكَلْبَ فَشَكَرَ اللَّهُ لَهُ فَغَفَرَ لَهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَإِنَّ لَنَا فِي هَذِهِ الْبَهَائِمِ لأَجْرًا فَقَالَ ‏"‏ فِي كُلِّ كَبِدٍ رَطْبَةٍ أَجْرٌ ‏"‏ ‏.‏\hadithno{5859}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as sayings:A person suffered from intense thirst while on a journey, when he found a well. He climbed down into it and drank (water) and then came out and saw a dog lolling its tongue on account of thirst and eating the moistened earth. The person said: This dog has suffered from thirst as I had suffered from it. He climbed down into the well, filled his shoe with water, then caught it in his mouth until he climbed up and made the dog drink it. So Allah appreciated this act of his and pardoned him. Then (the Companions around him) said: Allah's Messenger, is there for us a reward even for (serving) such animals? He said: Yes, there is a reward for service to every living animal}}
\hadithdefcmd{muslim}{5860}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ امْرَأَةً بَغِيًّا رَأَتْ كَلْبًا فِي يَوْمٍ حَارٍّ يُطِيفُ بِبِئْرٍ قَدْ أَدْلَعَ لِسَانَهُ مِنَ الْعَطَشِ فَنَزَعَتْ لَهُ بِمُوقِهَا فَغُفِرَ لَهَا ‏"‏ ‏.‏\hadithno{5860}\hadithtrans{Abu Huraira reported Allah's Messenger (may pace be upon him) as saying:A prostitute saw a dog moving around a well on a hot day and hanging out its tongue because of thirst. She drew water for it in her shoe and she was pardoned (for this act of hers)}}
\hadithdefcmd{muslim}{5861}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَمَا كَلْبٌ يُطِيفُ بِرَكِيَّةٍ قَدْ كَادَ يَقْتُلُهُ الْعَطَشُ إِذْ رَأَتْهُ بَغِيٌّ مِنْ بَغَايَا بَنِي إِسْرَائِيلَ فَنَزَعَتْ مُوقَهَا فَاسْتَقَتْ لَهُ بِهِ فَسَقَتْهُ إِيَّاهُ فَغُفِرَ لَهَا بِهِ ‏"‏ ‏.‏\hadithno{5861}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There was a dog moving around a well whom thirst would have killed. Suddenly a prostitute from the prostitutes of Bani Isra'il happened to see it and she drew water in her shoe and made it drink, and she was pardoned because of this}}
