% Auto-generated chapter 48 for nasai
% Hadiths in this chapter: 339

\hadithdefcmd{nasai}{5040}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ أَبِي زَائِدَةَ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ طَلْقِ بْنِ حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَشَرَةٌ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ وَقَصُّ الأَظْفَارِ وَغَسْلُ الْبَرَاجِمِ وَإِعْفَاءُ اللِّحْيَةِ وَالسِّوَاكُ وَالاِسْتِنْشَاقُ وَنَتْفُ الإِبْطِ وَحَلْقُ الْعَانَةِ وَانْتِقَاصُ الْمَاءِ ‏"‏ ‏.‏ قَالَ مُصْعَبٌ وَنَسِيتُ الْعَاشِرَةَ إِلاَّ أَنْ تَكُونَ الْمَضْمَضَةَ ‏.‏\hadithno{5040}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah [SAW] said: "Ten things are part of the Fitrah: Trimming the mustache, trimming the nails, washing the joints, letting the beard grow, using the Siwak, rinsing the nose, plucking the armpit hairs, shaving the pubes, and washing with water (after relieving oneself)." Mus'ab bin Shaibah said: "I have forgotten the tenth, unless it was rinsing the mouth}}
\hadithdefcmd{nasai}{5041}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ طَلْقًا، يَذْكُرُ عَشْرَةً مِنَ الْفِطْرَةِ السِّوَاكَ وَقَصَّ الشَّارِبِ وَتَقْلِيمَ الأَظْفَارِ وَغَسْلَ الْبَرَاجِمِ وَحَلْقَ الْعَانَةِ وَالاِسْتِنْشَاقَ ‏.‏ وَأَنَا شَكَكْتُ فِي الْمَضْمَضَةِ ‏.‏\hadithno{5041}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Hasan}\hadithtrans{Al-Mu'tamir narrated that his father said:"I heard Talq mentioning ten things that have to do with the Fitrah: Using the Siwak, trimming the mustache, clipping the nails, washing the joints, shaving the pubes, rinsing the nose, and I am not sure about rinsing the mouth}}
\hadithdefcmd{nasai}{5042}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ طَلْقِ بْنِ حَبِيبٍ، قَالَ عَشْرَةٌ مِنَ السُّنَّةِ السِّوَاكُ وَقَصُّ الشَّارِبِ وَالْمَضْمَضَةُ وَالاِسْتِنْشَاقُ وَتَوْفِيرُ اللِّحْيَةِ وَقَصُّ الأَظْفَارِ وَنَتْفُ الإِبْطِ وَالْخِتَانُ وَحَلْقُ الْعَانَةِ وَغَسْلُ الدُّبُرِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَحَدِيثُ سُلَيْمَانَ التَّيْمِيِّ وَجَعْفَرِ بْنِ إِيَاسٍ أَشْبَهُ بِالصَّوَابِ مِنْ حَدِيثِ مُصْعَبِ بْنِ شَيْبَةَ وَمُصْعَبٌ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{5042}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Talq bin Habib said:"Ten things are from the Sunnah: Using the Siwak, trimming the mustache, rinsing the mouth, rinsing the nose, letting the beard grow, trimming the nails, plucking the armpit hairs, circumcision, shaving the pubes and washing one's backside}}
\hadithdefcmd{nasai}{5043}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ بِشْرٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الْفِطْرَةِ الْخِتَانُ وَحَلْقُ الْعَانَةِ وَنَتْفُ الضَّبْعِ وَتَقْلِيمُ الظُّفْرِ وَتَقْصِيرُ الشَّارِبِ ‏"‏ ‏.‏ وَقَفَهُ مَالِكٌ ‏.‏\hadithno{5043}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Five things are of the Fitrah: Circumcision, shaving the pubes, plucking the armpit hair, clipping the nails and trimming the mustache}}
\hadithdefcmd{nasai}{5044}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَمْسٌ مِنَ الْفِطْرَةِ تَقْلِيمُ الأَظْفَارِ وَقَصُّ الشَّارِبِ وَنَتْفُ الإِبْطِ وَحَلْقُ الْعَانَةِ وَالْخِتَانُ ‏.‏\hadithno{5044}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"Five things are of the Fitrah: Clipping the nails, trimming the mustache, plucking the armpit hairs, shaving the pubes, and circumcision." (Sahih Mawquf)}}
\hadithdefcmd{nasai}{5045}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَلْقَمَةَ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَحْفُوا الشَّوَارِبَ وَأَعْفُوا اللِّحَى ‏"‏ ‏.‏\hadithno{5045}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar:That the Messenger of Allah [SAW] said: "Trim the mustache and let the beard grow}}
\hadithdefcmd{nasai}{5046}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَلْقَمَةَ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعْفُوا اللِّحَى وَأَحْفُوا الشَّوَارِبَ ‏"‏ ‏.‏\hadithno{5046}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Let the beard grow and trim the mustache}}
\hadithdefcmd{nasai}{5047}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ يُوسُفَ بْنَ صُهَيْبٍ، يُحَدِّثُ عَنْ حَبِيبِ بْنِ يَسَارٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ لَمْ يَأْخُذْ شَارِبَهُ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{5047}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Al-Arqam said:"I heard the Messenger of Allah [SAW] say: 'Whoever does not take from his mustache, he is not one of us}}
\hadithdefcmd{nasai}{5048}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى صَبِيًّا حَلَقَ بَعْضَ رَأْسِهِ وَتَرَكَ بَعْضَ فَنَهَى عَنْ ذَلِكَ وَقَالَ ‏ "‏ احْلِقُوهُ كُلَّهُ أَوِ اتْرُكُوهُ كُلَّهُ ‏"‏ ‏.‏\hadithno{5048}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that :The Prophet [SAW] saw a boy, part of whose head had been shaven and part had been left. He forbade that and said: "Shave all of it, or leave all of it}}
\hadithdefcmd{nasai}{5049}{أَخْبَرَنَا مُحَمَّدُ بْنُ مُوسَى الْحَرَشِيُّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، عَنْ عَلِيٍّ، نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَحْلِقَ الْمَرْأَةُ رَأْسَهَا ‏.‏\hadithno{5049}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ali:"The Messenger of Allah [SAW] forbade women to shave their heads}}
\hadithdefcmd{nasai}{5050}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ أَبِي الرِّجَالِ، عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نَهَانِي اللَّهُ عَزَّ وَجَلَّ عَنِ الْقَزَعِ ‏"‏ ‏.‏\hadithno{5050}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that :The Prophet [SAW] said: "Allah, the Mighty and Sublime, has forbidden me from Al-Qaza' (to shave part of the head and leave part)}}
\hadithdefcmd{nasai}{5051}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ سُفْيَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْقَزَعِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ حَدِيثُ يَحْيَى بْنِ سَعِيدٍ وَمُحَمَّدِ بْنِ بِشْرٍ أَوْلَى بِالصَّوَابِ ‏.‏\hadithno{5051}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] forbade Al-Qaza' (to shave part of the head and leave part)}}
\hadithdefcmd{nasai}{5052}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا سُفْيَانُ، أَخُو قَبِيصَةَ وَمُعَاوِيَةُ بْنُ هِشَامٍ قَالاَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَلِي شَعْرٌ فَقَالَ ‏"‏ ذُبَابٌ ‏"‏ ‏.‏ فَظَنَنْتُ أَنَّهُ يَعْنِينِي فَأَخَذْتُ مِنْ شَعْرِي ثُمَّ أَتَيْتُهُ فَقَالَ لِي ‏"‏ لَمْ أَعْنِكَ وَهَذَا أَحْسَنُ ‏"‏ ‏.‏\hadithno{5052}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Wa'il bin Hujr said:"I came to the Prophet [SAW] and I had hair. He said: 'This is bad,' and I thought he meant me, so I cut my hair then I came to him. He said to me: 'I didn't mean you, but this is better}}
\hadithdefcmd{nasai}{5053}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسٍ، قَالَ كَانَ شَعْرُ النَّبِيِّ صلى الله عليه وسلم شَعْرًا رَجِلاً لَيْسَ بِالْجَعْدِ وَلاَ بِالسَّبْطِ بَيْنَ أُذُنَيْهِ وَعَاتِقِهِ ‏.‏\hadithno{5053}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The hair of the Prophet [SAW] was wavy, neither curly nor straight, and (hung down) between his ears and his shoulders}}
\hadithdefcmd{nasai}{5054}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ دَاوُدَ الأَوْدِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، قَالَ لَقِيتُ رَجُلاً صَحِبَ النَّبِيَّ صلى الله عليه وسلم كَمَا صَحِبَهُ أَبُو هُرَيْرَةَ أَرْبَعَ سِنِينَ قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَمْتَشِطَ أَحَدُنَا كُلَّ يَوْمٍ ‏.‏\hadithno{5054}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Humaid bin 'Abdur-Rahman Al-Himyari said:"I met a man who accompanied the Prophet [SAW] as Abu Hurairah accompanied him for four years, who said: 'The Messenger of Allah [SAW] forbade us from combing our hair everyday}}
\hadithdefcmd{nasai}{5055}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّرَجُّلِ إِلاَّ غِبًّا ‏.‏\hadithno{5055}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mughaffal said:"The Messenger of Allah [SAW] forbade combing one's hair, except every other day}}
\hadithdefcmd{nasai}{5056}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ التَّرَجُّلِ إِلاَّ غِبًّا ‏.‏\hadithno{5056}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Hasan that:The Prophet [SAW] forbade coming one's hair except every other day}}
\hadithdefcmd{nasai}{5057}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بِشْرٌ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، وَمُحَمَّدٍ، قَالاَ التَّرَجُّلُ غِبٌّ ‏.‏\hadithno{5057}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Al-Hasan and Muhammad said:"Combing one's hair (should be done) every other day}}
\hadithdefcmd{nasai}{5058}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ كَهْمَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ كَانَ رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَامِلاً بِمِصْرَ فَأَتَاهُ رَجُلٌ مِنْ أَصْحَابِهِ فَإِذَا هُوَ شَعِثُ الرَّأْسِ مُشْعَانٌّ قَالَ مَا لِي أَرَاكَ مُشْعَانًّا وَأَنْتَ أَمِيرٌ قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَنْهَانَا عَنِ الإِرْفَاهِ ‏.‏ قُلْنَا وَمَا الإِرْفَاهُ قَالَ التَّرَجُّلُ كُلَّ يَوْمٍ ‏.‏\hadithno{5058}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Shaqiq said:"One of the Companions of the Prophet [SAW] was a governor in Egypt, and one of his companions came to him and found him with unkempt, wild hair. He said: 'How come I see you with wild hair when you are a governor?' He said: 'The Prophet of Allah [SAW] forbade us from Al-Irfah,' and we said: 'What is Al-Irfah?' He said: 'To comb your hair every day}}
\hadithdefcmd{nasai}{5059}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ مُحَمَّدِ بْنِ بِشْرٍ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ التَّيَامُنَ يَأْخُذُ بِيَمِينِهِ وَيُعْطِي بِيَمِينِهِ وَيُحِبُّ التَّيَمُّنَ فِي جَمِيعِ أُمُورِهِ ‏.‏\hadithno{5059}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] used to like to start in the right. He would accept with his right hand and give with his right hand, and he liked to start on the right in all his affairs}}
\hadithdefcmd{nasai}{5060}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ، قَالَ حَدَّثَنَا الْمُعَافَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ مَا رَأَيْتُ أَحَدًا أَحْسَنَ فِي حُلَّةٍ حَمْرَاءَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَجُمَّتُهُ تَضْرِبُ مَنْكِبَيْهِ ‏.‏\hadithno{5060}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Al-Bara' said:"I have never seen anyone who looked more handsome in a red Hullah than the Messenger of Allah [SAW], with his long hair that came down to his shoulders}}
\hadithdefcmd{nasai}{5061}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ شَعْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى أَنْصَافِ أُذُنَيْهِ ‏.‏\hadithno{5061}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"The hair of the Messenger of Allah [SAW] came halfway down his ears}}
\hadithdefcmd{nasai}{5062}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، قَالَ حَدَّثَنِي الْبَرَاءُ، قَالَ مَا رَأَيْتُ رَجُلاً أَحْسَنَ فِي حُلَّةٍ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ وَرَأَيْتُ لَهُ لِمَّةً تَضْرِبُ قَرِيبًا مِنْ مَنْكِبَيْهِ ‏.‏\hadithno{5062}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Bara' said:"I have never seen any man more handsome in a red Hullah than the Messenger of Allah [SAW]." He said: "And I saw his long hair, coming almost to his shoulders}}
\hadithdefcmd{nasai}{5063}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْمَاعِيلَ بْنِ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ بْنِ يَرِيمَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ عَلَى قِرَاءَةِ مَنْ تَأْمُرُونِّي أَقْرَأُ لَقَدْ قَرَأْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِضْعًا وَسَبْعِينَ سُورَةً وَإِنَّ زَيْدًا لَصَاحِبُ ذُؤَابَتَيْنِ يَلْعَبُ مَعَ الصِّبْيَانِ ‏.‏\hadithno{5063}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Mas'ud said:"According to whose recitation do you want me to recite? Because I recited seventy-odd Surahs to the Messenger of Allah [SAW] when Zaid had two braids, and was playing with the other boys}}
\hadithdefcmd{nasai}{5064}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو شِهَابٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي وَائِلٍ، قَالَ خَطَبَنَا ابْنُ مَسْعُودٍ فَقَالَ كَيْفَ تَأْمُرُونِّي أَقْرَأُ عَلَى قِرَاءَةِ زَيْدِ بْنِ ثَابِتٍ بَعْدَ مَا قَرَأْتُ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم بِضْعًا وَسَبْعِينَ سُورَةً وَإِنَّ زَيْدًا مَعَ الْغِلْمَانِ لَهُ ذُؤَابَتَانِ ‏.‏\hadithno{5064}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Wa'il said:"Ibn Mas'ud addressed us and said: 'How do you want me to recite? According to the recitation of Zaid bin Thabit, when I learned seventy-odd Surahs from the mouth of the Messenger of Allah [SAW] while Zaid was with the other boys with two braids?}}
\hadithdefcmd{nasai}{5065}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْمُسْتَمِرِ الْعُرُوقِيُّ، قَالَ حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا غَسَّانُ بْنُ الأَغَرِّ بْنِ حُصَيْنٍ النَّهْشَلِيُّ، قَالَ حَدَّثَنِي عَمِّي، زِيَادُ بْنُ الْحُصَيْنِ عَنْ أَبِيهِ، قَالَ لَمَّا قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ادْنُ مِنِّي ‏"‏ ‏.‏ فَدَنَا مِنْهُ فَوَضَعَ يَدَهُ عَلَى ذُؤَابَتِهِ ثُمَّ أَجْرَى يَدَهُ وَسَمَّتَ عَلَيْهِ وَدَعَا لَهُ ‏.‏\hadithno{5065}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Ziyad bin Al-Husain narrated that his father said:"When he came to the Prophet [SAW] in Al-Madinah, the Messenger of Allah [SAW] said to him: 'Come closer to me.' So he came closer to him, and he put his hand on his braid and wiped his head and prayed for him}}
\hadithdefcmd{nasai}{5066}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا قَاسِمٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَلِي جُمَّةٌ قَالَ ‏"‏ ذُبَابٌ ‏"‏ ‏.‏ وَظَنَنْتُ أَنَّهُ يَعْنِينِي فَانْطَلَقْتُ فَأَخَذْتُ مِنْ شَعْرِي فَقَالَ ‏"‏ إِنِّي لَمْ أَعْنِكَ وَهَذَا أَحْسَنُ ‏"‏ ‏.‏\hadithno{5066}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Wa'il bin Hujr said:"I came to the Prophet [SAW] and I had long hair. He said: 'It is not good,' and I thought he meant me, so I went and cut my hair. He said: 'I did not mean you, but this is better}}
\hadithdefcmd{nasai}{5067}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، وَذَكَرَ، آخَرَ قَبْلَهُ عَنْ عَيَّاشِ بْنِ عَبَّاسٍ الْقِتْبَانِيِّ، أَنَّ شُيَيْمَ بْنَ بَيْتَانَ، حَدَّثَهُ أَنَّهُ، سَمِعَ رُوَيْفِعَ بْنَ ثَابِتٍ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَا رُوَيْفِعُ لَعَلَّ الْحَيَاةَ سَتَطُولُ بِكَ بَعْدِي فَأَخْبِرِ النَّاسَ أَنَّهُ مَنْ عَقَدَ لِحْيَتَهُ أَوْ تَقَلَّدَ وَتَرًا أَوِ اسْتَنْجَى بِرَجِيعِ دَابَّةٍ أَوْ عَظْمٍ فَإِنَّ مُحَمَّدًا بَرِيءٌ مِنْهُ ‏"‏ ‏.‏\hadithno{5067}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ruwaifi' bin Thabit said:"The Messenger of Allah [SAW] said: 'O Ruwaifi', you may live for a long time after me, so tell the people that whoever ties up his beard, or twists it, or hangs an amulet, or cleans himself (after relieving himself) with animal dung or bones, Muhammad has nothing to do with him}}
\hadithdefcmd{nasai}{5068}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ نَتْفِ الشَّيْبِ ‏.‏\hadithno{5068}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that:The Messenger of Allah [SAW] forbade plucking gray hairs}}
\hadithdefcmd{nasai}{5069}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ أَبُو سَلَمَةَ إِنَّ أَبَا هُرَيْرَةَ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ح وَأَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ قَالَ أَخْبَرَنِي يُونُسُ عَنِ ابْنِ شِهَابٍ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَخْبَرَهُ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْيَهُودُ وَالنَّصَارَى لاَ تَصْبُغُ فَخَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{5069}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] said: "The Jews and Christians do not dye their hair, so be different from them}}
\hadithdefcmd{nasai}{5070}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{5070}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated from Abu Hurairah:A similar report was narrated from Abu Hurairah, from the Messenger of Allah [SAW]}}
\hadithdefcmd{nasai}{5071}{أَخْبَرَنِي الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ تَصْبُغُ فَخَالِفُوا عَلَيْهِمْ فَاصْبُغُوا ‏"‏ ‏.‏\hadithno{5071}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'The Jews and the Christians do not dye their hair, so be different from them and dye your hair}}
\hadithdefcmd{nasai}{5072}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ حَدَّثَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ - عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سُلَيْمَانَ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ تَصْبُغُ فَخَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{5072}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet [SAW] said: "The Jews and Christians do not dye their hair, so be different from them}}
\hadithdefcmd{nasai}{5073}{أَخْبَرَنِي عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ جَنَابٍ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَيِّرُوا الشَّيْبَ وَلاَ تَشَبَّهُوا بِالْيَهُودِ ‏"‏ ‏.‏\hadithno{5073}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Change gray hair, but do not imitate the Jews}}
\hadithdefcmd{nasai}{5074}{أَخْبَرَنَا حُمَيْدُ بْنُ مَخْلَدِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ كُنَاسَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عُثْمَانَ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الزُّبَيْرِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَيِّرُوا الشَّيْبَ وَلاَ تَشَبَّهُوا بِالْيَهُودِ ‏"‏ ‏.‏ وَكِلاَهُمَا غَيْرُ مَحْفُوظٍ ‏.‏\hadithno{5074}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Az-Zubair said:"The Messenger of Allah [SAW] said: 'Change gray hair but do not imitate the Jews}}
\hadithdefcmd{nasai}{5075}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عُبَيْدِ اللَّهِ الْحَلَبِيُّ، عَنْ عُبَيْدِ اللَّهِ، - وَهُوَ ابْنُ عَمْرٍو - عَنْ عَبْدِ الْكَرِيمِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، رَفَعَهُ أَنَّهُ قَالَ ‏ "‏ قَوْمٌ يَخْضِبُونَ بِهَذَا السَّوَادِ آخِرَ الزَّمَانِ كَحَوَاصِلِ الْحَمَامِ لاَ يَرِيحُونَ رَائِحَةَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{5075}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas, who attributed it to the Prophet [SAW], said:"Some people will dye their hair black like the breasts of pigeons at the end of time, but they will not even smell the fragrance of Paradise}}
\hadithdefcmd{nasai}{5076}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أُتِيَ بِأَبِي قُحَافَةَ يَوْمَ فَتْحِ مَكَّةَ وَرَأْسُهُ وَلِحْيَتُهُ كَالثَّغَامَةِ بَيَاضًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَيِّرُوا هَذَا بِشَىْءٍ وَاجْتَنِبُوا السَّوَادَ ‏"‏ ‏.‏\hadithno{5076}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"Abu Quhafah was brought on the Day of the Conquest of Makkah, and his hair and beard were white like the Thaghamah. The Messenger of Allah [SAW] said: 'Change this with something, but avoid black}}
\hadithdefcmd{nasai}{5077}{أَخْبَرَنَا مُحَمَّدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ يَعْلَى، قَالَ حَدَّثَنَا بِهِ أَبِي، عَنْ غَيْلاَنَ، عَنْ أَبِي إِسْحَاقَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْضَلُ مَا غَيَّرْتُمْ بِهِ الشَّمَطَ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏\hadithno{5077}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Dharr that:The Prophet [SAW] said: "The best things with which you can change gray hair are Henna and Katam}}
\hadithdefcmd{nasai}{5078}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ الأَجْلَحِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحْسَنَ مَا غَيَّرْتُمْ بِهِ الشَّيْبَ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏\hadithno{5078}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah [SAW] said: 'The best things with which you can change gray hair are Henna and Katam}}
\hadithdefcmd{nasai}{5079}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَشْعَثَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنِي ابْنُ أَبِي لَيْلَى، عَنِ الأَجْلَحِ، فَلَقِيتُ الأَجْلَحَ فَحَدَّثَنِي عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ مِنْ أَحْسَنِ مَا غَيَّرْتُمْ بِهِ الشَّيْبَ الْحِنَّاءَ وَالْكَتَمَ ‏"‏ ‏.‏\hadithno{5079}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said:"I heard the Prophet [SAW] say: 'Some of the best things with which you can change gray hair are Henna and Katam}}
\hadithdefcmd{nasai}{5080}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنِ الأَجْلَحِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحْسَنَ مَا غَيَّرْتُمْ بِهِ الشَّيْبَ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏ خَالَفَهُ الْجُرَيْرِيُّ وَكَهْمَسٌ ‏.‏\hadithno{5080}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah [SAW] said: 'The best things with which you can change gray hair are Henna and Katam}}
\hadithdefcmd{nasai}{5081}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحْسَنَ مَا غَيَّرْتُمْ بِهِ الشَّيْبَ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏\hadithno{5081}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Buraidah said:"The Messenger of Allah [SAW] said: 'The best things with which you can change gray hair are Henna and Katam}}
\hadithdefcmd{nasai}{5082}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ كَهْمَسًا، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحْسَنَ مَا غَيَّرْتُمْ بِهِ الشَّيْبَ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏\hadithno{5082}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that:He heard that the Messenger of Allah [SAW] said: "The best things with which you can change gray hair are Henna and Katam}}
\hadithdefcmd{nasai}{5083}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ إِيَادِ بْنِ لَقِيطٍ، عَنْ أَبِي رِمْثَةَ، قَالَ أَتَيْتُ أَنَا وَأَبِي النَّبِيَّ، صلى الله عليه وسلم وَكَانَ قَدْ لَطَخَ لِحْيَتَهُ بِالْحِنَّاءِ ‏.‏\hadithno{5083}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Rimthah said:"My father and I came to the Prophet [SAW] and he had dyed his beard with Henna}}
\hadithdefcmd{nasai}{5084}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ إِيَادِ بْنِ لَقِيطٍ، عَنْ أَبِي رِمْثَةَ، رَضِيَ اللَّهُ عَنْهُ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَرَأَيْتُهُ قَدْ لَطَخَ لِحْيَتَهُ بِالصُّفْرَةِ ‏.‏\hadithno{5084}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Rimthah said:"I came to the Prophet [SAW] and I saw that he had dyed his beard with yellow dye}}
\hadithdefcmd{nasai}{5085}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا الدَّرَاوَرْدِيُّ، عَنْ زَيْدِ بْنِ أَسْلَمَ، قَالَ رَأَيْتُ ابْنَ عُمَرَ يُصَفِّرُ لِحْيَتَهُ بِالْخَلُوقِ فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّكَ تُصَفِّرُ لِحْيَتَكَ بِالْخَلُوقِ ‏.‏ قَالَ إِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَفِّرُ بِهَا لِحْيَتَهُ وَلَمْ يَكُنْ شَىْءٌ مِنَ الصِّبْغِ أَحَبَّ إِلَيْهِ مِنْهَا وَلَقَدْ كَانَ يَصْبُغُ بِهَا ثِيَابَهُ كُلَّهَا حَتَّى عِمَامَتَهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا أَوْلَى بِالصَّوَابِ مِنْ حَدِيثِ قُتَيْبَةَ ‏.‏\hadithno{5085}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Zaid bin Aslam said:"I saw Ibn 'Umar dyeing his beard yellow with Khaluq and I said: 'O Abu 'Abdur-Rahman, are you dyeing your beard yellow with Khaluq?' He said: 'I saw the Messenger of Allah [SAW] dyeing his beard yellow with it, and there was no other kind of dye that was dearer to him than this. He used to dye all of his clothes with it, even his 'Imamah (turban)}}
\hadithdefcmd{nasai}{5086}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّهُ سَأَلَهُ هَلْ خَضَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لَمْ يَبْلُغْ ذَلِكَ إِنَّمَا كَانَ شَىْءٌ فِي صُدْغَيْهِ ‏.‏\hadithno{5086}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Qatadah :That he asked Anas: "Did the Messenger of Allah [SAW] dye his hair? He said: "His gray hair didn't go far, it was only a little at his temples}}
\hadithdefcmd{nasai}{5087}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنَا الْمُثَنَّى، - يَعْنِي ابْنَ سَعِيدٍ - قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَخْضِبُ إِنَّمَا كَانَ الشَّمَطُ عِنْدَ الْعَنْفَقَةِ يَسِيرًا وَفِي الصُّدْغَيْنِ يَسِيرًا وَفِي الرَّأْسِ يَسِيرًا ‏.‏\hadithno{5087}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that:The Messenger of Allah [SAW] did not dye his hair; his gray hair were only a little beneath his lower lip and at his temples, and a little on his head}}
\hadithdefcmd{nasai}{5088}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ الرُّكَيْنَ، يُحَدِّثُ عَنِ الْقَاسِمِ بْنِ حَسَّانَ، عَنْ عَمِّهِ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَكْرَهُ عَشْرَ خِصَالٍ الصُّفْرَةَ يَعْنِي الْخَلُوقَ وَتَغْيِيرَ الشَّيْبِ وَجَرَّ الإِزَارِ وَالتَّخَتُّمَ بِالذَّهَبِ وَالضَّرْبَ بِالْكِعَابِ وَالتَّبَرُّجَ بِالزِّينَةِ لِغَيْرِ مَحِلِّهَا وَالرُّقَى إِلاَّ بِالْمُعَوِّذَاتِ وَتَعْلِيقَ التَّمَائِمِ وَعَزْلَ الْمَاءِ بِغَيْرِ مَحِلِّهِ وَإِفْسَادَ الصَّبِيِّ غَيْرَ مُحَرِّمِهِ ‏.‏\hadithno{5088}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud that:The Prophet of Allah [SAW] disliked ten things: Yellow dye, meaning Khaluq, changing gray hair, dragging one's Izar, wearing gold rings, playing with dice (Ki'ab), (a woman) showing her adornment to people to whom it is not permissible for her to show it, reciting Ruqyah, unless it is with Al-Mu'awidhat (Verses seeking refuge with Allah), hanging amulets, removing to ejaculate in other than the right place, and taking away the milk of an infant boy (by having intercourse with his mother)- but he did not say that this is Haram}}
\hadithdefcmd{nasai}{5089}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا الْمُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا مُطِيعُ بْنُ مَيْمُونٍ، حَدَّثَتْنَا صَفِيَّةُ بِنْتُ عِصْمَةَ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، مَدَّتْ يَدَهَا إِلَى النَّبِيِّ صلى الله عليه وسلم بِكِتَابٍ فَقَبَضَ يَدَهُ فَقَالَتْ يَا رَسُولَ اللَّهِ مَدَدْتُ يَدِي إِلَيْكَ بِكِتَابٍ فَلَمْ تَأْخُذْهُ ‏.‏ فَقَالَ ‏"‏ إِنِّي لَمْ أَدْرِ أَيَدُ امْرَأَةٍ هِيَ أَوْ رَجُلٍ ‏"‏ ‏.‏ قَالَتْ بَلْ يَدُ امْرَأَةٍ ‏.‏ قَالَ ‏"‏ لَوْ كُنْتِ امْرَأَةً لَغَيَّرْتِ أَظْفَارَكِ بِالْحِنَّاءِ ‏"‏ ‏.‏\hadithno{5089}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:A woman reached out her hand (to give) a letter to the Prophet [SAW], and he withdrew his hand. She said: "O Messenger of Allah, I reached out my hand (to give you) a letter and you did not take it." He said: "I did not know whether it was the hand of a woman or a man." She said: "It is the hand of a woman." He said: "If you were a woman, you would change your nails (by dyeing them with Henna)}}
\hadithdefcmd{nasai}{5090}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا أَبُو زَيْدٍ، سَعِيدُ بْنُ الرَّبِيعِ قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، قَالَ سَمِعْتُ كَرِيمَةَ، قَالَتْ سَمِعْتُ عَائِشَةَ، سَأَلَتْهَا امْرَأَةٌ عَنِ الْخِضَابِ، بِالْحِنَّاءِ قَالَتْ لاَ بَأْسَ بِهِ وَلَكِنْ أَكْرَهُ هَذَا لأَنَّ حِبِّي صلى الله عليه وسلم كَانَ يَكْرَهُ رِيحَهُ ‏.‏ تَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{5090}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Karimah said:"I heard a woman asking 'Aishah about dyeing the hair with Henna. She said: 'There is nothing wrong with it, but I do not like to do it because my beloved- meaning the Prophet [SAW]- disliked its smell}}
\hadithdefcmd{nasai}{5091}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، قَالَ حَدَّثَنَا أَبِي وَأَبُو الأَسْوَدِ النَّضْرُ بْنُ عَبْدِ الْجَبَّارِ، قَالاَ حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ عَيَّاشِ بْنِ عَبَّاسٍ الْقِتْبَانِيِّ، عَنْ أَبِي الْحُصَيْنِ الْهَيْثَمِ بْنِ شُفَىٍّ، - وَقَالَ أَبُو الأَسْوَدِ شَفِيٌّ - إِنَّهُ سَمِعَهُ يَقُولُ خَرَجْتُ أَنَا وَصَاحِبٌ، لِي يُسَمَّى أَبَا عَامِرٍ - رَجُلٌ مِنَ الْمَعَافِرِ - لِنُصَلِّيَ بِإِيلِيَاءَ وَكَانَ قَاصُّهُمْ رَجُلاً مِنَ الأَزْدِ يُقَالُ لَهُ أَبُو رَيْحَانَةَ مِنَ الصَّحَابَةِ قَالَ أَبُو الْحُصَيْنِ فَسَبَقَنِي صَاحِبِي إِلَى الْمَسْجِدِ ثُمَّ أَدْرَكْتُهُ فَجَلَسْتُ إِلَى جَنْبِهِ فَقَالَ هَلْ أَدْرَكْتَ قَصَصَ أَبِي رَيْحَانَةَ فَقُلْتُ لاَ ‏.‏ فَقَالَ سَمِعْتُهُ يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَشْرٍ عَنِ الْوَشْرِ وَالْوَشْمِ وَالنَّتْفِ وَعَنْ مُكَامَعَةِ الرَّجُلِ الرَّجُلَ بِغَيْرِ شِعَارٍ وَعَنْ مُكَامَعَةِ الْمَرْأَةِ الْمَرْأَةَ بِغَيْرِ شِعَارٍ وَأَنْ يَجْعَلَ الرَّجُلُ أَسْفَلَ ثِيَابِهِ حَرِيرًا مِثْلَ الأَعَاجِمِ أَوْ يَجْعَلَ عَلَى مَنْكِبَيْهِ حَرِيرًا أَمْثَالَ الأَعَاجِمِ وَعَنِ النُّهْبَى وَعَنْ رُكُوبِ النُّمُورِ وَلُبُوسِ الْخَوَاتِيمِ إِلاَّ لِذِي سُلْطَانٍ ‏.‏\hadithno{5091}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Al-Husain Al-Haitham bin Shufayy that he said:"A friend of mine who was called Abu 'Amir, from Al-Ma'afir, and I went out to pray in Jerusalem. Their preacher was a man from (the tribe of) Azd who was called Abu Raihanah, one of the Companions." Abu Al-Husain said: "My companion reached the Masjid before I did, then I caught up with him, and sat beside him. He said: 'Have you heard the preaching of Abu Raihanah?' I said: 'No.' He said: 'I heard him say: 'The Messenger of Allah [SAW] forbade ten things: Filing (the teeth), tattoos, plucking (hair), for two men to lie under one cover with no barrier between them, for two women to lie under one cover with no barrier between them, for a man to add more than four fingers' width of silk to the bottom of his garment like the foreigners (Persians), (and he forbade) plundering, riding (while sitting on) leopard skins and wearing rings- except for rulers}}
\hadithdefcmd{nasai}{5092}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ هِشَامٍ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ مُعَاوِيَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الزُّورِ ‏.‏\hadithno{5092}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sa'eed bin Al-Musayyab that Mu'awiyah said:"The Messenger of Allah [SAW] forbade giving a false impression}}
\hadithdefcmd{nasai}{5093}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، قَالَ رَأَيْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ عَلَى الْمِنْبَرِ وَمَعَهُ فِي يَدِهِ كُبَّةٌ مِنْ كُبَبِ النِّسَاءِ مِنْ شَعْرٍ فَقَالَ مَا بَالُ الْمُسْلِمَاتِ يَصْنَعْنَ مِثْلَ هَذَا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَيُّمَا امْرَأَةٍ زَادَتْ فِي رَأْسِهَا شَعْرًا لَيْسَ مِنْهُ فَإِنَّهُ زُورٌ تَزِيدُ فِيهِ ‏"‏ ‏.‏\hadithno{5093}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Sa'eed Al-Maqburi said:"I saw Mu'awiyah bin Abi Sufyan on the Minbar, holding a ball of hair such as women use. He said: "What is wrong with Muslim women who put such things (on their heads)? I heard the Messenger of Allah [SAW] say: "Any woman who adds hair to her head that is not hers, it is something false, that she is adding to her head}}
\hadithdefcmd{nasai}{5094}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو النَّضْرِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنِ امْرَأَتِهِ، فَاطِمَةَ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ ‏.‏\hadithno{5094}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hisham bin 'Urwah, from his wife Fatimah, from Asma' bint Abi Bakr, that:The Messenger of Allah [SAW] cursed the woman who affixes hair extensions and the woman who has that done}}
\hadithdefcmd{nasai}{5095}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُوتَشِمَةَ ‏.‏ أَرْسَلَهُ الْوَلِيدُ بْنُ أَبِي هِشَامٍ ‏.‏\hadithno{5095}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] cursed the woman who affixes hair extensions and the woman who has that done, the woman who does tattoos and the woman who has that done}}
\hadithdefcmd{nasai}{5096}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، قَالَ حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنِ الْوَلِيدِ بْنِ أَبِي هِشَامٍ، عَنْ نَافِعٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏.‏\hadithno{5096}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Nafi' that he heard that:The Messenger of Allah [SAW] cursed the woman who affixes hair extensions and the woman who has that done, the woman who does tattoos and the woman who has that done}}
\hadithdefcmd{nasai}{5097}{أَخْبَرَنَا مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مِسْكِينُ بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ ‏"‏ ‏.‏\hadithno{5097}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Safiyyah bint Shaibah, that 'Aishah said:"The Messenger of Allah [SAW] said: 'May Allah curse the woman who affixes hair extensions and the woman who has that done}}
\hadithdefcmd{nasai}{5098}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا خَلَفُ بْنُ مُوسَى، قَالَ حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنِ الْحَسَنِ الْعُرَنِيِّ، عَنْ يَحْيَى بْنِ الْجَزَّارِ، عَنْ مَسْرُوقٍ، أَنَّ امْرَأَةً، أَتَتْ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ فَقَالَتْ إِنِّي امْرَأَةٌ زَعْرَاءُ أَيَصْلُحُ أَنْ أَصِلَ فِي شَعْرِي فَقَالَ لاَ ‏.‏ قَالَتْ أَشَىْءٌ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَوْ تَجِدُهُ فِي كِتَابِ اللَّهِ قَالَ لاَ بَلْ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَجِدُهُ فِي كِتَابِ اللَّهِ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{5098}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Masruq that:A woman came to 'Abdullah bin Mas'ud and said: "I am a woman with little hair, is it alright for me to add extensions to my hair?" He said: "No." She said: "Is it something that you heard from the Messenger of Allah [SAW] or that you find in the Book of Allah?" He said: "No, rather I heard it from the Messenger of Allah [SAW] and I find it in the Book of Allah." And he quoted the Hadith}}
\hadithdefcmd{nasai}{5099}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاشِمَاتِ وَالْمُوتَشِمَاتِ وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ الْمُغَيِّرَاتِ ‏.‏\hadithno{5099}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] cursed the women who do tattoos and the women who have them done, Al-Mutanammisat, and the women who have their teeth separated for the sake of beauty, those who change (the creation of Allah)}}
\hadithdefcmd{nasai}{5100}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، قَالَ قَالَ عَبْدُ اللَّهِ الْمُتَفَلِّجَاتِ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{5100}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibrahim said:"Abdullah said: 'The women who have their teeth separated..." and he quoted the Hadith}}
\hadithdefcmd{nasai}{5101}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا أَبَانُ بْنُ صَمْعَةَ، عَنْ أُمِّهِ، قَالَتْ سَمِعْتُ عَائِشَةَ، تَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوَاشِمَةِ وَالْمُسْتَوْشِمَةِ وَالْوَاصِلَةِ وَالْمُسْتَوْصِلَةِ وَالنَّامِصَةِ وَالْمُتَنَمِّصَةِ ‏.‏\hadithno{5101}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Aban bin Sam'ah narrated that his mother said:"I heard 'Aishah say: 'The Messenger of Allah [SAW] forbade the woman who does tattoos and the woman who has that done, the woman who affixes hair extensions and the woman who has that done, An-Namisah (the one who does the plucking) and Al-Mutanammisah (the one who has it done)}}
\hadithdefcmd{nasai}{5102}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُرَّةَ، يُحَدِّثُ عَنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ، قَالَ آكِلُ الرِّبَا وَمُوكِلُهُ وَكَاتِبُهُ إِذَا عَلِمُوا ذَلِكَ وَالْوَاشِمَةُ وَالْمَوْشُومَةُ لِلْحُسْنِ وَلاَوِي الصَّدَقَةِ وَالْمُرْتَدُّ أَعْرَابِيًّا بَعْدَ الْهِجْرَةِ مَلْعُونُونَ عَلَى لِسَانِ مُحَمَّدٍ صلى الله عليه وسلم يَوْمَ الْقِيَامَةِ ‏.‏\hadithno{5102}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Murrah, from Al-Harith, from 'Abdullah, who said:"The one who consumes Riba, the one who pays it, and the one who writes it down, if they know that it is Riba; the woman who does tattoos and the woman who has that done for the purpose of beautification; the one who withholds Sadaqah (Zakah); and the one who reverts to the life of a Bedouin after having emigrated- they will (all) be cursed upon the tongue of Muhammad [SAW] on the Day of Resurrection}}
\hadithdefcmd{nasai}{5103}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا حُصَيْنٌ، وَمُغِيرَةُ، وَابْنُ، عَوْنٍ عَنِ الشَّعْبِيِّ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ آكِلَ الرِّبَا وَمُوكِلَهُ وَكَاتِبَهُ وَمَانِعَ الصَّدَقَةِ وَكَانَ يَنْهَى عَنِ النَّوْحِ ‏.‏ أَرْسَلَهُ ابْنُ عَوْنٍ وَعَطَاءُ بْنُ السَّائِبِ ‏.‏\hadithno{5103}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Husain, Mughirah, and Ibn 'Awn, from Ash-Sh'abi, from Al-Harith, from 'Ali, that:The Messenger of Allah [SAW] cursed the one who consumes Riba, the one who pays it, the one who writes it down, and the one who withholds Sadaqah (Zakah). And he used to forbid wailing (in mourning for the dead)}}
\hadithdefcmd{nasai}{5104}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الشَّعْبِيِّ، عَنِ الْحَارِثِ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم آكِلَ الرِّبَا وَمُوكِلَهُ وَشَاهِدَهُ وَكَاتِبَهُ وَالْوَاشِمَةَ وَالْمُوتَشِمَةَ قَالَ إِلاَّ مِنْ دَاءٍ فَقَالَ نَعَمْ وَالْحَالُّ وَالْمُحَلَّلُ لَهُ وَمَانِعُ الصَّدَقَةِ وَكَانَ يَنْهَى عَنِ النَّوْحِ وَلَمْ يَقُلْ لَعَنَ ‏.‏\hadithno{5104}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Awn, from Ash-Sha'bi, from Al-Harith, who said:"The Messenger of Allah [SAW] cursed the one who consumes Riba, the one who pays it, the one who writes it down and the one who witnesses it; the woman who does tattoos and the woman who has that done"- he said: "Unless it is done as a remedy;" he said: "Yes"- "the man who married a woman in order to divorce her so that she may go back to her first husband and the man (the first husband) for whom that is done; and the one who withholds Sadaqah (Zakah). And he used to forbid wailing (in mourning), but he did not say 'cursed}}
\hadithdefcmd{nasai}{5105}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا خَلَفٌ، - يَعْنِي ابْنَ خَلِيفَةَ - عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنِ الشَّعْبِيِّ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم آكِلَ الرِّبَا وَمُوكِلَهُ وَشَاهِدَهُ وَكَاتِبَهُ وَالْوَاشِمَةَ وَالْمُوتَشِمَةَ وَنَهَى عَنِ النَّوْحِ وَلَمْ يَقُلْ لَعَنَ صَاحِبَ ‏.‏\hadithno{5105}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that from 'Ata' bin As-Sa'ib, from Ash-Sha'bi who said:"The Messenger of Allah [SAW] cursed the one who consumes Riba, the one who pays it, the one who witnesses it and the one who writes it down; the woman who does tattoos and the woman who has that done; and forbade wailing (in mourning), but he did not say that its doer is cursed}}
\hadithdefcmd{nasai}{5106}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ عُمَرُ بِامْرَأَةٍ تَشِمُ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ هَلْ سَمِعَ أَحَدٌ مِنْكُمْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو هُرَيْرَةَ فَقُمْتُ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ أَنَا سَمِعْتُهُ ‏.‏ قَالَ فَمَا سَمِعْتَهُ قُلْتُ سَمِعْتُهُ يَقُولُ ‏ "‏ لاَ تَشِمْنَ وَلاَ تَسْتَوْشِمْنَ ‏"‏ ‏.‏\hadithno{5106}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"A woman who did tattoos was brought to 'Umar and he said: 'I adjure you by Allah, did any one among you hear (anything from) the Messenger of Allah [SAW]?' Abu Hurairah said: "I stood up and said: 'O Commander of the Believers! I heard him (say something).' He said: 'What did you hear?' I said: 'I heard him say: Do not do tattoos and do not have tattoos done}}
\hadithdefcmd{nasai}{5107}{أَخْبَرَنَا أَبُو عَلِيٍّ، مُحَمَّدُ بْنُ يَحْيَى الْمَرْوَزِيُّ قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، عَنْ أَبِي حَمْزَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنِ الْعُرْيَانِ بْنِ الْهَيْثَمِ، عَنْ قَبِيصَةَ بْنِ جَابِرٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْعَنُ الْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ وَالْمُوتَشِمَاتِ اللاَّتِي يُغَيِّرْنَ خَلْقَ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{5107}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Mas'ud said:"I heard the Messenger of Allah [SAW] cursing Al-Mutanammisat, women who have their teeth separated, and women who have tattoos done, those who change the creation of Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{5108}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنِ الْعُرْيَانِ بْنِ الْهَيْثَمِ، عَنْ قَبِيصَةَ بْنِ جَابِرٍ، عَنْ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْعَنُ الْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ وَالْمُوتَشِمَاتِ اللاَّتِي يُغَيِّرْنَ خَلْقَ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{5108}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"I heard the Messenger of Allah [SAW] cursing Al-Mutanammisat, women who have their teeth separated, and women who have tattoos done, those who change the creation of Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{5109}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ أَنْبَأَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، عَنِ الْعُرْيَانِ بْنِ الْهَيْثَمِ، عَنْ قَبِيصَةَ بْنِ جَابِرٍ، عَنْ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَعَنَ اللَّهُ الْمُتَنَمِّصَاتِ وَالْمُوتَشِمَاتِ وَالْمُتَفَلِّجَاتِ اللاَّتِي يُغَيِّرْنَ خَلْقَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{5109}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"I heard the Messenger of Allah [SAW] say: 'May Allah curse Al-Mutanammisat, women who have tattoos done and women who have their teeth separated, those who change the creation of Allah, Mighty and Sublime}}
\hadithdefcmd{nasai}{5110}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، قَالَ حَدَّثَنِي عَيَّاشُ بْنُ عَبَّاسٍ الْقِتْبَانِيُّ، عَنْ أَبِي الْحُصَيْنِ الْحِمْيَرِيِّ، أَنَّهُ كَانَ هُوَ وَصَاحِبٌ لَهُ يَلْزَمَانِ أَبَا رَيْحَانَةَ يَتَعَلَّمَانِ مِنْهُ خَيْرًا قَالَ فَحَضَرَ صَاحِبِي يَوْمًا فَأَخْبَرَنِي صَاحِبِي أَنَّهُ سَمِعَ أَبَا رَيْحَانَةَ يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّمَ الْوَشْرَ وَالْوَشْمَ وَالنَّتْفَ ‏.‏\hadithno{5110}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Al-Husain Al-Himyari that :He and a companion of his used to stay with Abu Raihanah to learn good things from him. He said: "One day my companion came and told me that he heard Abu Raihanah say: 'The Messenger of Allah [SAW] forbade filing (the teeth), tattoos, and plucking hairs}}
\hadithdefcmd{nasai}{5111}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْحُصَيْنِ الْحِمْيَرِيِّ، عَنْ أَبِي رَيْحَانَةَ، قَالَ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْوَشْرِ وَالْوَشْمِ ‏.‏\hadithno{5111}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Raihanah said:"We heard that the Messenger of Allah [SAW] forbade filing (the teeth) and tattoos}}
\hadithdefcmd{nasai}{5112}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْحُصَيْنِ الْحِمْيَرِيِّ، عَنْ أَبِي رَيْحَانَةَ، قَالَ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْوَشْرِ وَالْوَشْمِ ‏.‏\hadithno{5112}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Raihanah said:"We heard that the Messenger of Allah [SAW] forbade filing (the teeth) and tattoos}}
\hadithdefcmd{nasai}{5113}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا دَاوُدُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ - عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مِنْ خَيْرِ أَكْحَالِكُمُ الإِثْمِدَ إِنَّهُ يَجْلُو الْبَصَرَ وَيُنْبِتُ الشَّعَرَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ لَيِّنُ الْحَدِيثِ ‏.‏\hadithno{5113}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:The Messenger of Allah [SAW] said: "One of the best kinds of kohl that you use is Ithmid (antimony); it brightens the vision and makes the hair (eye-lashes) grow}}
\hadithdefcmd{nasai}{5114}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، سُئِلَ عَنْ شَيْبِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ إِذَا ادُّهِنَ رَأْسُهُ لَمْ يُرَ مِنْهُ وَإِذَا لَمْ يُدَّهَنْ رُئِيَ مِنْهُ ‏.‏\hadithno{5114}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Simak said:"I heard Jabir bin Samurah being asked about the gray hairs of the Prophet [SAW]. He said: 'If he put oil on his head they could not be seen, but if he did not put oil on his head, they could be seen}}
\hadithdefcmd{nasai}{5115}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا الْقَعْنَبِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ زَيْدٍ، عَنْ أَبِيهِ، أَنَّ ابْنَ عُمَرَ، كَانَ يَصْبُغُ ثِيَابَهُ بِالزَّعْفَرَانِ فَقِيلَ لَهُ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْبُغُ ‏.‏\hadithno{5115}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Zaid narrated from his father that:Ibn 'Umar used to dye his garments with saffron. He was asked about that and he said: "The Messenger of Allah [SAW] used to dye his clothes (with it)}}
\hadithdefcmd{nasai}{5116}{أَخْبَرَنَا أَبُو عُبَيْدَةَ بْنُ أَبِي السَّفَرِ، عَنْ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا بَكْرٌ الْمُزَلِّقُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَطَاءٍ الْهَاشِمِيُّ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، قَالَ سَأَلْتُ عَائِشَةَ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَطَيَّبُ قَالَتْ نَعَمْ بِذِكَارَةِ الطِّيبِ الْمِسْكِ وَالْعَنْبَرِ ‏.‏\hadithno{5116}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muhammad bin 'Ali said:"I asked 'Aishah: 'Did the Messenger of Allah [SAW] wear perfume?' She said: 'Yes, the perfumes used by men: Musk and amber}}
\hadithdefcmd{nasai}{5117}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، - يَعْنِي الْحَفَرِيَّ - عَنْ سُفْيَانَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ رَجُلٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ طِيبُ الرِّجَالِ مَا ظَهَرَ رِيحُهُ وَخَفِيَ لَوْنُهُ وَطِيبُ النِّسَاءِ مَا ظَهَرَ لَوْنُهُ وَخَفِيَ رِيحُهُ ‏"‏ ‏.‏\hadithno{5117}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'The perfume for men is that whose scent is apparent while its color is hidden, and the perfume for women is that whose color is apparent, while its scent is hidden}}
\hadithdefcmd{nasai}{5118}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ الرَّقِّيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ الْفِرْيَابِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنِ الطُّفَاوِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ طِيبُ الرِّجَالِ مَا ظَهَرَ رِيحُهُ وَخَفِيَ لَوْنُهُ وَطِيبُ النِّسَاءِ مَا ظَهَرَ لَوْنُهُ وَخَفِيَ رِيحُهُ ‏"‏ ‏.‏\hadithno{5118}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet [SAW] said: "The perfume for men is that whose scent is apparent while its color is hidden, and the perfume for women is that whose color is apparent, while its scent is hidden}}
\hadithdefcmd{nasai}{5119}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا شَبَابَةُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ خُلَيْدِ بْنِ جَعْفَرٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ امْرَأَةً مِنْ بَنِي إِسْرَائِيلَ اتَّخَذَتْ خَاتِمًا مِنَ ذَهَبٍ وَحَشَتْهُ مِسْكًا ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ أَطْيَبُ الطِّيبِ ‏"‏ ‏.‏\hadithno{5119}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah [SAW] said: 'A woman from among the Children of Israel took a ring of gold and filled it with musk.' The Messenger of Allah [SAW] said: 'That is the best kind of perfume}}
\hadithdefcmd{nasai}{5120}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عِمْرَانَ بْنِ ظَبْيَانَ، عَنْ حُكَيْمِ بْنِ سَعْدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم بِهِ رَدْعٌ مِنْ خَلُوقٍ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اذْهَبْ فَانْهَكْهُ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ فَقَالَ ‏"‏ اذْهَبْ فَانْهَكْهُ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ فَقَالَ ‏"‏ اذْهَبْ فَانْهَكْهُ ثُمَّ لاَ تَعُدْ ‏"‏ ‏.‏\hadithno{5120}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"A man came to the Prophet [SAW] wearing a little dab of Khaluq." The Prophet [SAW] said to him: 'Go and scrub it off.' Then he came (again) and he said: 'Go and scrub it off.' Then he came to him (again) and he said: 'Go and scrub it off, and don't put it on again}}
\hadithdefcmd{nasai}{5121}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، قَالَ سَمِعْتُ أَبَا حَفْصِ بْنَ عَمْرٍو، وَقَالَ، عَلَى إِثْرِهِ يُحَدِّثُ عَنْ يَعْلَى بْنِ مُرَّةَ، أَنَّهُ مَرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ مُتَخَلِّقٌ فَقَالَ لَهُ ‏"‏ هَلْ لَكَ امْرَأَةٌ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَاغْسِلْهُ ثُمَّ اغْسِلْهُ ثُمَّ لاَ تَعُدْ ‏"‏ ‏.‏\hadithno{5121}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ya'la bin Murrah that:He passed by the Prophet [SAW] wearing Khaluq. He said to him: "Do you have a wife?" I said: "No." He said: "Wash it off, then wash it off, then do not put it on again}}
\hadithdefcmd{nasai}{5122}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ ‏\{‏ أَبَا، ‏\}‏ حَفْصِ بْنَ عَمْرٍو عَنْ يَعْلَى بْنِ مُرَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَبْصَرَ رَجُلاً مُتَخَلِّقًا قَالَ ‏ "‏ اذْهَبْ فَاغْسِلْهُ ثُمَّ اغْسِلْهُ وَلاَ تَعُدْ ‏"‏ ‏.‏\hadithno{5122}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ya'la bin Murrah that:The Messenger of Allah [SAW] saw a man wearing Khaluq and said: "Go and wash it off, then wash it off, and do not put it on again}}
\hadithdefcmd{nasai}{5123}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَمْرٍو، عَنْ رَجُلٍ، عَنْ يَعْلَى، نَحْوَهُ ‏.‏ خَالَفَهُ سُفْيَانُ رَوَاهُ عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَبْدِ اللَّهِ بْنِ حَفْصٍ، عَنْ يَعْلَى، ‏.‏\hadithno{5123}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Daif}\hadithtrans{Narrated from Ibn 'Amr:A similar report was narrated from Ibn 'Amr, from a man, from Ya'la}}
\hadithdefcmd{nasai}{5124}{أَخْبَرَنَا مُحَمَّدُ بْنُ النَّضْرِ بْنِ مُسَاوِرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَبْدِ اللَّهِ بْنِ حَفْصٍ، عَنْ يَعْلَى بْنِ مُرَّةَ الثَّقَفِيِّ، قَالَ أَبْصَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِي رَدْعٌ مِنْ خَلُوقٍ قَالَ ‏"‏ يَا يَعْلَى لَكَ امْرَأَةٌ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ اغْسِلْهُ ثُمَّ لاَ تَعُدْ ثُمَّ اغْسِلْهُ ثُمَّ لاَ تَعُدْ ثُمَّ اغْسِلْهُ ثُمَّ لاَ تَعُدْ ‏"‏ ‏.‏ قَالَ فَغَسَلْتُهُ ثُمَّ لَمْ أَعُدْ ثُمَّ غَسَلْتُهُ ثُمَّ لَمْ أَعُدْ ثُمَّ غَسَلْتُهُ ثُمَّ لَمْ أَعُدْ ‏.‏\hadithno{5124}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ya'la bin Murrah Ath-Thaqafi said:"The Messenger of Allah [SAW] saw me wearing a little dab of Khaluq. He said: 'O Ya'la, do you have a wife?' I said: 'No.' He said: 'Wash it off and do not put it on again, then wash it off and do not put it on again, then wash it off and do not put it on again.' I said: 'So I washed it off, and did not put it on again, then I washed it off and did not put it on again, then I washed it off, and did not put it on again}}
\hadithdefcmd{nasai}{5125}{أَخْبَرَنِي إِسْمَاعِيلُ بْنُ يَعْقُوبَ الصَّبِيحِيُّ، قَالَ حَدَّثَنَا ابْنُ مُوسَى، - يَعْنِي مُحَمَّدًا - قَالَ أَخْبَرَنِي أَبِي، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَبْدِ اللَّهِ بْنِ حَفْصٍ، عَنْ يَعْلَى، قَالَ مَرَرْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا مُتَخَلِّقٌ فَقَالَ ‏"‏ أَىْ يَعْلَى هَلْ لَكَ امْرَأَةٌ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَاغْسِلْهُ ثُمَّ اغْسِلْهُ ثُمَّ اغْسِلْهُ ثُمَّ لاَ تَعُدْ ‏"‏ ‏.‏ قَالَ ‏.‏ فَذَهَبْتُ فَغَسَلْتُهُ ثُمَّ غَسَلْتُهُ ثُمَّ غَسَلْتُهُ ثُمَّ لَمْ أَعُدْ ‏.‏\hadithno{5125}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ya'la said:"I passed by the Messenger of Allah [SAW] and I was wearing Khaluq. He said: 'O Ya'la, do you have a wife?' I said: 'No.' He said: 'Go and wash it off, then wash it off, then wash it off, and do not put it on again.' So I went and washed it off, then washed it off, then washed it off, and I did not put it on again}}
\hadithdefcmd{nasai}{5126}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ثَابِتٌ، - وَهُوَ ابْنُ عُمَارَةَ - عَنْ غُنَيْمِ بْنِ قَيْسٍ، عَنِ الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرَأَةٍ اسْتَعْطَرَتْ فَمَرَّتْ عَلَى قَوْمٍ لِيَجِدُوا مِنْ رِيحِهَا فَهِيَ زَانِيَةٌ ‏"‏ ‏.‏\hadithno{5126}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Al-Ash'ari said:"The Messenger of Allah [SAW] said: 'Any woman who puts on perfume then passes by people so that they can smell her fragrance then she is an adulteress}}
\hadithdefcmd{nasai}{5127}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ بْنِ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ الْعَبَّاسِ الْهَاشِمِيِّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، قَالَ سَمِعْتُ صَفْوَانَ بْنَ سُلَيْمٍ، - وَلَمْ أَسْمَعْ مِنْ صَفْوَانَ غَيْرَهُ - يُحَدِّثُ عَنْ رَجُلٍ ثِقَةٍ عَنْ أَبِي هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا خَرَجَتِ الْمَرْأَةُ إِلَى الْمَسْجِدِ فَلْتَغْتَسِلْ مِنَ الطِّيبِ كَمَا تَغْتَسِلُ مِنَ الْجَنَابَةِ ‏"‏ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{5127}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'If a woman goes out to the Masjid, let her perform Ghusl to remove perfume as she would perform Ghusl to remove Janabah (impurity following sexual activity).'" This is an abridged form of it}}
\hadithdefcmd{nasai}{5128}{أَخْبَرَنَا مُحَمَّدُ بْنُ هِشَامِ بْنِ عِيسَى الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا أَبُو عَلْقَمَةَ الْفَرْوِيُّ عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ خُصَيْفَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرَأَةٍ أَصَابَتْ بَخُورًا فَلاَ تَشْهَدْ مَعَنَا الْعِشَاءَ الآخِرَةَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ أَعْلَمُ أَحَدًا تَابَعَ يَزِيدَ بْنَ خُصَيْفَةَ عَنْ بُسْرِ بْنِ سَعِيدٍ عَلَى قَوْلِهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَقَدْ خَالَفَهُ يَعْقُوبُ بْنُ عَبْدِ اللَّهِ بْنِ الأَشَجِّ رَوَاهُ عَنْ زَيْنَبَ الثَّقَفِيَّةِ ‏.‏\hadithno{5128}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'If a woman has perfumed herself with incense, let her not attend 'Isha' prayer}}
\hadithdefcmd{nasai}{5129}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ بْنِ هِلاَلٍ، قَالَ حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَهِدَتْ إِحْدَاكُنَّ صَلاَةَ الْعِشَاءِ فَلاَ تَمَسَّ طِيبًا ‏"‏ ‏.‏\hadithno{5129}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Zainab, the wife of 'Abdullah, said:"The Messenger of Allah [SAW] said: 'If one of you wants to attend 'Isha' prayer, let her not touch perfume}}
\hadithdefcmd{nasai}{5130}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ ابْنِ عَجْلاَنَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَهِدَتْ إِحْدَاكُنَّ الْعِشَاءَ فَلاَ تَمَسَّ طِيبًا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ حَدِيثُ يَحْيَى وَجَرِيرٍ أَوْلَى بِالصَّوَابِ مِنْ حَدِيثِ وُهَيْبِ بْنِ خَالِدٍ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{5130}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zainab, the wife of 'Abdullah, said:The Messenger of Allah [SAW] said: "If one of you wants to attend 'Isha' prayer, let her not touch perfume}}
\hadithdefcmd{nasai}{5131}{أَخْبَرَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ يَعْقُوبَ الْحِمْصِيُّ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ الثَّقَفِيَّةِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيَّتُكُنَّ خَرَجَتْ إِلَى الْمَسْجِدِ فَلاَ تَقْرَبَنَّ طِيبًا ‏"‏ ‏.‏\hadithno{5131}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab Ath-Thaqafiyyah that :The Prophet of Allah [SAW] said: "If any one of you goes out to the Masjid, let her not go near perfume}}
\hadithdefcmd{nasai}{5132}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ الْقُرَشِيِّ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ زَيْنَبَ الثَّقَفِيَّةِ، امْرَأَةِ عَبْدِ اللَّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهَا أَنْ لاَ تَمَسَّ الطِّيبَ إِذَا خَرَجَتْ إِلَى الْعِشَاءِ الآخِرَةِ ‏.‏\hadithno{5132}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab Ath-Thaqafiyyah, the wife of 'Abdullah, that:The Messenger of Allah [SAW] told her not to touch perfume if she wanted to go out to 'Isha' the later}}
\hadithdefcmd{nasai}{5133}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، قَالَ أَنْبَأَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ هِشَامٍ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ الثَّقَفِيَّةِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا خَرَجَتِ الْمَرْأَةُ إِلَى الْعِشَاءِ الآخِرَةِ فَلاَ تَمَسَّ طِيبًا ‏"‏ ‏.‏\hadithno{5133}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab Ath-Thaqafiyyah that:The Messenger of Allah [SAW] said: "If a woman goes out to (pray) 'Isha', let her not touch perfume}}
\hadithdefcmd{nasai}{5134}{أَخْبَرَنِي يُوسُفُ بْنُ سَعِيدٍ، قَالَ بَلَغَنِي عَنْ حَجَّاجٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي زِيَادُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ الثَّقَفِيَّةِ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَهِدَتْ إِحْدَاكُنَّ الصَّلاَةَ فَلاَ تَمَسَّ طِيبًا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا غَيْرُ مَحْفُوظٍ مِنْ حَدِيثِ الزُّهْرِيِّ ‏.‏\hadithno{5134}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zainab Ath-Thaqafiyyah said:"The Messenger of Allah [SAW] said: 'If one of you wants to attend the prayer, let her not touch perfume}}
\hadithdefcmd{nasai}{5135}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ أَبُو طَاهِرٍ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ إِذَا اسْتَجْمَرَ اسْتَجْمَرَ بِالأُلُوَّةِ غَيْرَ مُطَرَّاةٍ وَبِكَافُورٍ يَطْرَحُهُ مَعَ الأُلُوَّةِ ثُمَّ قَالَ هَكَذَا كَانَ يَسْتَجْمِرُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5135}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Nafi' said:"When Ibn 'Umar burned incense he would burn Al-Uluwwah that was not mixed with anything else, or camphor mixed with some Al-Uluwwah. Then he said: 'This is what the Messenger of Allah [SAW] used to burn}}
\hadithdefcmd{nasai}{5136}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا عُشَّانَةَ، - هُوَ الْمَعَافِرِيُّ - حَدَّثَهُ أَنَّهُ، سَمِعَ عُقْبَةَ بْنَ عَامِرٍ، يُخْبِرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَمْنَعُ أَهْلَهُ الْحِلْيَةَ وَالْحَرِيرَ وَيَقُولُ ‏ "‏ إِنْ كُنْتُمْ تُحِبُّونَ حِلْيَةَ الْجَنَّةِ وَحَرِيرَهَا فَلاَ تَلْبَسُوهَا فِي الدُّنْيَا ‏"‏ ‏.‏\hadithno{5136}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Uqbah bin 'Amir narrated that:The Messenger of Allah [SAW] used to tell his wives not to wear jewelry and silk. He said: "If you want the jewelry and silk of Paradise, then do not wear them in this world}}
\hadithdefcmd{nasai}{5137}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، عَنِ امْرَأَتِهِ، عَنْ أُخْتِ، حُذَيْفَةَ قَالَتْ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا مَعْشَرَ النِّسَاءِ أَمَا لَكُنَّ فِي الْفِضَّةِ مَا تَحَلَّيْنَ أَمَا إِنَّهُ لَيْسَ مِنِ امْرَأَةٍ تَحَلَّتْ ذَهَبًا تُظْهِرُهُ إِلاَّ عُذِّبَتْ بِهِ ‏"‏ ‏.‏\hadithno{5137}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Rib'i, from his wife, that the sister of Hudhaifah said:"The Messenger of Allah [SAW] addressed us and said: 'O women, do you not have any silver to wear for adornment? For there is no woman among you who wears gold and shows it, but she will be punished because of it}}
\hadithdefcmd{nasai}{5138}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ مَنْصُورًا، يُحَدِّثُ عَنْ رِبْعِيٍّ، عَنِ امْرَأَتِهِ، عَنْ أُخْتِ، حُذَيْفَةَ قَالَتْ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا مَعْشَرَ النِّسَاءِ أَمَا لَكُنَّ فِي الْفِضَّةِ مَا تَحَلَّيْنَ أَمَا إِنَّهُ لَيْسَ مِنْكُنَّ امْرَأَةٌ تُحَلَّى ذَهَبًا تُظْهِرُهُ إِلاَّ عُذِّبَتْ بِهِ ‏"‏ ‏.‏\hadithno{5138}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Rib'i, from his wife, that the sister of Hudhaifah said:"The Messenger of Allah [SAW] addressed us and said: 'O women, do you not have any silver to wear for adornment? For there is no woman among you who wears gold and shows it, but she will be punished because of it}}
\hadithdefcmd{nasai}{5139}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي مَحْمُودُ بْنُ عَمْرٍو، أَنَّ أَسْمَاءَ بِنْتَ يَزِيدَ، حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ تَحَلَّتْ - يَعْنِي - بِقِلاَدَةٍ مِنْ ذَهَبٍ جُعِلَ فِي عُنُقِهَا مِثْلُهَا مِنَ النَّارِ وَأَيُّمَا امْرَأَةٍ جَعَلَتْ فِي أُذُنِهَا خُرْصًا مِنْ ذَهَبٍ جَعَلَ اللَّهُ عَزَّ وَجَلَّ فِي أُذُنِهَا مِثْلَهُ خُرْصًا مِنَ النَّارِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5139}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Asma' bint Yazid narrated that:The Messenger of Allah [SAW] said: "Any woman who puts on a necklace of gold, Allah will put something similar of fire around her neck. Any woman who puts earrings of gold on her ears, Allah, the Mighty and Sublime, will put earrings of fire on her ears on the Day of Resurrection}}
\hadithdefcmd{nasai}{5140}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي زَيْدٌ، عَنْ أَبِي سَلاَّمٍ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، أَنَّ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حَدَّثَهُ قَالَ جَاءَتْ بِنْتُ هُبَيْرَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي يَدِهَا فَتَخٌ - فَقَالَ كَذَا فِي كِتَابِ أَبِي أَىْ خَوَاتِيمَ ضِخَامٍ - فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضْرِبُ يَدَهَا فَدَخَلَتْ عَلَى فَاطِمَةَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَشْكُو إِلَيْهَا الَّذِي صَنَعَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَانْتَزَعَتْ فَاطِمَةُ سِلْسِلَةً فِي عُنُقِهَا مِنْ ذَهَبٍ وَقَالَتْ هَذِهِ أَهْدَاهَا إِلَىَّ أَبُو حَسَنٍ فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالسِّلْسِلَةُ فِي يَدِهَا فَقَالَ ‏"‏ يَا فَاطِمَةُ أَيَغُرُّكِ أَنْ يَقُولَ النَّاسُ ابْنَةُ رَسُولِ اللَّهِ وَفِي يَدِهَا سِلْسِلَةٌ مِنْ نَارٍ ‏"‏ ‏.‏ ثُمَّ خَرَجَ وَلَمْ يَقْعُدْ فَأَرْسَلَتْ فَاطِمَةُ بِالسِّلْسِلَةِ إِلَى السُّوقِ فَبَاعَتْهَا وَاشْتَرَتْ بِثَمَنِهَا غُلاَمًا - وَقَالَ مَرَّةً عَبْدًا - وَذَكَرَ كَلِمَةً مَعْنَاهَا فَأَعْتَقَتْهُ فَحُدِّثَ بِذَلِكَ فَقَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَنْجَى فَاطِمَةَ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{5140}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Asma' Ar-Rahabi that Thawban, the freed slave of the Messenger of Allah [SAW], told him:"Fatimah bint Hubairah came to the Messenger of Allah [SAW] with a big ring on her hand." He (the narrator) said: "This is what I found in the book of my father, a huge ring."- "The Messenger of Allah [SAW] started hitting her hand, so she entered upon Fatimah, the daughter of the Messenger of Allah [SAW], and complained to her about what the Messenger of Allah [SAW] had done. Fatimah took off a gold chain from her neck and said: 'This was given to me by Abu Hasan.' The Messenger of Allah [SAW] came in and (ﷺ) the chain in her hand. He said: 'O Fatimah, would you like the people to say that the daughter of the Messenger of Allah [SAW] has a chain of fire in her hand?' Then he went out, without sitting down. Fatimah sent the chain to the market and sold it, and she bought a slave with the money, and set him free. He was told of that and he said: 'Praise be to Allah, Who has saved Fatimah from the Fire}}
\hadithdefcmd{nasai}{5141}{أَخْبَرَنَا سُلَيْمَانُ بْنُ سَلْمٍ الْبَلْخِيُّ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلاَّمٍ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ جَاءَتْ بِنْتُ هُبَيْرَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي يَدِهَا فَتَخٌ مِنْ ذَهَبٍ أَىْ خَوَاتِيمَ ضِخَامٍ نَحْوَهُ ‏.‏\hadithno{5141}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Thawban said:"The daughter of Hubairah came to the Messenger of Allah [SAW] and on her hand were large gold rings." - a similar report}}
\hadithdefcmd{nasai}{5142}{أَخْبَرَنَا إِسْحَاقُ بْنُ شَاهِينَ الْوَاسِطِيُّ، قَالَ أَنْبَأَنَا خَالِدٌ، عَنْ مُطَرِّفٍ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَسْبَاطٌ، عَنْ مُطَرِّفٍ، عَنْ أَبِي الْجَهْمِ، عَنْ أَبِي زَيْدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنْتُ قَاعِدًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَتَتْهُ امْرَأَةٌ فَقَالَتْ يَا رَسُولَ اللَّهِ سِوَارَيْنِ مِنْ ذَهَبٍ ‏.‏ قَالَ ‏"‏ سِوَارَانِ مِنْ نَارٍ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ طَوْقٌ مِنْ ذَهَبٍ ‏.‏ قَالَ ‏"‏ طَوْقٌ مِنْ نَارٍ ‏"‏ ‏.‏ قَالَتْ قُرْطَيْنِ مِنْ ذَهَبٍ ‏.‏ قَالَ ‏"‏ قُرْطَيْنِ مِنْ نَارٍ ‏"‏ ‏.‏ قَالَ وَكَانَ عَلَيْهِمَا سِوَارَانِ مِنْ ذَهَبٍ فَرَمَتْ بِهِمَا قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ الْمَرْأَةَ إِذَا لَمْ تَتَزَيَّنْ لِزَوْجِهَا صَلِفَتْ عِنْدَهُ ‏.‏ قَالَ ‏"‏ مَا يَمْنَعُ إِحْدَاكُنَّ أَنْ تَصْنَعَ قُرْطَيْنِ مِنْ فِضَّةٍ ثُمَّ تُصَفِّرَهُ بِزَعْفَرَانٍ أَوْ بِعَبِيرٍ ‏"‏ ‏.‏ اللَّفْظُ لاِبْنِ حَرْبٍ ‏.‏\hadithno{5142}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"I was sitting with the Prophet [SAW] when a woman came to him and said: 'O Messenger of Allah, two bracelets of gold.' He said: 'Two bracelets of fire.' She said: 'O Messenger of Allah, a necklace of gold.' He said: 'A necklace of fire.' She said: 'Two earrings of gold.' He said: 'Two earrings of fire.' She was wearing two bracelets of gold, so she took them off and said: 'O Messenger of Allah, if a woman does not adorn herself for her husband, she will become unattractive to him.' He said: 'What is there to keep any one of you from making earrings of silver and painting them yellow with saffron or some 'Abir'?' This is the wording of Ibn Harb}}
\hadithdefcmd{nasai}{5143}{أَخْبَرَنِي الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى عَلَيْهَا مَسَكَتَىْ ذَهَبٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُخْبِرُكِ بِمَا هُوَ أَحْسَنُ مِنْ هَذَا لَوْ نَزَعْتِ هَذَا وَجَعَلْتِ مَسَكَتَيْنِ مِنْ وَرِقٍ ثُمَّ صَفَّرْتِهِمَا بِزَعْفَرَانٍ كَانَتَا حَسَنَتَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا غَيْرُ مَحْفُوظٍ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{5143}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah [SAW] saw her wearing two bracelets of gold. The Messenger of Allah [SAW] said: "Shall I not tell you of something that is better than this? Why don't you take these off and wear two bracelets of silver, and paint them yellow with saffron, and they will look fine}}
\hadithdefcmd{nasai}{5144}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي أَفْلَحَ الْهَمْدَانِيِّ، عَنِ ابْنِ زُرَيْرٍ، أَنَّهُ سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَخَذَ حَرِيرًا فَجَعَلَهُ فِي يَمِينِهِ وَأَخَذَ ذَهَبًا فَجَعَلَهُ فِي شِمَالِهِ ثُمَّ قَالَ ‏ "‏ إِنَّ هَذَيْنِ حَرَامٌ عَلَى ذُكُورِ أُمَّتِي ‏"‏ ‏.‏\hadithno{5144}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali bin Abi Talib said:"The Prophet of Allah [SAW] took hold of some silk in his right hand and some gold in his left, then he said: 'These two are forbidden for the males of my Ummah}}
\hadithdefcmd{nasai}{5145}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنِ ابْنِ أَبِي الصَّعْبَةِ، عَنْ رَجُلٍ، مِنْ هَمْدَانَ يُقَالُ لَهُ أَبُو أَفْلَحَ عَنِ ابْنِ زُرَيْرٍ، أَنَّهُ سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ حَرِيرًا فَجَعَلَهُ فِي يَمِينِهِ وَأَخَذَ ذَهَبًا فَجَعَلَهُ فِي شِمَالِهِ ثُمَّ قَالَ ‏ "‏ إِنَّ هَذَيْنِ حَرَامٌ عَلَى ذُكُورِ أُمَّتِي ‏"‏ ‏.‏\hadithno{5145}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali bin Abi Talib said:"The Prophet of Allah [SAW] took hold of some silk in his right hand, and some gold in his left, then he said: 'These two are forbidden for the males of my Ummah}}
\hadithdefcmd{nasai}{5146}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ لَيْثِ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنِ ابْنِ أَبِي الصَّعْبَةِ، عَنْ رَجُلٍ، مِنْ هَمْدَانَ يُقَالُ لَهُ أَفْلَحُ عَنِ ابْنِ زُرَيْرٍ، أَنَّهُ سَمِعَ عَلِيًّا، يَقُولُ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَخَذَ حَرِيرًا فَجَعَلَهُ فِي يَمِينِهِ وَأَخَذَ ذَهَبًا فَجَعَلَهُ فِي شِمَالِهِ ثُمَّ قَالَ ‏ "‏ إِنَّ هَذَيْنِ حَرَامٌ عَلَى ذُكُورِ أُمَّتِي ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَحَدِيثُ ابْنُ الْمُبَارَكِ أَوْلَى بِالصَّوَابِ إِلاَّ قَوْلَهُ أَفْلَحَ فَإِنَّ أَبَا أَفْلَحَ أَشْبَهُ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{5146}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali said:"The Prophet of Allah [SAW] took hold of some silk in his right hand, and some gold in his left, then he said: 'These two are forbidden for the males of my Ummah}}
\hadithdefcmd{nasai}{5147}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي الصَّعْبَةِ، عَنْ أَبِي أَفْلَحَ الْهَمْدَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ زُرَيْرٍ الْغَافِقِيِّ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَهَبًا بِيَمِينِهِ وَحَرِيرًا بِشِمَالِهِ فَقَالَ ‏ "‏ هَذَا حَرَامٌ عَلَى ذُكُورِ أُمَّتِي ‏"‏ ‏.‏\hadithno{5147}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Zurair Al-Ghafiqi said:"I heard 'Ali say: 'The Messenger of Allah [SAW] took some gold in his right hand and some silk in his left hand and said: This is forbidden for the males of my Ummah}}
\hadithdefcmd{nasai}{5148}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ الدِّرْهَمِيُّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي مُوسَى، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُحِلَّ الذَّهَبُ وَالْحَرِيرُ لإِنَاثِ أُمَّتِي وَحُرِّمَ عَلَى ذُكُورِهَا ‏"‏ ‏.‏\hadithno{5148}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Musa that :The Messenger of Allah [SAW] said: "Gold and silk have been permitted for the females of my Ummah, and forbidden to the males}}
\hadithdefcmd{nasai}{5149}{أَخْبَرَنَا الْحَسَنُ بْنُ قَزَعَةَ، عَنْ سُفْيَانَ بْنِ حَبِيبٍ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ مُعَاوِيَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الْحَرِيرِ وَالذَّهَبِ إِلاَّ مُقَطَّعًا ‏.‏ خَالَفَهُ عَبْدُ الْوَهَّابِ رَوَاهُ عَنْ خَالِدٍ عَنْ مَيْمُونٍ عَنْ أَبِي قِلاَبَةَ ‏.‏\hadithno{5149}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mu'awiyah that:The Messenger of Allah [SAW] forbade wearing silk and gold, unless it was broken (into smaller pieces)}}
\hadithdefcmd{nasai}{5150}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ مَيْمُونٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ مُعَاوِيَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الذَّهَبِ إِلاَّ مُقَطَّعًا وَعَنْ رُكُوبِ الْمَيَاثِرِ ‏.‏\hadithno{5150}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mu'awiyah that :The Messenger of Allah [SAW] forbade wearing gold unless it was broken (into smaller pieces), and (he forbade) riding on Al-Mayathir}}
\hadithdefcmd{nasai}{5151}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي شَيْخٍ، أَنَّهُ سَمِعَ مُعَاوِيَةَ، وَعِنْدَهُ، جَمْعٌ مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم قَالَ أَتَعْلَمُونَ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الذَّهَبِ إِلاَّ مُقَطَّعًا قَالُوا اللَّهُمَّ نَعَمْ ‏.‏\hadithno{5151}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Shaikh that he heard Mu'awiyah say,:When a group of the Companions of Muhammad [SAW] were with him: "Do you know that the Prophet of Allah [SAW] forbade wearing gold unless it was broken (into smaller pieces)?" They said: "By Allah, yes}}
\hadithdefcmd{nasai}{5152}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ أَنْبَأَنَا أَسْبَاطٌ، عَنْ مُغِيرَةَ، عَنْ مَطَرٍ، عَنْ أَبِي شَيْخٍ، قَالَ بَيْنَمَا نَحْنُ مَعَ مُعَاوِيَةَ فِي بَعْضِ حَجَّاتِهِ إِذْ جَمَعَ رَهْطًا مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم فَقَالَ لَهُمْ أَلَسْتُمْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الذَّهَبِ إِلاَّ مُقَطَّعًا قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ خَالَفَهُ يَحْيَى بْنُ أَبِي كَثِيرٍ عَلَى اخْتِلاَفٍ بَيْنَ أَصْحَابِهِ عَلَيْهِ ‏.‏\hadithno{5152}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Shaikh said:"While we were with Mu'awiyah on one of his pilgrimages, he gathered together a group of the Companions of Muhammad [SAW] and said to them: 'Do you not know that the Messenger of Allah [SAW] forbade wearing gold unless it was broken (into smaller pieces)?' They said: 'By Allah, yes}}
\hadithdefcmd{nasai}{5153}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى، حَدَّثَنِي أَبُو شَيْخٍ الْهُنَائِيُّ، عَنْ أَبِي حِمَّانَ، أَنَّ مُعَاوِيَةَ، عَامَ حَجَّ جَمَعَ نَفَرًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْكَعْبَةِ فَقَالَ لَهُمْ أَنْشُدُكُمُ اللَّهَ أَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسِ الذَّهَبِ قَالُوا نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ ‏.‏ خَالَفَهُ حَرْبُ بْنُ شَدَّادٍ رَوَاهُ عَنْ يَحْيَى عَنْ أَبِي شَيْخٍ عَنْ أَخِيهِ حِمَّانَ ‏.‏\hadithno{5153}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Himman:That when Mu'awiyah went on Hajj, he gathered together a group of the Companions of the Messenger of Allah [SAW] at the Ka'bah and said to them: "I adjure you by Allah, did the Messenger of Allah [SAW] forbid wearing gold?" They said: "Yes." He said: "And I bear witness to that}}
\hadithdefcmd{nasai}{5154}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنِي أَبُو شَيْخٍ، عَنْ أَخِيهِ، حِمَّانَ أَنَّ مُعَاوِيَةَ، عَامَ حَجَّ جَمَعَ نَفَرًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْكَعْبَةِ فَقَالَ لَهُمْ أَنْشُدُكُمْ بِاللَّهِ هَلْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبُوسِ الذَّهَبِ قَالُوا نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ ‏.‏ خَالَفَهُ الأَوْزَاعِيُّ عَلَى اخْتِلاَفِ أَصْحَابِهِ عَلَيْهِ فِيهِ ‏.‏\hadithno{5154}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Shaikh narrated from his brother Himman:That when Mu'awiyah went on Hajj, he gathered together a group of the Companions of the Messenger of Allah [SAW] at the Ka'bah and said to them: "I adjure you by Allah, did the Messenger of Allah [SAW] forbid wearing gold?" They said: "Yes." He said: "And I bear witness to that}}
\hadithdefcmd{nasai}{5155}{أَخْبَرَنِي شُعَيْبُ بْنُ شُعَيْبِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنِ الأَوْزَاعِيِّ، عَنْ حَدِيثِ، يَحْيَى بْنِ أَبِي كَثِيرٍ قَالَ حَدَّثَنِي أَبُو شَيْخٍ، قَالَ حَدَّثَنِي حِمَّانُ، قَالَ حَجَّ مُعَاوِيَةُ فَدَعَا نَفَرًا مِنَ الأَنْصَارِ فِي الْكَعْبَةِ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ أَلَمْ تَسْمَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ الذَّهَبِ قَالُوا نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ ‏.‏\hadithno{5155}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Himman said:"Mu'awiyah went on Hajj and he called a group of Ansar to the Ka'bah. He said: 'I adjure you by Allah, did you hear the Messenger of Allah [SAW] forbid gold?' They said: 'Yes.' He said: 'And I bear witness to that}}
\hadithdefcmd{nasai}{5156}{أَخْبَرَنَا نُصَيْرُ بْنُ الْفَرَجِ، قَالَ حَدَّثَنَا عُمَارَةُ بْنُ بِشْرٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ حَدَّثَنِي حِمَّانُ، قَالَ حَجَّ مُعَاوِيَةُ فَدَعَا نَفَرًا مِنَ الأَنْصَارِ فِي الْكَعْبَةِ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ أَلَمْ تَسْمَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الذَّهَبِ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ ‏.‏\hadithno{5156}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Himman said:Mu'awiyah went on Hajj and he called a group of Ansar to the Ka'bah. He said: 'I adjure you by Allah, did you hear the Messenger of Allah [SAW] forbid gold?' They said: 'Yes.' He said: 'And I bear witness to that}}
\hadithdefcmd{nasai}{5157}{وَأَخْبَرَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، عَنْ عُقْبَةَ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنِي يَحْيَى، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ حَدَّثَنِي أَبُو حِمَّانَ، قَالَ حَجَّ مُعَاوِيَةُ فَدَعَا نَفَرًا مِنَ الأَنْصَارِ فِي الْكَعْبَةِ فَقَالَ أَلَمْ تَسْمَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الذَّهَبِ قَالُوا نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ ‏.‏\hadithno{5157}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Himman said:"Mu'awiyah went on Hajj and he called a group of Ansar to the Ka'bah. He said: 'Did you hear the Messenger of Allah [SAW] forbid gold?' They said: 'Yes.' He said: 'And I bear witness to that}}
\hadithdefcmd{nasai}{5158}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحِيمِ الْبَرْقِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، قَالَ حَدَّثَنِي حِمَّانُ، قَالَ حَجَّ مُعَاوِيَةُ فَدَعَا نَفَرًا مِنَ الأَنْصَارِ فِي الْكَعْبَةِ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ أَلَمْ تَسْمَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ الذَّهَبِ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عُمَارَةُ أَحْفَظُ مِنْ يَحْيَى وَحَدِيثُهُ أَوْلَى بِالصَّوَابِ ‏.‏\hadithno{5158}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Himman said:"Mu'awiyah went on Hajj and he called a group of Ansar to the Ka'bah. He said: 'I adjure you by Allah, did you hear the Messenger of Allah [SAW] forbid gold?' They said: 'Yes.' He said: 'And I bear witness to that}}
\hadithdefcmd{nasai}{5159}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا بَيْهَسُ بْنُ فَهْدَانَ، قَالَ حَدَّثَنَا أَبُو شَيْخٍ الْهُنَائِيُّ، قَالَ سَمِعْتُ مُعَاوِيَةَ، وَحَوْلَهُ، نَاسٌ مِنَ الْمُهَاجِرِينَ وَالأَنْصَارِ فَقَالَ لَهُمْ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الْحَرِيرِ فَقَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ وَنَهَى عَنْ لُبْسِ الذَّهَبِ إِلاَّ مُقَطَّعًا قَالُوا نَعَمْ ‏.‏ خَالَفَهُ عَلِيُّ بْنُ غُرَابٍ رَوَاهُ عَنْ بَيْهَسٍ عَنْ أَبِي شَيْخٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{5159}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Shaikh Al-Huna'i said:"I heard Mu'awiyah say to a group of Muhajirun and Ansar who were around him: 'Do you know that the Messenger of Allah [SAW] forbade wearing silk?' They said: 'By Allah, yes.' He said 'And (he forbade) wearing gold unless it was broken (into smaller pieces)?' They said: 'Yes.'" 'Ali bin Ghurab contradicted him; he reported it from Bahais, from Abu Shaikh, from Ibn 'Umar}}
\hadithdefcmd{nasai}{5160}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ غُرَابٍ، قَالَ حَدَّثَنَا بَيْهَسُ بْنُ فَهْدَانَ، قَالَ أَنْبَأَنَا أَبُو شَيْخٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسِ الذَّهَبِ إِلاَّ مُقَطَّعًا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ حَدِيثُ النَّضْرِ أَشْبَهُ بِالصَّوَابِ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{5160}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Shaikh said:"I heard Ibn 'Umar say: 'The Messenger of Allah [SAW] forbade wearing gold unless it is broken (into smaller pieces)}}
\hadithdefcmd{nasai}{5161}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا سَلْمُ بْنُ زَرِيرٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ طَرَفَةَ، عَنْ جَدِّهِ، عَرْفَجَةَ بْنِ أَسْعَدَ أَنَّهُ أُصِيبَ أَنْفُهُ يَوْمَ الْكُلاَبِ فِي الْجَاهِلِيَّةِ فَاتَّخَذَ أَنْفًا مِنْ وَرِقٍ فَأَنْتَنَ عَلَيْهِ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَتَّخِذَ أَنْفًا مِنْ ذَهَبٍ ‏.‏\hadithno{5161}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Arafah bin As'ad that:His nose was cut off at the battle of Al-Kulab during the Jahiliyyah, so he wore a nose made of silver, but it began to rot, so the Prophet [SAW] told him to wear a nose made of gold}}
\hadithdefcmd{nasai}{5162}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ أَبِي الأَشْهَبِ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ طَرَفَةَ، عَنْ عَرْفَجَةَ بْنِ أَسْعَدَ بْنِ كَرِبٍ، - قَالَ وَكَانَ جَدُّهُ - قَالَ حَدَّثَنِي أَنَّهُ، رَأَى جَدَّهُ قَالَ أُصِيبَ أَنْفُهُ يَوْمَ الْكُلاَبِ فِي الْجَاهِلِيَّةِ قَالَ فَاتَّخَذَ أَنْفًا مِنْ فِضَّةٍ فَأَنْتَنَ عَلَيْهِ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَتَّخِذَهُ مِنْ ذَهَبٍ ‏.‏\hadithno{5162}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin Tarafah, from 'Arafah bin As'ad bin Karib, who was his grandfather- saying that he saw his grandfather, and he said:"His nose had been cut off at the battle of Al-Kulab during the Jahiliyyah, so he wore a nose made of silver, but it began to rot on him, so the Prophet [SAW] told him to wear a nose made of gold}}
\hadithdefcmd{nasai}{5163}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدِ بْنِ كَثِيرٍ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، عَنْ عِيسَى بْنِ يُونُسَ، عَنِ الضَّحَّاكِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَطَاءٍ الْخُرَاسَانِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَالَ عُمَرُ لِصُهَيْبٍ مَا لِي أَرَى عَلَيْكَ خَاتَمَ الذَّهَبِ قَالَ قَدْ رَآهُ مَنْ هُوَ خَيْرٌ مِنْكَ فَلَمْ يَعِبْهُ ‏.‏ قَالَ مَنْ هُوَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5163}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"Umar said to Suhaib: 'Why do I see you wearing a ring of gold?' He said: 'One who was better than you saw it and did not criticize it.' He said: 'Who was that?' He said: 'The Messenger of Allah [SAW]}}
\hadithdefcmd{nasai}{5164}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمَ الذَّهَبِ فَلَبِسَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاتَّخَذَ النَّاسُ خَوَاتِيِمَ الذَّهَبِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي كُنْتُ أَلْبَسُ هَذَا الْخَاتَمَ وَإِنِّي لَنْ أَلْبَسَهُ أَبَدًا ‏"‏ ‏.‏ فَنَبَذَهُ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ ‏.‏\hadithno{5164}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] started to wear a gold ring, and the people started to wear gold rings. The Messenger of Allah [SAW] said: 'I was wearing this ring, but I will never wear it again.' He threw it away and the people threw their rings away}}
\hadithdefcmd{nasai}{5165}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ بْنِ يَرِيمَ، قَالَ قَالَ عَلِيٌّ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنْ خَاتِمَ الذَّهَبِ وَعَنِ الْقَسِّيِّ وَعَنِ الْمَيَاثِرِ الْحُمْرِ وَعَنِ الْجِعَةِ ‏.‏\hadithno{5165}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali said:"The Prophet [SAW] forbade me to wear gold rings and Al-Qassi, red Al-Miyathir, and (to drink) Al-Ji'ah}}
\hadithdefcmd{nasai}{5166}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدِ الرَّحِيمِ، عَنْ زَكَرِيَّا، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ، عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ خَاتَمِ الذَّهَبِ وَعَنِ الْقَسِّيِّ وَعَنِ الْمَيَاثِرِ الْحُمْرِ ‏.‏\hadithno{5166}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Prophet [SAW] forbade me to wear gold rings, and Al-Qassi, red Al-Miyathir}}
\hadithdefcmd{nasai}{5167}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ آدَمَ - قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ، سَمِعَهُ مِنْ، عَلِيٍّ يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ حَلْقَةِ الذَّهَبِ وَعَنِ الْمِيثَرَةِ الْحَمْرَاءِ وَعَنِ الثِّيَابِ الْقَسِّيَّةِ وَعَنِ الْجِعَةِ شَرَابٌ يُصْنَعُ مِنَ الشَّعِيرِ وَالْحِنْطَةِ وَذَكَرَ مِنْ شِدَّتِهِ ‏.‏ خَالَفَهُ عَمَّارُ بْنُ رُزَيْقٍ رَوَاهُ عَنْ أَبِي إِسْحَاقَ عَنْ صَعْصَعَةَ عَنْ عَلِيٍّ ‏.‏\hadithno{5167}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali said:"The Messenger of Allah [SAW] forbade gold rings, red Al-Miyathir, Qassiyah garments and Al-Ji'ah, which is a drink made from barley and wheat." - And he mentioned its strength}}
\hadithdefcmd{nasai}{5168}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ صَعْصَعَةَ بْنِ صُوحَانَ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ حَلْقَةِ الذَّهَبِ وَالْقَسِّيِّ وَالْمِيثَرَةِ وَالْجِعَةِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الَّذِي قَبْلَهُ أَشْبَهُ بِالصَّوَابِ ‏.‏\hadithno{5168}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade me (to wear) gold rings and Al-Qassi, Al-Mitharah, and Al-Ji'ah}}
\hadithdefcmd{nasai}{5169}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ أَنْبَأَنَا إِسْرَائِيلُ، عَنْ إِسْمَاعِيلَ بْنِ سُمَيْعٍ، عَنْ مَالِكِ بْنِ عُمَيْرٍ، عَنْ صَعْصَعَةَ بْنِ صُوحَانَ، قَالَ قُلْتُ لِعَلِيٍّ انْهَنَا عَمَّا نَهَاكَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ نَهَانِي عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَحَلْقَةِ الذَّهَبِ وَلُبْسِ الْحَرِيرِ وَالْقَسِّيِّ وَالْمِيثَرَةِ الْحَمْرَاءِ ‏.‏\hadithno{5169}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Sa'sa'ah bin Suwhan said:"I said to 'Ali: 'Forbid to us that which the Messenger of Allah [SAW] forbade to you.' He said: 'He forbade me from Ad-Dubba', Al-Hantam, gold circles (rings), wearing silk, and Al-Qassi, and red Al-Mitharah}}
\hadithdefcmd{nasai}{5170}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، دُحَيْمٌ قَالَ حَدَّثَنَا مَرْوَانُ، - هُوَ ابْنُ مُعَاوِيَةَ - قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - هُوَ ابْنُ سُمَيْعٍ الْحَنَفِيُّ - عَنْ مَالِكِ بْنِ عُمَيْرٍ، قَالَ جَاءَ صَعْصَعَةُ بْنُ صُوحَانَ إِلَى عَلِيٍّ فَقَالَ انْهَنَا عَمَّا نَهَاكَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالنَّقِيرِ وَالْجِعَةِ وَنَهَانَا عَنْ حَلْقَةِ الذَّهَبِ وَلُبْسِ الْحَرِيرِ وَلُبْسِ الْقَسِّيِّ وَالْمِيثَرَةِ الْحَمْرَاءِ ‏.‏\hadithno{5170}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Malik bin 'Umair said:"Sa'sa'ah bin Suwhan came to 'Ali and said: 'Forbid to us from that which the Messenger of Allah [SAW] forbade to you.' He said: 'He forbade us from Ad-Dubba', Al-Hantam, An-Naqir, Al-Ji'ah, and he forbade us from gold circles (rings), wearing silk, and wearing Al-Qassi, and red Al-Mitharah}}
\hadithdefcmd{nasai}{5171}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنْ إِسْمَاعِيلَ بْنِ سُمَيْعٍ، عَنْ مَالِكِ بْنِ عُمَيْرٍ، قَالَ قَالَ صَعْصَعَةُ بْنُ صُوحَانَ لِعَلِيٍّ يَا أَمِيرَ الْمُؤْمِنِينَ انْهَنَا عَمَّا نَهَاكَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْجِعَةِ وَعَنْ حِلَقِ الذَّهَبِ وَلُبْسِ الْحَرِيرِ وَعَنِ الْمِيثَرَةِ الْحَمْرَاءِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ حَدِيثُ مَرْوَانَ وَعَبْدِ الْوَاحِدِ أَوْلَى بِالصَّوَابِ مِنْ حَدِيثِ إِسْرَائِيلَ ‏.‏\hadithno{5171}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Sa'sa'ah bin Suwhan said to 'Ali:"O Commander of the Believers! Forbid us from that which the Messenger of Allah [SAW] forbade you from." He said: "He forbade us from Ad-Dubba, Al-Hantam, Al-Ji'ah, and from gold circles (rings), and from wearing silk, and from red Al-Mitharah}}
\hadithdefcmd{nasai}{5172}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، وَعُثْمَانُ بْنُ عُمَرَ، قَالَ أَبُو عَلِيٍّ حَدَّثَنَا وَقَالَ، عُثْمَانُ أَنْبَأَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَلِيٍّ، قَالَ نَهَانِي حِبِّي صلى الله عليه وسلم عَنْ ثَلاَثٍ لاَ أَقُولُ نَهَى النَّاسَ نَهَانِي عَنْ تَخَتُّمِ الذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيِّ وَعَنِ الْمُعَصْفَرِ الْمُفَدَّمَةِ وَلاَ أَقْرَأُ سَاجِدًا وَلاَ رَاكِعًا ‏.‏ تَابَعَهُ الضَّحَّاكُ بْنُ عُثْمَانَ ‏.‏\hadithno{5172}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"My beloved, the Messenger of Allah [SAW], forbade me three things but I do not say that he forbade them to the people. He forbade me from wearing rings of gold, from wearing Al-Qassi, and Al-Mu'asfar Al-Mufaddam (garments that are deeply dyed with safflower), and (he forbade me) from reciting Qur'an when prostrating or bowing." He was followed (in that narration) by Ad-Dahhak bin 'Uthman}}
\hadithdefcmd{nasai}{5173}{أَخْبَرَنَا الْحَسَنُ بْنُ دَاوُدَ الْمُنْكَدِرِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ، عَنْ إِبْرَاهِيمَ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ أَقُولُ نَهَاكُمْ عَنْ تَخَتُّمِ الذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيِّ وَعَنْ لُبْسِ الْمُفَدَّمِ وَالْمُعَصْفَرِ وَعَنِ الْقِرَاءَةِ رَاكِعًا ‏.‏\hadithno{5173}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade me- but I do not say that he forbade you- from wearing rings of gold, and from wearing Al-Qassi, and from wearing Al-Mufaddam (garments dyed deep red) and Al-Mu'asfar (garments dyed with safflower), and from reciting Qur'an while bowing}}
\hadithdefcmd{nasai}{5174}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحِيمِ الْبَرْقِيُّ، قَالَ حَدَّثَنَا أَبُو الأَسْوَدِ، قَالَ حَدَّثَنَا نَافِعُ بْنُ يَزِيدَ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ إِبْرَاهِيمَ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَلِيًّا، يَقُولُ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْقِرَاءَةِ وَأَنَا رَاكِعٌ وَعَنْ لُبْسِ الذَّهَبِ وَالْمُعَصْفَرِ ‏.‏\hadithno{5174}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibrahim that his father told him that he heard 'Ali say:"The Messenger of Allah [SAW] forbade me to recite Qur'an while bowing and to wear gold and garments dyed with safflower}}
\hadithdefcmd{nasai}{5175}{أَخْبَرَنَا الْحَسَنُ بْنُ قَزَعَةَ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ أَقُولُ نَهَاكُمْ عَنْ خَاتَمِ الذَّهَبِ وَعَنِ الْقَسِّيِّ وَالْمُعَصْفَرِ وَأَنْ لاَ أَقْرَأَ وَأَنَا رَاكِعٌ ‏.‏\hadithno{5175}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibrahim bin 'Abdullah bin Hunain that his father said:"I heard 'Ali say: 'The Messenger of Allah [SAW] forbade me- but I do not say that he forbade you- from wearing gold rings, Al-Qassi, and garments dyed with safflower, and reciting Qur'an while bowing}}
\hadithdefcmd{nasai}{5176}{أَخْبَرَنِي هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، عَنْ مُحَمَّدِ بْنِ عِيسَى، - وَهُوَ ابْنُ الْقَاسِمِ بْنِ سُمَيْعٍ - قَالَ حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ، مَوْلَى عَلِيٍّ عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ تَخَتُّمِ الذَّهَبِ وَعَنِ الْمُعَصْفَرِ وَعَنْ لُبْسِ الْقَسِّيِّ وَعَنِ الْقِرَاءَةِ فِي الرُّكُوعِ ‏.‏\hadithno{5176}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade me from rings of gold, garments dyed with safflower, and wearing Al-Qassi, and from reciting Qur'an while bowing}}
\hadithdefcmd{nasai}{5177}{أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَجَّاجِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ حُنَيْنٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ عَلِيًّا، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسِ الْقَسِّيِّ وَالْمُعَصْفَرِ وَعَنِ التَّخَتُّمِ بِالذَّهَبِ ‏.‏\hadithno{5177}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Hunain- the freed slave of Ibn 'Abbas- that 'Ali said:"The Messenger of Allah [SAW] forbade me from wearing Al-Qassi, garments dyed with safflower, and gold rings}}
\hadithdefcmd{nasai}{5178}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، - وَهُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ حُنَيْنٍ، مَوْلَى عَلِيٍّ عَنْ عَلِيٍّ، رضى الله عنه قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَرْبَعٍ عَنِ التَّخَتُّمِ بِالذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيِّ وَعَنْ قِرَاءَةِ الْقُرْآنِ وَأَنَا رَاكِعٌ وَعَنْ لُبْسِ الْمُعَصْفَرِ ‏.‏ وَوَافَقَهُ أَيُّوبُ إِلاَّ أَنَّهُ لَمْ يُسَمِّ الْمَوْلَى ‏.‏\hadithno{5178}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Hunain, the freed slave of 'Ali, that 'Ali said:"The Messenger of Allah [SAW] forbade me from four: Gold rings, wearing Al-Qassi, reciting Qur'an while I am bowing, and from wearing garments dyed with safflower}}
\hadithdefcmd{nasai}{5179}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورِ بْنِ جَعْفَرٍ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا حَفْصُ بْنُ عَبْدِ الرَّحْمَنِ الْبَلْخِيُّ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنْ مَوْلًى، لِلْعَبَّاسِ أَنَّ عَلِيًّا، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسِ الْمُعَصْفَرِ وَعَنِ الْقَسِّيِّ وَعَنِ التَّخَتُّمِ بِالذَّهَبِ وَأَنْ أَقْرَأَ وَأَنَا رَاكِعٌ ‏.‏\hadithno{5179}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Nafi', from a freed slave of Ibn 'Abbas, that 'Ali said:"The Messenger of Allah [SAW] forbade me from wearing garments dyed with safflower, and from Al-Qassi, and from gold rings, and that I recite Qur'an while I am bowing}}
\hadithdefcmd{nasai}{5180}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا حَرْبٌ، - وَهُوَ ابْنُ شَدَّادٍ - عَنْ يَحْيَى، قَالَ حَدَّثَنِي عَمْرُو بْنُ سَعْدٍ الْفَدَكِيُّ، أَنَّ نَافِعًا، أَخْبَرَهُ قَالَ حَدَّثَنِي ابْنُ حُنَيْنٍ، أَنَّ عَلِيًّا، حَدَّثَهُ قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثِيَابِ الْمُعَصْفَرِ وَعَنْ خَاتَمِ الذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيِّ وَأَنْ أَقْرَأَ وَأَنَا رَاكِعٌ ‏.‏ خَالَفَهُ اللَّيْثُ بْنُ سَعْدٍ ‏.‏\hadithno{5180}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Hunain narrated that 'Ali said to him:"The Messenger of Allah [SAW] forbade me (from wearing) garments dyed with safflower, and from gold rings, and from wearing Al-Qassi, and that I recite Qur'an while I am bowing}}
\hadithdefcmd{nasai}{5181}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ بَعْضِ، مَوَالِي الْعَبَّاسِ عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُعَصْفَرِ وَالثِّيَابِ الْقَسِّيَّةِ وَعَنْ أَنْ يَقْرَأَ وَهُوَ رَاكِعٌ ‏.‏\hadithno{5181}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ali that :The Messenger of Allah [SAW] forbade (wearing) garments dyed with safflower, and Al-Qassiyah garments, and reciting Qur'an while he is bowing}}
\hadithdefcmd{nasai}{5182}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا أَبُو عَمْرٍو الأَوْزَاعِيُّ، عَنْ يَحْيَى، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{5182}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade" and he quoted the same Hadith}}
\hadithdefcmd{nasai}{5183}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنْ أَشْعَثَ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، قَالَ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنِ الْقَسِّيِّ وَالْحَرِيرِ وَخَاتَمِ الذَّهَبِ وَأَنْ أَقْرَأَ رَاكِعًا ‏.‏ خَالَفَهُ هِشَامٌ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{5183}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Prophet [SAW] forbade me from Al-Qassi, silk, gold rings, and that I recite Qur'an while bowing." Hisham contradicted him, he did not narrate it in Marfu' form}}
\hadithdefcmd{nasai}{5184}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، قَالَ نَهَى عَنْ مَيَاثِرِ الأُرْجُوَانِ، وَلُبْسِ الْقَسِّيِّ، وَخَاتَمِ الذَّهَبِ، ‏.‏\hadithno{5184}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abidah, from 'Ali, he said:"He forbade red Al-Mayathir, wearing Al-Qassi, and gold rings}}
\hadithdefcmd{nasai}{5185}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ أَخْبَرَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، قَالَ نَهَى عَنْ مَيَاثِرِ الأُرْجُوَانِ، وَخَوَاتِيمِ الذَّهَبِ، ‏.‏\hadithno{5185}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abidah said:"He forbade red Al-Mayathir, and gold rings}}
\hadithdefcmd{nasai}{5186}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا إِبْرَاهِيمُ، عَنِ الْحَجَّاجِ، - هُوَ ابْنُ الْحَجَّاجِ - عَنْ قَتَادَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُبَيْدٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ تَخَتُّمِ الذَّهَبِ ‏.‏\hadithno{5186}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] forbade me to wear gold rings}}
\hadithdefcmd{nasai}{5187}{أَخْبَرَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، قَالَ حَدَّثَنَا حَفْصٌ اللَّيْثِيُّ، قَالَ أَشْهَدُ عَلَى عِمْرَانَ أَنَّهُ حَدَّثَنَا قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسِ الْحَرِيرِ وَعَنِ التَّخَتُّمِ بِالذَّهَبِ وَعَنِ الشُّرْبِ فِي الْحَنَاتِمِ ‏.‏\hadithno{5187}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hafs Al-Laithi said:"I bear witness that 'Imran narrated to us, he said: 'The Messenger of Allah [SAW] forbade wearing silk, and gold rings, and drinking from Al-Hanatim}}
\hadithdefcmd{nasai}{5188}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بَكْرِ بْنِ سَوَادَةَ، أَنَّ أَبَا النَّجِيبِ، حَدَّثَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ حَدَّثَهُ أَنَّ رَجُلاً قَدِمَ مِنْ نَجْرَانَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ خَاتَمٌ مِنْ ذَهَبٍ فَأَعْرَضَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ إِنَّكَ جِئْتَنِي وَفِي يَدِكَ جَمْرَةٌ مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{5188}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:A man came from Najran to the Messenger of Allah [SAW]. He was wearing a gold ring, and the Messenger of Allah [SAW] turned away from him, and said: "You have come to me with a coal of fire on your hand}}
\hadithdefcmd{nasai}{5189}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ رَجُلٍ، حَدَّثَهُ عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَجُلاً، كَانَ جَالِسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم وَعَلَيْهِ خَاتَمٌ مِنْ ذَهَبٍ وَفِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِخْصَرَةٌ أَوْ جَرِيدَةٌ فَضَرَبَ بِهَا النَّبِيُّ صلى الله عليه وسلم إِصْبَعَهُ فَقَالَ الرَّجُلُ مَا لِي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَلاَ تَطْرَحُ هَذَا الَّذِي فِي إِصْبَعِكَ ‏"‏ ‏.‏ فَأَخَذَهُ الرَّجُلُ فَرَمَى بِهِ فَرَآهُ النَّبِيُّ صلى الله عليه وسلم بَعْدَ ذَلِكَ فَقَالَ ‏"‏ مَا فَعَلَ الْخَاتَمُ ‏"‏ ‏.‏ قَالَ رَمَيْتُ بِهِ ‏.‏ قَالَ ‏"‏ مَا بِهَذَا أَمَرْتُكَ إِنَّمَا أَمَرْتُكَ أَنْ تَبِيعَهُ فَتَسْتَعِينَ بِثَمَنِهِ ‏"‏ ‏.‏ وَهَذَا حَدِيثٌ مُنْكَرٌ ‏.‏\hadithno{5189}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Bara' bin 'Azib that :A man was sitting with the Prophet [SAW] and he was wearing a gold ring. The Messenger of Allah [SAW] had a stick in his hand and the Prophet [SAW] struck his finger. The man said: "What's wrong with me, O Messenger of Allah?" He said: "Why don't you get rid of this thing that is on your finger?" The man took it and threw it away. The Prophet [SAW] saw him after that and said: "What happened to the ring?" He said: "I threw it away." He said: "I did not tell you to do that, rather I told you to sell it and benefit from its price." This Hadith is Munkar}}
\hadithdefcmd{nasai}{5190}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنِ النُّعْمَانِ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَبْصَرَ فِي يَدِهِ خَاتَمًا مِنْ ذَهَبٍ فَجَعَلَ يَقْرَعُهُ بِقَضِيبٍ مَعَهُ فَلَمَّا غَفَلَ النَّبِيُّ صلى الله عليه وسلم أَلْقَاهُ قَالَ ‏ "‏ مَا أُرَانَا إِلاَّ قَدْ أَوْجَعْنَاكَ وَأَغْرَمْنَاكَ ‏"‏ ‏.‏ خَالَفَهُ يُونُسُ رَوَاهُ عَنِ الزُّهْرِيِّ عَنْ أَبِي إِدْرِيسَ مُرْسَلاً ‏.‏\hadithno{5190}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Tha'labah Al-Khushani that :The Prophet [SAW] saw a gold ring on his hand, and he started to smack him with a stick that he had in his hand. When the Prophet [SAW] looked away, he threw it away. He said: "I think that he hurt you or we made you lose money}}
\hadithdefcmd{nasai}{5191}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، أَنَّ رَجُلاً، مِمَّنْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم لَبِسَ خَاتَمًا مِنْ ذَهَبٍ نَحْوَهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَحَدِيثُ يُونُسَ أَوْلَى بِالصَّوَابِ مِنْ حَدِيثِ النُّعْمَانِ ‏.‏\hadithno{5191}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Idris Al-Khawlani narrated that:A man, among those who met the Prophet [SAW], wore a gold ring. A similar report}}
\hadithdefcmd{nasai}{5192}{أَخْبَرَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ بْنِ مُحَمَّدٍ الْقُرَشِيُّ الدِّمَشْقِيُّ أَبُو عَبْدِ الْمَلِكِ، قِرَاءَةً قَالَ حَدَّثَنَا ابْنُ عَائِذٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى عَلَى رَجُلٍ خَاتَمًا مِنْ ذَهَبٍ نَحْوَهُ ‏.‏\hadithno{5192}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Idris Al-Khawlani that:The Messenger of Allah [SAW] saw a man wearing a gold ring. A similar report}}
\hadithdefcmd{nasai}{5193}{أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ الْعُمَرِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى فِي يَدِ رَجُلٍ خَاتَمَ ذَهَبٍ فَضَرَبَ إِصْبَعَهُ بِقَضِيبٍ كَانَ مَعَهُ حَتَّى رَمَى بِهِ ‏.‏\hadithno{5193}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Idris that :The Prophet [SAW] saw a gold ring on a man's hand and he struck his finger with a stick that he had with him, until he threw it away}}
\hadithdefcmd{nasai}{5194}{أَخْبَرَنِي أَبُو بَكْرٍ، أَحْمَدُ بْنُ عَلِيٍّ الْمَرْوَزِيُّ قَالَ حَدَّثَنَا الْوَرَكَانِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مُرْسَلٌ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَالْمَرَاسِيلُ أَشْبَهُ بِالصَّوَابِ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{5194}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Daif}\hadithtrans{Ibrahim bin Sa'd bin Shihab narrated that:The Messenger of Allah [SAW]...In Mursal form}}
\hadithdefcmd{nasai}{5195}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُسْلِمٍ، - مِنْ أَهْلِ مَرْوَ أَبُو طَيْبَةَ - قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَعَلَيْهِ خَاتَمٌ مِنْ حَدِيدٍ فَقَالَ ‏"‏ مَا لِي أَرَى عَلَيْكَ حِلْيَةَ أَهْلِ النَّارِ ‏"‏ ‏.‏ فَطَرَحَهُ ثُمَّ جَاءَهُ وَعَلَيْهِ خَاتَمٌ مِنْ شَبَهٍ فَقَالَ ‏"‏ مَا لِي أَجِدُ مِنْكَ رِيحَ الأَصْنَامِ ‏"‏ ‏.‏ فَطَرَحَهُ قَالَ يَا رَسُولَ اللَّهِ مِنْ أَىِّ شَىْءٍ أَتَّخِذُهُ قَالَ ‏"‏ مِنْ وَرِقٍ وَلاَ تُتِمَّهُ مِثْقَالاً ‏"‏ ‏.‏\hadithno{5195}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Buraidah narrated from his father that:A man came to the Prophet [SAW] and he was wearing an iron ring. He said: "Why do I see you wearing the jewelry of the people of Hell?" He threw it away, then he came and he was wearing a brass ring. He said: "Why do I notice the stench of idols from you?" So he threw it away, and said: "O Messenger of Allah, what should I use?" He said: "Silver, but it should not equal a Mithqal}}
\hadithdefcmd{nasai}{5196}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ وَرِقٍ فَصُّهُ حَبَشِيٌّ وَنُقِشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5196}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that :The Prophet [SAW] wore a ring of silver with an Ethiopian stone (Fass), on which was inscribed (the phrase): "Muhammad Rasul Allah (Muhammad the Messenger of Allah)}}
\hadithdefcmd{nasai}{5197}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبَّادُ بْنُ مُوسَى، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، قَالَ أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَاتَمُ فِضَّةٍ يَتَخَتَّمُ بِهِ فِي يَمِينِهِ فَصُّهُ حَبَشِيٌّ يَجْعَلُ فَصَّهُ مِمَّا يَلِي كَفَّهُ ‏.‏\hadithno{5197}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah [SAW] had a ring of silver which he wore on his right hand. It had an Ethiopian stone (Fass), and he used to wear the stone (Fass) next to his palm}}
\hadithdefcmd{nasai}{5198}{أَخْبَرَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خَلِيٍّ الْحِمْصِيُّ، - وَكَانَ أَبُوهُ خَالِدٌ عَلَى قَضَاءِ حِمْصَ - قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سَلَمَةُ، - وَهُوَ ابْنُ عَبْدِ الْمَلِكِ الْعَوْصِيُّ - عَنِ الْحَسَنِ، - وَهُوَ ابْنُ صَالِحِ بْنِ حَىٍّ - عَنْ عَاصِمٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ خَاتَمُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فِضَّةٍ وَكَانَ فَصُّهُ مِنْهُ ‏.‏\hadithno{5198}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The ring of the Messenger of Allah [SAW] was of silver and its stone (Fass) was made of silver too}}
\hadithdefcmd{nasai}{5199}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامٍ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ حُمَيْدًا، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ خَاتَمُهُ مِنْ وَرِقٍ فَصُّهُ مِنْهُ ‏.‏\hadithno{5199}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas that:The Prophet's ring was made of silver and its stone (Fass) was made of silver too}}
\hadithdefcmd{nasai}{5200}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، قَالَ حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم مِنْ فِضَّةٍ فَصُّهُ مِنْهُ ‏.‏\hadithno{5200}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The ring of the Prophet [SAW] was made of silver and its stone (Fass) was made of silver too}}
\hadithdefcmd{nasai}{5201}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ بِشْرٍ، - وَهُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ أَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى الرُّومِ فَقَالُوا إِنَّهُمْ لاَ يَقْرَءُونَ كِتَابًا إِلاَّ مَخْتُومًا ‏.‏ فَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِهِ فِي يَدِهِ وَنُقِشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5201}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] wanted to write to the Romans, but they (the Companions) said: 'They do not read any letter unless it has a seal.' So he took a ring of silver, and it is as if I can see its whiteness on his hand, and on it were engraved (the words): "Muhammad Rasul Allah (Muhammad the Messenger of Allah)}}
\hadithdefcmd{nasai}{5202}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ أَبُو الْجَوْزَاءِ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ أَخَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْعِشَاءِ الآخِرَةِ حَتَّى مَضَى شَطْرُ اللَّيْلِ ثُمَّ خَرَجَ فَصَلَّى بِنَا كَأَنِّي أَنْظُرُ إِلَى بَيَاضِ خَاتَمِهِ فِي يَدِهِ مِنْ فِضَّةٍ ‏.‏\hadithno{5202}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] delayed 'Isha' prayer one night, until half the night had passed, then he came out and led us in prayer. And it is as if I can see the whiteness of his silver ring on his hand}}
\hadithdefcmd{nasai}{5203}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ‏\{‏ ابْنُ، ‏\}‏ وَهْبٍ عَنْ سُلَيْمَانَ، - هُوَ ابْنُ بِلاَلٍ - عَنْ شَرِيكٍ، - هُوَ ابْنُ أَبِي نَمِرٍ - عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ شَرِيكٌ وَأَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَلْبَسُ خَاتَمَهُ فِي يَمِينِهِ ‏.‏\hadithno{5203}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Wahab narrated from Sulaiman - and he is Ibn Bilal - from Sharik - and he is Ibn Abi Namr - from Ibrahim Ibn 'Abdullah bin Hunain, from his father, from 'Ali; Sharik said:"And Abu Salamah informed me" - That the Prophet [SAW] used to wear his ring on his right hand}}
\hadithdefcmd{nasai}{5204}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ الْبَحْرَانِيُّ، قَالَ حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنِ ابْنِ أَبِي رَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَخَتَّمُ بِيَمِينِهِ ‏.‏\hadithno{5204}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin Ja'far that:The Prophet [SAW] used to wear his ring on his right hand}}
\hadithdefcmd{nasai}{5205}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ أَبِي عَتَّابٍ، سَهْلِ بْنِ حَمَّادٍ ح وَأَنْبَأَنَا أَبُو دَاوُدَ، قَالَ ‏\{‏ حَدَّثَنَا سَهْلُ بْنُ حَمَّادٍ، قَالَ ‏\}‏ حَدَّثَنَا أَبُو مَكِينٍ، قَالَ حَدَّثَنَا إِيَاسُ بْنُ الْحَارِثِ بْنِ الْمُعَيْقِيبِ، عَنْ جَدِّهِ، مُعَيْقِيبٍ أَنَّهُ قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم حَدِيدًا مَلْوِيًّا عَلَيْهِ فِضَّةٌ - قَالَ - وَرُبَّمَا كَانَ فِي يَدِي ‏.‏ فَكَانَ مُعَيْقِيبٌ عَلَى خَاتَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5205}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Iyas bin Al-Harith bin Al-Mu'aiqib narrated that his grandfather Mu'aiqib said:"The ring of the Prophet [SAW] was made of iron with silver twisted around it." He said: "And sometimes it was on my hand." And Mu'aiqib was the keeper of the ring of the Messenger of Allah [SAW]}}
\hadithdefcmd{nasai}{5206}{أَخْبَرَنِي عَلِيُّ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ الْمِصِّيصِيُّ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ مَنْصُورٍ، - مِنْ أَهْلِ ثَغْرٍ ثِقَةٌ - قَالَ حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ أَبِي النَّجِيبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَقْبَلَ رَجُلٌ مِنَ الْبَحْرَيْنِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَلَّمَ فَلَمْ يَرُدَّ عَلَيْهِ وَكَانَ فِي يَدِهِ خَاتَمٌ مِنْ ذَهَبٍ وَجُبَّةُ حَرِيرٍ فَأَلْقَاهُمَا ثُمَّ سَلَّمَ فَرَدَّ عَلَيْهِ السَّلاَمَ ثُمَّ قَالَ يَا رَسُولَ اللَّهِ أَتَيْتُكَ آنِفًا فَأَعْرَضْتَ عَنِّي ‏.‏ فَقَالَ ‏"‏ إِنَّهُ كَانَ فِي يَدِكَ جَمْرَةٌ مِنْ نَارٍ ‏"‏ ‏.‏ قَالَ لَقَدْ جِئْتُ إِذًا بِجَمْرٍ كَثِيرٍ ‏.‏ قَالَ ‏"‏ إِنَّ مَا جِئْتَ بِهِ لَيْسَ بِأَجْزَأَ عَنَّا مِنْ حِجَارَةِ الْحَرَّةِ وَلَكِنَّهُ مَتَاعُ الْحَيَاةِ الدُّنْيَا ‏"‏ ‏.‏ قَالَ فَمَاذَا أَتَخَتَّمُ قَالَ ‏"‏ حَلْقَةً مِنْ حَدِيدٍ أَوْ وَرِقٍ أَوْ صُفْرٍ ‏"‏ ‏.‏\hadithno{5206}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri:"A man came from Al-Bahrain to the Prophet [SAW] and greeted him with Salam, but he did not return his greeting. He was wearing a gold ring on his hand, and was wearing a silken Jubbah. He took them off, then he greeted him with Salam, and he returned his greeting. Then he said: 'O Messenger of Allah, I came to you just now, and you turned away from me.' He said: 'You had a coal of fire on your hand.' He said: 'Then I have brought many coals.' He said: 'What you have brought with you is no better for us than the stones of Al-Harrah, but it is a temporary convenience of this world.' He said: 'What should I use for a ring?' He said: 'A ring of iron or silver or brass}}
\hadithdefcmd{nasai}{5207}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، قَالَ حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدِ اتَّخَذَ حَلْقَةً مِنْ فِضَّةٍ فَقَالَ ‏ "‏ مَنْ أَرَادَ أَنْ يَصُوغَ عَلَيْهِ فَلْيَفْعَلْ وَلاَ تَنْقُشُوا عَلَى نَقْشِهِ ‏"‏ ‏.‏\hadithno{5207}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] came out wearing a silver ring. He said: 'Whoever wants to make a ring like this, let him do so, but do not put the same inscription}}
\hadithdefcmd{nasai}{5208}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ الْحَرَّانِيُّ قَالَ حَدَّثَنَا هَارُونُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا وَنَقَشَ عَلَيْهِ نَقْشًا قَالَ ‏ "‏ إِنَّا قَدِ اتَّخَذْنَا خَاتَمًا وَنَقَشْنَا فِيهِ نَقْشًا فَلاَ يَنْقُشْ أَحَدٌ عَلَى نَقْشِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ أَنَسٌ فَكَأَنِّي أَنْظُرُ إِلَى وَبِيصِهِ فِي يَدِهِ ‏.‏\hadithno{5208}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah [SAW] put on a ring, and he had some words inscribed on it. He said: 'We have put on a ring and have had some words engraved on it; no one of you should copy this inscription.'" Then Anas said: "It is as if I can see its whiteness on his hand}}
\hadithdefcmd{nasai}{5209}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى الْخُوَارَزْمِيُّ، بِبَغْدَادَ قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا الْعَوَّامُ بْنُ حَوْشَبٍ، عَنْ أَزْهَرَ بْنِ رَاشِدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسْتَضِيئُوا بِنَارِ الْمُشْرِكِينَ وَلاَ تَنْقُشُوا عَلَى خَوَاتِيمِكُمْ عَرَبِيًّا ‏"‏ ‏.‏\hadithno{5209}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah [SAW] said: 'Do not be so close to the Mushrikin that you can benefit from the light of their fires, and do not engrave Arabic (words) on your rings}}
\hadithdefcmd{nasai}{5210}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، قَالَ قَالَ عَلِيٌّ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَلِيُّ سَلِ اللَّهَ الْهُدَى وَالسَّدَادَ ‏"‏ ‏.‏ وَنَهَانِي أَنْ أَجْعَلَ الْخَاتَمَ فِي هَذِهِ وَهَذِهِ ‏.‏ وَأَشَارَ يَعْنِي بِالسَّبَّابَةِ وَالْوُسْطَى ‏.‏\hadithno{5210}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Burdah said:'Ali said: "The Messenger of Allah [SAW] said to me: 'O 'Ali, ask Allah for guidance and steadfastness,' and he forbade me from placing a ring on this one and this one' - and he pointed to his forefinger and middle finger}}
\hadithdefcmd{nasai}{5211}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْخَاتَمِ فِي هَذِهِ وَهَذِهِ ‏.‏ يَعْنِي السَّبَّابَةَ وَالْوُسْطَى ‏.‏ وَاللَّفْظُ لاِبْنِ الْمُثَنَّى ‏.‏\hadithno{5211}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade me to wear a ring on this one and this one," meaning the forefinger and middle finger. And this is the wording of Ibn Al-Muthanna}}
\hadithdefcmd{nasai}{5212}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُلِ اللَّهُمَّ اهْدِنِي وَسَدِّدْنِي ‏"‏ ‏.‏ وَنَهَانِي أَنْ أَضَعَ الْخَاتَمَ فِي هَذِهِ وَهَذِهِ وَأَشَارَ بِشْرٌ بِالسَّبَّابَةِ وَالْوُسْطَى ‏.‏ قَالَ وَقَالَ عَاصِمٌ أَحَدُهُمَا ‏.‏\hadithno{5212}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] said to me: 'Say: O Allah, guide me and make me steadfast,' and he forbade me to put a ring on this one and this one" - and Bishr (one of the narrators) pointed to his forefinger and middle finger. And 'Asim said: "One of the two of them}}
\hadithdefcmd{nasai}{5213}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، عَنْ سَعِيدِ بْنِ عَامِرٍ، عَنْ هَمَّامٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ الْخَلاَءَ نَزَعَ خَاتَمَهُ ‏.‏\hadithno{5213}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that:When entering the Khala', the Messenger of Allah [SAW] would take off his ring}}
\hadithdefcmd{nasai}{5214}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ ذَهَبٍ وَجَعَلَ فَصَّهُ مِنْ قِبَلِ كَفِّهِ فَاتَّخَذَ النَّاسُ خَوَاتِيمَ الذَّهَبِ فَأَلْقَى رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمَهُ وَقَالَ ‏ "‏ لاَ أَلْبَسُهُ أَبَدًا ‏"‏ ‏.‏ وَأَلْقَى النَّاسُ خَوَاتِيمَهُمْ ‏.‏\hadithno{5214}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] put on a ring of gold and put its stone toward his palm. Then the people started to wear rings of gold. Then the Messenger of Allah [SAW] threw away his ring and said: 'I will never wear it again,' and the people threw away their rings}}
\hadithdefcmd{nasai}{5215}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ ذَهَبٍ وَجَعَلَ فَصَّهُ مِمَّا يَلِي كَفَّهُ فَاتَّخَذَ النَّاسُ خَوَاتِيمَ فَطَرَحَهُ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏ "‏ لاَ أَلْبَسُهُ أَبَدًا ‏"‏ ‏.‏\hadithno{5215}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] put on a ring of gold and put its stone (Fass) toward his palm. Then the people started to wear rings, and the Messenger of Allah [SAW] discarded it and said: "I will never wear it again}}
\hadithdefcmd{nasai}{5216}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم تَخَتَّمَ خَاتَمًا مِنْ ذَهَبٍ ثُمَّ طَرَحَهُ وَلَبِسَ خَاتَمًا مِنْ وَرِقٍ وَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ وَقَالَ ‏ "‏ لاَ يَنْبَغِي لأَحَدٍ أَنْ يَنْقُشَ عَلَى نَقْشِ خَاتَمِي هَذَا ‏"‏ ‏.‏ ثُمَّ جَعَلَ فَصَّهُ فِي بَطْنِ كَفِّهِ ‏.‏\hadithno{5216}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"The Prophet [SAW] used to wear a ring of gold, then he discarded it, and put on a ring of silver on which was engraved (the words): 'Muhammad Rasul Allah.' He said: 'No one else should engrave his ring with an inscription like this ring of mine.' Then he put the stone toward the palm of his hand}}
\hadithdefcmd{nasai}{5217}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ الْمُغِيرَةِ بْنِ زِيَادٍ، قَالَ حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَبِسَ خَاتَمًا مِنْ ذَهَبٍ ثَلاَثَةَ أَيَّامٍ فَلَمَّا رَآهُ أَصْحَابُهُ فَشَتْ خَوَاتِيمُ الذَّهَبِ فَرَمَى بِهِ فَلاَ نَدْرِي مَا فَعَلَ ثُمَّ أَمَرَ بِخَاتَمٍ مِنْ فِضَّةٍ فَأَمَرَ أَنْ يُنْقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ وَكَانَ فِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى مَاتَ وَفِي يَدِ أَبِي بَكْرٍ حَتَّى مَاتَ وَفِي يَدِ عُمَرَ حَتَّى مَاتَ وَفِي يَدِ عُثْمَانَ سِتَّ سِنِينَ مِنْ عَمَلِهِ فَلَمَّا كَثُرَتْ عَلَيْهِ الْكُتُبُ دَفَعَهُ إِلَى رَجُلٍ مِنَ الأَنْصَارِ فَكَانَ يَخْتِمُ بِهِ فَخَرَجَ الأَنْصَارِيُّ إِلَى قَلِيبٍ لِعُثْمَانَ فَسَقَطَ فَالْتُمِسَ فَلَمْ يُوجَدْ فَأَمَرَ بِخَاتَمٍ مِثْلِهِ وَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5217}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] wore a ring of gold for three days, and when his Companions saw it, gold rings became popular. Then he threw it away and we did not realize what he had done. Then he ordered that a ring of silver be made, and that (the words): "Muhammad Rasul Allah" be engraved on it. It remained on the hand of the Messenger of Allah [SAW] until he died, then on the hand of Abu Bakr until he died, then on the hand of 'Umar until he died. Then (it remained) on the hand of 'Uthman for the first six years of his duties, but when he had to write many letters, he gave it to a man from among Ansar who used to seal letters with it. Then the Ansari went out to a well belonging to 'Uthman and the ring fell. They looked for it but could not find it. He ordered that a similar ring be made and engraved (the words): "Muhammad Rasul Allah" on it}}
\hadithdefcmd{nasai}{5218}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ ذَهَبٍ وَكَانَ فَصُّهُ فِي بَاطِنِ كَفِّهِ فَاتَّخَذَ النَّاسُ خَوَاتِيمَ مِنْ ذَهَبٍ فَطَرَحَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَرَحَ النَّاسُ خَوَاتِيمَهُمْ وَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ فَكَانَ يَخْتِمُ بِهِ وَلاَ يَلْبَسُهُ ‏.‏\hadithno{5218}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] put on a ring of gold, and he used to wear its stone (Fass) next to his palm. Then the people started to wear rings of gold. Then the Messenger of Allah [SAW] discarded it, and the people discarded their rings. Then he acquired a ring of silver with which he used to seal letters, but he did not wear it}}
\hadithdefcmd{nasai}{5219}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُثْمَانَ بْنِ أَبِي صَفْوَانَ الثَّقَفِيُّ، - مِنْ وَلَدِ عُثْمَانَ بْنِ أَبِي الْعَاصِ - قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ، قَالَ حَدَّثَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنْ أَبِي بَكْرِ بْنِ أَبِي شَيْخٍ، قَالَ كُنْتُ جَالِسًا مَعَ سَالِمٍ فَمَرَّ بِنَا رَكْبٌ لأُمِّ الْبَنِينَ مَعَهُمْ أَجْرَاسٌ فَحَدَّثَ نَافِعًا سَالِمٌ عَنْ أَبِيهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رَكْبًا مَعَهُمْ جُلْجُلٌ ‏"‏ ‏.‏ كَمْ تَرَى مَعَ هَؤُلاَءِ مِنَ الْجُلْجُلِ ‏.‏\hadithno{5219}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Bakr bin Abi Shaikh said:"I was sitting with Salim when a caravan belonging to Umm Al-Banin passed by us, and they had bells with them. Salim narrated to Nafi' from his father, that the Prophet [SAW] said: 'The angels do not accompany a caravan that has small bells with them.' How often do you see small bells with these people}}
\hadithdefcmd{nasai}{5220}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ الطَّرَسُوسِيُّ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنْ أَبِي بَكْرِ بْنِ مُوسَى، قَالَ كُنْتُ مَعَ سَالِمِ بْنِ عَبْدِ اللَّهِ فَحَدَّثَ سَالِمٌ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا جُلْجُلٌ ‏"‏ ‏.‏\hadithno{5220}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Bakr bin Musa said:"I was with Salim bin 'Abdullah when Salim narrated from his father, that the Prophet [SAW] said: 'The angels do not accompany groups of people who have small bells with them}}
\hadithdefcmd{nasai}{5221}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنْ بُكَيْرِ بْنِ مُوسَى، عَنْ سَالِمٍ، عَنْ أَبِيهِ، رَفَعَهُ قَالَ ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا جُلْجُلٌ ‏"‏ ‏.‏\hadithno{5221}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Salim, from his father,:Who attributed it to the Prophet [SAW]: "The angels do not accompany groups of people who have small bells with them}}
\hadithdefcmd{nasai}{5222}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدِ بْنِ مُسَلَّمٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ بَابَيْهِ، مَوْلَى آلِ نَوْفَلٍ أَنَّ أُمَّ، سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ جُلْجُلٌ وَلاَ جَرَسٌ وَلاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا جَرَسٌ ‏"‏ ‏.‏\hadithno{5222}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Umm Salamah, the wife of the Prophet [SAW], said:"I heard the Messenger of Allah [SAW] say: 'The angels do not enter a house in which there is a small bell, or a bell, and the angels do not accompany groups of people who have bells with them}}
\hadithdefcmd{nasai}{5223}{أَخْبَرَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ كُنْتُ جَالِسًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَآنِي رَثَّ الثِّيَابِ فَقَالَ ‏"‏ أَلَكَ مَالٌ ‏"‏ ‏.‏ قُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ مِنْ كُلِّ الْمَالِ ‏.‏ قَالَ ‏"‏ فَإِذَا آتَاكَ اللَّهُ مَالاً فَلْيُرَ أَثَرُهُ عَلَيْكَ ‏"‏ ‏.‏\hadithno{5223}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Al-Ahwas that his father said:"I was sitting with the Messenger of Allah [SAW] and he saw that I was dressed in scruffy clothes. He said: 'Do you have any wealth?' I said: 'Yes, O Messenger of Allah, all kinds of wealth.' He said: 'If Allah gives you wealth then let its effect be seen on you}}
\hadithdefcmd{nasai}{5224}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِيهِ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم فِي ثَوْبٍ دُونٍ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلَكَ مَالٌ ‏"‏ ‏.‏ قَالَ نَعَمْ مِنْ كُلِّ الْمَالِ ‏.‏ قَالَ ‏"‏ مِنْ أَىِّ الْمَالِ ‏"‏ ‏.‏ قَالَ قَدْ آتَانِيَ اللَّهُ مِنَ الإِبِلِ وَالْغَنَمِ وَالْخَيْلِ وَالرَّقِيقِ ‏.‏ قَالَ ‏"‏ فَإِذَا آتَاكَ اللَّهُ مَالاً فَلْيُرَ عَلَيْكَ أَثَرُ نِعْمَةِ اللَّهِ وَكَرَامَتِهِ ‏"‏ ‏.‏\hadithno{5224}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Al-Ahwas, from his father, :That he came to the Prophet [SAW] wearing shabby clothes. The Prophet [SAW] said to him: "Do you have any wealth?" He said: "Yes, all kinds of wealth." He said: "What kinds of wealth?" He said: "Allah has given me camels, cattle, sheep, horses and slaves." He said: "If Allah has given you wealth, then let the effect of Allah's blessing and generosity be seen on you}}
\hadithdefcmd{nasai}{5225}{أَخْبَرَنَا ابْنُ السُّنِّيِّ، قِرَاءَةً قَالَ حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ، أَحْمَدُ بْنُ شُعَيْبٍ لَفْظًا قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، - وَهُوَ ابْنُ سُلَيْمَانَ - قَالَ سَمِعْتُ مَعْمَرًا، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ وَنَتْفُ الإِبْطِ وَتَقْلِيمُ الأَظْفَارِ وَالاِسْتِحْدَادُ وَالْخِتَانُ ‏"‏ ‏.‏\hadithno{5225}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said to me: 'Five things are from the Fitrah: Trimming the mustache, plucking the armpit hairs, clipping the nails, shaving the pubes and circumcision}}
\hadithdefcmd{nasai}{5226}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَحْفُوا الشَّوَارِبَ وَأَعْفُوا اللِّحَى ‏"‏ ‏.‏\hadithno{5226}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Prophet [SAW] said: "Trim the mustache and let the beard grow}}
\hadithdefcmd{nasai}{5227}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ مُحَمَّدَ بْنَ أَبِي يَعْقُوبَ، يُحَدِّثُ ‏\{‏ عَنِ الْحَسَنِ بْنِ سَعْدٍ، ‏\}‏ عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ أَمْهَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم آلَ جَعْفَرٍ ثَلاَثَةً أَنْ يَأْتِيَهُمْ ثُمَّ أَتَاهُمْ فَقَالَ ‏"‏ لاَ تَبْكُوا عَلَى أَخِي بَعْدَ الْيَوْمِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ ادْعُوا إِلَىَّ بَنِي أَخِي ‏"‏ ‏.‏ فَجِيءَ بِنَا كَأَنَّا أَفْرُخٌ فَقَالَ ‏"‏ ادْعُوا لِي الْحَلاَّقَ ‏"‏ ‏.‏ فَأَمَرَ بِحَلْقِ رُءُوسِنَا ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{5227}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Ja'far said:"The Messenger of Allah [SAW] stayed away from the family of Ja'far (when he died) for three days, then he came to them, and said: 'Do not weep for my brother after today.' Then he said: 'Call my brother's sons to me.' We were brought like little chicks, and he said: 'Call the barber for me.' Then he ordered that our heads be shaved}}
\hadithdefcmd{nasai}{5228}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ، قَالَ أَنْبَأَنَا حَمَّادٌ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْقَزَعِ ‏.‏\hadithno{5228}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:The Prophet [SAW] forbade Al-Qaza' (shaving part of the head and leaving part)}}
\hadithdefcmd{nasai}{5229}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَمِعَ ابْنَ عُمَرَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ الْقَزَعِ ‏.‏\hadithno{5229}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar said:"I heard the Messenger of Allah [SAW] forbidding Al-Qaza' (shaving part of the head and leaving part)}}
\hadithdefcmd{nasai}{5230}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ عُمَرَ بْنِ نَافِعٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْقَزَعِ ‏.‏\hadithno{5230}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] forbade Al-Qaza' (shaving part of the head and leaving part)}}
\hadithdefcmd{nasai}{5231}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ أَخْبَرَنِي عُمَرُ بْنُ نَافِعٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْقَزَعِ ‏.‏\hadithno{5231}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that :The Prophet [SAW] forbade Al-Qaza' (shaving part of the head and leaving part)}}
\hadithdefcmd{nasai}{5232}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ، عَنْ أُمَيَّةَ بْنِ خَالِدٍ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجِلاً مَرْبُوعًا عَرِيضَ مَا بَيْنَ الْمَنْكِبَيْنِ كَثَّ اللِّحْيَةِ تَعْلُوهُ حُمْرَةٌ جُمَّتُهُ إِلَى شَحْمَتَىْ أُذُنَيْهِ لَقَدْ رَأَيْتُهُ فِي حُلَّةٍ حَمْرَاءَ مَا رَأَيْتُ أَحْسَنَ مِنْهُ ‏.‏\hadithno{5232}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Al-Bara' said:"The Messenger of Allah [SAW] was a man of average height with broad shoulders, a thick beard and a reddish complexion, and his hair came down to his earlobes. I saw him in a red Hullah and I never saw anything more handsome than him}}
\hadithdefcmd{nasai}{5233}{أَخْبَرَنَا حَاجِبُ بْنُ سُلَيْمَانَ، عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ مَا رَأَيْتُ مِنْ ذِي لِمَّةٍ أَحْسَنَ فِي حُلَّةٍ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَهُ شَعْرٌ يَضْرِبُ مَنْكِبَيْهِ ‏.‏\hadithno{5233}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Al-Bara' said:"I never saw any long haired man in a Hullah who was more handsome than the Messenger of Allah [SAW], and he had hair that came down to his shoulders}}
\hadithdefcmd{nasai}{5234}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ شَعْرُ النَّبِيِّ صلى الله عليه وسلم إِلَى نِصْفِ أُذُنَيْهِ ‏.‏\hadithno{5234}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that:The hair of the Prophet [SAW] came halfway down his ears}}
\hadithdefcmd{nasai}{5235}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَضْرِبُ شَعْرُهُ إِلَى مَنْكِبَيْهِ ‏.‏\hadithno{5235}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that:The hair of the Prophet [SAW] came down to his shoulders}}
\hadithdefcmd{nasai}{5236}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ أَنْبَأَنَا عِيسَى، عَنِ الأَوْزَاعِيِّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ أَتَانَا النَّبِيُّ صلى الله عليه وسلم فَرَأَى رَجُلاً ثَائِرَ الرَّأْسِ فَقَالَ ‏ "‏ أَمَا يَجِدُ هَذَا مَا يُسَكِّنُ بِهِ شَعْرَهُ ‏"‏ ‏.‏\hadithno{5236}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Prophet [SAW] came to us and saw a man with wild hair. He said: 'Could this man not find anything with which to calm down his hair?}}
\hadithdefcmd{nasai}{5237}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عُمَرُ بْنُ عَلِيِّ بْنِ مُقَدَّمٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أَبِي قَتَادَةَ، قَالَ كَانَتْ لَهُ جُمَّةٌ ضَخْمَةٌ فَسَأَلَ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يُحْسِنَ إِلَيْهَا وَأَنْ يَتَرَجَّلَ كُلَّ يَوْمٍ ‏.‏\hadithno{5237}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Qatadah said:That he had long thick hair. "He asked the Prophet (about it) and he told him to take care of it and comb it every day}}
\hadithdefcmd{nasai}{5238}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسْدُلُ شَعْرَهُ وَكَانَ الْمُشْرِكُونَ يَفْرُقُونَ شُعُورَهُمْ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ مُوَافَقَةَ أَهْلِ الْكِتَابِ فِيمَا لَمْ يُؤْمَرْ فِيهِ بِشَىْءٍ ثُمَّ فَرَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ ‏.‏\hadithno{5238}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that:The Messenger of Allah [SAW] used to let his hair hang down (without a parting) and the Mushrikun used to part their hair. The Messenger of Allah [SAW] liked to act in accordance with the People of the Book, in matters where no specific command had been given to him. Then the Messenger of Allah [SAW] parted his hair after that}}
\hadithdefcmd{nasai}{5239}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنِ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُقَالُ لَهُ عُبَيْدٌ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَنْهَى عَنْ كَثِيرٍ مِنَ الإِرْفَاهِ ‏.‏ سُئِلَ ابْنُ بُرَيْدَةَ عَنِ الإِرْفَاهِ قَالَ مِنْهُ التَّرَجُّلُ ‏.‏\hadithno{5239}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that:A man from among the Companions of the Prophet [SAW] who was called 'Ubaid said: "The Messenger of Allah [SAW] used to forbid too much of Al-Irfah." Ibn Buraidah was asked what too much of Al-Irfah meant, and he said: "It includes combing the hair}}
\hadithdefcmd{nasai}{5240}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي الأَشْعَثُ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، وَذَكَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُحِبُّ التَّيَامُنَ مَا اسْتَطَاعَ فِي طُهُورِهِ وَتَنَعُّلِهِ وَتَرَجُّلِهِ ‏.‏\hadithno{5240}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah [SAW] liked to start on the right whenever possible; when purifying himself, when putting on his shoes, and when combing his hair}}
\hadithdefcmd{nasai}{5241}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، وَسُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ، يُخْبِرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ يَصْبُغُونَ فَخَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{5241}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that :The Messenger of Allah [SAW] said: "The Jews and the Christians do not dye their hair, so be different from them}}
\hadithdefcmd{nasai}{5242}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا عَزْرَةُ، - وَهُوَ ابْنُ ثَابِتٍ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِأَبِي قُحَافَةَ وَرَأْسُهُ وَلِحْيَتُهُ كَأَنَّهُ ثَغَامَةٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ غَيِّرُوا أَوِ اخْضِبُوا ‏"‏ ‏.‏\hadithno{5242}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"Abu Quhafah was brought to the Messenger of Allah [SAW] and his head and beard were white like the Thaghamah. The Prophet [SAW] said: 'Change this, or dye it}}
\hadithdefcmd{nasai}{5243}{أَخْبَرَنَا يَحْيَى بْنُ حَكِيمٍ، قَالَ حَدَّثَنَا أَبُو قُتَيْبَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عُبَيْدٍ، قَالَ رَأَيْتُ ابْنَ عُمَرَ يُصَفِّرُ لِحْيَتَهُ فَقُلْتُ لَهُ فِي ذَلِكَ فَقَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَفِّرُ لِحْيَتَهُ ‏.‏\hadithno{5243}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ubaid said:"I saw Ibn 'Umar dyeing his beard yellow and I asked him about that. 'He said: "I saw the Prophet [SAW] dye his beard yellow}}
\hadithdefcmd{nasai}{5244}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ أَنْبَأَنَا عَمْرُو بْنُ مُحَمَّدٍ، قَالَ أَنْبَأَنَا ابْنُ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَلْبَسُ النِّعَالَ السِّبْتِيَّةَ وَيُصَفِّرُ لِحْيَتَهُ بِالْوَرْسِ وَالزَّعْفَرَانِ ‏.‏ وَكَانَ ابْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{5244}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Prophet [SAW] used to wear Sibtiyyah sandals and dye his beard yellow with Wars and saffron." And Ibn 'Umar used to do that}}
\hadithdefcmd{nasai}{5245}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ مُعَاوِيَةَ، وَهُوَ عَلَى الْمِنْبَرِ بِالْمَدِينَةِ وَأَخْرَجَ مِنْ كُمِّهِ قُصَّةً مِنْ شَعْرٍ فَقَالَ يَا أَهْلَ الْمَدِينَةِ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَنْهَى عَنْ مِثْلِ هَذِهِ وَقَالَ ‏ "‏ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ اتَّخَذَ نِسَاؤُهُمْ مِثْلَ هَذَا ‏"‏ ‏.‏\hadithno{5245}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Humaid bin 'Abdur-Rahman said:"I heard Mu'awiyah say, when he was on the Minbar in Al-Madinah, and he brought out a hairpiece from his sleeve: 'O people of Al-Madinah, where are your knowledgeable ones? I heard the Messenger of Allah [SAW] forbid such things as this, and he said: "The Children of Israel were destroyed when their women started to wear things like this}}
\hadithdefcmd{nasai}{5246}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَدِمَ مُعَاوِيَةُ الْمَدِينَةَ فَخَطَبَنَا وَأَخَذَ كُبَّةً مِنْ شَعْرٍ قَالَ مَا كُنْتُ أَرَى أَحَدًا يَفْعَلُهُ إِلاَّ الْيَهُودَ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَلَغَهُ فَسَمَّاهُ الزُّورَ ‏.‏\hadithno{5246}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"Mu'awiyah came to Al-Madinah and addressed us. He took hold of a hairpiece and said: 'I never used to see anyone do this except the Jews. The Messenger of Allah [SAW] heard of it and he called it "giving a false impression}}
\hadithdefcmd{nasai}{5247}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا مَحْبُوبُ بْنُ مُوسَى، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، عَنْ يَعْقُوبَ بْنِ الْقَعْقَاعِ، عَنْ قَتَادَةَ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ مُعَاوِيَةَ، أَنَّهُ قَالَ يَا أَيُّهَا النَّاسُ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَاكُمْ عَنِ الزُّورِ ‏.‏ قَالَ وَجَاءَ بِخِرْقَةٍ سَوْدَاءَ فَأَلْقَاهَا بَيْنَ أَيْدِيهِمْ فَقَالَ هُوَ هَذَا تَجْعَلُهُ الْمَرْأَةُ فِي رَأْسِهَا ثُمَّ تَخْتَمِرُ عَلَيْهِ ‏.‏\hadithno{5247}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Mu'awiyah said:"O people, the Prophet [SAW] forbade you to give false impressions. He brought a piece of black cloth and threw it in front of them and said: 'This is what women are putting on their heads and covering it}}
\hadithdefcmd{nasai}{5248}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنَا أَسَدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ هِشَامِ بْنِ أَبِي عَبْدِ اللَّهِ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ مُعَاوِيَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الزُّورِ وَالزُّورُ الْمَرْأَةُ تَلِفُّ عَلَى رَأْسِهَا ‏.‏\hadithno{5248}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Mu'awiyah that:The Messenger of Allah [SAW] forbade giving a false impression, and the false impression of a woman when she adds extra hair to her head}}
\hadithdefcmd{nasai}{5249}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ الْوَاصِلَةَ ‏.‏\hadithno{5249}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] cursed the woman who affixes hair extensions}}
\hadithdefcmd{nasai}{5250}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَتْنِي فَاطِمَةُ، عَنْ أَسْمَاءَ، أَنَّ امْرَأَةً، جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ بِنْتًا لِي عَرُوسٌ وَإِنَّهَا اشْتَكَتْ فَتَمَزَّقَ شَعْرُهَا فَهَلْ عَلَىَّ جُنَاحٌ إِنْ وَصَلْتُ لَهَا فِيهِ فَقَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ ‏"‏ ‏.‏\hadithno{5250}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Asma' that:A woman came to the Messenger of Allah [SAW] and said: "O Messenger of Allah [SAW], a daughter of mine is going to get married. She got sick and her hair fell out. Is there any sin on me if I give her hair extensions?" He said: "Allah has cursed the woman who affixes hair extensions and the one who has that done}}
\hadithdefcmd{nasai}{5251}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاصِلَةَ وَالْمُوتَصِلَةَ وَالْوَاشِمَةَ وَالْمُوتَشِمَةَ ‏.‏\hadithno{5251}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] cursed the woman who affixes hair extensions and the one who has that done, and the woman who does tattoos and the one who has that done}}
\hadithdefcmd{nasai}{5252}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ اللَّهُ الْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ أَلاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5252}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"May Allah curse Al-Mutanammisat and who have their teeth separated. Shall I not curse those whom the Messenger of Allah [SAW] cursed?}}
\hadithdefcmd{nasai}{5253}{أَخْبَرَنَا أَحْمَدُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ الأَعْمَشَ، يُحَدِّثُ عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاشِمَاتِ وَالْمُتَفَلِّجَاتِ وَالْمُتَنَمِّصَاتِ الْمُغَيِّرَاتِ خَلْقَ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{5253}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] cursed the women who do tattoos, those who have their teeth separated and Al-Mutanammisat who change the creation of Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{5254}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ اللَّهُ الْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ وَالْمُتَوَشِّمَاتِ الْمُغَيِّرَاتِ خَلْقَ اللَّهِ ‏.‏ فَأَتَتْهُ امْرَأَةٌ فَقَالَتْ أَنْتَ الَّذِي تَقُولُ كَذَا وَكَذَا قَالَ وَمَا لِيَ لاَ أَقُولُ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5254}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"May Allah curse Al-Mutanammisat and their teeth separated, who have tattoos done, changing the creation of Allah." A woman came to him and said: "Are you the one who said such-and-such?" He said: "Why should I not say what the Messenger of Allah [SAW] said?}}
\hadithdefcmd{nasai}{5255}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، قَالَ كَانَ عَبْدُ اللَّهِ يَقُولُ لَعَنَ اللَّهُ الْمُتَوَشِّمَاتِ وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ أَلاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5255}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibrahim said:"Abdullah used to say: 'May Allah curse the women who have tattoos done and Al-Mutanammisat, and have the women who have their teeth separated. Should I not curse those whom the Messenger of Allah [SAW] cursed?}}
\hadithdefcmd{nasai}{5256}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَتَزَعْفَرَ الرَّجُلُ ‏.‏\hadithno{5256}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] forbade men to use saffron}}
\hadithdefcmd{nasai}{5257}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيِّ بْنِ مُقَدَّمٍ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ يَحْيَى بْنِ عُمَارَةَ الأَنْصَارِيُّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُزَعْفِرَ الرَّجُلُ جِلْدَهُ ‏.‏\hadithno{5257}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) forbade men to use saffron on their skin}}
\hadithdefcmd{nasai}{5258}{أَخْبَرَنَا إِسْحَاقُ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أُتِيَ بِطِيبٍ لَمْ يَرُدَّهُ ‏.‏\hadithno{5258}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:"If perfume was brought to the Prophet [SAW], he would not refuse it}}
\hadithdefcmd{nasai}{5259}{أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي جَعْفَرٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ عُرِضَ عَلَيْهِ طِيبٌ فَلاَ يَرُدَّهُ فَإِنَّهُ خَفِيفُ الْمَحْمَلِ طَيِّبُ الرَّائِحَةِ ‏"‏ ‏.‏\hadithno{5259}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] said: "Whoever is offered perfume, let him not refuse it for it is easy to carry, and smells good}}
\hadithdefcmd{nasai}{5260}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ ابْنِ عَجْلاَنَ، عَنْ بُكَيْرٍ، ح وَأَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، قَالَ حَدَّثَنِي بُكَيْرُ بْنُ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَهِدَتْ إِحْدَاكُنَّ الْعِشَاءَ فَلاَ تَمَسَّ طِيبًا ‏"‏ ‏.‏\hadithno{5260}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zainab, the wife of 'Abdullah, said:"The Messenger of Allah [SAW] said: 'If one of you (women) wants to attend 'Isha' (prayer). Let her not touch any perfume}}
\hadithdefcmd{nasai}{5261}{أَخْبَرَنَا أَحْمَدُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ هِشَامٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَخْبَرَتْنِي زَيْنَبُ الثَّقَفِيَّةُ، امْرَأَةُ عَبْدِ اللَّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ إِذَا خَرَجْتِ إِلَى الْعِشَاءِ فَلاَ تَمَسَّ طِيبًا ‏"‏ ‏.‏\hadithno{5261}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Busr bin Sa'eed that Zainab, the wife of 'Abdullah, told him that :The Messenger of Allah [SAW] said to her: "If you go out to 'Isha' then do not touch any perfume}}
\hadithdefcmd{nasai}{5262}{وَحَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي جَعْفَرٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ الثَّقَفِيَّةِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيَّتُكُنَّ خَرَجَتْ إِلَى الْمَسْجِدِ فَلاَ تَقْرَبَنَّ طِيبًا ‏"‏ ‏.‏\hadithno{5262}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zainab Ath-Thaqafiyyah that:The Prophet [SAW] said: "Any one of you (women) who wants to go out to the Masjid should not go near any perfume}}
\hadithdefcmd{nasai}{5263}{أَخْبَرَنَا مُحَمَّدُ بْنُ هِشَامِ بْنِ عِيسَى، قَالَ حَدَّثَنَا أَبُو عَلْقَمَةَ الْفَرْوِيُّ عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ خُصَيْفَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ أَصَابَتْ بَخُورًا فَلاَ تَشْهَدْ مَعَنَا الْعِشَاءَ الآخِرَةَ ‏"‏ ‏.‏\hadithno{5263}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that :The Messenger of Allah [SAW] said: "Any woman who has been perfumed with incense should not attend 'Isha' the later with us}}
\hadithdefcmd{nasai}{5264}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ غَزْوَانَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ خُلَيْدِ بْنِ جَعْفَرٍ، وَالْمُسْتَمِرِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ ذَكَرَ النَّبِيُّ صلى الله عليه وسلم امْرَأَةً حَشَتْ خَاتَمَهَا بِالْمِسْكِ فَقَالَ ‏ "‏ وَهُوَ أَطْيَبُ الطِّيبِ ‏"‏ ‏.‏\hadithno{5264}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed said:"The Prophet [SAW] mentioned a woman who filled her ring with musk and said: 'That is the best of perfume}}
\hadithdefcmd{nasai}{5265}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، وَيَزِيدُ، وَمُعْتَمِرٌ، وَبِشْرُ بْنُ الْمُفَضَّلِ، قَالُوا حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي مُوسَى، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ أَحَلَّ لإِنَاثِ أُمَّتِي الْحَرِيرَ وَالذَّهَبَ وَحَرَّمَهُ عَلَى ذُكُورِهَا ‏"‏ ‏.‏\hadithno{5265}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Musa that:The Messenger of Allah [SAW] said: "Allah has permitted silk and gold to the females of my Ummah, and has forbidden them to the males}}
\hadithdefcmd{nasai}{5266}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنْ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نُهِيتُ عَنِ الثَّوْبِ الأَحْمَرِ، وَخَاتَمِ الذَّهَبِ، وَأَنْ أَقْرَأَ وَأَنَا رَاكِعٌ، ‏.‏\hadithno{5266}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"I was forbidden to wear red garments and gold rings, and to recite Qur'an when bowing}}
\hadithdefcmd{nasai}{5267}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، قَالَ أَخْبَرَنِي إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَلِيٍّ، قَالَ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنْ خَاتَمِ الذَّهَبِ وَأَنْ أَقْرَأَ الْقُرْآنَ وَأَنَا رَاكِعٌ وَعَنِ الْقَسِّيِّ وَعَنِ الْمُعَصْفَرِ ‏.‏\hadithno{5267}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Prophet [SAW] forbade me from wearing gold rings, reciting Qur'an while I am bowing, and from Al-Qassi, and garments dyed with safflower}}
\hadithdefcmd{nasai}{5268}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، عَنِ اللَّيْثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَلِيًّا، يَقُولُ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ خَاتَمِ الذَّهَبِ وَعَنْ لُبُوسِ الْقَسِّيِّ وَالْمُعَصْفَرِ وَقِرَاءَةِ الْقُرْآنِ وَأَنَا رَاكِعٌ ‏.‏\hadithno{5268}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali said:"The Messenger of Allah [SAW] forbade me from wearing gold rings, and from garments of Al-Qassi, and garments dyed with safflower, and reciting Qur'an while bowing}}
\hadithdefcmd{nasai}{5269}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْقِرَاءَةِ فِي الرُّكُوعِ ‏.‏\hadithno{5269}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade me from reciting Qur'an while bowing}}
\hadithdefcmd{nasai}{5270}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا حَرْبٌ، عَنْ يَحْيَى، حَدَّثَنِي عَمْرُو بْنُ سَعْدٍ الْفَدَكِيُّ، أَنَّ نَافِعًا، أَخْبَرَهُ حَدَّثَنِي ابْنُ حُنَيْنٍ، أَنَّ عَلِيًّا، حَدَّثَهُ قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثِيَابِ الْمُعَصْفَرِ وَعَنْ خَاتَمِ الذَّهَبِ وَلُبْسِ الْقَسِّيِّ وَأَنْ أَقْرَأَ وَأَنَا رَاكِعٌ ‏.‏\hadithno{5270}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali said:"The Messenger of Allah [SAW] forbade me from wearing garments dyed with safflower, and from gold rings, and from wearing Al-Qassi, and that I recite Qur'an while I am bowing}}
\hadithdefcmd{nasai}{5271}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ مُحَمَّدَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُ عَنِ ابْنِ حُنَيْنٍ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَرْبَعٍ عَنْ لُبْسِ ثَوْبٍ مُعَصْفَرٍ وَعَنِ التَّخَتُّمِ بِخَاتَمِ الذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيَّةِ وَأَنْ أَقْرَأَ الْقُرْآنَ وَأَنَا رَاكِعٌ ‏.‏\hadithno{5271}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade me from four things: Wearing garments dyed with safflower, and from wearing gold rings, and from wearing Al-Qassiyah garments, and reciting Qur'an while I am bowing}}
\hadithdefcmd{nasai}{5272}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، أَخْبَرَنِي خَالِدُ بْنُ مَعْدَانَ، أَنَّ ابْنَ حُنَيْنٍ، حَدَّثَهُ أَنَّ عَلِيًّا قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثِيَابِ الْمُعَصْفَرِ وَعَنِ الْحَرِيرِ وَأَنْ يَقْرَأَ وَهُوَ رَاكِعٌ وَعَنْ خَاتَمِ الذَّهَبِ ‏.‏\hadithno{5272}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Hunain, that 'Ali said that:The Messenger of Allah [SAW] forbade garments dyed with safflower, and from silk, and reciting Qur'an while he is bowing, and from gold rings}}
\hadithdefcmd{nasai}{5273}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ النَّضْرَ بْنَ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ خَاتَمِ الذَّهَبِ ‏.‏\hadithno{5273}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet [SAW] forbade gold rings}}
\hadithdefcmd{nasai}{5274}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنِ الْحَجَّاجِ، - وَهُوَ ابْنُ الْحَجَّاجِ - عَنْ قَتَادَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُبَيْدٍ، عَنْ بُشَيْرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ تَخَتُّمِ الذَّهَبِ ‏.‏\hadithno{5274}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:The Messenger of Allah [SAW] forbade gold rings}}
\hadithdefcmd{nasai}{5275}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمَ الذَّهَبِ فَلَبِسَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاتَّخَذَ النَّاسُ خَوَاتِيمَ الذَّهَبِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي كُنْتُ أَلْبَسُ هَذَا الْخَاتَمَ وَإِنِّي لَنْ أَلْبَسَهُ أَبَدًا ‏"‏ ‏.‏ فَنَبَذَهُ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ ‏.‏\hadithno{5275}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] took a ring of gold and put it on, and the people started to wear gold rings too. The Messenger of Allah [SAW] said: 'I used to wear this ring, but I will never wear it again.' Then he threw it away, and the people threw their rings away}}
\hadithdefcmd{nasai}{5276}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ نَقْشُ خَاتَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5276}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The inscription on the ring of the Messenger of Allah [SAW] was: Muhammad Rasul Allah (Muhammad the Messenger of Allah)}}
\hadithdefcmd{nasai}{5277}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ أَنْبَأَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ وَرِقٍ وَفَصُّهُ حَبَشِيٌّ وَنَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5277}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that :The Prophet [SAW] put on a silver ring with and Ethiopian stone (Fass), on which the inscription was: "Muhammad Rasul Allah}}
\hadithdefcmd{nasai}{5278}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ بِشْرٍ، - وَهُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ أَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى الرُّومِ فَقَالُوا إِنَّهُمْ لاَ يَقْرَءُونَ كِتَابًا إِلاَّ مَخْتُومًا ‏.‏ فَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِهِ فِي يَدِهِ وَنُقِشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5278}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] wanted to write to the Romans, and they (the Companions) said: 'They do not read any letter unless it has a seal.' So he took a ring of silver and it is as if I can see its whiteness on his hand, and engraved on it (were the words): 'Muhammad Rasul Allah}}
\hadithdefcmd{nasai}{5279}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ وَرِقٍ وَفَصُّهُ حَبَشِيٌّ ‏.‏\hadithno{5279}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that:The Messenger of Allah [SAW] put on a ring of silver with an Ethiopian stone (Fass)}}
\hadithdefcmd{nasai}{5280}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنِ الْحَسَنِ، - وَهُوَ ابْنُ صَالِحٍ - عَنْ عَاصِمٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم مِنْ فِضَّةٍ وَفَصُّهُ مِنْهُ ‏.‏\hadithno{5280}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"The ring of the Prophet [SAW] was of silver, and its stone (Fass) was made of silver too}}
\hadithdefcmd{nasai}{5281}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ حُجْرٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدِ اصْطَنَعْنَا خَاتَمًا وَنَقَشْنَا عَلَيْهِ نَقْشًا فَلاَ يَنْقُشْ عَلَيْهِ أَحَدٌ ‏"‏ ‏.‏\hadithno{5281}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] said: 'We have had a ring made with an inscription, and no one else should copy this inscription}}
\hadithdefcmd{nasai}{5282}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اصْطَنَعَ خَاتَمًا فَقَالَ ‏ "‏ إِنَّا قَدِ اتَّخَذْنَا خَاتَمًا وَنَقَشْنَا عَلَيْهِ نَقْشًا فَلاَ يَنْقُشْ عَلَيْهِ أَحَدٌ ‏"‏ ‏.‏ وَإِنِّي لأَرَى بَرِيقَهُ فِي خِنْصَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5282}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that:The Prophet [SAW] had a ring and he said: "We have had a ring made with an inscription, and no one else should copy this inscription." It is as if I can see its shining on the little finer of the Messenger of Allah [SAW]}}
\hadithdefcmd{nasai}{5283}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَامِرٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَخَتَّمُ فِي يَمِينِهِ ‏.‏\hadithno{5283}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Prophet [SAW] used to wear his ring on his right hand}}
\hadithdefcmd{nasai}{5284}{أَخْبَرَنَا الْحُسَيْنُ بْنُ عِيسَى الْبِسْطَامِيُّ، قَالَ حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِ خَاتَمِ النَّبِيِّ صلى الله عليه وسلم فِي إِصْبَعِهِ الْيُسْرَى ‏.‏\hadithno{5284}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"It is as if I can see the whiteness of the Prophet's ring on his left finger}}
\hadithdefcmd{nasai}{5285}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا ثَابِتٌ، أَنَّهُمْ سَأَلُوا أَنَسًا عَنْ خَاتَمِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ مِنْ فِضَّةٍ ‏.‏ وَرَفَعَ إِصْبَعَهُ الْيُسْرَى الْخِنْصَرَ ‏.‏\hadithno{5285}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thabit narrated that :They asked Anas about the ring of the Messenger of Allah [SAW] and he said: "It is as if I can see the shining of his silver ring, and he raised his left little finger}}
\hadithdefcmd{nasai}{5286}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ نَهَانِي نَبِيُّ اللَّهِ صلى الله عليه وسلم عَنِ الْخَاتَمِ فِي السَّبَّابَةِ وَالْوُسْطَى ‏.‏\hadithno{5286}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Burdah said:"I heard 'Ali say: 'The Prophet of Allah [SAW] forbade me to wear a ring on the forefinger and middle finger}}
\hadithdefcmd{nasai}{5287}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَلْبَسَ فِي إِصْبَعِي هَذِهِ وَفِي الْوُسْطَى وَالَّتِي تَلِيهَا ‏.‏\hadithno{5287}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah [SAW] forbade me to wear (a ring) on this finger," and it was on the middle finger and the one next to it}}
\hadithdefcmd{nasai}{5288}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَخَتَّمُ بِخَاتَمٍ مِنْ ذَهَبٍ ثُمَّ طَرَحَهُ وَلَبِسَ خَاتَمًا مِنْ وَرِقٍ وَنُقِشَ عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ ثُمَّ قَالَ ‏ "‏ لاَ يَنْبَغِي لأَحَدٍ أَنْ يَنْقُشَ عَلَى نَقْشِ خَاتَمِي هَذَا ‏"‏ ‏.‏ وَجَعَلَ فَصَّهُ فِي بَطْنِ كَفِّهِ ‏.‏\hadithno{5288}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Prophet [SAW] wore a ring of gold, then he discarded it and wore a ring of silver on which were engraved (the words) 'Muhammad Rasul Allah.' Then he said: 'No one should copy this inscription of mine.' And he wore the stone (Fass) toward his palm}}
\hadithdefcmd{nasai}{5289}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ حَرْبٍ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، عَنْ سُلَيْمَانَ الشَّيْبَانِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا فَلَبِسَهُ قَالَ ‏ "‏ شَغَلَنِي هَذَا عَنْكُمْ مُنْذُ الْيَوْمِ إِلَيْهِ نَظْرَةٌ وَإِلَيْكُمْ نَظْرَةٌ ‏"‏ ‏.‏ ثُمَّ أَلْقَاهُ ‏.‏\hadithno{5289}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that :The Messenger of Allah [SAW] took a ring and put it on, then he said: "This distracted me from you all day, shifting my gaze from it to you (and back again)." Then he threw it away}}
\hadithdefcmd{nasai}{5290}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اصْطَنَعَ خَاتَمًا مِنْ ذَهَبٍ وَكَانَ يَلْبَسُهُ فَجَعَلَ فَصَّهُ فِي بَاطِنِ كَفِّهِ فَصَنَعَ النَّاسُ ثُمَّ إِنَّهُ جَلَسَ عَلَى الْمِنْبَرِ فَنَزَعَهُ وَقَالَ ‏"‏ إِنِّي كُنْتُ أَلْبَسُ هَذَا الْخَاتَمَ وَأَجْعَلُ فَصَّهُ مِنْ دَاخِلٍ ‏"‏ ‏.‏ فَرَمَى بِهِ ثُمَّ قَالَ ‏"‏ وَاللَّهِ لاَ أَلْبَسُهُ أَبَدًا ‏"‏ ‏.‏ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ ‏.‏\hadithno{5290}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] had a ring made of gold and he used to wear it with the stone (Fass) against his palm, and the people did likewise. Then he sat on the Minbar and said: "I used to wear this ring and put its stone (Fass) on the inside." Then he threw it away and said: "By Allah, I will never wear it again." And the people threw their rings away}}
\hadithdefcmd{nasai}{5291}{أَخْبَرَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، قِرَاءَةً عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، أَنَّهُ رَأَى فِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ يَوْمًا وَاحِدًا فَصَنَعُوهُ فَلَبِسُوهُ فَطَرَحَ النَّبِيُّ صلى الله عليه وسلم وَطَرَحَ النَّاسُ ‏.‏\hadithno{5291}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that:He saw a ring of silver on the hand of the Messenger of Allah [SAW] one day, and the people made and wore similar rings. Then the Prophet [SAW] threw his ring away and the people threw their rings away too}}
\hadithdefcmd{nasai}{5292}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اتَّخَذَ خَاتَمًا مِنْ ذَهَبٍ وَكَانَ جَعَلَ فَصَّهُ فِي بَاطِنِ كَفِّهِ فَاتَّخَذَ النَّاسُ خَوَاتِيمَ مِنْ ذَهَبٍ فَطَرَحَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَرَحَ النَّاسُ خَوَاتِيمَهُمْ وَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ فَكَانَ يَخْتِمُ بِهِ وَلاَ يَلْبَسُهُ ‏.‏\hadithno{5292}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] put on a ring of gold, and he used to wear its stone (Fass) next to his palm. Then the people started to wear rings of gold too. Then the Messenger of Allah [SAW] threw it away, and the people threw their rings away too. Then he took a ring of silver and he used to seal letters with it, but he did not wear it}}
\hadithdefcmd{nasai}{5293}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ ذَهَبٍ وَجَعَلَ فَصَّهُ مِمَّا يَلِي بَطْنَ كَفِّهِ فَاتَّخَذَ النَّاسُ الْخَوَاتِيمَ فَأَلْقَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ أَلْبَسُهُ أَبَدًا ‏"‏ ‏.‏ ثُمَّ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ فَأَدْخَلَهُ فِي يَدِهِ ثُمَّ كَانَ فِي يَدِ أَبِي بَكْرٍ ثُمَّ كَانَ فِي يَدِ عُمَرَ ثُمَّ كَانَ فِي يَدِ عُثْمَانَ حَتَّى هَلَكَ فِي بِئْرِ أَرِيسٍ ‏.‏\hadithno{5293}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] put on a ring of gold and he used to wear its stone (Fass) next to his palm. Then the people started to wear rings too. Then the Messenger of Allah [SAW] threw it away and said: "I will never wear it again." Then the Messenger of Allah [SAW] took a ring of silver, and wore it on his hand. Then it was on the hand of Abu Bakr, then on the hand of 'Umar, then on the hand of 'Uthman, until it was lost in the well of Aris}}
\hadithdefcmd{nasai}{5294}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَآنِي سَيِّئَ الْهَيْئَةِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ مِنْ شَىْءٍ ‏"‏ ‏.‏ قَالَ نَعَمْ مِنْ كُلِّ الْمَالِ قَدْ آتَانِي اللَّهُ ‏.‏ فَقَالَ ‏"‏ إِذَا كَانَ لَكَ مَالٌ فَلْيُرَ عَلَيْكَ ‏"‏ ‏.‏\hadithno{5294}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Al-Ahwas that his father said:"I entered upon the Messenger of Allah [SAW] and he saw me looking scruffy. The Prophet [SAW] said: 'Do you have anything?' He said: 'Yes, Allah has given me all kinds of wealth.' He said: 'If you have wealth, let it be seen on you}}
\hadithdefcmd{nasai}{5295}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّهُ رَأَى حُلَّةَ سِيَرَاءَ تُبَاعُ عِنْدَ بَابِ الْمَسْجِدِ فَقُلْتُ يَا رَسُولَ اللَّهِ لَوِ اشْتَرَيْتَ هَذَا لِيَوْمِ الْجُمُعَةِ وَلِلْوَفْدِ إِذَا قَدِمُوا عَلَيْكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏ قَالَ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدُ مِنْهَا بِحُلَلٍ فَكَسَانِي مِنْهَا حُلَّةً فَقَالَ يَا رَسُولَ اللَّهِ كَسَوْتَنِيهَا وَقَدْ قُلْتَ فِيهَا مَا قُلْتَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَمْ أَكْسُكَهَا لِتَلْبَسَهَا إِنَّمَا كَسَوْتُكَهَا لِتَكْسُوهَا أَوْ لِتَبِيعَهَا ‏"‏ ‏.‏ فَكَسَاهَا عُمَرُ أَخًا لَهُ مِنْ أُمِّهِ مُشْرِكًا ‏.‏\hadithno{5295}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Umar bin Al-Khattab that:He saw a Hullah of Sira' silk being offered for sale at the door of the Masjid. I said: "O Messenger of Allah, why don't you buy this and wear it on Fridays, and (when meeting) the delegations when they come to you?" The Messenger of Allah [SAW] said: "This is only worn by one who has no share in the Hereafter." After that some (other) Hullahs were brought to the Messenger of Allah [SAW] and he gave me one. He said: "O Messenger of Allah, you gave me this when you said what you said about it!" The Prophet [SAW] said: "I did not give it to you to wear it! Rather I gave it to you to give away or to sell." So 'Umar gave it to a brother of his son on his mother's side who was an idolater}}
\hadithdefcmd{nasai}{5296}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ رَأَيْتُ عَلَى زَيْنَبَ بِنْتِ النَّبِيِّ صلى الله عليه وسلم قَمِيصَ حَرِيرٍ سِيَرَاءَ ‏.‏\hadithno{5296}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"I saw Zainab, the daughter of the Prophet [SAW], wearing a Qamis of Sira}}
\hadithdefcmd{nasai}{5297}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، عَنْ بَقِيَّةَ، حَدَّثَنِي الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ حَدَّثَنِي أَنَّهُ، رَأَى عَلَى أُمِّ كُلْثُومٍ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم بُرْدَ سِيَرَاءَ وَالسِّيَرَاءُ الْمُضَلَّعُ بِالْقَزِّ ‏.‏\hadithno{5297}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that:He saw Umm Kalthum, the daughter of the Messenger of Allah [SAW], wearing a Burdah of Sira' silk, and Sira' is a fabric with stripes of silk}}
\hadithdefcmd{nasai}{5298}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ، وَأَبُو عَامِرٍ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَوْنٍ الثَّقَفِيِّ، قَالَ سَمِعْتُ أَبَا صَالِحٍ الْحَنَفِيَّ، يَقُولُ سَمِعْتُ عَلِيًّا، يَقُولُ أُهْدِيَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حُلَّةُ سِيَرَاءَ فَبَعَثَ بِهَا إِلَىَّ فَلَبِسْتُهَا فَعَرَفْتُ الْغَضَبَ فِي وَجْهِهِ فَقَالَ ‏ "‏ أَمَا إِنِّي لَمْ أُعْطِكَهَا لِتَلْبَسَهَا ‏"‏ ‏.‏ فَأَمَرَنِي فَأَطَرْتُهَا بَيْنَ نِسَائِي ‏.‏\hadithno{5298}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ali said:"A Hullah of Sira' was given to the Messenger of Allah [SAW] and he sent it to me. I put it on, then I saw anger in his face. He said: 'I did not give it to you to wear it.' Then he told me to divide it among my womenfolk}}
\hadithdefcmd{nasai}{5299}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ الْمَخْزُومِيُّ، عَنْ حَنْظَلَةَ بْنِ أَبِي سُفْيَانَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يُحَدِّثُ أَنَّ عُمَرَ، خَرَجَ فَرَأَى حُلَّةَ إِسْتَبْرَقٍ تُبَاعُ فِي السُّوقِ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ اشْتَرِهَا فَالْبَسْهَا يَوْمَ الْجُمُعَةِ وَحِينَ يَقْدَمُ عَلَيْكَ الْوَفْدُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ هَذَا مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ ثُمَّ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِثَلاَثِ حُلَلٍ مِنْهَا فَكَسَا عُمَرَ حُلَّةً وَكَسَا عَلِيًّا حُلَّةً وَكَسَا أُسَامَةَ حُلَّةً فَأَتَاهُ فَقَالَ يَا رَسُولَ اللَّهِ قُلْتَ فِيهَا مَا قُلْتَ ثُمَّ بَعَثْتَ إِلَىَّ ‏.‏ فَقَالَ ‏"‏ بِعْهَا وَاقْضِ بِهَا حَاجَتَكَ أَوْ شَقِّقْهَا خُمُرًا بَيْنَ نِسَائِكَ ‏"‏ ‏.‏\hadithno{5299}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar narrated that:'Umar went out and saw a Hullah of Al-Istabraq being offered for sale in the marketplace. He went to the Messenger of Allah [SAW] and said: "O Messenger of Allah, buy this and wear it on Fridays, and when the delegations come to you." The Messenger of Allah [SAW] said: "This is only worn by the one who has no share (in the Hereafter)." Then three Hullahs (of the same fabric) were brought to the Messenger of Allah [SAW] and he gave one to 'Umar, one to 'Ali and one to Usamah. He ('Umar) came to him and said: "O Messenger of Allah, you said what you said about it, then you sent one to me!" He said: "Sell it and spend the money on your needs, or cut it into pieces for your womenfolk to use as head covers}}
\hadithdefcmd{nasai}{5300}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ أَبِي إِسْحَاقَ - قَالَ قَالَ سَالِمٌ مَا الإِسْتَبْرَقُ قُلْتُ مَا غَلُظَ مِنَ الدِّيبَاجِ وَخَشُنَ مِنْهُ ‏.‏ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ رَأَى عُمَرُ مَعَ رَجُلٍ حُلَّةَ سُنْدُسٍ فَأَتَى بِهَا النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اشْتَرِ هَذِهِ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{5300}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Yahya - bin Ishaq - said:"Salim said: 'What is Al-Istabraq?' I said: 'A thick type of Ad-Dibaj, and a coarse type of it.' He said: 'I heard 'Abdullah (bin 'Umar) say: "Umar saw a Hullah of Sundus with a man, and he brought it to the Messenger of Allah [SAW] and said: 'Buy this'" and he quoted the Hadith}}
\hadithdefcmd{nasai}{5301}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا ابْنُ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، وَيَزِيدُ بْنُ أَبِي زِيَادٍ، عَنِ ابْنِ أَبِي لَيْلَى، وَأَبُو فَرْوَةَ عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، قَالَ اسْتَسْقَى حُذَيْفَةُ فَأَتَاهُ دُهْقَانٌ بِمَاءٍ فِي إِنَاءٍ مِنْ فِضَّةٍ فَحَذَفَهُ ثُمَّ اعْتَذَرَ إِلَيْهِمْ مِمَّا صَنَعَ بِهِ وَقَالَ إِنِّي نَهَيْتُهُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَشْرَبُوا فِي إِنَاءِ الذَّهَبِ وَالْفِضَّةِ وَلاَ تَلْبَسُوا الدِّيبَاجَ وَلاَ الْحَرِيرَ فَإِنَّهَا لَهُمْ فِي الدُّنْيَا وَلَنَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5301}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin 'Ukaim said:"Hudhaifah asked for some water and the chief brought water in a silver vessel. He threw it aside, then he apologized to them for what he had done, and said: 'I told him before not to do that. I heard the Messenger of Allah [SAW] say: Do not drink from vessels of gold and silver, and do not wear Ad-Dibaj or silk. They are for them in this world, and for you in the Hereafter}}
\hadithdefcmd{nasai}{5302}{أَخْبَرَنَا الْحَسَنُ بْنُ قَزَعَةَ، عَنْ خَالِدٍ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ وَاقِدِ بْنِ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ، قَالَ دَخَلْتُ عَلَى أَنَسِ بْنِ مَالِكٍ حِينَ قَدِمَ الْمَدِينَةَ فَسَلَّمْتُ عَلَيْهِ فَقَالَ مِمَّنْ أَنْتَ قُلْتُ أَنَا وَاقِدُ بْنُ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ ‏.‏ قَالَ إِنَّ سَعْدًا كَانَ أَعْظَمَ النَّاسِ وَأَطْوَلَهُ ‏.‏ ثُمَّ بَكَى فَأَكْثَرَ الْبُكَاءَ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ إِلَى أُكَيْدِرَ صَاحِبِ دُومَةَ بَعْثًا فَأَرْسَلَ إِلَيْهِ بِجُبَّةِ دِيبَاجٍ مَنْسُوجَةٍ فِيهَا الذَّهَبُ فَلَبِسَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَامَ عَلَى الْمِنْبَرِ وَقَعَدَ فَلَمْ يَتَكَلَّمْ وَنَزَلَ فَجَعَلَ النَّاسُ يَلْمُسُونَهَا بِأَيْدِيهِمْ فَقَالَ ‏ "‏ أَتَعْجَبُونَ مِنْ هَذِهِ لَمَنَادِيلُ سَعْدٍ فِي الْجَنَّةِ أَحْسَنُ مِمَّا تَرَوْنَ ‏"‏ ‏.‏\hadithno{5302}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Wafid bin 'Amr bin Sa'd bin Mu'adh said:"I entered upon Anas bin Malik when he came to Al-Madinah and greeted him with Salam. He said: 'Where are you from?' I said: 'I am Wafid bin 'Amr bin Sa'd bin Mu'adh.' He said: 'Sa'd was the greatest and most virtuous of people.' Then he wept a great deal, then he said: 'The Messenger of Allah [SAW] sent a delegation to Ukaidir the ruler of Dumah, who sent him a Jubbah made of Ad-Dibaj interwoven with gold. The Messenger of Allah [SAW] put it on, then he stood on the Minbar and sat, without speaking, then he came down and the people started touching it with their hands. He said: 'Are you admiring this? The handkerchiefs of Sa'd in Paradise are more beautiful than what you see}}
\hadithdefcmd{nasai}{5303}{حَدَّثَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ لَبِسَ النَّبِيُّ صلى الله عليه وسلم قِبَاءً مِنْ دِيبَاجٍ أُهْدِيَ لَهُ ثُمَّ أَوْشَكَ أَنْ نَزَعَهُ فَأَرْسَلَ بِهِ إِلَى عُمَرَ فَقِيلَ لَهُ قَدْ أَوْشَكَ مَا نَزَعْتَهُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ نَهَانِي عَنْهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ فَجَاءَ عُمَرُ يَبْكِي فَقَالَ يَا رَسُولَ اللَّهِ كَرِهْتَ أَمْرًا وَأَعْطَيْتَنِيهِ ‏.‏ قَالَ ‏"‏ إِنِّي لَمْ أُعْطِكَهُ لِتَلْبَسَهُ إِنَّمَا أَعْطَيْتُكَهُ لِتَبِيعَهُ ‏"‏ ‏.‏ فَبَاعَهُ عُمَرُ بِأَلْفَىْ دِرْهَمٍ ‏.‏\hadithno{5303}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir said:"The Prophet [SAW] put on a Qaba' of Ad-Dibaj that had been given to him, but he soon took it off and sent it to 'Umar. It was said to him: 'How soon you took it off, O Messenger of Allah.' He said: 'Jibril, peace be upon him, prohibited me from wearing it.' Then 'Umar came weeping and said: 'O Messenger of Allah, you disliked something but you gave it to me.' He said: 'I did not give it to you to wear it, rather I gave it to you to sell it.' So 'Umar sold it for two thousand Dirhams}}
\hadithdefcmd{nasai}{5304}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، وَهُوَ عَلَى الْمِنْبَرِ يَخْطُبُ وَيَقُولُ قَالَ مُحَمَّدٌ صلى الله عليه وسلم ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا فَلَنْ يَلْبَسَهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5304}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdullah bin Az-Zubair said, while he was on the Minbar delivering a Khutbah:"Muhammad [SAW] said: 'Whoever wears silk in this world, will not wear it in the Hereafter}}
\hadithdefcmd{nasai}{5305}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ أَنْبَأَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ حَدَّثَنَا خَلِيفَةُ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، قَالَ لاَ تُلْبِسُوا نِسَاءَكُمُ الْحَرِيرَ فَإِنِّي سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَبِسَهُ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5305}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Khalifah said:"I heard 'Abdullah bin Az-Zubair say: 'Do not let your womenfolk wear silk, for I heard 'Umar bin Al-Khattab say: The Messenger of Allah [SAW] said: Whoever wears it in this world will not wear it in the Hereafter}}
\hadithdefcmd{nasai}{5306}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، قَالَ أَنْبَأَنَا حَرْبٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي عِمْرَانُ بْنُ حِطَّانَ، أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ عَنْ لُبْسِ الْحَرِيرِ، فَقَالَ سَلْ عَائِشَةَ ‏.‏ فَسَأَلْتُ عَائِشَةَ قَالَتْ سَلْ عَبْدَ اللَّهِ بْنَ عُمَرَ ‏.‏ فَسَأَلْتُ ابْنَ عُمَرَ فَقَالَ حَدَّثَنِي أَبُو حَفْصٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا فَلاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5306}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Imran bin Hittan narrated that :He asked 'Abdullah bin 'Abbas about wearing silk. He said: "Ask 'Aishah." "So I asked 'Aishah and she said: 'Ask 'Abdullah bin 'Umar.' So I asked Ibn 'Umar and he said: 'Abu Hafs told me, that the Messenger of Allah [SAW] said: "Whoever wears silk in this world will have no share in the Hereafter}}
\hadithdefcmd{nasai}{5307}{أَخْبَرَنَا سُلَيْمَانُ بْنُ سَلْمٍ، قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، وَبِشْرِ بْنِ الْمُحْتَفِزِ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا يَلْبَسُ الْحَرِيرَ مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏\hadithno{5307}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar, :That the Messenger of Allah [SAW] said: "Silk is only worn by one who has no share}}
\hadithdefcmd{nasai}{5308}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا أَبُو النُّعْمَانِ، سَنَةَ سَبْعٍ وَمِائَتَيْنِ قَالَ حَدَّثَنَا الصَّعْقُ بْنُ حَزْنٍ، عَنْ قَتَادَةَ، عَنْ عَلِيٍّ الْبَارِقِيِّ، قَالَ أَتَتْنِي امْرَأَةٌ تَسْتَفْتِينِي فَقُلْتُ لَهَا هَذَا ابْنُ عُمَرَ ‏.‏ فَاتَّبَعَتْهُ تَسْأَلُهُ وَاتَّبَعْتُهَا أَسْمَعُ مَا يَقُولُ ‏.‏ قَالَتْ أَفْتِنِي فِي الْحَرِيرِ ‏.‏ قَالَ نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5308}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali Al-Bariqi said:"A woman came to me to ask a question, and I said to her: 'There is Ibn 'Umar.' So she went after him to ask him, and I went after her to hear what he would say. She said: 'Tell me about silk.' He said: 'The Messenger of Allah [SAW] forbade it}}
\hadithdefcmd{nasai}{5309}{أَخْبَرَنَا سُلَيْمَانُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ وَنَهَانَا عَنْ سَبْعٍ نَهَانَا عَنْ خَوَاتِيمِ الذَّهَبِ وَعَنْ آنِيَةِ الْفِضَّةِ وَعَنِ الْمَيَاثِرِ وَالْقِسِّيَّةِ وَالإِسْتَبْرَقِ وَالدِّيبَاجِ وَالْحَرِيرِ ‏.‏\hadithno{5309}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bara' bin 'Azib said:"The Messenger of Allah [SAW] enjoined seven things upon us, and forbade seven things for us. He forbade to us gold rings, silver vessels, Al-Mayathir, Al-Qassiyah, Al-Istabraq, Ad-Dibaj, and silk}}
\hadithdefcmd{nasai}{5310}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْخَصَ لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَالزُّبَيْرِ بْنِ الْعَوَّامِ فِي قُمُصِ حَرِيرٍ مِنْ حِكَّةٍ كَانَتْ بِهِمَا ‏.‏\hadithno{5310}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that:The Messenger of Allah [SAW] granted a concession to 'Abdur-Rahman bin 'Awf and Az-Zubair bin Al-'Awwam allowing them to wear silken shirts because of scabies that they were suffering from}}
\hadithdefcmd{nasai}{5311}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لِعَبْدِ الرَّحْمَنِ وَالزُّبَيْرِ فِي قُمُصِ حَرِيرٍ كَانَتْ بِهِمَا يَعْنِي لِحِكَّةٍ ‏.‏\hadithno{5311}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that:The Prophet [SAW] granted a concession to 'Abdur-Rahman and Az-Zubair to wear silken shirts because of scabies that they were suffering from}}
\hadithdefcmd{nasai}{5312}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، قَالَ كُنَّا مَعَ عُتْبَةَ بْنِ فَرْقَدٍ فَجَاءَ كِتَابُ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَلْبَسُ الْحَرِيرَ إِلاَّ مَنْ لَيْسَ لَهُ مِنْهُ شَىْءٌ فِي الآخِرَةِ إِلاَّ هَكَذَا ‏"‏ ‏.‏ وَقَالَ أَبُو عُثْمَانَ بِأُصْبُعَيْهِ اللَّتَيْنِ تَلِيَانِ الإِبْهَامَ فَرَأَيْتُهُمَا أَزْرَارَ الطَّيَالِسَةِ حَتَّى رَأَيْتُ الطَّيَالِسَةَ ‏.‏\hadithno{5312}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jarir from Sulaiman At-Taimi, from Abu 'Uthman A-Nahdi, who said:"We were with 'Utbah bin Farqad when the letter of 'Umar came, saying that the Messenger of Allah [SAW] said: 'No one wears silk except one who has no share of it in the Hereafter, except this much.'" And Abu 'Uthman gestured with the two fingers that are next to the thumb. And I saw the two of them pointing to the borders of the Tayalisah, so that I could see the Tayalisah}}
\hadithdefcmd{nasai}{5313}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ وَبَرَةَ، عَنِ الشَّعْبِيِّ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، ح وَأَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي حَصِينٍ، عَنْ إِبْرَاهِيمَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، عَنْ عُمَرَ، أَنَّهُ لَمْ يُرَخِّصْ فِي الدِّيبَاجِ إِلاَّ مَوْضِعَ أَرْبَعِ أَصَابِعَ ‏.‏\hadithno{5313}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Umar that:He did not allow the wearing of silk except (something) the width of four fingers}}
\hadithdefcmd{nasai}{5314}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَعَلَيْهِ حُلَّةٌ حَمْرَاءُ مُتَرَجِّلاً لَمْ أَرَ قَبْلَهُ وَلاَ بَعْدَهُ أَحَدًا هُوَ أَجْمَلُ مِنْهُ ‏.‏\hadithno{5314}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bara' said:"I saw the Prophet [SAW] wearing a red Hullah, with his hair combed, and I have never seen anyone before or since, who was more handsome than he}}
\hadithdefcmd{nasai}{5315}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ أَحَبُّ الثِّيَابِ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم الْحِبَرَةَ ‏.‏\hadithno{5315}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The most beloved of garments to the Prophet of Allah [SAW] was the Hibarah}}
\hadithdefcmd{nasai}{5316}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، أَنَّ خَالِدَ بْنَ مَعْدَانَ، أَخْبَرَهُ أَنَّ جُبَيْرَ بْنَ نُفَيْرٍ أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو أَخْبَرَهُ أَنَّهُ، رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ ثَوْبَانِ مُعَصْفَرَانِ فَقَالَ ‏ "‏ هَذِهِ ثِيَابُ الْكُفَّارِ فَلاَ تَلْبَسْهَا ‏"‏ ‏.‏\hadithno{5316}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin 'Amr narrated that:The Messenger of Allah [SAW] saw him wearing two garments dyed with safflower and he said: "This is the clothing of disbelievers; do not wear it}}
\hadithdefcmd{nasai}{5317}{أَخْبَرَنِي حَاجِبُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ أَبِي رَوَّادٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم وَعَلَيْهِ ثَوْبَانِ مُعَصْفَرَانِ فَغَضِبَ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏"‏ اذْهَبْ فَاطْرَحْهُمَا عَنْكَ ‏"‏ ‏.‏ قَالَ أَيْنَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ فِي النَّارِ ‏"‏ ‏.‏\hadithno{5317}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that:He came to the Prophet [SAW] wearing two garments dyed with safflower. The Prophet [SAW] got angry and said: "Go and take them off." He said: "Where should I throw them, O Messenger of Allah?" He said: "In the fire}}
\hadithdefcmd{nasai}{5318}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ إِبْرَاهِيمَ بْنَ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، أَخْبَرَهُ أَنَّ أَبَاهُ حَدَّثَهُ أَنَّهُ، سَمِعَ عَلِيًّا، يَقُولُ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ خَاتَمِ الذَّهَبِ وَعَنْ لَبُوسِ الْقَسِّيِّ وَالْمُعَصْفَرِ وَقِرَاءَةِ الْقُرْآنِ وَأَنَا رَاكِعٌ ‏.‏\hadithno{5318}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali said:"The Messenger of Allah [SAW] forbade me from wearing gold rings, and from wearing Al-Qassiyah garments, and garments dyed with safflower, and reciting Qur'an while I am bowing}}
\hadithdefcmd{nasai}{5319}{أَخْبَرَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ، قَالَ أَنْبَأَنَا أَبُو نُوحٍ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ إِيَادِ بْنِ لَقِيطٍ، عَنْ أَبِي رِمْثَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ ثَوْبَانِ أَخْضَرَانِ ‏.‏\hadithno{5319}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Rimthah said:"The Messenger of Allah [SAW] came out to us wearing two green garments}}
\hadithdefcmd{nasai}{5320}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا قَيْسٌ، عَنْ خَبَّابِ بْنِ الأَرَتِّ، قَالَ شَكَوْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُتَوَسِّدٌ بُرْدَةً لَهُ فِي ظِلِّ الْكَعْبَةِ فَقُلْنَا أَلاَ تَسْتَنْصِرُ لَنَا أَلاَ تَدْعُو اللَّهَ لَنَا\hadithno{5320}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Khabbab bin Al-Aratt said:"We complained to the Messenger of Allah [SAW] when he was reclining on his rolled-up Burdah in the shade of the Ka'bah. We said: 'Will you not pray for victory for us, will you not pray to Allah for us?}}
\hadithdefcmd{nasai}{5321}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ أَنْبَأَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ جَاءَتِ امْرَأَةٌ بِبُرْدَةٍ - قَالَ سَهْلٌ - هَلْ تَدْرُونَ مَا الْبُرْدَةُ قَالُوا نَعَمْ هَذِهِ الشَّمْلَةُ مَنْسُوجٌ فِي حَاشِيَتِهَا ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي نَسَجْتُ هَذِهِ بِيَدِي أَكْسُوكَهَا فَأَخَذَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُحْتَاجًا إِلَيْهَا فَخَرَجَ إِلَيْنَا وَإِنَّهَا لإِزَارُهُ ‏.‏\hadithno{5321}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Sahl bin Sa'd said:"A woman brought a Burdah" - Sahl said: "Do you know what a Burdah is?" They said: "Yes, it is a cloak with two woven borders" - and she said: 'O Messenger of Allah, I wove this with my own hands for you to wear.' The Messenger of Allah [SAW] took it as he had need of it, then he came out to us and he was wearing it as his Izar (lower garment)}}
\hadithdefcmd{nasai}{5322}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ أَبِي عَرُوبَةَ، يُحَدِّثُ عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَسُوا مِنْ ثِيَابِكُمُ الْبَيَاضَ فَإِنَّهَا أَطْهَرُ وَأَطْيَبُ وَكَفِّنُوا فِيهَا مَوْتَاكُمْ ‏"‏ ‏.‏ قَالَ يَحْيَى لَمْ أَكْتُبْهُ ‏.‏ قُلْتُ لِمَ قَالَ اسْتَغْنَيْتُ بِحَدِيثِ مَيْمُونِ بْنِ أَبِي شَبِيبٍ عَنْ سَمُرَةَ ‏.‏\hadithno{5322}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah that:The Prophet [SAW] said: "Wear white garments, for they are purer and better, and shroud your dead in them}}
\hadithdefcmd{nasai}{5323}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكُمْ بِالْبَيَاضِ مِنَ الثِّيَابِ فَلْيَلْبَسْهَا أَحْيَاؤُكُمْ وَكَفِّنُوا فِيهَا مَوْتَاكُمْ فَإِنَّهَا مِنْ خَيْرِ ثِيَابِكُمْ ‏"‏ ‏.‏\hadithno{5323}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Samurah said:"The Messenger of Allah [SAW] said: 'You should wear white garments; dress your living ones in them, and shroud your dead in them, for they are among the best of your garments}}
\hadithdefcmd{nasai}{5324}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْبِيَةً وَلَمْ يُعْطِ مَخْرَمَةَ شَيْئًا فَقَالَ مَخْرَمَةُ يَا بُنَىَّ انْطَلِقْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَانْطَلَقْتُ مَعَهُ قَالَ ادْخُلْ فَادْعُهُ لِي ‏.‏ قَالَ فَدَعَوْتُهُ فَخَرَجَ إِلَيْهِ وَعَلَيْهِ قِبَاءٌ مِنْهَا فَقَالَ ‏ "‏ خَبَّأْتُ هَذَا لَكَ ‏"‏ ‏.‏ فَنَظَرَ إِلَيْهِ فَلَبِسَهُ مَخْرَمَةُ ‏.‏\hadithno{5324}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Miswar bin Makhramah said:"The Messenger of Allah [SAW] distributed some Qaba's but he did not give anything to Makhramah. Makhramah said: 'O my son, let us go to the Messenger of Allah [SAW].' So I went with him and he said: 'Go in and call him for me.' So I called him, and he came out wearing one of the Qaba's. He said: 'I kept this for you.' And he looked at him, and Makhramah put it on}}
\hadithdefcmd{nasai}{5325}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ بِعَرَفَاتٍ فَقَالَ ‏ "‏ مَنْ لَمْ يَجِدْ إِزَارًا فَلْيَلْبَسِ السَّرَاوِيلَ وَمَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ ‏"‏ ‏.‏\hadithno{5325}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:He heard the Prophet [SAW] say in 'Arafat: "Whoever cannot find an Izar (waist wrapper), let him wear trousers, and whoever cannot find sandals, let him wear Khuffs (leather socks)}}
\hadithdefcmd{nasai}{5326}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمًا، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَا رَجُلٌ يَجُرُّ إِزَارَهُ مِنَ الْخُيَلاَءِ خَسَفَ بِهِ فَهُوَ يَتَجَلْجَلُ فِي الأَرْضِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5326}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:The Messenger of Allah [SAW] said: "While a man was dragging his Izar out of pride, the earth swallowed him up, and he will continue sinking into it until the Day of Resurrection}}
\hadithdefcmd{nasai}{5327}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، ح وَأَنْبَأَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَرَّ ثَوْبَهُ - أَوْ قَالَ إِنَّ الَّذِي يَجُرُّ ثَوْبَهُ - مِنَ الْخُيَلاَءِ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5327}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] said: 'Whoever drags his garment out of pride, Allah will not look at him on the Day of Resurrection}}
\hadithdefcmd{nasai}{5328}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ جَرَّ ثَوْبَهُ مِنْ مَخِيلَةٍ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ لَمْ يَنْظُرْ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5328}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Muharib said:"I heard Ibn 'Umar narrating that the Messenger of Allah [SAW] said: 'Whoever drags his garment out of vanity, Allah, the Mighty and Sublime, will not look at him on the Day of Resurrection}}
\hadithdefcmd{nasai}{5329}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُسْلِمِ بْنِ نُذَيْرٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَوْضِعُ الإِزَارِ إِلَى أَنْصَافِ السَّاقَيْنِ وَالْعَضَلَةِ فَإِنْ أَبَيْتَ فَأَسْفَلَ فَإِنْ أَبَيْتَ فَمِنْ وَرَاءِ السَّاقِ وَلاَ حَقَّ لِلْكَعْبَيْنِ فِي الإِزَارِ ‏"‏ ‏.‏ وَاللَّفْظُ لِمُحَمَّدٍ ‏.‏\hadithno{5329}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hudhaifah said:"The Messenger of Allah [SAW] said: 'The Izar should come to the middle of the shins and the calf. If you insist, then a little lower, and if you insist, then a little further down, but the Izar has no right to (come to) the ankle." This is the wordings of Muhammad}}
\hadithdefcmd{nasai}{5330}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبُو يَعْقُوبَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَحْتَ الْكَعْبَيْنِ مِنَ الإِزَارِ فَفِي النَّارِ ‏"‏ ‏.‏\hadithno{5330}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Whatever of the Izar comes below the ankles is in the Fire}}
\hadithdefcmd{nasai}{5331}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي سَعِيدٌ الْمَقْبُرِيُّ، وَقَدْ كَانَ يُخْبِرُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَسْفَلَ مِنَ الْكَعْبَيْنِ مِنَ الإِزَارِ فَفِي النَّارِ ‏"‏ ‏.‏\hadithno{5331}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that :The Prophet [SAW] said: "Whatever of the Izar comes below the ankles is in the Fire}}
\hadithdefcmd{nasai}{5332}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عَقِيلٍ، قَالَ حَدَّثَنِي جَدِّي، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَشْعَثَ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ لاَ يَنْظُرُ إِلَى مُسْبِلِ الإِزَارِ ‏"‏ ‏.‏\hadithno{5332}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ash'ath said:"I heard Sa'eed bin Jubair narrate from Ibn 'Abbas that the Prophet [SAW] said: 'Allah will not look at the Musbil (the one who lets his Izar come below the ankles)}}
\hadithdefcmd{nasai}{5333}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ مِهْرَانَ الأَعْمَشَ، عَنْ سُلَيْمَانَ بْنِ مُسْهِرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ الْمَنَّانُ بِمَا أَعْطَى وَالْمُسْبِلُ إِزَارَهُ وَالْمُنَفِّقُ سِلْعَتَهُ بِالْحَلِفِ الْكَاذِبِ ‏"‏ ‏.‏\hadithno{5333}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah [SAW] said: 'There are three to whom Allah (the Mighty and Sublime) will not speak on the Day of Resurrection, nor will He sanctify them, and theirs will be a painful torment: The one who reminds others of what he has given them (Al-Mannan), the one who lets his Izar come below his ankles, and the one who sells his product by means of false oaths}}
\hadithdefcmd{nasai}{5334}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي رَوَّادٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الإِسْبَالُ فِي الإِزَارِ وَالْقَمِيصِ وَالْعِمَامَةِ مَنْ جَرَّ مِنْهَا شَيْئًا خُيَلاَءَ لاَ يَنْظُرُ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5334}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Al-Isbal may apply to the Izar, the Qamis and the turban. Whoever drags any one of these out of vanity, Allah will not look at him on the Day of Resurrection}}
\hadithdefcmd{nasai}{5335}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ جَرَّ ثَوْبَهُ مِنَ الْخُيَلاَءِ لاَ يَنْظُرُ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ إِنَّ أَحَدَ شِقَّىْ إِزَارِي يَسْتَرْخِي إِلاَّ أَنْ أَتَعَاهَدَ ذَلِكَ مِنْهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّكَ لَسْتَ مِمَّنْ يَصْنَعُ ذَلِكَ خُيَلاَءَ ‏"‏ ‏.‏\hadithno{5335}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Salim, from his father, that:The Messenger of Allah [SAW] said: "Whoever drags his garment out of pride, Allah will not look at him on the Day of Resurrection." Abu Bakr said: "O Messenger of Allah, one side of my Izar slips unless I pay attention to it." The Prophet [SAW]: "You are not one of those who do that out of pride}}
\hadithdefcmd{nasai}{5336}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ جَرَّ ثَوْبَهُ مِنَ الْخُيَلاَءِ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ ‏"‏ ‏.‏ قَالَتْ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ فَكَيْفَ تَصْنَعُ النِّسَاءُ بِذُيُولِهِنَّ قَالَ ‏"‏ تُرْخِينَهُ شِبْرًا ‏"‏ ‏.‏ قَالَتْ إِذًا تَنْكَشِفَ أَقْدَامُهُنَّ ‏.‏ قَالَ ‏"‏ تُرْخِينَهُ ذِرَاعًا لاَ تَزِدْنَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{5336}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Whoever drags his garment out of pride, Allah will not look at him.' Umm Salamah said: 'O Messenger of Allah, what should women do with their hems?' He said: 'Let it down a hand span.' She said: 'But then their feet will show.' He said: 'Let it down a forearm's length, but no more than that}}
\hadithdefcmd{nasai}{5337}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، قَالَ أَخْبَرَنِي أَبِي قَالَ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ نَافِعٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا ذَكَرَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ذُيُولَ النِّسَاءِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُرْخِينَ شِبْرًا ‏"‏ ‏.‏ قَالَتْ أُمُّ سَلَمَةَ إِذًا يَنْكَشِفَ عَنْهَا ‏.‏ قَالَ ‏"‏ تُرْخِي ذِرَاعًا لاَ تَزِيدُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{5337}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umm Salamah that:She mentioned women's hems to the Messenger of Allah [SAW], and the Messenger of Allah [SAW] said: "Let it down a hand span." Umm Salamah said: "But that will uncover (her feet)." He said: "Let it down a forearm's length, but no more than that}}
\hadithdefcmd{nasai}{5338}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ بْنِ عَبْدِ الْجَبَّارِ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَيُّوبُ بْنُ مُوسَى، عَنْ نَافِعٍ، عَنْ صَفِيَّةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا ذَكَرَ فِي الإِزَارِ مَا ذَكَرَ قَالَتْ أُمُّ سَلَمَةَ فَكَيْفَ بِالنِّسَاءِ قَالَ ‏"‏ يُرْخِينَ شِبْرًا ‏"‏ ‏.‏ قَالَتْ إِذًا تَبْدُوَ أَقْدَامُهُنَّ ‏.‏ قَالَ ‏"‏ فَذِرَاعًا لاَ يَزِدْنَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{5338}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Umm Salamah that:When the Prophet [SAW] said what he said about the Izar, Umm Salamah said: "What about women?" He said: "Let it down a hand span." She said: "But then their feet will show." He said: "Then (let it down) a forearm's length, but no more than that}}
\hadithdefcmd{nasai}{5339}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا النَّضْرُ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، - وَهُوَ ابْنُ سُلَيْمَانَ - قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَمْ تَجُرُّ الْمَرْأَةُ مِنْ ذَيْلِهَا قَالَ ‏"‏ شِبْرًا ‏"‏ ‏.‏ قَالَتْ إِذًا يَنْكَشِفَ عَنْهَا ‏.‏ قَالَ ‏"‏ ذِرَاعٌ لاَ تَزِيدُ عَلَيْهَا ‏"‏ ‏.‏\hadithno{5339}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:"The Messenger of Allah [SAW] was asked how much a woman should let her hem drag. He said: 'A hand span.' She said: 'But then it will uncover her (feet).' He said: 'A forearm's length, and no more than that}}
\hadithdefcmd{nasai}{5340}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ اشْتِمَالِ الصَّمَّاءِ وَأَنْ يَحْتَبِيَ فِي ثَوْبٍ وَاحِدٍ لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ ‏.‏\hadithno{5340}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah [SAW] forbade Ishtimal As-Samma' and wrapping oneself in a single garment (that did not cover the private parts)}}
\hadithdefcmd{nasai}{5341}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ اشْتِمَالِ الصَّمَّاءِ وَأَنْ يَحْتَبِيَ الرَّجُلُ فِي ثَوْبٍ وَاحِدٍ لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ ‏.‏\hadithno{5341}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah [SAW] forbade Ishtimal As-Samma' and wrapping oneself in a single garment (that did not cover the private parts)}}
\hadithdefcmd{nasai}{5342}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ اشْتِمَالِ الصَّمَّاءِ وَأَنْ يَحْتَبِيَ فِي ثَوْبٍ وَاحِدٍ ‏.‏\hadithno{5342}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:"The Messenger of Allah [SAW] forbade Ishtimal As-Samma' and wrapping oneself in a single garment (that did not cover the private parts)}}
\hadithdefcmd{nasai}{5343}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُسَاوِرٍ الْوَرَّاقِ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم عِمَامَةً حَرْقَانِيَّةً ‏.‏\hadithno{5343}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ja'far bin 'Amr bin Huraith that his father said:"I saw the Prophet [SAW] wearing a black turban}}
\hadithdefcmd{nasai}{5344}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ يَوْمَ فَتْحِ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ بِغَيْرِ إِحْرَامٍ ‏.‏\hadithno{5344}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:On the Day of the Conquest of Makkah, the Messenger of Allah [SAW] entered (the city) wearing a black turban, and he was not in Ihram}}
\hadithdefcmd{nasai}{5345}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ شَرِيكٍ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ الْفَتْحِ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{5345}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Prophet [SAW] entered (Makkah) on the Day of the Conquest wearing a black turban}}
\hadithdefcmd{nasai}{5346}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَبَانَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُسَاوِرٍ الْوَرَّاقِ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، قَالَ كَأَنِّي أَنْظُرُ السَّاعَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ قَدْ أَرْخَى طَرَفَهَا بَيْنَ كَتِفَيْهِ ‏.‏\hadithno{5346}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ja'far bin 'Amr bin Umayyah that his father said:"It is as if I am looking now at the Messenger of Allah [SAW] on the Minbar, wearing a black turban, the end of which he has let hang down between his shoulders}}
\hadithdefcmd{nasai}{5347}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي طَلْحَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏"‏ ‏.‏\hadithno{5347}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Talhah that:The Prophet [SAW] said: "The angels do not enter a house in which there is a dog or an image}}
\hadithdefcmd{nasai}{5348}{أَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي طَلْحَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةُ تَمَاثِيلَ ‏"‏ ‏.‏\hadithno{5348}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Talhah said:"I heard the Messenger of Allah [SAW] say: 'The angels do not enter a house in which there is a dog or an image of an animate being}}
\hadithdefcmd{nasai}{5349}{أَخْبَرَنَا عَلِيُّ بْنُ شُعَيْبٍ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ دَخَلَ عَلَى أَبِي طَلْحَةَ الأَنْصَارِيِّ يَعُودُهُ فَوَجَدَ عِنْدَهُ سَهْلَ بْنَ حُنَيْفٍ فَأَمَرَ أَبُو طَلْحَةَ إِنْسَانًا يَنْزِعُ نَمَطًا تَحْتَهُ فَقَالَ لَهُ سَهْلٌ لِمَ تَنْزِعُ قَالَ لأَنَّ فِيهِ تَصَاوِيرُ وَقَدْ قَالَ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَا قَدْ عَلِمْتَ ‏.‏ قَالَ أَلَمْ يَقُلْ ‏ "‏ إِلاَّ مَا كَانَ رَقْمًا فِي ثَوْبٍ ‏"‏ ‏.‏ قَالَ بَلَى وَلَكِنَّهُ أَطْيَبُ لِنَفْسِي ‏.‏\hadithno{5349}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah that:He entered upon Abu Talhah Al-Ansari to visit him (when he was sick), and he found Sahl bin Hunaif there. Abu Talhah told someone to remove a blanket from beneath him, and Sahl said to him: "Why do you want to remove it?" He said: "Because there are images on it, and the Messenger of Allah [SAW] said what you know concerning them." He said: "Did he not say: Except for patterns on fabrics?" He said: "Yes, but this makes me feel more comfortable}}
\hadithdefcmd{nasai}{5350}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي بُكَيْرٌ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ، عَنْ أَبِي طَلْحَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ صُورَةٌ ‏"‏ ‏.‏ قَالَ بُسْرٌ ثُمَّ اشْتَكَى زَيْدٌ فَعُدْنَاهُ فَإِذَا عَلَى بَابِهِ سِتْرٌ فِيهِ صُورَةٌ قُلْتُ لِعُبَيْدِ اللَّهِ الْخَوْلاَنِيِّ أَلَمْ يُخْبِرْنَا زَيْدٌ عَنِ الصُّورَةِ يَوْمَ الأَوَّلِ قَالَ قَالَ عُبَيْدُ اللَّهِ أَلَمْ تَسْمَعْهُ يَقُولُ ‏"‏ إِلاَّ رَقْمًا فِي ثَوْبٍ ‏"‏ ‏.‏\hadithno{5350}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Talhah that:The Messenger of Allah [SAW] said: "The angels do not enter any house in which there is an image." Busr said: "Then Zaid fell sick and we went to visit him, and on his door there was a curtain on which there was an image. I said to 'Ubaidullah Al-Khawlani: 'Didn't Zaid tell us about images yesterday?' 'Ubaidullah said: 'Didn't you hear him say: Except for patterns on fabrics?}}
\hadithdefcmd{nasai}{5351}{حَدَّثَنَا مَسْعُودُ بْنُ جُوَيْرِيَةَ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَلِيٍّ، قَالَ صَنَعْتُ طَعَامًا فَدَعَوْتُ النَّبِيَّ صلى الله عليه وسلم فَجَاءَ فَدَخَلَ فَرَأَى سِتْرًا فِيهِ تَصَاوِيرُ فَخَرَجَ وَقَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ تَصَاوِيرُ ‏"‏ ‏.‏\hadithno{5351}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali said:"I made some food and invited the Prophet [SAW] (to come and eat). He came and entered, then he saw a curtain on which there were images, so he went out and said: 'The Angels do not enter a house in which there are images}}
\hadithdefcmd{nasai}{5352}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَرْجَةً ثُمَّ دَخَلَ وَقَدْ عَلَّقْتُ قِرَامًا فِيهِ الْخَيْلُ أُولاَتُ الأَجْنِحَةِ - قَالَتْ - فَلَمَّا رَآهُ قَالَ ‏ "‏ انْزِعِيهِ ‏"‏ ‏.‏\hadithno{5352}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] went out, then he came in, and I had hung up a curtain on which there were (images of) horses with wings. When he saw it, he said: 'Get rid of it}}
\hadithdefcmd{nasai}{5353}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، قَالَ حَدَّثَنَا عَزْرَةُ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ لَنَا سِتْرٌ فِيهِ تِمْثَالُ طَيْرٍ مُسْتَقْبِلَ الْبَيْتِ إِذَا دَخَلَ الدَّاخِلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ حَوِّلِيهِ فَإِنِّي كُلَّمَا دَخَلْتُ فَرَأَيْتُهُ ذَكَرْتُ الدُّنْيَا ‏"‏ ‏.‏ قَالَتْ وَكَانَ لَنَا قَطِيفَةٌ لَهَا عَلَمٌ فَكُنَّا نَلْبَسُهَا فَلَمْ نَقْطَعْهُ ‏.‏\hadithno{5353}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah, the wife of the Prophet [SAW], said:"We had a curtain on which there were images of birds, at the entrance to the house. The Messenger of Allah [SAW] said: 'O 'Aishah, remove it, for ever time I come in and see it, I remember this world.'" She said: "We had a plush wrap, with a border on it, that we would wear, and it was not cut off}}
\hadithdefcmd{nasai}{5354}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ كَانَ فِي بَيْتِي ثَوْبٌ فِيهِ تَصَاوِيرُ فَجَعَلْتُهُ إِلَى سَهْوَةٍ فِي الْبَيْتِ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي إِلَيْهِ ثُمَّ قَالَ ‏ "‏ يَا عَائِشَةُ أَخِّرِيهِ عَنِّي ‏"‏ ‏.‏ فَنَزَعْتُهُ فَجَعَلْتُهُ وَسَائِدَ ‏.‏\hadithno{5354}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"In my house there was a cloth on which were images, which I put in a niche of the house, and the Messenger of Allah [SAW] used to pray facing it. Then he said: 'O 'Aishah, take it away from me.' So I took it down and made it into pillows}}
\hadithdefcmd{nasai}{5355}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنَا عَمْرٌو، قَالَ حَدَّثَنَا بُكَيْرٌ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، أَنَّ أَبَاهُ، حَدَّثَهُ عَنْ عَائِشَةَ، أَنَّهَا نَصَبَتْ سِتْرًا فِيهِ تَصَاوِيرُ فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَزَعَهُ فَقَطَعَتْهُ وِسَادَتَيْنِ ‏.‏ قَالَ رَجُلٌ فِي الْمَجْلِسِ حِينَئِذٍ يُقَالُ لَهُ رَبِيعَةُ بْنُ عَطَاءٍ أَنَا سَمِعْتُ أَبَا مُحَمَّدٍ - يَعْنِي الْقَاسِمَ - عَنْ عَائِشَةَ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْتَفِقُ عَلَيْهِمَا ‏.‏\hadithno{5355}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:She put up a curtain on which there were images, then the Messenger of Allah [SAW] came in and took it down, so she cut it up (and made) two pillows. A man in the gathering there whose name was Rabi'ah bin 'Ata' said: "I heard Abu Muhammad - meaning Al-Qasim - narrate that 'Aishah said: 'The Messenger of Allah [SAW] used to recline on them}}
\hadithdefcmd{nasai}{5356}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ سَفَرٍ وَقَدْ سَتَّرْتُ بِقِرَامٍ عَلَى سَهْوَةٍ لِي فِيهِ تَصَاوِيرُ فَنَزَعَهُ وَقَالَ ‏ "‏ أَشَدُّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الَّذِينَ يُضَاهُونَ بِخَلْقِ اللَّهِ ‏"‏ ‏.‏\hadithno{5356}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] came from a journey, and I had hung a curtain on which there were images over a niche. He took it down and said: 'The people who will be most severely punished on the Day of Resurrection will be those who try to match the creation of Allah}}
\hadithdefcmd{nasai}{5357}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، أَنَّهُ سَمِعَ الْقَاسِمَ بْنَ مُحَمَّدٍ، يُخْبِرُ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ سَتَّرْتُ بِقِرَامٍ فِيهِ تَمَاثِيلُ فَلَمَّا رَآهُ تَلَوَّنَ وَجْهُهُ ثُمَّ هَتَكَهُ بِيَدِهِ وَقَالَ ‏ "‏ إِنَّ أَشَدَّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الَّذِينَ يُشَبِّهُونَ بِخَلْقِ اللَّهِ ‏"‏ ‏.‏\hadithno{5357}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah, the wife of the Prophet [SAW], said:"The Messenger of Allah [SAW] entered upon me, and I had put up a curtain on which there were images. When he saw it, his face changed color, then he tore it down with his hand and said: 'The people who will be most severely punished on the Day of Resurrection will be those who try to imitate the creation of Allah}}
\hadithdefcmd{nasai}{5358}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، قَالَ كُنْتُ جَالِسًا عِنْدَ ابْنِ عَبَّاسٍ أَتَاهُ رَجُلٌ مِنْ أَهْلِ الْعِرَاقِ فَقَالَ إِنِّي أُصَوِّرُ هَذِهِ التَّصَاوِيرَ فَمَا تَقُولُ فِيهَا فَقَالَ ادْنُهْ ادْنُهْ سَمِعْتُ مُحَمَّدًا صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَوَّرَ صُورَةً فِي الدُّنْيَا كُلِّفَ يَوْمَ الْقِيَامَةِ أَنْ يَنْفُخَ فِيهَا الرُّوحَ وَلَيْسَ بِنَافِخِهِ ‏"‏ ‏.‏\hadithno{5358}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that An-Nadr bin Anas said:"I was sitting with Ibn 'Abbas when a man from among the people of Al-'Iraq came to him and said: 'I make these images; what do you say concerning them?' He said: 'Come closer, come closer. I heard Muhammad [SAW] say: Whoever makes an image in this world will be commanded on the Day of Resurrection to breathe a soul into it, and he will not be able to do so}}
\hadithdefcmd{nasai}{5359}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَوَّرَ صُورَةً عُذِّبَ حَتَّى يَنْفُخَ فِيهَا الرُّوحَ وَلَيْسَ بِنَافِخٍ فِيهَا ‏"‏ ‏.‏\hadithno{5359}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah [SAW] said: 'Whoever makes an image will be punished until (he is commanded) to breathe a soul into it, and he will not be able to do so}}
\hadithdefcmd{nasai}{5360}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَوَّرَ صُورَةً كُلِّفَ يَوْمَ الْقِيَامَةِ أَنْ يَنْفُخَ فِيهَا الرُّوحَ وَلَيْسَ بِنَافِخٍ ‏"‏ ‏.‏\hadithno{5360}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Whoever makes an image will be commanded on the Day of Resurrection to breathe the soul into it but he will not be able to do so}}
\hadithdefcmd{nasai}{5361}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ الَّذِينَ يَصْنَعُونَهَا يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ يُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏ ‏.‏\hadithno{5361}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:The Prophet [SAW] said: "The makers of these images will be punished on the Day of Resurrection, and it will be said to them: 'Breathe life into that which you have created}}
\hadithdefcmd{nasai}{5362}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ وَيُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏ ‏.‏\hadithno{5362}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah, the wife of the Prophet [SAW], that:The Messenger of Allah [SAW] said: "The makers of these images will be punished on the Day of Resurrection, and it will be said to them: 'Bring to life that which you have created}}
\hadithdefcmd{nasai}{5363}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ إِنَّ أَشَدَّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الَّذِينَ يُضَاهُونَ اللَّهَ فِي خَلْقِهِ ‏.‏\hadithno{5363}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah, the wife of the Prophet [SAW], said:"The people who will be most severely punished on the Day of Resurrection will be those who try to match the creation of Allah}}
\hadithdefcmd{nasai}{5364}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، قَالَ حَدَّثَنَا حُصَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ أَشَدِّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الْمُصَوِّرُونَ ‏"‏ ‏.‏ وَقَالَ أَحْمَدُ ‏"‏ الْمُصَوِّرِينَ ‏"‏ ‏.‏\hadithno{5364}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] said: 'Among the people who will be most severely punished on the Day of Resurrection will be the image-makers}}
\hadithdefcmd{nasai}{5365}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي بَكْرٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ اسْتَأْذَنَ جِبْرِيلُ عَلَيْهِ السَّلاَمُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ ادْخُلْ ‏"‏ ‏.‏ فَقَالَ كَيْفَ أَدْخُلُ وَفِي بَيْتِكَ سِتْرٌ فِيهِ تَصَاوِيرُ فَإِمَّا أَنْ تُقْطَعَ رُءُوسُهَا أَوْ تُجْعَلَ بِسَاطًا يُوطَأُ فَإِنَّا مَعْشَرَ الْمَلاَئِكَةِ لاَ نَدْخُلُ بَيْتًا فِيهِ تَصَاوِيرُ ‏.‏\hadithno{5365}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"Jibril, peace be upon him, asked permission to enter upon the Prophet [SAW] and he said: 'Come in.' He said: 'How can I come in when there is a curtain in your house on which there are images? You should either cut off their heads or make it into a rug to be stepped on, for we Angels do not enter a house in which there are images}}
\hadithdefcmd{nasai}{5366}{أَخْبَرَنَا الْحَسَنُ بْنُ قَزَعَةَ، عَنْ سُفْيَانَ بْنِ حَبِيبٍ، وَمُعْتَمِرِ بْنِ سُلَيْمَانَ، عَنْ أَشْعَثَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُصَلِّي فِي لُحُفِنَا ‏.‏ قَالَ سُفْيَانُ مَلاَحِفِنَا ‏.‏\hadithno{5366}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] would not pray in our blankets}}
\hadithdefcmd{nasai}{5367}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، قَالَ حَدَّثَنَا أَنَسٌ، أَنَّ نَعْلَ، رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ لَهَا قِبَالاَنِ ‏.‏\hadithno{5367}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas narrated that :The sandals of the Messenger of Allah [SAW] had two straps}}
\hadithdefcmd{nasai}{5368}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، قَالَ كَانَ لِنَعْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم قِبَالاَنِ ‏.‏\hadithno{5368}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Amr bin Aws said:"The sandals of the Messenger of Allah [SAW] had two straps}}
\hadithdefcmd{nasai}{5369}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْقَطَعَ شِسْعُ نَعْلِ أَحَدِكُمْ فَلاَ يَمْشِ فِي نَعْلٍ وَاحِدَةٍ حَتَّى يُصْلِحَهَا ‏"‏ ‏.‏\hadithno{5369}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet [SAW] said: "If the strap of the sandal of one of you breaks, let him not walk in one sandal until he fixes it}}
\hadithdefcmd{nasai}{5370}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي رَزِينٍ، قَالَ رَأَيْتُ أَبَا هُرَيْرَةَ يَضْرِبُ بِيَدِهِ عَلَى جَبْهَتِهِ يَقُولُ يَا أَهْلَ الْعِرَاقِ تَزْعُمُونَ أَنِّي أَكْذِبُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَشْهَدُ لَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا انْقَطَعَ شِسْعُ نَعْلِ أَحَدِكُمْ فَلاَ يَمْشِ فِي الأُخْرَى حَتَّى يُصْلِحَهَا ‏"‏ ‏.‏\hadithno{5370}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Razin said:"I saw Abu Hurairah clap his hand to his forehead and say: 'O people of Al-'Iraq, you claim that I tell lies about the Messenger of Allah [SAW]. I bear witness that I heard the Messenger of Allah [SAW] say: If the strap of the sandal of one of you breaks, let him not walk in the other until he fixes it}}
\hadithdefcmd{nasai}{5371}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ أَبِي الْوَزِيرِ أَبُو مُطَرِّفٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اضْطَجَعَ عَلَى نِطْعٍ فَعَرِقَ فَقَامَتْ أُمُّ سُلَيْمٍ إِلَى عَرَقِهِ فَنَشَّفَتْهُ فَجَعَلَتْهُ فِي قَارُورَةٍ فَرَآهَا النَّبِيُّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا هَذَا الَّذِي تَصْنَعِينَ يَا أُمَّ سُلَيْمٍ ‏"‏ ‏.‏ قَالَتْ أَجْعَلُ عَرَقَكَ فِي طِيبِي فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{5371}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that:The Prophet [SAW] lay down on a leather mat and sweated. Umm Sulaim got up and collected his sweat and put it in a bottle. The Prophet [SAW] saw her and said: "What are you doing O Umm Sulaim?" She said: "I am putting your sweat in my perfume." And the Prophet [SAW] smiled}}
\hadithdefcmd{nasai}{5372}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ سَمُرَةَ بْنِ سَهْمٍ، - رَجُلٌ مِنْ قَوْمِهِ - قَالَ نَزَلْتُ عَلَى أَبِي هَاشِمِ بْنِ عُتْبَةَ وَهُوَ طَعِينٌ فَأَتَاهُ مُعَاوِيَةُ يَعُودُهُ فَبَكَى أَبُو هَاشِمٍ فَقَالَ مُعَاوِيَةُ مَا يُبْكِيكَ أَوَجَعٌ يُشْئِزُكَ أَمْ عَلَى الدُّنْيَا فَقَدْ ذَهَبَ صَفْوُهَا قَالَ كُلٌّ لاَ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَهِدَ إِلَىَّ عَهْدًا وَدِدْتُ أَنِّي كُنْتُ تَبِعْتُهُ قَالَ ‏ "‏ إِنَّهُ لَعَلَّكَ تُدْرِكُ أَمْوَالاً تُقْسَمُ بَيْنَ أَقْوَامٍ وَإِنَّمَا يَكْفِيكَ مِنْ ذَلِكَ خَادِمٌ وَمَرْكَبٌ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ فَأَدْرَكْتُ فَجَمَعْتُ ‏.‏\hadithno{5372}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Samurah bin Sahm said:"I came to Abu Hashim bin 'Utbah when he was suffering the plague, and Mu'awiyah came to visit him. Abu Hashim wept. Mu'awiyah said to him: 'Why are you weeping? Is it because of some pain that is hurting you, or is it for this world, the best of which has gone?' He said: 'Neither, but the Messenger of Allah [SAW] gave me some advice, which I wish that I had followed. He said: "Perhaps you will live to see wealth that will be distributed among the people when all that would suffice you of that would be a servant and a mount to ride in the cause of Allah." I lived to see that, and I accumulated (wealth)}}
\hadithdefcmd{nasai}{5373}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، قَالَ كَانَتْ قَبِيعَةُ سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فِضَّةٍ ‏.‏\hadithno{5373}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Umamah bin Sahl said:"The pommel of the sword of the Messenger of Allah [SAW] was of silver}}
\hadithdefcmd{nasai}{5374}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا هَمَّامٌ، وَجَرِيرٌ، قَالاَ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ كَانَ نَعْلُ سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فِضَّةٍ وَقَبِيعَةُ سَيْفِهِ فِضَّةٌ وَمَا بَيْنَ ذَلِكَ حِلَقُ فِضَّةٍ ‏.‏\hadithno{5374}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The metallic end of the scabbard of the Messenger of Allah [SAW] was of silver, the pommel of his sword was silver, and in between were rings of silver}}
\hadithdefcmd{nasai}{5375}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، قَالَ كَانَتْ قَبِيعَةُ سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فِضَّةٍ ‏.‏\hadithno{5375}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Sa'eed bin Abi Al-Hasan said:"The pommel of the sword of the Messenger of Allah [SAW] was of silver}}
\hadithdefcmd{nasai}{5376}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ عَاصِمَ بْنَ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُلِ اللَّهُمَّ سَدِّدْنِي وَاهْدِنِي ‏"‏ ‏.‏ وَنَهَانِي عَنِ الْجُلُوسِ عَلَى الْمَيَاثِرِ وَالْمَيَاثِرُ قَسِّيٌّ كَانَتْ تَصْنَعُهُ النِّسَاءُ لِبُعُولَتِهِنَّ عَلَى الرَّحْلِ كَالْقَطَائِفِ مِنَ الأُرْجُوَانِ ‏.‏\hadithno{5376}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ali said:The Messenger of Allah [SAW] said to me: "Say: O Allah, make me steadfast and guide me." And he forbade me to sit on Al-Mayathir." Al-Mayathir: Qassi which the women used to put on the saddles for their husbands, such as red cushions}}
\hadithdefcmd{nasai}{5377}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، قَالَ قَالَ أَبُو رِفَاعَةَ انْتَهَيْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَخْطُبُ فَقُلْتُ يَا رَسُولَ اللَّهِ رَجُلٌ غَرِيبٌ جَاءَ يَسْأَلُ عَنْ دِينِهِ لاَ يَدْرِي مَا دِينُهُ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَرَكَ خُطْبَتَهُ حَتَّى انْتَهَى إِلَىَّ فَأُتِيَ بِكُرْسِيٍّ خِلْتُ قَوَائِمَهُ حَدِيدًا فَقَعَدَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يُعَلِّمُنِي مِمَّا عَلَّمَهُ اللَّهُ ثُمَّ أَتَى خُطْبَتَهُ فَأَتَمَّهَا ‏.‏\hadithno{5377}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Humaid bin Hilal said:"Abu Rifa'ah said: 'I came to the Messenger of Allah [SAW] while he was delivering a Khutbah, and said: "O Messenger of Allah, a stranger has come to ask about his religion, for he does not know what his religion is." The Messenger of Allah [SAW] stopped delivering his Khutbah and turned to me. A chair was brought, and I think its legs were of iron. The Messenger of Allah [SAW] sat down on it and started to teach me what Allah has taught him, then he went and completed his Khutbah}}
\hadithdefcmd{nasai}{5378}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِي جُحَيْفَةَ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم بِالْبَطْحَاءِ وَهُوَ فِي قُبَّةٍ حَمْرَاءَ وَعِنْدَهُ أُنَاسٌ يَسِيرُ فَجَاءَهُ بِلاَلٌ فَأَذَّنَ فَجَعَلَ يُتْبِعُ فَاهُ هَا هُنَا وَهَا هُنَا ‏.‏\hadithno{5378}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Juhaifah said:"We were with the Prophet (ﷺ) in Al-Batha' and he was in a red tent, and some people were with him, and he was about to set out. Bilal came and called the Adhan, turning this way and that}}
