% Auto-generated chapter 2 for tirmidhi
% Hadiths in this chapter: 304

\hadithdefcmd{tirmidhi}{149}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ، عَنْ حَكِيمِ بْنِ حَكِيمٍ، وَهُوَ ابْنُ عَبَّادِ بْنِ حُنَيْفٍ أَخْبَرَنِي نَافِعُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ أَخْبَرَنِي ابْنُ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَمَّنِي جِبْرِيلُ عَلَيْهِ السَّلاَمُ عِنْدَ الْبَيْتِ مَرَّتَيْنِ فَصَلَّى الظُّهْرَ فِي الأُولَى مِنْهُمَا حِينَ كَانَ الْفَىْءُ مِثْلَ الشِّرَاكِ ثُمَّ صَلَّى الْعَصْرَ حِينَ كَانَ كُلُّ شَيْءٍ مِثْلَ ظِلِّهِ ثُمَّ صَلَّى الْمَغْرِبَ حِينَ وَجَبَتِ الشَّمْسُ وَأَفْطَرَ الصَّائِمُ ثُمَّ صَلَّى الْعِشَاءَ حِينَ غَابَ الشَّفَقُ ثُمَّ صَلَّى الْفَجْرَ حِينَ بَرَقَ الْفَجْرُ وَحَرُمَ الطَّعَامُ عَلَى الصَّائِمِ ‏.‏ وَصَلَّى الْمَرَّةَ الثَّانِيَةَ الظُّهْرَ حِينَ كَانَ ظِلُّ كُلِّ شَيْءٍ مِثْلَهُ لِوَقْتِ الْعَصْرِ بِالأَمْسِ ثُمَّ صَلَّى الْعَصْرَ حِينَ كَانَ ظِلُّ كُلِّ شَيْءٍ مِثْلَيْهِ ثُمَّ صَلَّى الْمَغْرِبَ لِوَقْتِهِ الأَوَّلِ ثُمَّ صَلَّى الْعِشَاءَ الآخِرَةَ حِينَ ذَهَبَ ثُلُثُ اللَّيْلِ ثُمَّ صَلَّى الصُّبْحَ حِينَ أَسْفَرَتِ الأَرْضُ ثُمَّ الْتَفَتَ إِلَىَّ جِبْرِيلُ فَقَالَ يَا مُحَمَّدُ هَذَا وَقْتُ الأَنْبِيَاءِ مِنْ قَبْلِكَ ‏.‏ وَالْوَقْتُ فِيمَا بَيْنَ هَذَيْنِ الْوَقْتَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَبُرَيْدَةَ وَأَبِي مُوسَى وَأَبِي مَسْعُودٍ الأَنْصَارِيِّ وَأَبِي سَعِيدٍ وَجَابِرٍ وَعَمْرِو بْنِ حَزْمٍ وَالْبَرَاءِ وَأَنَسٍ ‏.‏\hadithno{149}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated that :the Prophet said: "Jibril (peace be upon him) led me (in Salat) twice at the House. So he prayed Zuhr the first time when the shadow was similar to (the length of) the strap a sandal. Then he prayed Asr when everything was similar (to the length of) its shadow. Then he prayed Maghrib when the sun had set and the fasting person breaks fast. Then he prayed Isha when the twilight had vanished. Then he prayed Fajr when Fajr (dawn) began, and when eating is prohibited for the fasting person. The second time he prayed Zuhr when the shadow of everything was similar to (the length of) it, at the time of Asr the day before. Then he prayed Asr when the shadow of everything was about twice as long as it. Then he prayed Maghrib at the same time as he did the first time. Then he prayed Isha, the later one, when a third of the night had gone. Then he prayed Subh when the land glowed. Then Jibril turned towards me and said: "O Muhammad! These are the times of the Prophets before you, and the (best) time is what is between these two times}}
\hadithdefcmd{tirmidhi}{150}{أَخْبَرَنِي أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا حُسَيْنُ بْنُ عَلِيِّ بْنِ حُسَيْنٍ، أَخْبَرَنِي وَهْبُ بْنُ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَمَّنِي جِبْرِيلُ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ ابْنِ عَبَّاسٍ بِمَعْنَاهُ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ ‏"‏ لِوَقْتِ الْعَصْرِ بِالأَمْسِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَالَ مُحَمَّدٌ أَصَحُّ شَيْءٍ فِي الْمَوَاقِيتِ حَدِيثُ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ وَحَدِيثُ جَابِرٍ فِي الْمَوَاقِيتِ قَدْ رَوَاهُ عَطَاءُ بْنُ أَبِي رَبَاحٍ وَعَمْرُو بْنُ دِينَارٍ وَأَبُو الزُّبَيْرِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ وَهْبِ بْنِ كَيْسَانَ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{150}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Jabir bin Abdullah narrated that :Allah's Messenger said: "Jibril led me (in Salat)". He mentioned something similar to the Hadith of Ibn Abbas (no. 149) in meaning, but he did not mention: "At the time of Asr the day before}}
\hadithdefcmd{tirmidhi}{151}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِلصَّلاَةِ أَوَّلاً وَآخِرًا وَإِنَّ أَوَّلَ وَقْتِ صَلاَةِ الظُّهْرِ حِينَ تَزُولُ الشَّمْسُ وَآخِرَ وَقْتِهَا حِينَ يَدْخُلُ وَقْتُ الْعَصْرِ وَإِنَّ أَوَّلَ وَقْتِ صَلاَةِ الْعَصْرِ حِينَ يَدْخُلُ وَقْتُهَا وَإِنَّ آخِرَ وَقْتِهَا حِينَ تَصْفَرُّ الشَّمْسُ وَإِنَّ أَوَّلَ وَقْتِ الْمَغْرِبِ حِينَ تَغْرُبُ الشَّمْسُ وَإِنَّ آخِرَ وَقْتِهَا حِينَ يَغِيبُ الأُفُقُ وَإِنَّ أَوَّلَ وَقْتِ الْعِشَاءِ الآخِرَةِ حِينَ يَغِيبُ الأُفُقُ وَإِنَّ آخِرَ وَقْتِهَا حِينَ يَنْتَصِفُ اللَّيْلُ وَإِنَّ أَوَّلَ وَقْتِ الْفَجْرِ حِينَ يَطْلُعُ الْفَجْرُ وَإِنَّ آخِرَ وَقْتِهَا حِينَ تَطْلُعُ الشَّمْسُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ مُحَمَّدًا يَقُولُ حَدِيثُ الأَعْمَشِ عَنْ مُجَاهِدٍ فِي الْمَوَاقِيتِ أَصَحُّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ فُضَيْلٍ عَنِ الأَعْمَشِ وَحَدِيثُ مُحَمَّدِ بْنِ فُضَيْلٍ خَطَأٌ أَخْطَأَ فِيهِ مُحَمَّدُ بْنُ فُضَيْلٍ ‏.‏ حَدَّثَنَا هَنَّادٌ حَدَّثَنَا أَبُو أُسَامَةَ عَنْ أَبِي إِسْحَاقَ الْفَزَارِيِّ عَنِ الأَعْمَشِ عَنْ مُجَاهِدٍ قَالَ كَانَ يُقَالُ إِنَّ لِلصَّلاَةِ أَوَّلاً وَآخِرًا فَذَكَرَ نَحْوَ حَدِيثِ مُحَمَّدِ بْنِ فُضَيْلٍ عَنِ الأَعْمَشِ نَحْوَهُ بِمَعْنَاهُ ‏.‏\hadithno{151}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Indeed for (the time of) Salat (there is a) beginning and an end. The beginning of the time for the Zuhr prayer is when the sun passes the zenith, and the end of its time is when the time for Asr enters. The beginning of the time for the Asr [prayer] is when its time enters, and the end of its time is when the sun yellows (turns pale). The beginning of the time of Maghrib is when the sun as set, and the end of its time is when the twilight has vanished (i.e., the horizon is invisible because of darkness). The beginning of the time for Isha, the later one, is when the horizon has vanished, and the end of its time is when the night is at its half. The beginning of the time for Fajr is when Fajr begins, and its end is when the sun rises}}
\hadithdefcmd{tirmidhi}{152}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَالْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، وَأَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى الْمَعْنَى، وَاحِدٌ، قَالُوا حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَسَأَلَهُ عَنْ مَوَاقِيتِ الصَّلاَةِ فَقَالَ ‏"‏ أَقِمْ مَعَنَا إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ فَأَمَرَ بِلاَلاً فَأَقَامَ حِينَ طَلَعَ الْفَجْرُ ثُمَّ أَمَرَهُ فَأَقَامَ حِينَ زَالَتِ الشَّمْسُ فَصَلَّى الظُّهْرَ ثُمَّ أَمَرَهُ فَأَقَامَ فَصَلَّى الْعَصْرَ وَالشَّمْسُ بَيْضَاءُ مُرْتَفِعَةٌ ثُمَّ أَمَرَهُ بِالْمَغْرِبِ حِينَ وَقَعَ حَاجِبُ الشَّمْسِ ثُمَّ أَمَرَهُ بِالْعِشَاءِ فَأَقَامَ حِينَ غَابَ الشَّفَقُ ثُمَّ أَمَرَهُ مِنَ الْغَدِ فَنَوَّرَ بِالْفَجْرِ ثُمَّ أَمَرَهُ بِالظُّهْرِ فَأَبْرَدَ وَأَنْعَمَ أَنْ يُبْرِدَ ثُمَّ أَمَرَهُ بِالْعَصْرِ فَأَقَامَ وَالشَّمْسُ آخِرَ وَقْتِهَا فَوْقَ مَا كَانَتْ ثُمَّ أَمَرَهُ فَأَخَّرَ الْمَغْرِبَ إِلَى قُبَيْلِ أَنْ يَغِيبَ الشَّفَقُ ثُمَّ أَمَرَهُ بِالْعِشَاءِ فَأَقَامَ حِينَ ذَهَبَ ثُلُثُ اللَّيْلِ ثُمَّ قَالَ ‏"‏ أَيْنَ السَّائِلُ عَنْ مَوَاقِيتِ الصَّلاَةِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَنَا ‏.‏ فَقَالَ ‏"‏ مَوَاقِيتُ الصَّلاَةِ كَمَا بَيْنَ هَذَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ قَالَ وَقَدْ رَوَاهُ شُعْبَةُ عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ أَيْضًا ‏.‏\hadithno{152}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sulaiman bin Buraidah narrated that his father said:"A man came to the Prophet to ask him about the times for Salat. So he said: 'Stay with us, In sha Allah.' So he ordered Bilal to call the Iqamah when Fajr began, then he ordered him to call the Iqamah when the Sun passed the zenith, then he prayed Zuhr. Then he ordered him to call the Iqamah to pray Asr while the sun was elevated and white. Then he ordered him (to call the Iqamah for) Maghrib when the (top) edge of the sun had set. Then he ordered him to call the Iqamah for Isha when the horizon (twilight) had vanished. Then he ordered him in the morning (to give the call for Fajr prayer), when the light of Fajr glowed. Then he ordered (him to call the Iqamah for) Zuhr, so he waited well until it had cooled. Then he ordered (him to call the Iqamah for) Asr, so he calIed the Iqamah while the sun was later in its position than what it was (the day before). Then he ordered him to delay Maghrib until right before the twilight had disappeared. Then he ordered (him to call the Iqamah for) Isha, so he called the Iqamah when a third of the night had passed. Then he said: 'Where is the one who asked about he times for the Salat?' So the man said, 'It is I.' So he said: 'The times [or the Salat are what are between these two]}}
\hadithdefcmd{tirmidhi}{153}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، قَالَ وَحَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصَلِّي الصُّبْحَ فَيَنْصَرِفُ النِّسَاءُ قَالَ الأَنْصَارِيُّ فَيَمُرُّ النِّسَاءُ مُتَلَفِّفَاتٍ بِمُرُوطِهِنَّ مَا يُعْرَفْنَ مِنَ الْغَلَسِ ‏.‏ وَقَالَ قُتَيْبَةُ مُتَلَفِّعَاتٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَنَسٍ وَقَيْلَةَ بِنْتِ مَخْرَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ الزُّهْرِيُّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ نَحْوَهُ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ يَسْتَحِبُّونَ التَّغْلِيسَ بِصَلاَةِ الْفَجْرِ ‏.‏\hadithno{153}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"Allah's Messenger would pray Subh (at such time that) the women would leave (after the prayer)" - AI-AnsarI (one of the narrators) said - the women would pass by wrapped in their Mirts and they would not be recognizable due to the darkness." And Qutaibah said: "covered." (instead of "wrapped)}}
\hadithdefcmd{tirmidhi}{154}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، - هُوَ ابْنُ سُلَيْمَانَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَسْفِرُوا بِالْفَجْرِ فَإِنَّهُ أَعْظَمُ لِلأَجْرِ ‏"‏ ‏.‏ قَالَ وَقَدْ رَوَى شُعْبَةُ وَالثَّوْرِيُّ هَذَا الْحَدِيثَ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ ‏.‏ قَالَ وَرَوَاهُ مُحَمَّدُ بْنُ عَجْلاَنَ أَيْضًا عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ وَجَابِرٍ وَبِلاَلٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ رَافِعِ بْنِ خَدِيجٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَأَى غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ الإِسْفَارَ بِصَلاَةِ الْفَجْرِ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ ‏.‏ وَقَالَ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ مَعْنَى الإِسْفَارِ أَنْ يَضِحَ الْفَجْرُ فَلاَ يُشَكَّ فِيهِ وَلَمْ يَرَوْا أَنَّ مَعْنَى الإِسْفَارِ تَأْخِيرُ الصَّلاَةِ ‏.‏\hadithno{154}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Rafi bin Khadlj said:"I heard Allah's Messenger saying: 'Perform Fajr at AI-Isfar, for indeed its reward is greater}}
\hadithdefcmd{tirmidhi}{155}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ أَحَدًا كَانَ أَشَدَّ تَعْجِيلاً لِلظُّهْرِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ مِنْ أَبِي بَكْرٍ وَلاَ مِنْ عُمَرَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ وَخَبَّابٍ وَأَبِي بَرْزَةَ وَابْنِ مَسْعُودٍ وَزَيْدِ بْنِ ثَابِتٍ وَأَنَسٍ وَجَابِرِ بْنِ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ أَهْلُ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ وَقَدْ تَكَلَّمَ شُعْبَةُ فِي حَكِيمِ بْنِ جُبَيْرٍ مِنْ أَجْلِ حَدِيثِهِ الَّذِي رَوَى عَنِ ابْنِ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ النَّاسَ وَلَهُ مَا يُغْنِيهِ ‏"‏ ‏.‏ قَالَ يَحْيَى وَرَوَى لَهُ سُفْيَانُ وَزَائِدَةُ وَلَمْ يَرَ يَحْيَى بِحَدِيثِهِ بَأْسًا ‏.‏ قَالَ مُحَمَّدٌ وَقَدْ رُوِيَ عَنْ حَكِيمِ بْنِ جُبَيْرٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي تَعْجِيلِ الظُّهْرِ ‏.‏\hadithno{155}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"I have not seen anyone who hastened Zuhr more than Allah's Messenger nor Abu Bakr, nor Umar}}
\hadithdefcmd{tirmidhi}{156}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ حِينَ زَالَتِ الشَّمْسُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَهُوَ أَحْسَنُ حَدِيثٍ فِي هَذَا الْبَابِ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏\hadithno{156}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas bin Malik narrated:"Allah's Messenger prayed Zuhr when the sun had passed the zenith}}
\hadithdefcmd{tirmidhi}{157}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأَبِي ذَرٍّ وَابْنِ عُمَرَ وَالْمُغِيرَةِ وَالْقَاسِمِ بْنِ صَفْوَانَ عَنْ أَبِيهِ وَأَبِي مُوسَى وَابْنِ عَبَّاسٍ وَأَنَسٍ ‏.‏ قَالَ وَرُوِيَ عَنْ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا وَلاَ يَصِحُّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَارَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ تَأْخِيرَ صَلاَةِ الظُّهْرِ فِي شِدَّةِ الْحَرِّ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ الشَّافِعِيُّ إِنَّمَا الإِبْرَادُ بِصَلاَةِ الظُّهْرِ إِذَا كَانَ مَسْجِدًا يَنْتَابُ أَهْلُهُ مِنَ الْبُعْدِ فَأَمَّا الْمُصَلِّي وَحْدَهُ وَالَّذِي يُصَلِّي فِي مَسْجِدِ قَوْمِهِ فَالَّذِي أُحِبُّ لَهُ أَنْ لاَ يُؤَخِّرَ الصَّلاَةَ فِي شِدَّةِ الْحَرِّ ‏.‏ قَالَ أَبُو عِيسَى وَمَعْنَى مَنْ ذَهَبَ إِلَى تَأْخِيرِ الظُّهْرِ فِي شِدَّةِ الْحَرِّ هُوَ أَوْلَى وَأَشْبَهُ بِالاِتِّبَاعِ وَأَمَّا مَا ذَهَبَ إِلَيْهِ الشَّافِعِيُّ أَنَّ الرُّخْصَةَ لِمَنْ يَنْتَابُ مِنَ الْبُعْدِ وَالْمَشَقَّةِ عَلَى النَّاسِ فَإِنَّ فِي حَدِيثِ أَبِي ذَرٍّ مَا يَدُلُّ عَلَى خِلاَفِ مَا قَالَ الشَّافِعِيُّ ‏.‏ قَالَ أَبُو ذَرٍّ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَأَذَّنَ بِلاَلٌ بِصَلاَةِ الظُّهْرِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا بِلاَلُ أَبْرِدْ ثُمَّ أَبْرِدْ ‏"‏ ‏.‏ فَلَوْ كَانَ الأَمْرُ عَلَى مَا ذَهَبَ إِلَيْهِ الشَّافِعِيُّ لَمْ يَكُنْ لِلإِبْرَادِ فِي ذَلِكَ الْوَقْتِ مَعْنًى لاِجْتِمَاعِهِمْ فِي السَّفَرِ وَكَانُوا لاَ يَحْتَاجُونَ أَنْ يَنْتَابُوا مِنَ الْبُعْدِ ‏.‏\hadithno{157}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "In very hot weather, delay the (Zuhr) prayer until it becomes (a bit) cooler, because the severity of heat is from the raging of the Hell}}
\hadithdefcmd{tirmidhi}{158}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مُهَاجِرٍ أَبِي الْحَسَنِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي ذَرٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ فِي سَفَرٍ وَمَعَهُ بِلاَلٌ فَأَرَادَ بِلاَلٌ أَنْ يُقِيمَ فَقَالَ ‏"‏ أَبْرِدْ ‏"‏ ‏.‏ ثُمَّ أَرَادَ أَنْ يُقِيمَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبْرِدْ فِي الظُّهْرِ ‏"‏ ‏.‏ قَالَ حَتَّى رَأَيْنَا فَىْءَ التُّلُولِ ثُمَّ أَقَامَ فَصَلَّى فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ فَأَبْرِدُوا عَنِ الصَّلاَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{158}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Dharr narrated:"Allah's Messenger was on a journey and Bilal was with him. So he wanted to call for the prayer, but he (the Prophet) said: 'Let it get cooler.' Then he wanted to call for the prayer, so Allah's Messenger said: 'Let it get to the cooler time of Zuhr.'" He (i.e., Abu Dharr) said: "Until we saw the shadows of the hillocks, then he commanded that the Iqamah be called and then led the people in prayer. Allah's Messenger said: 'The severity of heat is from the raging of Hell, so wait until it becomes cooler for the (Zuhr) prayer}}
\hadithdefcmd{tirmidhi}{159}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ وَالشَّمْسُ فِي حُجْرَتِهَا لَمْ يَظْهَرِ الْفَىْءُ مِنْ حُجْرَتِهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي أَرْوَى وَجَابِرٍ وَرَافِعِ بْنِ خَدِيجٍ ‏.‏ قَالَ وَيُرْوَى عَنْ رَافِعٍ أَيْضًا عَنِ النَّبِيِّ صلى الله عليه وسلم فِي تَأْخِيرِ الْعَصْرِ وَلاَ يَصِحُّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ وَعَبْدُ اللَّهِ بْنُ مَسْعُودٍ وَعَائِشَةُ وَأَنَسٌ وَغَيْرُ وَاحِدٍ مِنَ التَّابِعِينَ تَعْجِيلُ صَلاَةِ الْعَصْرِ وَكَرِهُوا تَأْخِيرَهَا ‏.‏ وَبِهِ يَقُولُ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{159}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Urwah narrated from Aishah:"Allah's Messenger prayed Asr while the sun was (shining) in her chamber, (and) no shadow appeared in her chamber}}
\hadithdefcmd{tirmidhi}{160}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ دَخَلَ عَلَى أَنَسِ بْنِ مَالِكٍ فِي دَارِهِ بِالْبَصْرَةِ حِينَ انْصَرَفَ مِنَ الظُّهْرِ وَدَارُهُ بِجَنْبِ الْمَسْجِدِ فَقَالَ قُومُوا فَصَلُّوا الْعَصْرَ ‏.‏ قَالَ فَقُمْنَا فَصَلَّيْنَا فَلَمَّا انْصَرَفْنَا قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تِلْكَ صَلاَةُ الْمُنَافِقِ يَجْلِسُ يَرْقُبُ الشَّمْسَ حَتَّى إِذَا كَانَتْ بَيْنَ قَرْنَىِ الشَّيْطَانِ قَامَ فَنَقَرَ أَرْبَعًا لاَ يَذْكُرُ اللَّهَ فِيهَا إِلاَّ قَلِيلاً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{160}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Al-Ala bin Abdur-Raman narrated that :he visited Anas bin Malik in his home in Al Basrah after finishing Zuhr, and his home was next to the Masjid. So he said: 'Stand to pray Asr." He (Al-Ala) said: "So we stood to pray. When we were finished he (Anas) said: 'I heard Allah's Messenger saying: "That is the prayer of the hypocrite. He sits watching the sun, until when it is between the horns of the Shaitan he stands and pecks out four (units of prayer), not remembering Allah in them but a little}}
\hadithdefcmd{tirmidhi}{161}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَشَدَّ تَعْجِيلاً لِلظُّهْرِ مِنْكُمْ وَأَنْتُمْ أَشَدُّ تَعْجِيلاً لِلْعَصْرِ مِنْهُ ‏.‏\hadithno{161}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Umm Salamah narrated:"Allah's Messenger would hasten Zuhr more than you (people), while you (people) hasten Asr more than him}}
\hadithdefcmd{tirmidhi}{162}{قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ، عَنْ إِسْمَاعِيلَ ابْنِ عُلَيَّةَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أُمِّ سَلَمَةَ، نَحْوَهُ ‏.‏ وَوَجَدْتُ فِي كِتَابِي أَخْبَرَنِي عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، عَنِ ابْنِ جُرَيْجٍ، ‏.‏\hadithno{162}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Narrator not mentioned:[And I have in my book: "Ali bin Hujr informed me from lsma'il bin Ibrahim, from Ibn Juraij]}}
\hadithdefcmd{tirmidhi}{163}{وَحَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الْبَصْرِيُّ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَهَذَا أَصَحُّ ‏.‏\hadithno{163}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Similar narration is reported by Bishr ibn Mu'adh Al-Bari who said that :Isma'il ibn Ulayyah narrated to him from Ibn Juraij. This latter chain is more correct}}
\hadithdefcmd{tirmidhi}{164}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْمَغْرِبَ إِذَا غَرَبَتِ الشَّمْسُ وَتَوَارَتْ بِالْحِجَابِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَالصُّنَابِحِيِّ وَزَيْدِ بْنِ خَالِدٍ وَأَنَسٍ وَرَافِعِ بْنِ خَدِيجٍ وَأَبِي أَيُّوبَ وَأُمِّ حَبِيبَةَ وَعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ وَابْنِ عَبَّاسٍ ‏.‏ وَحَدِيثُ الْعَبَّاسِ قَدْ رُوِيَ مَوْقُوفًا عَنْهُ وَهُوَ أَصَحُّ ‏.‏ وَالصُّنَابِحِيُّ لَمْ يَسْمَعْ مِنَ النَّبِيِّ صلى الله عليه وسلم وَهُوَ صَاحِبُ أَبِي بَكْرٍ رضى الله عنه ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَلَمَةَ بْنِ الأَكْوَعِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ اخْتَارُوا تَعْجِيلَ صَلاَةِ الْمَغْرِبِ وَكَرِهُوا تَأْخِيرَهَا حَتَّى قَالَ بَعْضُ أَهْلِ الْعِلْمِ لَيْسَ لِصَلاَةِ الْمَغْرِبِ إِلاَّ وَقْتٌ وَاحِدٌ وَذَهَبُوا إِلَى حَدِيثِ النَّبِيِّ صلى الله عليه وسلم حَيْثُ صَلَّى بِهِ جِبْرِيلُ ‏.‏ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ ‏.‏\hadithno{164}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salmah bin AI-Akwa narrated:"Allah's Messenger prayed Maghrib when the sun had set and it (the sun) had hidden in the veil (of darkness)}}
\hadithdefcmd{tirmidhi}{165}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ بَشِيرِ بْنِ ثَابِتٍ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ أَنَا أَعْلَمُ النَّاسِ، بِوَقْتِ هَذِهِ الصَّلاَةِ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّيهَا لِسُقُوطِ الْقَمَرِ لِثَالِثَةٍ ‏"‏ ‏.‏\hadithno{165}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{An-Nu'man bin Bashir said:"I am the most knowledgeable among the people about the prescribed time of this prayer: Allah's Messenger would pray it when the moon set on the third (of the month)}}
\hadithdefcmd{tirmidhi}{166}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ أَبَانَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ أَبِي عَوَانَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى رَوَى هَذَا الْحَدِيثَ، هُشَيْمٌ عَنْ أَبِي بِشْرٍ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، ‏.‏ وَلَمْ يَذْكُرْ فِيهِ هُشَيْمٌ عَنْ بَشِيرِ بْنِ ثَابِتٍ، ‏.‏ وَحَدِيثُ أَبِي عَوَانَةَ أَصَحُّ عِنْدَنَا لأَنَّ يَزِيدَ بْنَ هَارُونَ رَوَى عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، نَحْوَ رِوَايَةِ أَبِي عَوَانَةَ ‏.‏\hadithno{166}\hadithgrade{Zubair Ali Zai: Isnaad Sahih}\hadithtrans{An-Nu'man bin Bashir said:A similar narration (from another chain linking to) this chain is also reported}}
\hadithdefcmd{tirmidhi}{167}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ أَنْ يُؤَخِّرُوا الْعِشَاءَ إِلَى ثُلُثِ اللَّيْلِ أَوْ نِصْفِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ سَمُرَةَ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَأَبِي بَرْزَةَ وَابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ الْخُدْرِيِّ وَزَيْدِ بْنِ خَالِدٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَغَيْرِهِمْ رَأَوْا تَأْخِيرَ صَلاَةِ الْعِشَاءِ الآخِرَةِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{167}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "If it were not that it would be a hardship on my Ummah, then I would have ordered you to delay Isha until the third of the night, or its half}}
\hadithdefcmd{tirmidhi}{168}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عَوْفٌ، قَالَ أَحْمَدُ وَحَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، هُوَ الْمُهَلَّبِيُّ وَإِسْمَاعِيلُ ابْنُ عُلَيَّةَ جَمِيعًا عَنْ عَوْفٍ، عَنْ سَيَّارِ بْنِ سَلاَمَةَ، هُوَ أَبُو الْمِنْهَالِ الرِّيَاحِيُّ عَنْ أَبِي بَرْزَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَكْرَهُ النَّوْمَ قَبْلَ الْعِشَاءِ وَالْحَدِيثَ بَعْدَهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي بَرْزَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ أَكْثَرُ أَهْلِ الْعِلْمِ النَّوْمَ قَبْلَ صَلاَةِ الْعِشَاءِ وَالْحَدِيثَ بَعْدَهَا وَرَخَّصَ فِي ذَلِكَ بَعْضُهُمْ ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ أَكْثَرُ الأَحَادِيثِ عَلَى الْكَرَاهِيَةِ ‏.‏ وَرَخَّصَ بَعْضُهُمْ فِي النَّوْمِ قَبْلَ صَلاَةِ الْعِشَاءِ فِي رَمَضَانَ ‏.‏ وَسَيَّارُ بْنُ سَلاَمَةَ هُوَ أَبُو الْمِنْهَالِ الرِّيَاحِيُّ ‏.‏\hadithno{168}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Barzah narrated:"The Prophet would dislike to sleep before Isha and to talk after it}}
\hadithdefcmd{tirmidhi}{169}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْمُرُ مَعَ أَبِي بَكْرٍ فِي الأَمْرِ مِنْ أَمْرِ الْمُسْلِمِينَ وَأَنَا مَعَهُمَا ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَوْسِ بْنِ حُذَيْفَةَ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ الْحَسَنُ بْنُ عُبَيْدِ اللَّهِ عَنْ إِبْرَاهِيمَ عَنْ عَلْقَمَةَ عَنْ رَجُلٍ مِنْ جُعْفِيٍّ يُقَالُ لَهُ قَيْسٌ أَوِ ابْنُ قَيْسٍ عَنْ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثَ فِي قِصَّةٍ طَوِيلَةٍ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ فِي السَّمَرِ بَعْدَ صَلاَةِ الْعِشَاءِ الآخِرَةِ فَكَرِهَ قَوْمٌ مِنْهُمُ السَّمَرَ بَعْدَ صَلاَةِ الْعِشَاءِ وَرَخَّصَ بَعْضُهُمْ إِذَا كَانَ فِي مَعْنَى الْعِلْمِ وَمَا لاَ بُدَّ مِنْهُ مِنَ الْحَوَائِجِ وَأَكْثَرُ الْحَدِيثِ عَلَى الرُّخْصَةِ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ سَمَرَ إِلاَّ لِمُصَلٍّ أَوْ مُسَافِرٍ ‏"‏ ‏.‏\hadithno{169}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Umar bin Al-Khattab narrated:"Allah's Messenger would talk during the night with Abu Bakr about matters concerning the Muslims while I was with them}}
\hadithdefcmd{tirmidhi}{170}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ الْعُمَرِيِّ، عَنِ الْقَاسِمِ بْنِ غَنَّامٍ، عَنْ عَمَّتِهِ أُمِّ فَرْوَةَ، وَكَانَتْ، مِمَّنْ بَايَعَتِ النَّبِيَّ صلى الله عليه وسلم قَالَتْ سُئِلَ النَّبِيُّ صلى الله عليه وسلم أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏ "‏ الصَّلاَةُ لأَوَّلِ وَقْتِهَا ‏"‏ ‏.‏\hadithno{170}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Farwah - and she was one of those who gave pledge of allegiance to the Prophet - narrated:"The Prophet was asked: 'Which deed is the best?' So he said: 'Salat in the beginning of its time}}
\hadithdefcmd{tirmidhi}{171}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ سَعِيدِ بْنِ عَبْدِ اللَّهِ الْجُهَنِيِّ، عَنْ مُحَمَّدِ بْنِ عُمَرَ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ يَا عَلِيُّ ثَلاَثٌ لاَ تُؤَخِّرْهَا الصَّلاَةُ إِذَا آنَتْ وَالْجَنَازَةُ إِذَا حَضَرَتْ وَالأَيِّمُ إِذَا وَجَدْتَ لَهَا كُفْؤًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ حَسَنٌ ‏.‏\hadithno{171}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Ali bin AbI Talib narrated that :the Prophet said to him: 'Ali! Three are not to be delayed: Salat when its time comes, a funeral whet it (a prepared body) is present, and the (marriage of a) single woman when there is an equal for her}}
\hadithdefcmd{tirmidhi}{172}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَعْقُوبُ بْنُ الْوَلِيدِ الْمَدَنِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوَقْتُ الأَوَّلُ مِنَ الصَّلاَةِ رِضْوَانُ اللَّهِ وَالْوَقْتُ الآخِرُ عَفْوُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى ابْنُ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ وَعَائِشَةَ وَابْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ فَرْوَةَ لاَ يُرْوَى إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ عُمَرَ الْعُمَرِيِّ وَلَيْسَ هُوَ بِالْقَوِيِّ عِنْدَ أَهْلِ الْحَدِيثِ وَاضْطَرَبُوا عَنْهُ فِي هَذَا الْحَدِيثِ وَهُوَ صَدُوقٌ وَقَدْ تَكَلَّمَ فِيهِ يَحْيَى بْنُ سَعِيدٍ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{172}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated that :Allah's Messenger said: "The beginning of the time for Salat is pleasing to Allah, and the end of its time is pardoned by Allah}}
\hadithdefcmd{tirmidhi}{173}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، عَنْ أَبِي يَعْفُورٍ، عَنِ الْوَليِدِ بْنِ الْعَيْزَارِ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، أَنَّ رَجُلاً، قَالَ لاِبْنِ مَسْعُودٍ أَىُّ الْعَمَلِ أَفْضَلُ قَالَ سَأَلْتُ عَنْهُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ الصَّلاَةُ عَلَى مَوَاقِيتِهَا ‏"‏ ‏.‏ قُلْتُ وَمَاذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَبِرُّ الْوَالِدَيْنِ ‏"‏ ‏.‏ قُلْتُ وَمَاذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَالْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى الْمَسْعُودِيُّ وَشُعْبَةُ وَسُلَيْمَانُ هُوَ أَبُو إِسْحَاقَ الشَّيْبَانِيُّ وَغَيْرُ وَاحِدٍ عَنِ الْوَلِيدِ بْنِ الْعَيْزَارِ هَذَا الْحَدِيثَ ‏.‏\hadithno{173}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Amr Ash-Shaibani narrated:"A man said to Ibn Mas'ud: 'Which deed is most virtuous?' He said: 'I asked Allah's Messenger (that). He said: "Salat at the beginning of its time." I asked him: "What is after that O Messenger of Allah?" He said: "Being dutiful to one's parents." I said: "What is after that [O Messenger of Allah]?" He said: "Jihad in the Way of Allah}}
\hadithdefcmd{tirmidhi}{174}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ إِسْحَاقَ بْنِ عُمَرَ، عَنْ عَائِشَةَ، قَالَتْ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةً لِوَقْتِهَا الآخِرِ مَرَّتَيْنِ حَتَّى قَبَضَهُ اللَّهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏ قَالَ الشَّافِعِيُّ وَالْوَقْتُ الأَوَّلُ مِنَ الصَّلاَةِ أَفْضَلُ ‏.‏ وَمِمَّا يَدُلُّ عَلَى فَضْلِ أَوَّلِ الْوَقْتِ عَلَى آخِرِهِ اخْتِيَارُ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ فَلَمْ يَكُونُوا يَخْتَارُونَ إِلاَّ مَا هُوَ أَفْضَلُ وَلَمْ يَكُونُوا يَدَعُونَ الْفَضْلَ وَكَانُوا يُصَلُّونَ فِي أَوَّلِ الْوَقْتِ ‏.‏ قَالَ حَدَّثَنَا بِذَلِكَ أَبُو الْوَلِيدِ الْمَكِّيُّ عَنِ الشَّافِعِيِّ ‏.‏\hadithno{174}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Aishah narrated:"Allah's Messenger did not pray any Salat at the end of its time two times, until Allah took him}}
\hadithdefcmd{tirmidhi}{175}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي تَفُوتُهُ صَلاَةُ الْعَصْرِ فَكَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَنَوْفَلِ بْنِ مُعَاوِيَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ الزُّهْرِيُّ أَيْضًا عَنْ سَالِمٍ عَنْ أَبِيهِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{175}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated that :the Prophet said: "Whoever misses the Asr prayer, then it is as if he was robbed of his family and his property}}
\hadithdefcmd{tirmidhi}{176}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْبَصْرِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَبَا ذَرٍّ أُمَرَاءُ يَكُونُونَ بَعْدِي يُمِيتُونَ الصَّلاَةَ فَصَلِّ الصَّلاَةَ لِوَقْتِهَا فَإِنْ صُلِّيَتْ لِوَقْتِهَا كَانَتْ لَكَ نَافِلَةً وَإِلاَّ كُنْتَ قَدْ أَحْرَزْتَ صَلاَتَكَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَعُبَادَةَ بْنِ الصَّامِتِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي ذَرٍّ حَدِيثٌ حَسَنٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ أَنْ يُصَلِّيَ الرَّجُلُ الصَّلاَةَ لِمِيقَاتِهَا إِذَا أَخَّرَهَا الإِمَامُ ثُمَّ يُصَلِّي مَعَ الإِمَامِ وَالصَّلاَةُ الأُولَى هِيَ الْمَكْتُوبَةُ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ ‏.‏ وَأَبُو عِمْرَانَ الْجَوْنِيُّ اسْمُهُ عَبْدُ الْمَلِكِ بْنُ حَبِيبٍ ‏.‏\hadithno{176}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Dharr narrated that :the Prophet said: "O Abu Dharr! There will be leaders after me who cause the Salat to die; so perform the Salat during its time. If you pray (with them) during its time, then that will be voluntary Salat for you, if not, then you will have attained your Salat}}
\hadithdefcmd{tirmidhi}{177}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ الأَنْصَارِيِّ، عَنْ أَبِي قَتَادَةَ، قَالَ ذَكَرُوا لِلنَّبِيِّ صلى الله عليه وسلم نَوْمَهُمْ عَنِ الصَّلاَةِ فَقَالَ ‏ "‏ إِنَّهُ لَيْسَ فِي النَّوْمِ تَفْرِيطٌ إِنَّمَا التَّفْرِيطُ فِي الْيَقَظَةِ فَإِذَا نَسِيَ أَحَدُكُمْ صَلاَةً أَوْ نَامَ عَنْهَا فَلْيُصَلِّهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي مَرْيَمَ وَعِمْرَانَ بْنِ حُصَيْنٍ وَجُبَيْرِ بْنِ مُطْعِمٍ وَأَبِي جُحَيْفَةَ وَأَبِي سَعِيدٍ وَعَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ وَذِي مِخْبَرٍ وَيُقَالُ ذِي مِخْمَرٍ وَهُوَ ابْنُ أَخِي النَّجَاشِيِّ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي قَتَادَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الرَّجُلِ يَنَامُ عَنِ الصَّلاَةِ أَوْ يَنْسَاهَا فَيَسْتَيْقِظُ أَوْ يَذْكُرُ وَهُوَ فِي غَيْرِ وَقْتِ صَلاَةٍ عِنْدَ طُلُوعِ الشَّمْسِ أَوْ عِنْدَ غُرُوبِهَا ‏.‏ فَقَالَ بَعْضُهُمْ يُصَلِّيهَا إِذَا اسْتَيْقَظَ أَوْ ذَكَرَ وَإِنْ كَانَ عِنْدَ طُلُوعِ الشَّمْسِ أَوْ عِنْدَ غُرُوبِهَا ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَالشَّافِعِيِّ وَمَالِكٍ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ يُصَلِّي حَتَّى تَطْلُعَ الشَّمْسُ أَوْ تَغْرُبَ ‏.‏\hadithno{177}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Qatadah narrated:"They asked the Prophet about when they sIept past the Salat. He said: 'There is no negligence in sleep, negligence is only while one is awake. So when one of you forgets a Salat, or sleeps through it, then let him pray it when he remembers it}}
\hadithdefcmd{tirmidhi}{178}{حَدَّثَنَا قُتَيْبَةُ، وَبِشْرُ بْنُ مُعَاذٍ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ سَمُرَةَ وَأَبِي قَتَادَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ أَنَّهُ قَالَ فِي الرَّجُلِ يَنْسَى الصَّلاَةَ قَالَ يُصَلِّيهَا مَتَى مَا ذَكَرَهَا فِي وَقْتٍ أَوْ فِي غَيْرِ وَقْتٍ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ بْنِ حَنْبَلٍ وَإِسْحَاقَ ‏.‏ وَيُرْوَى عَنْ أَبِي بَكْرَةَ أَنَّهُ نَامَ عَنْ صَلاَةِ الْعَصْرِ فَاسْتَيْقَظَ عِنْدَ غُرُوبِ الشَّمْسِ فَلَمْ يُصَلِّ حَتَّى غَرَبَتِ الشَّمْسُ ‏.‏ وَقَدْ ذَهَبَ قَوْمٌ مِنْ أَهْلِ الْكُوفَةِ إِلَى هَذَا وَأَمَّا أَصْحَابُنَا فَذَهَبُوا إِلَى قَوْلِ عَلِيِّ بْنِ أَبِي طَالِبٍ رَضِيَ اللَّهُ عَنْهُ ‏.‏\hadithno{178}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas (bin Malik) narrated that :Allah's Messenger said: "Whoever forgets a Salat then he is to pray it when he remembers it}}
\hadithdefcmd{tirmidhi}{179}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِي عُبَيْدَةَ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ إِنَّ الْمُشْرِكِينَ شَغَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ أَرْبَعِ صَلَوَاتٍ يَوْمَ الْخَنْدَقِ حَتَّى ذَهَبَ مِنَ اللَّيْلِ مَا شَاءَ اللَّهُ فَأَمَرَ بِلاَلاً فَأَذَّنَ ثُمَّ أَقَامَ فَصَلَّى الظُّهْرَ ثُمَّ أَقَامَ فَصَلَّى الْعَصْرَ ثُمَّ أَقَامَ فَصَلَّى الْمَغْرِبَ ثُمَّ أَقَامَ فَصَلَّى الْعِشَاءَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ لَيْسَ بِإِسْنَادِهِ بَأْسٌ إِلاَّ أَنَّ أَبَا عُبَيْدَةَ لَمْ يَسْمَعْ مِنْ عَبْدِ اللَّهِ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ بَعْضُ أَهْلِ الْعِلْمِ فِي الْفَوَائِتِ أَنْ يُقِيمَ الرَّجُلُ لِكُلِّ صَلاَةٍ إِذَا قَضَاهَا وَإِنْ لَمْ يُقِمْ أَجْزَأَهُ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{179}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah (bin Mas'ud] narrated:"The idolaters kept Allah's Messenger distracted from four prayers on the Day of Al-Khandaq (the battle of the Trench) until as much as Allah willed of the night had passed. So he ordered Bilal to call the Adhan, then he called the Iqamah to Zuhr, then he called the Iqamah to pray Asr, then he called the Iqamah to pray Maghrib, then he called the Iqamah to pray Isha}}
\hadithdefcmd{tirmidhi}{180}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، بُنْدَارٌ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ يَوْمَ الْخَنْدَقِ وَجَعَلَ يَسُبُّ كُفَّارَ قُرَيْشٍ قَالَ يَا رَسُولَ اللَّهِ مَا كِدْتُ أُصَلِّي الْعَصْرَ حَتَّى تَغْرُبَ الشَّمْسُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ إِنْ صَلَّيْتُهَا ‏"‏ ‏.‏ قَالَ فَنَزَلْنَا بُطْحَانَ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَوَضَّأْنَا فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ بَعْدَ مَا غَرَبَتِ الشَّمْسُ ثُمَّ صَلَّى بَعْدَهَا الْمَغْرِبَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{180}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin Abdullah narrated:"On the Day of Al-Khandaq (the battle of the Trench), Umar bin Al-Khattab came cursing the disbelievers of Quraish and said: 'O Allah's Messenger! I could not offer he Asr prayer until the sun was about to set.' The Prophet said: 'By Allah! I too have not offered the Salat.'" So he said: "We descended into Buthan, Allah's Messenger performed Wudu and we too performed Wudu. Allah's Messenger prayed Asr after the sun had set, then after it he prayed Maghrib}}
\hadithdefcmd{tirmidhi}{181}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، وَأَبُو النَّضْرِ، عَنْ مُحَمَّدِ بْنِ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ زُبَيْدٍ، عَنْ مُرَّةَ الْهَمْدَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ الْوُسْطَى صَلاَةُ الْعَصْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{181}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Mas'ud narrated that :Allah's Messenger said: "Salatul-Wusta is the Asr prayer}}
\hadithdefcmd{tirmidhi}{182}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ صَلاَةُ الْوُسْطَى صَلاَةُ الْعَصْرِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَزَيْدِ بْنِ ثَابِتٍ وَعَائِشَةَ وَحَفْصَةَ وَأَبِي هُرَيْرَةَ وَأَبِي هَاشِمِ بْنِ عُتْبَةَ ‏.‏ قَالَ أَبُو عِيسَى قَالَ مُحَمَّدٌ قَالَ عَلِيُّ بْنُ عَبْدِ اللَّهِ حَدِيثُ الْحَسَنِ عَنْ سَمُرَةَ بْنِ جُنْدَبٍ حَدِيثٌ صَحِيحٌ وَقَدْ سَمِعَ مِنْهُ ‏.‏ وَقَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ فِي صَلاَةِ الْوُسْطَى حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ الْعُلَمَاءِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ وَقَالَ زَيْدُ بْنُ ثَابِتٍ وَعَائِشَةُ صَلاَةُ الْوُسْطَى صَلاَةُ الظُّهْرِ ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ وَابْنُ عُمَرَ صَلاَةُ الْوُسْطَى صَلاَةُ الصُّبْحِ ‏.‏ حَدَّثَنَا أَبُو مُوسَى مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا قُرَيْشُ بْنُ أَنَسٍ عَنْ حَبِيبِ بْنِ الشَّهِيدِ قَالَ قَالَ لِي مُحَمَّدُ بْنُ سِيرِينَ سَلِ الْحَسَنَ مِمَّنْ سَمِعَ حَدِيثَ الْعَقِيقَةِ فَسَأَلْتُهُ فَقَالَ سَمِعْتُهُ مِنْ سَمُرَةَ بْنِ جُنْدَبٍ ‏.‏ قَالَ أَبُو عِيسَى وَأَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ بْنِ الْمَدِينِيِّ عَنْ قُرَيْشِ بْنِ أَنَسٍ بِهَذَا الْحَدِيثِ ‏.‏ قَالَ مُحَمَّدٌ قَالَ عَلِيٌّ وَسَمَاعُ الْحَسَنِ مِنْ سَمُرَةَ صَحِيحٌ ‏.‏ وَاحْتَجَّ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{182}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Smurah bin Jundub narrated that :the Prophet said: "Salatul-wusta is the Asr prayer}}
\hadithdefcmd{tirmidhi}{183}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مَنْصُورٌ، وَهُوَ ابْنُ زَاذَانَ عَنْ قَتَادَةَ، قَالَ أَخْبَرَنَا أَبُو الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ غَيْرَ، وَاحِدٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَكَانَ مِنْ أَحَبِّهِمْ إِلَىَّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ وَعَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ مَسْعُودٍ وَأَبِي سَعِيدٍ وَعُقْبَةَ بْنِ عَامِرٍ وَأَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَسَمُرَةَ بْنِ جُنْدَبٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَمُعَاذِ بْنِ عَفْرَاءَ وَالصُّنَابِحِيِّ وَلَمْ يَسْمَعْ مِنَ النَّبِيِّ صلى الله عليه وسلم وَسَلَمَةَ بْنِ الأَكْوَعِ وَزَيْدِ بْنِ ثَابِتٍ وَعَائِشَةَ وَكَعْبِ بْنِ مُرَّةَ وَأَبِي أُمَامَةَ وَعَمْرِو بْنِ عَبَسَةَ وَيَعْلَى بْنِ أُمَيَّةَ وَمُعَاوِيَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ عَنْ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ الْفُقَهَاءِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ أَنَّهُمْ كَرِهُوا الصَّلاَةَ بَعْدَ صَلاَةِ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ وَبَعْدَ صَلاَةِ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَأَمَّا الصَّلَوَاتُ الْفَوَائِتُ فَلاَ بَأْسَ أَنْ تُقْضَى بَعْدَ الْعَصْرِ وَبَعْدَ الصُّبْحِ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ قَالَ شُعْبَةُ لَمْ يَسْمَعْ قَتَادَةُ مِنْ أَبِي الْعَالِيَةِ إِلاَّ ثَلاَثَةَ أَشْيَاءَ حَدِيثَ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَبَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ وَحَدِيثَ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لا يَنْبَغِي لأَحَدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏ ‏.‏ وَحَدِيثَ عَلِيٍّ ‏"‏ الْقُضَاةُ ثَلاَثَةٌ ‏"‏ ‏.‏\hadithno{183}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"I head more than one of the Companions of the Prophet; Umar bin Al-Khattab among, and he was one of the most beloved among them to me - (narrating) that Allah's Messenger prohibited the Salat after Fajr until the sun had risen, and the Salat after Asr until the sun had set}}
\hadithdefcmd{tirmidhi}{184}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا صَلَّى النَّبِيُّ صلى الله عليه وسلم الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ لأَنَّهُ أَتَاهُ مَالٌ فَشَغَلَهُ عَنِ الرَّكْعَتَيْنِ بَعْدَ الظُّهْرِ فَصَلاَّهُمَا بَعْدَ الْعَصْرِ ثُمَّ لَمْ يَعُدْ لَهُمَا ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأُمِّ سَلَمَةَ وَمَيْمُونَةَ وَأَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى بَعْدَ الْعَصْرِ رَكْعَتَيْنِ ‏.‏ وَهَذَا خِلاَفُ مَا رُوِيَ عَنْهُ أَنَّهُ نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏"‏ ‏.‏ وَحَدِيثُ ابْنِ عَبَّاسٍ أَصَحُّ حَيْثُ قَالَ لَمْ يَعُدْ لَهُمَا ‏.‏ وَقَدْ رُوِيَ عَنْ زَيْدِ بْنِ ثَابِتٍ نَحْوُ حَدِيثِ ابْنِ عَبَّاسٍ ‏.‏ وَقَدْ رُوِيَ عَنْ عَائِشَةَ فِي هَذَا الْبَابِ رِوَايَاتٌ رُوِيَ عَنْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم مَا دَخَلَ عَلَيْهَا بَعْدَ الْعَصْرِ إِلاَّ صَلَّى رَكْعَتَيْنِ وَرُوِيَ عَنْهَا عَنْ أُمِّ سَلَمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَبَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏ وَالَّذِي اجْتَمَعَ عَلَيْهِ أَكْثَرُ أَهْلِ الْعِلْمِ عَلَى كَرَاهِيَةِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَبَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ إِلاَّ مَا اسْتُثْنِيَ مِنْ ذَلِكَ مِثْلُ الصَّلاَةِ بِمَكَّةَ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَبَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ بَعْدَ الطَّوَافِ فَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم رُخْصَةٌ فِي ذَلِكَ ‏.‏ وَقَدْ قَالَ بِهِ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمُ الصَّلاَةَ بِمَكَّةَ أَيْضًا بَعْدَ الْعَصْرِ وَبَعْدَ الصُّبْحِ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَمَالِكُ بْنُ أَنَسٍ وَبَعْضُ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{184}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet only performed the two rak'ah (units of prayer) after Asr because some wealth came to him which distracted him from the two rak'ah after Zuhr, so he prayed them after Asr, then he did not repeat that}}
\hadithdefcmd{tirmidhi}{185}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ كَهْمَسِ بْنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ لِمَنْ شَاءَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم فِي الصَّلاَةِ قَبْلَ الْمَغْرِبِ فَلَمْ يَرَ بَعْضُهُمُ الصَّلاَةَ قَبْلَ الْمَغْرِبِ ‏.‏ وَقَدْ رُوِيَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمْ كَانُوا يُصَلُّونَ قَبْلَ صَلاَةِ الْمَغْرِبِ رَكْعَتَيْنِ بَيْنَ الأَذَانِ وَالإِقَامَةِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ إِنْ صَلاَّهُمَا فَحَسَنٌ ‏.‏ وَهَذَا عِنْدَهُمَا عَلَى الاِسْتِحْبَابِ ‏.‏\hadithno{185}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Mughaffal narrated that :the Prophet said: "Between every two calls (to prayer) there is a Salat for whoever wills}}
\hadithdefcmd{tirmidhi}{186}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، وَعَنْ بُسْرِ بْنِ سَعِيدٍ، وَعَنِ الأَعْرَجِ، يُحَدِّثُونَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصُّبْحِ رَكْعَةً قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ الصُّبْحَ وَمَنْ أَدْرَكَ مِنَ الْعَصْرِ رَكْعَةً قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَ الْعَصْرَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهِ يَقُولُ أَصْحَابُنَا وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ عِنْدَهُمْ لِصَاحِبِ الْعُذْرِ مِثْلُ الرَّجُلِ يَنَامُ عَنِ الصَّلاَةِ أَوْ يَنْسَاهَا فَيَسْتَيْقِظُ وَيَذْكُرُ عِنْدَ طُلُوعِ الشَّمْسِ وَعِنْدَ غُرُوبِهَا ‏.‏\hadithno{186}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Whoever catches a Rak'ah of Subh before the sun has risen, then he has caught Subh. Whoever catches a Rak'ah of Asr before the sun has set, then he has caught Asr}}
\hadithdefcmd{tirmidhi}{187}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الظُّهْرِ وَالْعَصْرِ وَبَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِالْمَدِينَةِ مِنْ غَيْرِ خَوْفٍ وَلاَ مَطَرٍ ‏.‏ قَالَ فَقِيلَ لاِبْنِ عَبَّاسٍ مَا أَرَادَ بِذَلِكَ قَالَ أَرَادَ أَنْ لاَ يُحْرِجَ أُمَّتَهُ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ قَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ رَوَاهُ جَابِرُ بْنُ زَيْدٍ وَسَعِيدُ بْنُ جُبَيْرٍ وَعَبْدُ اللَّهِ بْنُ شَقِيقٍ الْعُقَيْلِيُّ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرُ هَذَا ‏.‏\hadithno{187}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Abbas said:"Allah's Messenger combined the Zuhr and Asr (prayers), and the Maghrib and Isha (prayers) in Al-Madinah, without being in a state of fear, nor due to rain}}
\hadithdefcmd{tirmidhi}{188}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ الْبَصْرِيُّ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ حَنَشٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ جَمَعَ بَيْنَ الصَّلاَتَيْنِ مِنْ غَيْرِ عُذْرٍ فَقَدْ أَتَى بَابًا مِنْ أَبْوَابِ الْكَبَائِرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَحَنَشٌ هَذَا هُوَ أَبُو عَلِيٍّ الرَّحَبِيُّ وَهُوَ حُسَيْنُ بْنُ قَيْسٍ وَهُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ضَعَّفَهُ أَحْمَدُ وَغَيْرُهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنْ لاَ يَجْمَعَ بَيْنَ الصَّلاَتَيْنِ إِلاَّ فِي السَّفَرِ أَوْ بِعَرَفَةَ ‏.‏ وَرَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ فِي الْجَمْعِ بَيْنَ الصَّلاَتَيْنِ لِلْمَرِيضِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ يَجْمَعُ بَيْنَ الصَّلاَتَيْنِ فِي الْمَطَرِ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَلَمْ يَرَ الشَّافِعِيُّ لِلْمَرِيضِ أَنْ يَجْمَعَ بَيْنَ الصَّلاَتَيْنِ ‏.‏\hadithno{188}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif}\hadithtrans{Ibn Abbas narrated that :the Prophet said: "Whoever combines two prayers without any excuse then he has committed something from the major sins}}
\hadithdefcmd{tirmidhi}{189}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ زَيْدٍ، عَنْ أَبِيهِ، قَالَ لَمَّا أَصْبَحْنَا أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ بِالرُّؤْيَا فَقَالَ ‏"‏ إِنَّ هَذِهِ لَرُؤْيَا حَقٍّ فَقُمْ مَعَ بِلاَلٍ فَإِنَّهُ أَنْدَى وَأَمَدُّ صَوْتًا مِنْكَ فَأَلْقِ عَلَيْهِ مَا قِيلَ لَكَ وَلْيُنَادِ بِذَلِكَ ‏"‏ ‏.‏ قَالَ فَلَمَّا سَمِعَ عُمَرُ بْنُ الْخَطَّابِ نِدَاءَ بِلاَلٍ بِالصَّلاَةِ خَرَجَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَجُرُّ إِزَارَهُ وَهُوَ يَقُولُ يَا رَسُولَ اللَّهِ وَالَّذِي بَعَثَكَ بِالْحَقِّ لَقَدْ رَأَيْتُ مِثْلَ الَّذِي قَالَ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلِلَّهِ الْحَمْدُ فَذَلِكَ أَثْبَتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ زَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ إِبْرَاهِيمُ بْنُ سَعْدٍ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ أَتَمَّ مِنْ هَذَا الْحَدِيثِ وَأَطْوَلَ وَذَكَرَ فِيهِ قِصَّةَ الأَذَانِ مَثْنَى مَثْنَى وَالإِقَامَةِ مَرَّةً مَرَّةً ‏.‏ وَعَبْدُ اللَّهِ بْنُ زَيْدٍ هُوَ ابْنُ عَبْدِ رَبِّهِ وَيُقَالُ ابْنُ عَبْدِ رَبٍّ وَلاَ نَعْرِفُ لَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْئًا يَصِحُّ إِلاَّ هَذَا الْحَدِيثَ الْوَاحِدَ فِي الأَذَانِ ‏.‏ وَعَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ عَاصِمٍ الْمَازِنِيُّ لَهُ أَحَادِيثُ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ عَمُّ عَبَّادِ بْنِ تَمِيمٍ ‏.‏\hadithno{189}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Albdullah bin Zaid narrated:"When we awoke, we went to Allah's Messenger to inform him of the dream. He said: 'Indeed this dream is true. So go to Bilal, for he has a better and louder voice than you. Convey to him what was said to you, so that he may call (to the prayer) with that.'" He said: "When Umar bin Al-Khattab heard Bilal calling for the prayer he went to Allah's Messenger, and he was dragging his Izar, (as he was hurrying) saying: 'O Allah's Messenger! By the One Who sent you with the truth! I dreamt the same as what he said.''' He said: "So Allah's Messenger said: 'To Allah is the praise, so that confirms it even more}}
\hadithdefcmd{tirmidhi}{190}{حَدَّثَنَا أَبُو بَكْرِ بْنُ النَّضْرِ بْنِ أَبِي النَّضْرِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ الْمُسْلِمُونَ حِينَ قَدِمُوا الْمَدِينَةَ يَجْتَمِعُونَ فَيَتَحَيَّنُونَ الصَّلَوَاتِ وَلَيْسَ يُنَادِي بِهَا أَحَدٌ فَتَكَلَّمُوا يَوْمًا فِي ذَلِكَ فَقَالَ بَعْضُهُمُ اتَّخِذُوا نَاقُوسًا مِثْلَ نَاقُوسِ النَّصَارَى ‏.‏ وَقَالَ بَعْضُهُمُ اتَّخِذُوا قَرْنًا مِثْلَ قَرْنِ الْيَهُودِ ‏.‏ قَالَ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ أَوَلاَ تَبْعَثُونَ رَجُلاً يُنَادِي بِالصَّلاَةِ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا بِلاَلُ قُمْ فَنَادِ بِالصَّلاَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عُمَرَ ‏.‏\hadithno{190}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"When the Muslims arrived in AI-Madinah, they used to assemble for the Salat, and guess the time for it there was no one who called for it (the prayer). One day they discussed that and some of them said that they should use a bell like the bell the Christians use. Others said they should use a trumpet like the horn the Jews use. But Umar [bin Al-Khattab] said: 'Wouldn't it better if we had a man call for the prayer?'" He said: "So Allah's Messenger said: 'O Bilal! Stand up and call for the Salat}}
\hadithdefcmd{tirmidhi}{191}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الْبَصْرِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ الْعَزِيزِ بْنِ عَبْدِ الْمَلِكِ بْنِ أَبِي مَحْذُورَةَ، قَالَ أَخْبَرَنِي أَبِي وَجَدِّي، جَمِيعًا عَنْ أَبِي مَحْذُورَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقْعَدَهُ وَأَلْقَى عَلَيْهِ الأَذَانَ حَرْفًا حَرْفًا ‏.‏ قَالَ إِبْرَاهِيمُ مِثْلَ أَذَانِنَا ‏.‏ قَالَ بِشْرٌ فَقُلْتُ لَهُ أَعِدْ عَلَىَّ ‏.‏ فَوَصَفَ الأَذَانَ بِالتَّرْجِيعِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي مَحْذُورَةَ فِي الأَذَانِ حَدِيثٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَعَلَيْهِ الْعَمَلُ بِمَكَّةَ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{191}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Mahdhurah narrated that :Allah's Messenger sat with him and taught him the Adhan word for word. Ibrahim said, "It is the same as our Adhan." Bishr said: "So I said to him, 'Repeat it to me.' So he described the Adhan with At-Tarjl}}
\hadithdefcmd{tirmidhi}{192}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، عَنْ عَامِرِ بْنِ عَبْدِ الْوَاحِدِ الأَحْوَلِ، عَنْ مَكْحُولٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَيْرِيزٍ، عَنْ أَبِي مَحْذُورَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عَلَّمَهُ الأَذَانَ تِسْعَ عَشْرَةَ كَلِمَةً وَالإِقَامَةَ سَبْعَ عَشْرَةَ كَلِمَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو مَحْذُورَةَ اسْمُهُ سَمُرَةُ بْنُ مِعْيَرٍ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا فِي الأَذَانِ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي مَحْذُورَةَ أَنَّهُ كَانَ يُفْرِدُ الإِقَامَةَ ‏.‏\hadithno{192}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Mahdhurah narrated that :the Prophet taught him the Adhan with nineteen phrases, and the Iqamah with seventeen phrases}}
\hadithdefcmd{tirmidhi}{193}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، وَيَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أُمِرَ بِلاَلٌ أَنْ يَشْفَعَ، الأَذَانَ وَيُوتِرَ الإِقَامَةَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَبِهِ يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{193}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"Bilal was ordered to make the phrases of the Adhan even, and the phrases of the Iqamah odd}}
\hadithdefcmd{tirmidhi}{194}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ كَانَ أَذَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم شَفْعًا شَفْعًا فِي الأَذَانِ وَالإِقَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ زَيْدٍ رَوَاهُ وَكِيعٌ عَنِ الأَعْمَشِ عَنْ عَمْرِو بْنِ مُرَّةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى قَالَ حَدَّثَنَا أَصْحَابُ مُحَمَّدٍ صلى الله عليه وسلم أَنَّ عَبْدَ اللَّهِ بْنَ زَيْدٍ رَأَى الأَذَانَ فِي الْمَنَامِ ‏.‏ وَقَالَ شُعْبَةُ عَنْ عَمْرِو بْنِ مُرَّةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى أَنَّ عَبْدَ اللَّهِ بْنَ زَيْدٍ رَأَى الأَذَانَ فِي الْمَنَامِ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ ابْنِ أَبِي لَيْلَى ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى لَمْ يَسْمَعْ مِنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ الأَذَانُ مَثْنَى مَثْنَى وَالإِقَامَةُ مَثْنَى مَثْنَى ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَأَهْلُ الْكُوفَةِ ‏.‏ قَالَ أَبُو عِيسَى ابْنُ أَبِي لَيْلَى هُوَ مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى كَانَ قَاضِيَ الْكُوفَةِ وَلَمْ يَسْمَعْ مِنْ أَبِيهِ شَيْئًا إِلاَّ أَنَّهُ يَرْوِي عَنْ رَجُلٍ عَنْ أَبِيهِ ‏.‏\hadithno{194}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Zaid said:"Allah's Messenger would say each phrase of the call (for prayer) two times, for the Adhan and the Iqamah}}
\hadithdefcmd{tirmidhi}{195}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، حَدَّثَنَا الْمُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْمُنْعِمِ، هُوَ صَاحِبُ السِّقَاءِ قَالَ حَدَّثَنَا يَحْيَى بْنُ مُسْلِمٍ، عَنِ الْحَسَنِ، وَعَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِبِلاَلٍ ‏ "‏ يَا بِلاَلُ إِذَا أَذَّنْتَ فَتَرَسَّلْ فِي أَذَانِكَ وَإِذَا أَقَمْتَ فَاحْدُرْ وَاجْعَلْ بَيْنَ أَذَانِكَ وَإِقَامَتِكَ قَدْرَ مَا يَفْرُغُ الآكِلُ مِنْ أَكْلِهِ وَالشَّارِبُ مِنْ شُرْبِهِ وَالْمُعْتَصِرُ إِذَا دَخَلَ لِقَضَاءِ حَاجَتِهِ وَلاَ تَقُومُوا حَتَّى تَرَوْنِي ‏"‏ ‏.‏\hadithno{195}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir [bin Abdullah] narrated:"Allah's Messenger said to Bilal: "O Bilal! When you call the Adhan then do so deliberately and slowly, and when you call the Iqamah then be quick. Allow enough time between your Adhan and Iqamah for the person eating to finish what he is eating, the person drinking to finish what he is drinking, and the one who needs time to relive himself, and do not stand until you see me}}
\hadithdefcmd{tirmidhi}{196}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الْمُنْعِمِ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَبْدِ الْمُنْعِمِ وَهُوَ إِسْنَادٌ مَجْهُولٌ وَعَبْدُ الْمُنْعِمِ شَيْخٌ بَصْرِيٌّ ‏.‏\hadithno{196}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Jabir [bin Abdullah] narrated:(Another chain for) a similar narration (as no)}}
\hadithdefcmd{tirmidhi}{197}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ بِلاَلاً يُؤَذِّنُ وَيَدُورُ وَيُتْبِعُ فَاهُ هَا هُنَا وَهَا هُنَا وَإِصْبَعَاهُ فِي أُذُنَيْهِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي قُبَّةٍ لَهُ حَمْرَاءَ أُرَاهُ قَالَ مِنْ أَدَمٍ فَخَرَجَ بِلاَلٌ بَيْنَ يَدَيْهِ بِالْعَنَزَةِ فَرَكَزَهَا بِالْبَطْحَاءِ فَصَلَّى إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَمُرُّ بَيْنَ يَدَيْهِ الْكَلْبُ وَالْحِمَارُ وَعَلَيْهِ حُلَّةٌ حَمْرَاءُ كَأَنِّي أَنْظُرُ إِلَى بَرِيقِ سَاقَيْهِ ‏.‏ قَالَ سُفْيَانُ نُرَاهُ حِبَرَةً ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي جُحَيْفَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلَيْهِ الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ أَنْ يُدْخِلَ الْمُؤَذِّنُ إِصْبَعَيْهِ فِي أُذُنَيْهِ فِي الأَذَانِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ وَفِي الإِقَامَةِ أَيْضًا يُدْخِلُ إِصْبَعَيْهِ فِي أُذُنَيْهِ ‏.‏ وَهُوَ قَوْلُ الأَوْزَاعِيِّ ‏.‏ وَأَبُو جُحَيْفَةَ اسْمُهُ وَهْبُ بْنُ عَبْدِ اللَّهِ السُّوَائِيُّ ‏.‏\hadithno{197}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Juhaifah narrated:"I saw Bilal calling the Adhan, and turning, and his (face) was following here and there, and his (index) fingers were in his ears, and Allah's Messenger was in a small red tent" - "I think," he (one of the narrators) said, "it was made from a hide" - so Bilal went out in front of him with an Anazah which he planted (in the ground) at Batha. Allah's Messenger prayed facing it, and a dog and a donkey passed in front of him; he was wearing a red Hullah, and it is as if I am now looking at the radiance of his shins." Sufyan said: "We think that it was a Hibrah}}
\hadithdefcmd{tirmidhi}{198}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا أَبُو إِسْرَائِيلَ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ بِلاَلٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُثَوِّبَنَّ فِي شَيْءٍ مِنَ الصَّلَوَاتِ إِلاَّ فِي صَلاَةِ الْفَجْرِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي مَحْذُورَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بِلاَلٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي إِسْرَائِيلَ الْمُلاَئِيِّ ‏.‏ وَأَبُو إِسْرَائِيلَ لَمْ يَسْمَعْ هَذَا الْحَدِيثَ مِنَ الْحَكَمِ بْنِ عُتَيْبَةَ قَالَ إِنَّمَا رَوَاهُ عَنِ الْحَسَنِ بْنِ عُمَارَةَ عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ ‏.‏ وَأَبُو إِسْرَائِيلَ اسْمُهُ إِسْمَاعِيلُ بْنُ أَبِي إِسْحَاقَ وَلَيْسَ هُوَ بِذَاكَ الْقَوِيِّ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي تَفْسِيرِ التَّثْوِيبِ فَقَالَ بَعْضُهُمُ التَّثْوِيبُ أَنْ يَقُولَ فِي أَذَانِ الْفَجْرِ الصَّلاَةُ خَيْرٌ مِنَ النَّوْمِ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَأَحْمَدَ ‏.‏ وَقَالَ إِسْحَاقُ فِي التَّثْوِيبِ غَيْرَ هَذَا قَالَ التَّثْوِيبُ الْمَكْرُوهُ هُوَ شَيْءٌ أَحْدَثَهُ النَّاسُ بَعْدَ النَّبِيِّ صلى الله عليه وسلم إِذَا أَذَّنَ الْمُؤَذِّنُ فَاسْتَبْطَأَ الْقَوْمَ قَالَ بَيْنَ الأَذَانِ وَالإِقَامَةِ قَدْ قَامَتِ الصَّلاَةُ حَىَّ عَلَى الصَّلاَةِ حَىَّ عَلَى الْفَلاَحِ ‏.‏ قَالَ وَهَذَا الَّذِي قَالَ إِسْحَاقُ هُوَ التَّثْوِيبُ الَّذِي قَدْ كَرِهَهُ أَهْلُ الْعِلْمِ وَالَّذِي أَحْدَثُوهُ بَعْدَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَالَّذِي فَسَّرَ ابْنُ الْمُبَارَكِ وَأَحْمَدُ أَنَّ التَّثْوِيبَ أَنْ يَقُولَ الْمُؤَذِّنُ فِي أَذَانِ الْفَجْرِ الصَّلاَةُ خَيْرٌ مِنَ النَّوْمِ وَهُوَ قَوْلٌ صَحِيحٌ وَيُقَالُ لَهُ التَّثْوِيبُ أَيْضًا وَهُوَ الَّذِي اخْتَارَهُ أَهْلُ الْعِلْمِ وَرَأَوْهُ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّهُ كَانَ يَقُولُ فِي صَلاَةِ الْفَجْرِ الصَّلاَةُ خَيْرٌ مِنَ النَّوْمِ ‏.‏ وَرُوِيَ عَنْ مُجَاهِدٍ قَالَ دَخَلْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ مَسْجِدًا وَقَدْ أُذِّنَ فِيهِ وَنَحْنُ نُرِيدُ أَنْ نُصَلِّيَ فِيهِ فَثَوَّبَ الْمُؤَذِّنُ فَخَرَجَ عَبْدُ اللَّهِ بْنُ عُمَرَ مِنَ الْمَسْجِدِ وَقَالَ اخْرُجْ بِنَا مِنْ عِنْدِ هَذَا الْمُبْتَدِعِ ‏.‏ وَلَمْ يُصَلِّ فِيهِ ‏.‏ قَالَ وَإِنَّمَا كَرِهَ عَبْدُ اللَّهِ التَّثْوِيبَ الَّذِي أَحْدَثَهُ النَّاسُ بَعْدُ ‏.‏\hadithno{198}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Bilal narrated:"Allah's Messenger said [to me]: 'Do not say the Tathwib for any prayer except the Fajr prayer.'" [He said:] There is something on this topic from Abu Mahdhurah. Abu `Eisa said: We do not know of the Hadith of Bilal except as a narration of Abu Isra'il Al-Mula'i. Abu Isra'il did not hear this Hadith from Al-Hakam bin `Utaibah. He said: He only reported it from Al-Hasan bin `Umarah, from Al-Hakam bin `Utaibah. Abu Isra'il's name is [Isma`il bin Abi Ishaq, and he is not strong according to the people of Hadith. The people of knowledge have differed over the interpretation of At-Tathwib. Some of them say that At-Tathwib is when one says "As-Salatu Khairummin An-Nawm, (prayer is better than sleep)" for the Adhan of Fajr. This is the saying of Ibn Al-Mubarak and Ahmad. Ishaq said something different about At-Tathwib, he said: "[The disliked Tathwib] is something that the people started after the Prophet; when the Mu'adh-dhin calls the Adhan and the people are slow in coming, so between the Adhan and the Iqamah he says: 'Qad Qamatis-Salat, Hayya `Alasalat, Hayya `AlalFalah. (Prayer is ready, come to prayer, come to success.)" [He said:] This Tathwib, which Ishaq mentioned, is the one that the people of knowledge dislike, which they innovated after the Prophet. But Ibn Al-Mubarak and Ahmad explained that At-Tathwib is when the Mu'adh-dhin says: "As-Salatu Khairum minan-Nawm, (prayer is better than sleep)" for the Adhan of Fajr. And this is the correct saying, and it is called At-Tathawwub as well, and this is the one chosen by the people of knowledge, and it is their opinion. It has been reported from `Abdullah bin `Umar that he would say: "As-Salatu Khairum-minan-Nawm, (prayer is better than sleep)" for Fajr. It has been reported from Mujahid that he said: "I entered a Masjid with `Abdullah bin `Umar in which the Adhan was called, and we wanted to pray in it. Then the Mu'adh-dhin said the Tathwib. So `Abdullah bin `Umar left the Masjid and said: 'Let us leave the place of this innovator' And he did not pray in it." [He said:] `Abdullah only disliked the Tathwib that the people invented later on}}
\hadithdefcmd{tirmidhi}{199}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، وَيَعْلَى بْنُ عُبَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادِ بْنِ أَنْعُمٍ الإِفْرِيقِيِّ، عَنْ زِيَادِ بْنِ نُعَيْمٍ الْحَضْرَمِيِّ، عَنْ زِيَادِ بْنِ الْحَارِثِ الصُّدَائِيِّ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أُؤَذِّنَ فِي صَلاَةِ الْفَجْرِ فَأَذَّنْتُ فَأَرَادَ بِلاَلٌ أَنْ يُقِيمَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَخَا صُدَاءٍ قَدْ أَذَّنَ وَمَنْ أَذَّنَ فَهُوَ يُقِيمُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ زِيَادٍ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ الإِفْرِيقِيِّ وَالإِفْرِيقِيُّ هُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ضَعَّفَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَغَيْرُهُ قَالَ أَحْمَدُ لاَ أَكْتُبُ حَدِيثَ الإِفْرِيقِيِّ ‏.‏ قَالَ وَرَأَيْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يُقَوِّي أَمْرَهُ وَيَقُولُ هُوَ مُقَارِبُ الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ أَنَّ مَنْ أَذَّنَ فَهُوَ يُقِيمُ ‏.‏\hadithno{199}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ziyad bin Al-Harith As-Suda'i narrated:"Allah's Messenger ordered me to call the Adhan for the Fajr prayer. I called the Adhan, then Bilal wanted to call the lqamah. Allah's Messenger said: 'Indeed the brother from Suda' has called the Adhan, and whoever calls the Adhan he calls the Iqamah}}
\hadithdefcmd{tirmidhi}{200}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ مُعَاوِيَةَ بْنِ يَحْيَى الصَّدَفِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُؤَذِّنُ إِلاَّ مُتَوَضِّئٌ ‏"‏ ‏.‏\hadithno{200}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "None should call the Adhan except for one with Wudu}}
\hadithdefcmd{tirmidhi}{201}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ لاَ يُنَادِي بِالصَّلاَةِ إِلاَّ مُتَوَضِّئٌ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ لَمْ يَرْفَعْهُ ابْنُ وَهْبٍ وَهُوَ أَصَحُّ مِنْ حَدِيثِ الْوَلِيدِ بْنِ مُسْلِمٍ ‏.‏ وَالزُّهْرِيُّ لَمْ يَسْمَعْ مِنْ أَبِي هُرَيْرَةَ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الأَذَانِ عَلَى غَيْرِ وُضُوءٍ فَكَرِهَهُ بَعْضُ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ الشَّافِعِيُّ وَإِسْحَاقُ ‏.‏ وَرَخَّصَ فِي ذَلِكَ بَعْضُ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَأَحْمَدُ ‏.‏\hadithno{201}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Shihab narrated that :Abu Hurairah said: "None should call (for the prayer except for one with Wudu)}}
\hadithdefcmd{tirmidhi}{202}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا إِسْرَائِيلُ، أَخْبَرَنِي سِمَاكُ بْنُ حَرْبٍ، سَمِعَ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ كَانَ مُؤَذِّنُ رَسُولِ اللَّهِ صلى الله عليه وسلم يُمْهِلُ فَلاَ يُقِيمُ حَتَّى إِذَا رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ خَرَجَ أَقَامَ الصَّلاَةَ حِينَ يَرَاهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرِ بْنِ سَمُرَةَ هُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ إِسْرَائِيلَ عَنْ سِمَاكٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَهَكَذَا قَالَ بَعْضُ أَهْلِ الْعِلْمِ إِنَّ الْمُؤَذِّنَ أَمْلَكُ بِالأَذَانِ وَالإِمَامَ أَمْلَكُ بِالإِقَامَةِ ‏.‏\hadithno{202}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin Samurah narrated:The Mu'adh-dhin of Allah's Messenger would wait and he would not call the Iqamah until he saw the Allah's Messenger had come out, he would call the Iqamah when he saw him}}
\hadithdefcmd{tirmidhi}{203}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ فَكُلُوا وَاشْرَبُوا حَتَّى تَسْمَعُوا تَأْذِينَ ابْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعَائِشَةَ وَأُنَيْسَةَ وَأَنَسٍ وَأَبِي ذَرٍّ وَسَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الأَذَانِ بِاللَّيْلِ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا أَذَّنَ الْمُؤَذِّنُ بِاللَّيْلِ أَجْزَأَهُ وَلاَ يُعِيدُ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا أَذَّنَ بِلَيْلٍ أَعَادَ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ ‏.‏ وَرَوَى حَمَّادُ بْنُ سَلَمَةَ عَنْ أَيُّوبَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَنَّ بِلاَلاً أَذَّنَ بِلَيْلٍ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُنَادِيَ ‏"‏ إِنَّ الْعَبْدَ نَامَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَيْرُ مَحْفُوظٍ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ حَدِيثُ حَمَّادِ بْنِ سَلَمَةَ عَنْ أَيُّوبَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم هُوَ غَيْرُ مَحْفُوظٍ وَأَخْطَأَ فِيهِ حَمَّادُ بْنُ سَلَمَةَ ‏.‏\hadithno{203}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim narrated from his father (Ibn Umar) that :the Prophet said: "Indeed Bilal calls the Adhan in the night, so eat and drink until you hear the Adhan of Ibn Umm Maktum}}
\hadithdefcmd{tirmidhi}{204}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ إِبْرَاهِيمَ بْنِ الْمُهَاجِرِ، عَنْ أَبِي الشَّعْثَاءِ، قَالَ خَرَجَ رَجُلٌ مِنَ الْمَسْجِدِ بَعْدَ مَا أُذِّنَ فِيهِ بِالْعَصْرِ فَقَالَ أَبُو هُرَيْرَةَ أَمَّا هَذَا فَقَدْ عَصَى أَبَا الْقَاسِمِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُثْمَانَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلَى هَذَا الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ أَنْ لاَ يَخْرُجَ أَحَدٌ مِنَ الْمَسْجِدِ بَعْدَ الأَذَانِ إِلاَّ مِنْ عُذْرٍ أَنْ يَكُونَ عَلَى غَيْرِ وُضُوءٍ أَوْ أَمْرٌ لاَ بُدَّ مِنْهُ ‏.‏ وَيُرْوَى عَنْ إِبْرَاهِيمَ النَّخَعِيِّ أَنَّهُ قَالَ يَخْرُجُ مَا لَمْ يَأْخُذِ الْمُؤَذِّنُ فِي الإِقَامَةِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا عِنْدَنَا لِمَنْ لَهُ عُذْرٌ فِي الْخُرُوجِ مِنْهُ ‏.‏ وَأَبُو الشَّعْثَاءِ اسْمُهُ سُلَيْمُ بْنُ أَسْوَدَ وَهُوَ وَالِدُ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ ‏.‏ وَقَدْ رَوَى أَشْعَثُ بْنُ أَبِي الشَّعْثَاءِ هَذَا الْحَدِيثَ عَنْ أَبِيهِ ‏.‏\hadithno{204}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Ash-Sha'tha said:"A man exited the Masjid after the Adhan for Asr had been called. So Abu Hurairah said: 'As for this person, he has indeed disobeyed Abul Qasim}}
\hadithdefcmd{tirmidhi}{205}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَا وَابْنُ عَمٍّ لِي فَقَالَ لَنَا ‏ "‏ إِذَا سَافَرْتُمَا فَأَذِّنَا وَأَقِيمَا وَلْيَؤُمَّكُمَا أَكْبَرُكُمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ اخْتَارُوا الأَذَانَ فِي السَّفَرِ ‏.‏ وَقَالَ بَعْضُهُمْ تُجْزِئُ الإِقَامَةُ إِنَّمَا الأَذَانُ عَلَى مَنْ يُرِيدُ أَنْ يَجْمَعَ النَّاسَ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{205}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Malik bin Al-Huwairih said:"A cousin of mine and I arrived as guests of Allah's Messenger. He said to us: 'When you travel then call the Adhan and Iqamah and let the eldest of you lead the prayer}}
\hadithdefcmd{tirmidhi}{206}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا أَبُو تُمَيْلَةَ، حَدَّثَنَا أَبُو حَمْزَةَ، عَنْ جَابِرٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَذَّنَ سَبْعَ سِنِينَ مُحْتَسِبًا كُتِبَتْ لَهُ بَرَاءَةٌ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَثَوْبَانَ وَمُعَاوِيَةَ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ غَرِيبٌ ‏.‏ وَأَبُو تُمَيْلَةَ اسْمُهُ يَحْيَى بْنُ وَاضِحٍ ‏.‏ وَأَبُو حَمْزَةَ السُّكَّرِيُّ اسْمُهُ مُحَمَّدُ بْنُ مَيْمُونٍ ‏.‏ وَجَابِرُ بْنُ يَزِيدَ الْجُعْفِيُّ ضَعَّفُوهُ تَرَكَهُ يَحْيَى بْنُ سَعِيدٍ وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ لَوْلاَ جَابِرٌ الْجُعْفِيُّ لَكَانَ أَهْلُ الْكُوفَةِ بِغَيْرِ حَدِيثٍ وَلَوْلاَ حَمَّادٌ لَكَانَ أَهْلُ الْكُوفَةِ بِغَيْرِ فِقْهٍ ‏.‏\hadithno{206}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet said: 'Whoever calls the Adhan for seven years, seeking reward for it, salvation from the Fire is written for him}}
\hadithdefcmd{tirmidhi}{207}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الإِمَامُ ضَامِنٌ وَالْمُؤَذِّنُ مُؤْتَمَنٌ اللَّهُمَّ أَرْشِدِ الأَئِمَّةَ وَاغْفِرْ لِلْمُؤَذِّنِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَسَهْلِ بْنِ سَعْدٍ وَعُقْبَةَ بْنِ عَامِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ وَحَفْصُ بْنُ غِيَاثٍ وَغَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى أَسْبَاطُ بْنُ مُحَمَّدٍ عَنِ الأَعْمَشِ قَالَ حُدِّثْتُ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{207}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "The Imam is answerable and the Mu'adh-dhin is entrusted. O Allah! Guide the Imams and pardon the Mu'adh-dhins}}
\hadithdefcmd{tirmidhi}{208}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ‏.‏ قَالَ وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَمِعْتُمُ النِّدَاءَ فَقُولُوا مِثْلَ مَا يَقُولُ الْمُؤَذِّنُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي رَافِعٍ وَأَبِي هُرَيْرَةَ وَأُمِّ حَبِيبَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَبْدِ اللَّهِ بْنِ رَبِيعَةَ وَعَائِشَةَ وَمُعَاذِ بْنِ أَنَسٍ وَمُعَاوِيَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى مَعْمَرٌ وَغَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ مِثْلَ حَدِيثِ مَالِكٍ ‏.‏ وَرَوَى عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ عَنِ الزُّهْرِيِّ هَذَا الْحَدِيثَ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرِوَايَةُ مَالِكٍ أَصَحُّ ‏.‏\hadithno{208}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed narrated that :Allah's Messenger said: "Whenyou hear the call (to prayer) then say the similar to what the Mu'adh-dhin says}}
\hadithdefcmd{tirmidhi}{209}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو زُبَيْدٍ، - وَهُوَ عَبْثَرُ بْنُ الْقَاسِمِ عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، قَالَ إِنَّ مِنْ آخِرِ مَا عَهِدَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنِ اتَّخِذْ مُؤَذِّنًا لاَ يَأْخُذُ عَلَى أَذَانِهِ أَجْرًا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُثْمَانَ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا أَنْ يَأْخُذَ الْمُؤَذِّنُ عَلَى الأَذَانِ أَجْرًا وَاسْتَحَبُّوا لِلْمُؤَذِّنِ أَنْ يَحْتَسِبَ فِي أَذَانِهِ ‏.‏\hadithno{209}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Uthman bin Abi Al-As narrated:"Indeed, amount the last (of orders) Allah's Messenger ordered me with was to employ a Mu'adh-dhin who would not take a wage for his Adhan}}
\hadithdefcmd{tirmidhi}{210}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ الْحُكَيْمِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يَسْمَعُ الْمُؤَذِّنَ وَأَنَا أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ رَضِيتُ بِاللَّهِ رَبًّا وَبِمُحَمَّدٍ رَسُولاً وَبِالإِسْلاَمِ دِينًا غُفِرَ لَهُ ذَنْبُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ عَنْ حُكَيْمِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ ‏.‏\hadithno{210}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sa'd bin Abi Waqqas narrated that :Allah's Messenger said: "Whoever says, when he hears the Mu'adh-dhin: (Wa Ana Ashadu An La Ilaha Illallah, Wahdahu La Sharika Lahu, Wa Anna Muhammadan Abduhu Wa Rasuluhu, Radittu Billahi Rabban Wa Bil-Islam Dinan, Wa Bi Muhammadin Rasulan) 'I too testify that none has the right to be worshiped but Allah, Alone without partners, and that Muhammad is His slave and Messenger, I am pleased with Allah as my Lord, with Islam as my religion and Muhammad as a Messenger.' - Allah will pardon his sins for him}}
\hadithdefcmd{tirmidhi}{211}{حَدَّثَنَا مُحَمَّدُ بْنُ سَهْلِ بْنِ عَسْكَرٍ الْبَغْدَادِيُّ، وَإِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالاَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ الْحِمْصِيُّ، حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ حِينَ يَسْمَعُ النِّدَاءَ اللَّهُمَّ رَبَّ هَذِهِ الدَّعْوَةِ التَّامَّةِ وَالصَّلاَةِ الْقَائِمَةِ آتِ مُحَمَّدًا الْوَسِيلَةَ وَالْفَضِيلَةَ وَابْعَثْهُ مَقَامًا مَحْمُودًا الَّذِي وَعَدْتَهُ إِلاَّ حَلَّتْ لَهُ الشَّفَاعَةُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ مُحَمَّدِ بْنِ الْمُنْكَدِرِ لاَ نَعْلَمُ أَحَدًا رَوَاهُ غَيْرَ شُعَيْبِ بْنِ أَبِي حَمْزَةَ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ ‏.‏ وَأَبُو حَمْزَةَ اسْمُهُ دِينَارٌ ‏.‏\hadithno{211}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Jabir bin Abdullah narrated that :Allah's Messenger said: "Whoever says, when he hears the call: (Allahumma, rabba hadhihidda 'watit-tammati was Salatilqa'imah, ati Muhammadanil wasilata wal-Fadilata, wab'athhu Maqamun Mahmudan alladhi wa'adtahu) 'O Allah! Lord of this perfect call and established prayer, grant Muhammad Al-Wasilah and Al-Fadilah, and raise him to the praised station that you promised him' - then intercession on the Day of Resurrection is made lawful for him}}
\hadithdefcmd{tirmidhi}{212}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، وَعَبْدُ الرَّزَّاقِ، وَأَبُو أَحْمَدَ وَأَبُو نُعَيْمٍ قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِي إِيَاسٍ، مُعَاوِيَةَ بْنِ قُرَّةَ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الدُّعَاءُ لاَ يُرَدُّ بَيْنَ الأَذَانِ وَالإِقَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ أَبُو إِسْحَاقَ الْهَمْدَانِيُّ عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ هَذَا ‏.‏\hadithno{212}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that :Allah's Messenger said: "The supplication made between the Adhan and Iqamah is not rejected}}
\hadithdefcmd{tirmidhi}{213}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ فُرِضَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ الصَّلَوَاتُ خَمْسِينَ ثُمَّ نُقِصَتْ حَتَّى جُعِلَتْ خَمْسًا ثُمَّ نُودِيَ يَا مُحَمَّدُ إِنَّهُ لاَ يُبَدَّلُ الْقَوْلُ لَدَىَّ وَإِنَّ لَكَ بِهَذِهِ الْخَمْسِ خَمْسِينَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُبَادَةَ بْنِ الصَّامِتِ وَطَلْحَةَ بْنِ عُبَيْدِ اللَّهِ وَأَبِي ذَرٍّ وَأَبِي قَتَادَةَ وَمَالِكِ بْنِ صَعْصَعَةَ وَأَبِي سَعِيدٍ الْخُدْرِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{213}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated:"On the Night of Isra, fifty prayers were made obligatory upon the Prophet. Then it was decreased until it was made five. Then it was called out: 'O Muhammad! Indeed My Word does not change; these five prayers will be recorded for you as fifty}}
\hadithdefcmd{tirmidhi}{214}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّلَوَاتُ الْخَمْسُ وَالْجُمُعَةُ إِلَى الْجُمُعَةِ كَفَّارَاتٌ لِمَا بَيْنَهُنَّ مَا لَمْ تُغْشَ الْكَبَائِرُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَنَسٍ وَحَنْظَلَةَ الأُسَيِّدِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{214}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "The five prayers, and Al-Jumuah (the Friday prayer) to Al-Jumuah are atonement for what is between them, as long as the major sins have not been committed}}
\hadithdefcmd{tirmidhi}{215}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَلاَةُ الْجَمَاعَةِ تَفْضُلُ عَلَى صَلاَةِ الرَّجُلِ وَحْدَهُ بِسَبْعٍ وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأُبَىِّ بْنِ كَعْبٍ وَمُعَاذِ بْنِ جَبَلٍ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى نَافِعٌ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ تَفْضُلُ صَلاَةُ الْجَمِيعِ عَلَى صَلاَةِ الرَّجُلِ وَحْدَهُ بِسَبْعٍ وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَعَامَّةُ مَنْ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم إِنَّمَا قَالُوا ‏"‏ خَمْسٍ وَعِشْرِينَ ‏"‏ ‏.‏ إِلاَّ ابْنَ عُمَرَ فَإِنَّهُ قَالَ ‏"‏ بِسَبْعٍ وَعِشْرِينَ ‏"‏ ‏.‏\hadithno{215}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that :Allah's Messenger said: "Salat in congregation is twenty-seven degrees more virtuous than a man's Salat alone}}
\hadithdefcmd{tirmidhi}{216}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ صَلاَةَ الرَّجُلِ فِي الْجَمَاعَةِ تَزِيدُ عَلَى صَلاَتِهِ وَحْدَهُ بِخَمْسَةٍ وَعِشْرِينَ جُزْءًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{216}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Indeed a man's Salat in the congregation is increased by twenty five rewards over his Salat alone}}
\hadithdefcmd{tirmidhi}{217}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ آمُرَ فِتْيَتِي أَنْ يَجْمَعُوا حُزَمَ الْحَطَبِ ثُمَّ آمُرَ بِالصَّلاَةِ فَتُقَامَ ثُمَّ أُحَرِّقَ عَلَى أَقْوَامٍ لاَ يَشْهَدُونَ الصَّلاَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي الدَّرْدَاءِ وَابْنِ عَبَّاسٍ وَمُعَاذِ بْنِ أَنَسٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمْ قَالُوا مَنْ سَمِعَ النِّدَاءَ فَلَمْ يُجِبْ فَلاَ صَلاَةَ لَهُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ هَذَا عَلَى التَّغْلِيظِ وَالتَّشْدِيدِ وَلاَ رُخْصَةَ لأَحَدٍ فِي تَرْكِ الْجَمَاعَةِ إِلاَّ مِنْ عُذْرٍ ‏.‏\hadithno{217}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "I was about to order my boys to collect bundles of firewood, then order Salat to be held, then burn (the homes) of the people who did not attend the Salat}}
\hadithdefcmd{tirmidhi}{218}{قَالَ مُجَاهِدٌ وَسُئِلَ ابْنُ عَبَّاسٍ عَنْ رَجُلٍ، يَصُومُ النَّهَارَ وَيَقُومُ اللَّيْلَ لاَ يَشْهَدُ جُمُعَةً وَلاَ جَمَاعَةً قَالَ هُوَ فِي النَّارِ ‏.‏ قَالَ حَدَّثَنَا بِذَلِكَ هَنَّادٌ حَدَّثَنَا الْمُحَارِبِيُّ عَنْ لَيْثٍ عَنْ مُجَاهِدٍ ‏.‏ قَالَ وَمَعْنَى الْحَدِيثِ أَنْ لاَ يَشْهَدَ الْجَمَاعَةَ وَالْجُمُعَةَ رَغْبَةً عَنْهَا وَاسْتِخْفَافًا بِحَقِّهَا وَتَهَاوُنًا بِهَا ‏.‏\hadithno{218}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Mujahid said:"Ibn Abbas was asked about a man who fasted during the day and stood (in prayers) during the night, but he did not attend the Friday prayer nor congregational prayer. He replied: 'He is in the Fire}}
\hadithdefcmd{tirmidhi}{219}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يَعْلَى بْنُ عَطَاءٍ، حَدَّثَنَا جَابِرُ بْنُ يَزِيدَ بْنِ الأَسْوَدِ الْعَامِرِيُّ، عَنْ أَبِيهِ، قَالَ شَهِدْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم حَجَّتَهُ فَصَلَّيْتُ مَعَهُ صَلاَةَ الصُّبْحِ فِي مَسْجِدِ الْخَيْفِ ‏.‏ قَالَ فَلَمَّا قَضَى صَلاَتَهُ وَانْحَرَفَ إِذَا هُوَ بِرَجُلَيْنِ فِي أُخْرَى الْقَوْمِ لَمْ يُصَلِّيَا مَعَهُ فَقَالَ ‏"‏ عَلَىَّ بِهِمَا ‏"‏ ‏.‏ فَجِيءَ بِهِمَا تُرْعَدُ فَرَائِصُهُمَا فَقَالَ ‏"‏ مَا مَنَعَكُمَا أَنْ تُصَلِّيَا مَعَنَا ‏"‏ ‏.‏ فَقَالاَ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا قَدْ صَلَّيْنَا فِي رِحَالِنَا ‏.‏ قَالَ فَلاَ تَفْعَلاَ إِذَا صَلَّيْتُمَا فِي رِحَالِكُمَا ثُمَّ أَتَيْتُمَا مَسْجِدَ جَمَاعَةٍ فَصَلِّيَا مَعَهُمْ فَإِنَّهَا لَكُمَا نَافِلَةٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مِحْجَنٍ الدِّيلِيِّ وَيَزِيدَ بْنِ عَامِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ يَزِيدَ بْنِ الأَسْوَدِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ قَالُوا إِذَا صَلَّى الرَّجُلُ وَحْدَهُ ثُمَّ أَدْرَكَ الْجَمَاعَةَ فَإِنَّهُ يُعِيدُ الصَّلَوَاتِ كُلَّهَا فِي الْجَمَاعَةِ وَإِذَا صَلَّى الرَّجُلُ الْمَغْرِبَ وَحْدَهُ ثُمَّ أَدْرَكَ الْجَمَاعَةَ قَالُوا فَإِنَّهُ يُصَلِّيهَا مَعَهُمْ وَيَشْفَعُ بِرَكْعَةٍ ‏.‏ وَالَّتِي صَلَّى وَحْدَهُ هِيَ الْمَكْتُوبَةُ عِنْدَهُمْ ‏.‏\hadithno{219}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir hin Yazid hin Al-Aswad [Al-Amir] narrated that his father said:"I attended Hajj with the Prophet. I prayed the Subh (Fajr) prayer with him in Masjid AI-Khaif." He said: "When the Prophet finished, he turned (from the Qiblah) and saw two men at the back of the people who had not prayed with him. He said, 'Bring them to me.' So I brought then while they were shuddering with fear. He said: 'What prevented you from praying with us?" They said: 'O Messenger of Allah!' We prayed at our camp.' So he said: 'Do not do that; when you pray in your camp then you come to a Masjid with a congregation, then pray with them. That will be a voluntary prayer for you}}
\hadithdefcmd{tirmidhi}{220}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ سُلَيْمَانَ النَّاجِيِّ الْبَصْرِيِّ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، قَالَ جَاءَ رَجُلٌ وَقَدْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَيُّكُمْ يَتَّجِرُ عَلَى هَذَا ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَصَلَّى مَعَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي أُمَامَةَ وَأَبِي مُوسَى وَالْحَكَمِ بْنِ عُمَيْرٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ مِنَ التَّابِعِينَ قَالُوا لاَ بَأْسَ أَنْ يُصَلِّيَ الْقَوْمُ جَمَاعَةً فِي مَسْجِدٍ قَدْ صُلِّيَ فِيهِ جَمَاعَةً ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ آخَرُونَ مِنْ أَهْلِ الْعِلْمِ يُصَلُّونَ فُرَادَى ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ وَابْنُ الْمُبَارَكِ وَمَالِكٌ وَالشَّافِعِيُّ يَخْتَارُونَ الصَّلاَةَ فُرَادَى ‏.‏ وَسُلَيْمَانُ النَّاجِيُّ بَصْرِيٌّ وَيُقَالُ سُلَيْمَانُ بْنُ الأَسْوَدِ ‏.‏ وَأَبُو الْمُتَوَكِّلِ اسْمُهُ عَلِيُّ بْنُ دَاوُدَ ‏.‏\hadithno{220}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed narrated:"A man came when Allah's Messenger had already prayed, so he said: 'Which of you will give some reward to this person?' So a man stood to pray with him}}
\hadithdefcmd{tirmidhi}{221}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، حَدَّثَنَا سُفْيَانُ، عَنْ عُثْمَانَ بْنِ حَكِيمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَهِدَ الْعِشَاءَ فِي جَمَاعَةٍ كَانَ لَهُ قِيَامُ نِصْفِ لَيْلَةٍ وَمَنْ صَلَّى الْعِشَاءَ وَالْفَجْرَ فِي جَمَاعَةٍ كَانَ لَهُ كَقِيَامِ لَيْلَةٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَعُمَارَةَ بْنِ رُوَيْبَةَ وَجُنْدَبِ بْنِ عَبْدِ اللَّهِ بْنِ سُفْيَانَ الْبَجَلِيِّ وَأُبَىِّ بْنِ كَعْبٍ وَأَبِي مُوسَى وَبُرَيْدَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُثْمَانَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ عَنْ عُثْمَانَ مَوْقُوفًا وَرُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عُثْمَانَ مَرْفُوعًا ‏.‏\hadithno{221}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Uthman bin Affan narrated that :Allah's Messenger said: "Whoever attends Isha (prayer) in congregation, then he has (the reward as if he had) stood half of the night. And whoever prays Isha and Fajr in congregation, then he has (the reward as if he had) spend the entire night standing (in prayer)}}
\hadithdefcmd{tirmidhi}{222}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنِ الْحَسَنِ، عَنْ جُنْدَبِ بْنِ سُفْيَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى الصُّبْحَ فَهُوَ فِي ذِمَّةِ اللَّهِ فَلاَ تُخْفِرُوا اللَّهَ فِي ذِمَّتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{222}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jundub bin Sufyan narrated that :the Prophet said: "Whoever prays the Subh then he is under the protection of Allah's covenant, so do not be treacherous with Allah in his covenant}}
\hadithdefcmd{tirmidhi}{223}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ أَبُو غَسَّانَ الْعَنْبَرِيُّ، عَنْ إِسْمَاعِيلَ الْكَحَّالِ، عَنْ عَبْدِ اللَّهِ بْنِ أَوْسٍ الْخُزَاعِيِّ، عَنْ بُرَيْدَةَ الأَسْلَمِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَشِّرِ الْمَشَّائِينَ فِي الظُّلَمِ إِلَى الْمَسَاجِدِ بِالنُّورِ التَّامِّ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مَرْفُوعٌ هُوَ صَحِيحٌ مُسْنَدٌ وَمَوْقُوفٌ إِلَى أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يُسْنَدْ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{223}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Buraidah Al-Aslami narrated that :the Prophet said: "Give glad tiding to those who walk to the Masajid in the dark; of a complete light on the Day of Resurrection}}
\hadithdefcmd{tirmidhi}{224}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ صُفُوفِ الرِّجَالِ أَوَّلُهَا وَشَرُّهَا آخِرُهَا وَخَيْرُ صُفُوفِ النِّسَاءِ آخِرُهَا وَشَرُّهَا أَوَّلُهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَابْنِ عَبَّاسٍ وَابْنِ عُمَرَ وَأَبِي سَعِيدٍ وَأُبَىٍّ وَعَائِشَةَ وَالْعِرْبَاضِ بْنِ سَارِيَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَسْتَغْفِرُ لِلصَّفِّ الأَوَّلِ ثَلاَثًا وَلِلثَّانِي مَرَّةً ‏.‏\hadithno{224}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "The best rows for the men are the first of them, and the worst are the last of them. And the best rows for the women are the last of them, and the worst are the first of them}}
\hadithdefcmd{tirmidhi}{225}{وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ النَّاسَ يَعْلَمُونَ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا عَلَيْهِ لاَسْتَهَمُوا عَلَيْهِ ‏"‏ ‏.‏ قَالَ حَدَّثَنَا بِذَلِكَ إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ حَدَّثَنَا مَعْنٌ حَدَّثَنَا مَالِكٌ عَنْ سُمَىٍّ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{225}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrator not mentioned:And the Prophet said: "If the people knew what (reward) is in the call (Adhan) and the first row, and they found no other way to get that except drawing lots, then they would draw lots}}
\hadithdefcmd{tirmidhi}{226}{وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، نَحْوَهُ ‏.‏\hadithno{226}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrator not mentioned:A Similar narration}}
\hadithdefcmd{tirmidhi}{227}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَوِّي صُفُوفَنَا فَخَرَجَ يَوْمًا فَرَأَى رَجُلاً خَارِجًا صَدْرُهُ عَنِ الْقَوْمِ فَقَالَ ‏"‏ لَتُسَوُّنَّ صُفُوفَكُمْ أَوْ لَيُخَالِفَنَّ اللَّهُ بَيْنَ وُجُوهِكُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ سَمُرَةَ وَالْبَرَاءِ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ النُّعْمَانِ بْنِ بَشِيرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مِنْ تَمَامِ الصَّلاَةِ إِقَامَةُ الصَّفِّ ‏"‏ ‏.‏ وَرُوِيَ عَنْ عُمَرَ أَنَّهُ كَانَ يُوَكِّلُ رِجَالاً بِإِقَامَةِ الصُّفُوفِ فَلاَ يُكَبِّرُ حَتَّى يُخْبَرَ أَنَّ الصُّفُوفَ قَدِ اسْتَوَتْ ‏.‏ وَرُوِيَ عَنْ عَلِيٍّ وَعُثْمَانَ أَنَّهُمَا كَانَا يَتَعَاهَدَانِ ذَلِكَ وَيَقُولاَنِ اسْتَوُوا ‏.‏ وَكَانَ عَلِيٌّ يَقُولُ تَقَدَّمْ يَا فُلاَنُ تَأَخَّرْ يَا فُلاَنُ ‏.‏\hadithno{227}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{An-Nu'man bin Bashir said:"Allah's Messenger would straighten our lines. One day he came out and saw a man whose chest was protruding from the people, so he said: 'You must straighten your lines, or Allah will cause disagreement to occur among your faces}}
\hadithdefcmd{tirmidhi}{228}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لِيَلِيَنِي مِنْكُمْ أُولُو الأَحْلاَمِ وَالنُّهَى ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ وَلاَ تَخْتَلِفُوا فَتَخْتَلِفَ قُلُوبُكُمْ وَإِيَّاكُمْ وَهَيْشَاتِ الأَسْوَاقِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ وَأَبِي مَسْعُودٍ وَأَبِي سَعِيدٍ وَالْبَرَاءِ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يُعْجِبُهُ أَنْ يَلِيَهُ الْمُهَاجِرُونَ وَالأَنْصَارُ لِيَحْفَظُوا عَنْهُ ‏.‏ قَالَ وَخَالِدٌ الْحَذَّاءُ هُوَ خَالِدُ بْنُ مِهْرَانَ يُكْنَى أَبَا الْمُنَازِلِ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ يُقَالُ إِنَّ خَالِدًا الْحَذَّاءَ مَا حَذَا نَعْلاً قَطُّ إِنَّمَا كَانَ يَجْلِسُ إِلَى حَذَّاءٍ فَنُسِبَ إِلَيْهِ ‏.‏ قَالَ وَأَبُو مَعْشَرٍ اسْمُهُ زِيَادُ بْنُ كُلَيْبٍ ‏.‏\hadithno{228}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah (Ibn Masud) narrated that :the Prophet said: "Let those among you with understanding and reason be close to me, then those after them, then those after them. And do not separate or dissention will occur among your hearts, and beware of the commotion of the markets}}
\hadithdefcmd{tirmidhi}{229}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ هَانِئِ بْنِ عُرْوَةَ الْمُرَادِيِّ، عَنْ عَبْدِ الْحَمِيدِ بْنِ مَحْمُودٍ، قَالَ صَلَّيْنَا خَلْفَ أَمِيرٍ مِنَ الأُمَرَاءِ فَاضْطَرَّنَا النَّاسُ فَصَلَّيْنَا بَيْنَ السَّارِيَتَيْنِ فَلَمَّا صَلَّيْنَا قَالَ أَنَسُ بْنُ مَالِكٍ كُنَّا نَتَّقِي هَذَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَفِي الْبَابِ عَنْ قُرَّةَ بْنِ إِيَاسٍ الْمُزَنِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مَنْ أَهْلِ الْعِلْمِ أَنْ يُصَفَّ بَيْنَ السَّوَارِي ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ فِي ذَلِكَ ‏.‏\hadithno{229}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdul-Hamid bin Mahmud said:"We prayed behind one of the Amirs, the people compelled us such that we prayed between two columns. When we had prayed, Anas bin Malik said: 'We would be prevented from this during the time of Allah's Messenger}}
\hadithdefcmd{tirmidhi}{230}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، قَالَ أَخَذَ زِيَادُ بْنُ أَبِي الْجَعْدِ بِيَدِي وَنَحْنُ بِالرَّقَّةِ فَقَامَ بِي عَلَى شَيْخٍ يُقَالُ لَهُ وَابِصَةُ بْنُ مَعْبَدٍ مِنْ بَنِي أَسَدٍ فَقَالَ زِيَادٌ حَدَّثَنِي هَذَا الشَّيْخُ أَنَّ رَجُلاً صَلَّى خَلْفَ الصَّفِّ وَحْدَهُ وَالشَّيْخُ يَسْمَعُ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُعِيدَ الصَّلاَةَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيِّ بْنِ شَيْبَانَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ وَابِصَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ أَنْ يُصَلِّيَ الرَّجُلُ خَلْفَ الصَّفِّ وَحْدَهُ وَقَالُوا يُعِيدُ إِذَا صَلَّى خَلْفَ الصَّفِّ وَحْدَهُ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَدْ قَالَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ يُجْزِئُهُ إِذَا صَلَّى خَلْفَ الصَّفِّ وَحْدَهُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ ‏.‏ وَقَدْ ذَهَبَ قَوْمٌ مِنْ أَهْلِ الْكُوفَةِ إِلَى حَدِيثِ وَابِصَةَ بْنِ مَعْبَدٍ أَيْضًا قَالُوا مَنْ صَلَّى خَلْفَ الصَّفِّ وَحْدَهُ يُعِيدُ ‏.‏ مِنْهُمْ حَمَّادُ بْنُ أَبِي سُلَيْمَانَ وَابْنُ أَبِي لَيْلَى وَوَكِيعٌ ‏.‏ وَرَوَى حَدِيثَ حُصَيْنٍ عَنْ هِلاَلِ بْنِ يِسَافٍ غَيْرُ وَاحِدٍ مِثْلَ رِوَايَةِ أَبِي الأَحْوَصِ عَنْ زِيَادِ بْنِ أَبِي الْجَعْدِ عَنْ وَابِصَةَ بْنِ مَعْبَدٍ ‏.‏ وَفِي حَدِيثِ حُصَيْنٍ مَا يَدُلُّ عَلَى أَنَّ هِلاَلاً قَدْ أَدْرَكَ وَابِصَةَ وَاخْتَلَفَ أَهْلُ الْحَدِيثِ فِي هَذَا فَقَالَ بَعْضُهُمْ حَدِيثُ عَمْرِو بْنِ مُرَّةَ عَنْ هِلاَلِ بْنِ يِسَافٍ عَنْ عَمْرِو بْنِ رَاشِدٍ عَنْ وَابِصَةَ بْنِ مَعْبَدٍ أَصَحُّ ‏.‏ وَقَالَ بَعْضُهُمْ حَدِيثُ حُصَيْنٍ عَنْ هِلاَلِ بْنِ يِسَافٍ عَنْ زِيَادِ بْنِ أَبِي الْجَعْدِ عَنْ وَابِصَةَ بْنِ مَعْبَدٍ أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا عِنْدِي أَصَحُّ مِنْ حَدِيثِ عَمْرِو بْنِ مُرَّةَ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ حَدِيثِ هِلاَلِ بْنِ يِسَافٍ عَنْ زِيَادِ بْنِ أَبِي الْجَعْدِ عَنْ وَابِصَةَ ‏.‏\hadithno{230}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hilal bin Yasar said:"Ziyad bin Abi Al-Ja'd took me by the hand while we were in Ar Raqqah, he made me stand before a Shaikh who was called Wabisah bin Ma'bad, from Bani Asad. Ziyad said: 'This Shaikh narrated to me that a prayed alone behind the row' - and the Shaikh was listening - 'so Allah's Messenger ordered him to repeat the Salat}}
\hadithdefcmd{tirmidhi}{231}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عَمْرِو بْنِ رَاشِدٍ، عَنْ وَابِصَةَ بْنِ مَعْبَدٍ، أَنَّ رَجُلاً، صَلَّى خَلْفَ الصَّفِّ وَحْدَهُ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُعِيدَ الصَّلاَةَ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ إِذَا صَلَّى الرَّجُلُ خَلْفَ الصَّفِّ وَحْدَهُ فَإِنَّهُ يُعِيدُ ‏.‏\hadithno{231}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Wabisah bin Ma'bad narrated:"A man prayed alone behind the row s the Prophet ordered him to repeat the Salat}}
\hadithdefcmd{tirmidhi}{232}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَقُمْتُ عَنْ يَسَارِهِ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَأْسِي مِنْ وَرَائِي فَجَعَلَنِي عَنْ يَمِينِهِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ قَالُوا إِذَا كَانَ الرَّجُلُ مَعَ الإِمَامِ يَقُومُ عَنْ يَمِينِ الإِمَامِ ‏.‏\hadithno{232}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"I prayed with the Prophet one night. I stood at his left, so Allah's Messenger took me by my head, from behind me, to put me on his right (side)}}
\hadithdefcmd{tirmidhi}{233}{حَدَّثَنَا بُنْدَارٌ، مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كُنَّا ثَلاَثَةً أَنْ يَتَقَدَّمَنَا أَحَدُنَا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَجَابِرٍ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ قَالُوا إِذَا كَانُوا ثَلاَثَةً قَامَ رَجُلاَنِ خَلْفَ الإِمَامِ ‏.‏ وَرُوِيَ عَنِ ابْنِ مَسْعُودٍ أَنَّهُ صَلَّى بِعَلْقَمَةَ وَالأَسْوَدِ فَأَقَامَ أَحَدَهُمَا عَنْ يَمِينِهِ وَالآخَرَ عَنْ يَسَارِهِ وَرَوَاهُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ النَّاسِ فِي إِسْمَاعِيلَ بْنِ مُسْلِمٍ الْمَكِّيِّ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{233}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Samurah bin Jundub narrated:"Allah's Messenger ordered us that when we were three, then one of us should stand forward}}
\hadithdefcmd{tirmidhi}{234}{حَدَّثَنَا إِسْحَاقُ الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ جَدَّتَهُ، مُلَيْكَةَ دَعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَتْهُ فَأَكَلَ مِنْهُ ثُمَّ قَالَ ‏"‏ قُومُوا فَلْنُصَلِّ بِكُمْ ‏"‏ ‏.‏ قَالَ أَنَسٌ فَقُمْتُ إِلَى حَصِيرٍ لَنَا قَدِ اسْوَدَّ مِنْ طُولِ مَا لُبِسَ فَنَضَحْتُهُ بِالْمَاءِ فَقَامَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفَفْتُ عَلَيْهِ أَنَا وَالْيَتِيمُ وَرَاءَهُ وَالْعَجُوزُ مِنْ وَرَائِنَا فَصَلَّى بِنَا رَكْعَتَيْنِ ثُمَّ انْصَرَفَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ قَالُوا إِذَا كَانَ مَعَ الإِمَامِ رَجُلٌ وَامْرَأَةٌ قَامَ الرَّجُلُ عَنْ يَمِينِ الإِمَامِ وَالْمَرْأَةُ خَلْفَهُمَا ‏.‏ وَقَدِ احْتَجَّ بَعْضُ النَّاسِ بِهَذَا الْحَدِيثِ فِي إِجَازَةِ الصَّلاَةِ إِذَا كَانَ الرَّجُلُ خَلْفَ الصَّفِّ وَحْدَهُ وَقَالُوا إِنَّ الصَّبِيَّ لَمْ تَكُنْ لَهُ صَلاَةٌ وَكَأَنَّ أَنَسًا كَانَ خَلْفَ النَّبِيِّ صلى الله عليه وسلم وَحْدَهُ فِي الصَّفِّ ‏.‏ وَلَيْسَ الأَمْرُ عَلَى مَا ذَهَبُوا إِلَيْهِ لأَنَّ النَّبِيَّ صلى الله عليه وسلم أَقَامَهُ مَعَ الْيَتِيمِ خَلْفَهُ فَلَوْلاَ أَنَّ النَّبِيَّ صلى الله عليه وسلم جَعَلَ لِلْيَتِيمِ صَلاَةً لَمَا أَقَامَ الْيَتِيمَ مَعَهُ وَلأَقَامَهُ عَنْ يَمِينِهِ ‏.‏ وَقَدْ رُوِيَ عَنْ مُوسَى بْنِ أَنَسٍ عَنْ أَنَسٍ أَنَّهُ صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم فَأَقَامَهُ عَنْ يَمِينِهِ ‏.‏ وَفِي هَذَا الْحَدِيثِ دَلاَلَةٌ أَنَّهُ إِنَّمَا صَلَّى تَطَوُّعًا أَرَادَ إِدْخَالَ الْبَرَكَةِ عَلَيْهِمْ ‏.‏\hadithno{234}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"My grandmother Mutalikah invited Allah's Messenger to a meal that she prepared. He ate from it, then said: 'Stand so tht we may lead you in prayer.'" He said: "I got a Hasir of our which had become dark because of prolonged use, so I washed it with water. Allah's Messenger stood on it, and the orphan and I aligned behind him and the only lady stood behind us. He (Allah's Messenger) led us in two Rak'ah of prayer and then left}}
\hadithdefcmd{tirmidhi}{235}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، قَالَ وَحَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ الزُّبَيْدِيِّ، عَنْ أَوْسِ بْنِ ضَمْعَجٍ، قَالَ سَمِعْتُ أَبَا مَسْعُودٍ الأَنْصَارِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَؤُمُّ الْقَوْمَ أَقْرَؤُهُمْ لِكِتَابِ اللَّهِ فَإِنْ كَانُوا فِي الْقِرَاءَةِ سَوَاءً فَأَعْلَمُهُمْ بِالسُّنَّةِ فَإِنْ كَانُوا فِي السُّنَّةِ سَوَاءً فَأَقْدَمُهُمْ هِجْرَةً فَإِنْ كَانُوا فِي الْهِجْرَةِ سَوَاءً فَأَكْبَرُهُمْ سِنًّا وَلاَ يُؤَمُّ الرَّجُلُ فِي سُلْطَانِهِ وَلاَ يُجْلَسُ عَلَى تَكْرِمَتِهِ فِي بَيْتِهِ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏ قَالَ مَحْمُودُ بْنُ غَيْلاَنَ قَالَ ابْنُ نُمَيْرٍ فِي حَدِيثِهِ ‏"‏ أَقْدَمُهُمْ سِنًّا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأَنَسِ بْنِ مَالِكٍ وَمَالِكِ بْنِ الْحُوَيْرِثِ وَعَمْرِو بْنِ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالُوا أَحَقُّ النَّاسِ بِالإِمَامَةِ أَقْرَؤُهُمْ لِكِتَابِ اللَّهِ وَأَعْلَمُهُمْ بِالسُّنَّةِ ‏.‏ وَقَالُوا صَاحِبُ الْمَنْزِلِ أَحَقُّ بِالإِمَامَةِ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا أَذِنَ صَاحِبُ الْمَنْزِلِ لِغَيْرِهِ فَلاَ بَأْسَ أَنْ يُصَلِّيَ بِهِ ‏.‏ وَكَرِهَهُ بَعْضُهُمْ وَقَالُوا السُّنَّةُ أَنْ يُصَلِّيَ صَاحِبُ الْبَيْتِ ‏.‏ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ وَقَوْلُ النَّبِيِّ صلى الله عليه وسلم ‏"‏ وَلاَ يُؤَمُّ الرَّجُلُ فِي سُلْطَانِهِ وَلاَ يُجْلَسُ عَلَى تَكْرِمَتِهِ فِي بَيْتِهِ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏ فَإِذَا أَذِنَ فَأَرْجُو أَنَّ الإِذْنَ فِي الْكُلِّ وَلَمْ يَرَ بِهِ بَأْسًا إِذَا أَذِنَ لَهُ أَنْ يُصَلِّيَ بِهِ ‏.‏\hadithno{235}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Mas'ud narrated that :Allah's Messenger said: "The one who recites most of the Book of Allah is to lead the people (in prayers). If they are equal in recitation, then the most knowledgeable in the Sunnah among them. If they are equal regarding the Sunnah, then the earliest of them to emigrate. If they are equal in their emigration then the eldest among them. And a man is not to be led in prayer in the place of his authority, and his spot of esteem in his home is not to be sat on without his permission}}
\hadithdefcmd{tirmidhi}{236}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَمَّ أَحَدُكُمُ النَّاسَ فَلْيُخَفِّفْ فَإِنَّ فِيهِمُ الصَّغِيرَ وَالْكَبِيرَ وَالضَّعِيفَ وَالْمَرِيضَ فَإِذَا صَلَّى وَحْدَهُ فَلْيُصَلِّ كَيْفَ شَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَدِيِّ بْنِ حَاتِمٍ وَأَنَسٍ وَجَابِرِ بْنِ سَمُرَةَ وَمَالِكِ بْنِ عَبْدِ اللَّهِ وَأَبِي وَاقِدٍ وَعُثْمَانَ بْنِ أَبِي الْعَاصِ وَأَبِي مَسْعُودٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ اخْتَارُوا أَنْ لاَ يُطِيلَ الإِمَامُ الصَّلاَةَ مَخَافَةَ الْمَشَقَّةِ عَلَى الضَّعِيفِ وَالْكَبِيرِ وَالْمَرِيضِ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو الزِّنَادِ اسْمُهُ عَبْدُ اللَّهِ بْنُ ذَكْوَانَ ‏.‏ وَالأَعْرَجُ هُوَ عَبْدُ الرَّحْمَنِ بْنُ هُرْمُزَ الْمَدِينِيُّ وَيُكْنَى أَبَا دَاوُدَ ‏.‏\hadithno{236}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "When one of you leads the people in prayer then let him be brief, for indeed here are among them the young and the old, the weak and the ill. When one of you prays alone, then let him pray as he wishes}}
\hadithdefcmd{tirmidhi}{237}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَخَفِّ النَّاسِ صَلاَةً فِي تَمَامٍ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاسْمُ أَبِي عَوَانَةَ وَضَّاحٌ ‏.‏ قَالَ أَبُو عِيسَى سَأَلْتُ قُتَيْبَةَ قُلْتُ أَبُو عَوَانَةَ مَا اسْمُهُ قَالَ وَضَّاحٌ ‏.‏ قُلْتُ ابْنُ مَنْ قَالَ لاَ أَدْرِي كَانَ عَبْدًا لاِمْرَأَةٍ بِالْبَصْرَةِ ‏.‏\hadithno{237}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas [bin Malik] narrated:"Allah's Messenger was among the lightest of people in Salat with its completeness}}
\hadithdefcmd{tirmidhi}{238}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنْ أَبِي سُفْيَانَ، طَرِيفٍ السَّعْدِيِّ عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مِفْتَاحُ الصَّلاَةِ الطُّهُورُ وَتَحْرِيمُهَا التَّكْبِيرُ وَتَحْلِيلُهَا التَّسْلِيمُ وَلاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بــ‏"‏الْحَمْدُ‏"‏ وَسُورَةٍ \_ فِي فَرِيضَةٍ أَوْ غَيْرِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ ‏.‏ قَالَ وَحَدِيثُ عَلِيِّ بْنِ أَبِي طَالِبٍ فِي هَذَا أَجْوَدُ إِسْنَادًا وَأَصَحُّ مِنْ حَدِيثِ أَبِي سَعِيدٍ وَقَدْ كَتَبْنَاهُ فِي أَوَّلِ كِتَابِ الْوُضُوءِ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ أَنَّ تَحْرِيمَ الصَّلاَةِ التَّكْبِيرُ وَلاَ يَكُونُ الرَّجُلُ دَاخِلاً فِي الصَّلاَةِ إِلاَّ بِالتَّكْبِيرِ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ أَبَا بَكْرٍ مُحَمَّدَ بْنَ أَبَانَ مُسْتَمْلِيَ وَكِيعٍ يَقُولُ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ مَهْدِيٍّ يَقُولُ لَوِ افْتَتَحَ الرَّجُلُ الصَّلاَةَ بِسَبْعِينَ اسْمًا مِنْ أَسْمَاءِ اللَّهِ وَلَمْ يُكَبِّرْ لَمْ يُجْزِهِ وَإِنْ أَحْدَثَ قَبْلَ أَنْ يُسَلِّمَ أَمَرْتُهُ أَنْ يَتَوَضَّأَ ثُمَّ يَرْجِعَ إِلَى مَكَانِهِ فَيُسَلِّمَ إِنَّمَا الأَمْرُ عَلَى وَجْهِهِ ‏.‏ قَالَ وَأَبُو نَضْرَةَ اسْمُهُ الْمُنْذِرُ بْنُ مَالِكِ بْنِ قُطَعَةَ ‏.‏\hadithno{238}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated that :Allah's Messenger said: "the key to Salat is the purification, its Tahrim is the Takbir, and its Tahlilis the Taslim, and there is no Salat for one who did not recite Al-Hamd and a Surah in the obligatory (prayer) or other prayers}}
\hadithdefcmd{tirmidhi}{239}{حَدَّثَنَا قُتَيْبَةُ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ سَمْعَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَبَّرَ لِلصَّلاَةِ نَشَرَ أَصَابِعَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَسَنٌ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنِ ابْنِ أَبِي ذِئْبٍ عَنْ سَعِيدِ بْنِ سِمْعَانَ عَنْ أَبِي هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ فِي الصَّلاَةِ رَفَعَ يَدَيْهِ مَدًّا ‏.‏ وَهَذَا أَصَحُّ مِنْ رِوَايَةِ يَحْيَى بْنِ الْيَمَانِ وَأَخْطَأَ يَحْيَى بْنُ الْيَمَانِ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{239}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"When Allah's Messenger performed the Takbir for Salat he would spread his fingers}}
\hadithdefcmd{tirmidhi}{240}{قَالَ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ الْحَنَفِيُّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ سِمْعَانَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ رَفَعَ يَدَيْهِ مَدًّا ‏.‏ قَالَ أَبُو عِيسَى قَالَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ وَهَذَا أَصَحُّ مِنْ حَدِيثِ يَحْيَى بْنِ الْيَمَانِ وَحَدِيثُ يَحْيَى بْنِ الْيَمَانِ خَطَأٌ ‏.‏\hadithno{240}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated:"When Allah's Messenger would enter the Salat he would raise his hands while they were extended}}
\hadithdefcmd{tirmidhi}{241}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، وَنَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، قَالاَ حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ عَنْ طُعْمَةَ بْنِ عَمْرٍو، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى لِلَّهِ أَرْبَعِينَ يَوْمًا فِي جَمَاعَةٍ يُدْرِكُ التَّكْبِيرَةَ الأُولَى كُتِبَتْ لَهُ بَرَاءَتَانِ بَرَاءَةٌ مِنَ النَّارِ وَبَرَاءَةٌ مِنَ النِّفَاقِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَنَسٍ مَوْقُوفًا وَلاَ أَعْلَمُ أَحَدًا رَفَعَهُ إِلاَّ مَا رَوَى سَلْمُ بْنُ قُتَيْبَةَ عَنْ طُعْمَةَ بْنِ عَمْرٍو عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ عَنْ أَنَسٍ ‏.‏ وَإِنَّمَا يُرْوَى هَذَا الْحَدِيثُ عَنْ حَبِيبِ بْنِ أَبِي حَبِيبٍ الْبَجَلِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَوْلُهُ ‏.‏ حَدَّثَنَا بِذَلِكَ، هَنَّادٌ حَدَّثَنَا وَكِيعٌ، عَنْ خَالِدِ بْنِ طَهْمَانَ، عَنْ حَبِيبِ بْنِ أَبِي حَبِيبٍ الْبَجَلِيِّ، عَنْ أَنَسٍ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏ وَرَوَى إِسْمَاعِيلُ بْنُ عَيَّاشٍ، هَذَا الْحَدِيثَ عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏ وَهَذَا حَدِيثٌ غَيْرُ مَحْفُوظٍ وَهُوَ حَدِيثٌ مُرْسَلٌ وَعُمَارَةُ بْنُ غَزِيَّةَ لَمْ يُدْرِكْ أَنَسَ بْنَ مَالِكٍ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ حَبِيبُ بْنُ أَبِي حَبِيبٍ يُكْنَى أَبَا الْكَشُوثَى وَيُقَالُ أَبُو عُمَيْرَةَ ‏.‏\hadithno{241}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :Allah's Messenger said: "Whoever performs Salat for Allah for forty days in congregation, catching the first Takbir, two absolutions are written for him: absolution from the Fire, and absolution from the Fire, and absolution from hypocrisy}}
\hadithdefcmd{tirmidhi}{242}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْبَصْرِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ عَلِيِّ بْنِ عَلِيٍّ الرِّفَاعِيِّ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ بِاللَّيْلِ كَبَّرَ ثُمَّ يَقُولُ ‏"‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ وَتَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏"‏ ‏.‏ ثُمَّ يَقُولُ ‏"‏ اللَّهُ أَكْبَرُ كَبِيرًا ‏"‏ ‏.‏ ثُمَّ يَقُولُ ‏"‏ أَعُوذُ بِاللَّهِ السَّمِيعِ الْعَلِيمِ مِنَ الشَّيْطَانِ الرَّجِيمِ مِنْ هَمْزِهِ وَنَفْخِهِ وَنَفْثِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَجَابِرٍ وَجُبَيْرِ بْنِ مُطْعِمٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي سَعِيدٍ أَشْهَرُ حَدِيثٍ فِي هَذَا الْبَابِ ‏.‏ وَقَدْ أَخَذَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ بِهَذَا الْحَدِيثِ وَأَمَّا أَكْثَرُ أَهْلِ الْعِلْمِ فَقَالُوا بِمَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏"‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ وَتَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏"‏ ‏.‏ وَهَكَذَا رُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ وَغَيْرِهِمْ ‏.‏ وَقَدْ تُكُلِّمَ فِي إِسْنَادِ حَدِيثِ أَبِي سَعِيدٍ كَانَ يَحْيَى بْنُ سَعِيدٍ يَتَكَلَّمُ فِي عَلِيِّ بْنِ عَلِيٍّ الرِّفَاعِيِّ وَقَالَ أَحْمَدُ لاَ يَصِحُّ هَذَا الْحَدِيثُ ‏.‏\hadithno{242}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eeed Al Khudri narrated:"When Allah;s Messenger stood for Salat during the night, he would say the Takbir (Allahu Akbar), then say: (Subhanaka Allahumma wa bihamdika wa Tabarakasmuka wa Ta'ala Jadduka wa la ilaha ghairuk.) 'Glorious You are O Allah, and with Your praise, and blesses is Your Name, and exalted is Your majesty, and none has the right to be worshipped but You' Then he would say: (A'udhu Bilahi As-Sami'il-Alimi min Ash-Shaitanir-Rajimi, min Hamzihi Wa Nafkhihi wa Nafthihi.)" 'Allah is undoubtedly the greatest.' (Allahu Akbaru Kabira). Then he would say: 'I seek refuge in Allah the All-Hearing, the All-Knowing, from the cursed Shaitan, from his madness, his arrogance, and his poetry}}
\hadithdefcmd{tirmidhi}{243}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، وَيَحْيَى بْنُ مُوسَى، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ حَارِثَةَ بْنِ أَبِي الرِّجَالِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ قَالَ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ وَتَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عَائِشَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَحَارِثَةُ قَدْ تُكُلِّمَ فِيهِ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَأَبُو الرِّجَالِ اسْمُهُ مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَدِينِيُّ ‏.‏\hadithno{243}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Aishah narrated:"When the Prophet opened the Salat he would say: (Subhanaka Allahumma wa bihamdika wa tabarakasmuka, wa ta'ala jadduka wa la ilaha ghairuk)" 'Glorious You are O Allah, and with Your praise, and blessed is Your Name, and exalted is Your majesty, and none has the right to be worshipped but You}}
\hadithdefcmd{tirmidhi}{244}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا سَعِيدُ بْنُ إِيَاسٍ الْجُرَيْرِيُّ، عَنْ قَيْسِ بْنِ عَبَايَةَ، عَنِ ابْنِ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ سَمِعَنِي أَبِي، وَأَنَا فِي الصَّلاَةِ، أَقُولُ‏:‏ ‏(‏بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ‏)‏ فَقَالَ لِي أَىْ بُنَىَّ مُحْدَثٌ إِيَّاكَ وَالْحَدَثَ ‏.‏ قَالَ وَلَمْ أَرَ أَحَدًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ أَبْغَضَ إِلَيْهِ الْحَدَثُ فِي الإِسْلاَمِ يَعْنِي مِنْهُ ‏.‏ قَالَ وَقَدْ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم وَمَعَ أَبِي بَكْرٍ وَمَعَ عُمَرَ وَمَعَ عُثْمَانَ فَلَمْ أَسْمَعْ أَحَدًا مِنْهُمْ يَقُولُهَا فَلاَ تَقُلْهَا إِذَا أَنْتَ صَلَّيْتَ فَقُلِ‏:‏ ‏(‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَغَيْرُهُمْ وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَأَحْمَدُ وَإِسْحَاقُ لاَ يَرَوْنَ أَنْ يَجْهَرَ بِـ ‏(‏بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏)‏ قَالُوا وَيَقُولُهَا فِي نَفْسِهِ ‏.‏\hadithno{244}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abdullah bin Mughaffal narrated:"While I was praying, I said: Bismillahir-Rahmanir-Rahim "In the Name of Allah, the Merciful, the Beneficent." My father heard me and said: "O my son this is a newly invented matter, beware of the newly-invented.'" He (Ibn Abdullah) said: "I have not seen any one of the Companions of Allah's Messenger who hated a newly invented matter in Islam more than him. And he said: 'Ihave performed Salat with the Prophet, and with Abu Bakr, and Umar, and with Uthman. I did not hear any one of them saying it. So do not say it. When you are performing Salat say: Al-Hamdu lilahi Rabbil-Alamin "All praise is due to Allah the Lord of all that exists}}
\hadithdefcmd{tirmidhi}{245}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي إِسْمَاعِيلُ بْنُ حَمَّادٍ، عَنْ أَبِي خَالِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَفْتَتِحُ صَلاَتَهُ بِـ ‏(‏بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِذَاكَ ‏.‏ وَقَدْ قَالَ بِهَذَا عِدَّةٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو هُرَيْرَةَ وَابْنُ عُمَرَ وَابْنُ عَبَّاسٍ وَابْنُ الزُّبَيْرِ وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ رَأَوُا الْجَهْرَ بِـ ‏(‏بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏)‏ وَبِهِ يَقُولُ الشَّافِعِيُّ ‏.‏ وَإِسْمَاعِيلُ بْنُ حَمَّادٍ هُوَ ابْنُ أَبِي سُلَيْمَانَ ‏.‏ وَأَبُو خَالِدٍ يُقَالُ هُوَ أَبُو خَالِدٍ الْوَالِبِيُّ وَاسْمُهُ هُرْمُزُ وَهُوَ كُوفِيٌّ ‏.‏\hadithno{245}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet would open his Salat with (Bismillahir-Rahmanir-Rahim)}}
\hadithdefcmd{tirmidhi}{246}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ يَفْتَتِحُونَ الْقِرَاءَةَ بِـ ‏(‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏)‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ كَانُوا يَسْتَفْتِحُونَ الْقِرَاءَةَ بِـ ‏(‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏)‏ ‏.‏ قَالَ الشَّافِعِيُّ إِنَّمَا مَعْنَى هَذَا الْحَدِيثِ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ وَعُثْمَانَ كَانُوا يَفْتَتِحُونَ الْقِرَاءَةَ بِـ ‏(‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏)‏ مَعْنَاهُ أَنَّهُمْ كَانُوا يَبْدَءُونَ بِقِرَاءَةِ فَاتِحَةِ الْكِتَابِ قَبْلَ السُّورَةِ وَلَيْسَ مَعْنَاهُ أَنَّهُمْ كَانُوا لاَ يَقْرَءُونَ ‏(‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏)‏ ‏.‏ وَكَانَ الشَّافِعِيُّ يَرَى أَنْ يُبْدَأَ بِـ‏(‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏)‏ وَأَنْ يُجْهَرَ بِهَا إِذَا جُهِرَ بِالْقِرَاءَةِ ‏.‏\hadithno{246}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas narrated:"Allah's Messenger, Abu Bakr, Umar and Uthman opened the Salat with (Al-Hamdu-lillahi rabbil-alamin)}}
\hadithdefcmd{tirmidhi}{247}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَبِي عُمَرَ الْمَكِّيُّ أَبُو عَبْدِ اللَّهِ الْعَدَنِيُّ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ وَأَنَسٍ وَأَبِي قَتَادَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُبَادَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَعَلِيُّ بْنُ أَبِي طَالِبٍ وَجَابِرُ بْنُ عَبْدِ اللَّهِ وَعِمْرَانُ بْنُ حُصَيْنٍ وَغَيْرُهُمْ قَالُوا لاَ تُجْزِئُ صَلاَةٌ إِلاَّ بِقِرَاءَةِ فَاتِحَةِ الْكِتَابِ ‏.‏ وَقَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ كُلُّ صَلاَةٍ لَمْ يُقْرَأْ فِيهَا بِفَاتِحَةِ الْكِتَابِ فَهِيَ خِدَاجٌ غَيْرُ تَمَامٍ ‏.‏ وَبِهِ يَقُولُ ابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ سَمِعْتُ ابْنَ أَبِي عُمَرَ يَقُولُ اخْتَلَفْتُ إِلَى ابْنِ عُيَيْنَةَ ثَمَانِيَةَ عَشْرَ سَنَةً وَكَانَ الْحُمَيْدِيُّ أَكْبَرَ مِنِّي بِسَنَةٍ ‏.‏ وَسَمِعْتُ ابْنَ أَبِي عُمَرَ يَقُولُ حَجَجْتُ سَبْعِينَ حَجَّةً مَاشِيًا عَلَى قَدَمَىَّ ‏.‏\hadithno{247}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ubadah bin As-Samil narrated that :the Prophet said: "There is no Salat for the one who does not recite Fatihatil-Kitab}}
\hadithdefcmd{tirmidhi}{248}{حَدَّثَنَا بُنْدَارٌ، مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ حُجْرِ بْنِ عَنْبَسٍ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم قَرَأَ‏:‏ ‏(‏غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏)‏ فَقَالَ ‏"‏ آمِينَ ‏"‏ ‏.‏ وَمَدَّ بِهَا صَوْتَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ وَائِلِ بْنِ حُجْرٍ حَدِيثٌ حَسَنٌ ‏.‏ وَبِهِ يَقُولُ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ يَرَوْنَ أَنَّ الرَّجُلَ يَرْفَعُ صَوْتَهُ بِالتَّأْمِينِ وَلاَ يُخْفِيهَا ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ عَنْ حُجْرٍ أَبِي الْعَنْبَسِ عَنْ عَلْقَمَةَ بْنِ وَائِلٍ عَنْ أَبِيهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ ‏:‏ ‏(‏ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏)‏ فَقَالَ ‏"‏ آمِينَ ‏"‏ ‏.‏ وَخَفَضَ بِهَا صَوْتَهُ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ مُحَمَّدًا يَقُولُ حَدِيثُ سُفْيَانَ أَصَحُّ مِنْ حَدِيثِ شُعْبَةَ فِي هَذَا وَأَخْطَأَ شُعْبَةُ فِي مَوَاضِعَ مِنْ هَذَا الْحَدِيثِ فَقَالَ عَنْ حُجْرٍ أَبِي الْعَنْبَسِ وَإِنَّمَا هُوَ حُجْرُ بْنُ عَنْبَسٍ وَيُكْنَى أَبَا السَّكَنِ ‏.‏ وَزَادَ فِيهِ عَنْ عَلْقَمَةَ بْنِ وَائِلٍ وَلَيْسَ فِيهِ عَنْ عَلْقَمَةَ وَإِنَّمَا هُوَ عَنْ حُجْرِ بْنِ عَنْبَسٍ عَنْ وَائِلِ بْنِ حُجْرٍ وَقَالَ وَخَفَضَ بِهَا صَوْتَهُ وَإِنَّمَا هُوَ وَمَدَّ بِهَا صَوْتَهُ ‏.‏ قَالَ أَبُو عِيسَى وَسَأَلْتُ أَبَا زُرْعَةَ عَنْ هَذَا الْحَدِيثِ فَقَالَ حَدِيثُ سُفْيَانَ فِي هَذَا أَصَحُّ مِنْ حَدِيثِ شُعْبَةَ ‏.‏ قَالَ وَرَوَى الْعَلاَءُ بْنُ صَالِحٍ الأَسَدِيُّ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ نَحْوَ رِوَايَةِ سُفْيَانَ ‏.‏\hadithno{248}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Wa'il bin Hujr narrated:"I heard the Prophet recite: (Not (the way) of those who earned Your anger, nor those who went astray) and he said: 'Amin.' And he stretched it out with his voice}}
\hadithdefcmd{tirmidhi}{249}{قَالَ أَبُو عِيسَى حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ أَبَانَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا الْعَلاَءُ بْنُ صَالِحٍ الأَسَدِيُّ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ حُجْرِ بْنِ عَنْبَسٍ، عَنْ وَائِلِ بْنِ حُجْرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ سُفْيَانَ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ ‏.‏\hadithno{249}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Wa'il bin Hujr who narrated it from :the Prophet, and it is similar to the narrations of Sufyan from Salamah bin Kuhail}}
\hadithdefcmd{tirmidhi}{250}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَمَّنَ الإِمَامُ فَأَمِّنُوا فَإِنَّهُ مَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{250}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said "When the Imam says 'Amin' then (all of you) say 'Amin.' For whoever's 'Amin' concurs with the 'Amin' of the angels, then his past sins will be forgiven}}
\hadithdefcmd{tirmidhi}{251}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ سَكْتَتَانِ حَفِظْتُهُمَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَنْكَرَ ذَلِكَ عِمْرَانُ بْنُ حُصَيْنٍ وَقَالَ حَفِظْنَا سَكْتَةً ‏.‏ فَكَتَبْنَا إِلَى أُبَىِّ بْنِ كَعْبٍ بِالْمَدِينَةِ فَكَتَبَ أُبَىٌّ أَنْ حَفِظَ سَمُرَةُ ‏.‏ قَالَ سَعِيدٌ فَقُلْنَا لِقَتَادَةَ مَا هَاتَانِ السَّكْتَتَانِ قَالَ إِذَا دَخَلَ فِي صَلاَتِهِ وَإِذَا فَرَغَ مِنَ الْقِرَاءَةِ ‏.‏ ثُمَّ قَالَ بَعْدَ ذَلِكَ وَإِذَا قَرَأَ ‏:‏ ‏(‏وَلاَ الضَّالِّينَ ‏)‏ ‏.‏ قَالَ وَكَانَ يُعْجِبُهُ إِذَا فَرَغَ مِنَ الْقِرَاءَةِ أَنْ يَسْكُتَ حَتَّى يَتَرَادَّ إِلَيْهِ نَفَسُهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ لِلإِمَامِ أَنْ يَسْكُتَ بَعْدَ مَا يَفْتَتِحُ الصَّلاَةَ وَبَعْدَ الْفَرَاغِ مِنَ الْقِرَاءَةِ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ وَأَصْحَابُنَا ‏.‏\hadithno{251}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Hasan narrated that :Samurah said: "there are two pauses that I preserved from Allah's Messenger." But Imran bin Husain rejected that and said: "We preserved one pause." "So we wrote to Ubayy bin Ka'b in Al-Madinah. Ubayy wrote that Samurah was correct." Sa'eed said: "We said to Qatadah: 'What are those two pauses?' He said: 'When he entered into his Salat, and when he finished his recitation.' Then he (Qatadah) said after that: 'And when he recited (Nor those who went astray.)' And he said: 'He liked to pause when he finished the recitation until he caught his breath}}
\hadithdefcmd{tirmidhi}{252}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ قَبِيصَةَ بْنِ هُلْبٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَؤُمُّنَا فَيَأْخُذُ شِمَالَهُ بِيَمِينِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ وَائِلِ بْنِ حُجْرٍ وَغُطَيْفِ بْنِ الْحَارِثِ وَابْنِ عَبَّاسٍ وَابْنِ مَسْعُودٍ وَسَهْلِ بْنِ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ هُلْبٍ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ يَرَوْنَ أَنْ يَضَعَ الرَّجُلُ يَمِينَهُ عَلَى شِمَالِهِ فِي الصَّلاَةِ ‏.‏ وَرَأَى بَعْضُهُمْ أَنْ يَضَعَهُمَا فَوْقَ السُّرَّةِ ‏.‏ وَرَأَى بَعْضُهُمْ أَنْ يَضَعَهُمَا تَحْتَ السُّرَّةِ ‏.‏ وَكُلُّ ذَلِكَ وَاسِعٌ عِنْدَهُمْ ‏.‏ وَاسْمُ هُلْبٍ يَزِيدُ بْنُ قُنَافَةَ الطَّائِيُّ ‏.‏\hadithno{252}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Qabisah bin Hulb narrated from :his father who said: "Allah's Messenger lead us in prayer and hold his left hand with his right}}
\hadithdefcmd{tirmidhi}{253}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكَبِّرُ فِي كُلِّ خَفْضٍ وَرَفْعٍ وَقِيَامٍ وَقُعُودٍ وَأَبُو بَكْرٍ وَعُمَرُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَنَسٍ وَابْنِ عُمَرَ وَأَبِي مَالِكٍ الأَشْعَرِيِّ وَأَبِي مُوسَى وَعِمْرَانَ بْنِ حُصَيْنٍ وَوَائِلِ بْنِ حُجْرٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَغَيْرُهُمْ وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ وَعَلَيْهِ عَامَّةُ الْفُقَهَاءِ وَالْعُلَمَاءِ ‏.‏\hadithno{253}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Mas'ud narrated:"Allah's Messenger would say the Takbir for every lowering and raising, standing and sitting, and (so did) Abu Bakr and Umar}}
\hadithdefcmd{tirmidhi}{254}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ الْمَرْوَزِيُّ، قَالَ سَمِعْتُ عَلِيَّ بْنَ الْحَسَنِ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُكَبِّرُ وَهُوَ يَهْوِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ قَالُوا يُكَبِّرُ الرَّجُلُ وَهُوَ يَهْوِي لِلرُّكُوعِ وَالسُّجُودِ ‏.‏\hadithno{254}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"Allah's Messenger would say the Takhir while he was going down}}
\hadithdefcmd{tirmidhi}{255}{حَدَّثَنَا قُتَيْبَةُ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ يَرْفَعُ يَدَيْهِ حَتَّى يُحَاذِيَ مَنْكِبَيْهِ وَإِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ ‏.‏ وَزَادَ ابْنُ أَبِي عُمَرَ فِي حَدِيثِهِ وَكَانَ لاَ يَرْفَعُ بَيْنَ السَّجْدَتَيْنِ ‏.‏\hadithno{255}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim narrated from :his father (Ibn Umar) who said: "I saw Allah's Messenger when he opened the Salat, raising his hands to the level of his shoulders, and (again) when he bowed, and when he raised his head from bowing." In his narration, Ibn Abi Umar added: "And he wuld not raise them between the two prostrations}}
\hadithdefcmd{tirmidhi}{256}{قَالَ أَبُو عِيسَى حَدَّثَنَا الْفَضْلُ بْنُ الصَّبَّاحِ الْبَغْدَادِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا الزُّهْرِيُّ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ ابْنِ أَبِي عُمَرَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ، وَعَلِيٍّ، وَوَائِلِ بْنِ حُجْرٍ، وَمَالِكِ بْنِ الْحُوَيْرِثِ، وَأَنَسٍ، وَأَبِي، هُرَيْرَةَ وَأَبِي حُمَيْدٍ وَأَبِي أُسَيْدٍ وَسَهْلِ بْنِ سَعْدٍ وَمُحَمَّدِ بْنِ مَسْلَمَةَ وَأَبِي قَتَادَةَ وَأَبِي مُوسَى الأَشْعَرِيِّ وَجَابِرٍ وَعُمَيْرٍ اللَّيْثِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهَذَا يَقُولُ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمُ ابْنُ عُمَرَ وَجَابِرُ بْنُ عَبْدِ اللَّهِ وَأَبُو هُرَيْرَةَ وَأَنَسٌ وَابْنُ عَبَّاسٍ وَعَبْدُ اللَّهِ بْنُ الزُّبَيْرِ وَغَيْرُهُمْ وَمِنَ التَّابِعِينَ الْحَسَنُ الْبَصْرِيُّ وَعَطَاءٌ وَطَاوُسٌ وَمُجَاهِدٌ وَنَافِعٌ وَسَالِمُ بْنُ عَبْدِ اللَّهِ وَسَعِيدُ بْنُ جُبَيْرٍ وَغَيْرُهُمْ ‏.‏ وَبِهِ يَقُولُ مَالِكٌ وَمَعْمَرٌ وَالأَوْزَاعِيُّ وَابْنُ عُيَيْنَةَ وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ قَدْ ثَبَتَ حَدِيثُ مَنْ يَرْفَعُ يَدَيْهِ وَذَكَرَ حَدِيثَ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ وَلَمْ يَثْبُتْ حَدِيثُ ابْنِ مَسْعُودٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَرْفَعْ يَدَيْهِ إِلاَّ فِي أَوَّلِ مَرَّةٍ ‏.‏ حَدَّثَنَا بِذَلِكَ أَحْمَدُ بْنُ عَبْدَةَ الآمُلِيُّ حَدَّثَنَا وَهْبُ بْنُ زَمْعَةَ عَنْ سُفْيَانَ بْنِ عَبْدِ الْمَلِكِ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ ‏.‏ قَالَ وَحَدَّثَنَا يَحْيَى بْنُ مُوسَى قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ قَالَ كَانَ مَالِكُ بْنُ أَنَسٍ يَرَى رَفْعَ الْيَدَيْنِ فِي الصَّلاَةِ ‏.‏ وَقَالَ يَحْيَى وَحَدَّثَنَا عَبْدُ الرَّزَّاقِ قَالَ كَانَ مَعْمَرٌ يَرَى رَفْعَ الْيَدَيْنِ فِي الصَّلاَةِ ‏.‏ وَسَمِعْتُ الْجَارُودَ بْنَ مُعَاذٍ يَقُولُ كَانَ سُفْيَانُ بْنُ عُيَيْنَةَ وَعُمَرُ بْنُ هَارُونَ وَالنَّضْرُ بْنُ شُمَيْلٍ يَرْفَعُونَ أَيْدِيَهُمْ إِذَا افْتَتَحُوا الصَّلاَةَ وَإِذَا رَكَعُوا وَإِذَا رَفَعُوا رُءُوسَهُمْ ‏.‏\hadithno{256}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim narrated:Same as 255 (above) with a different chain}}
\hadithdefcmd{tirmidhi}{257}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ عَلْقَمَةَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ أَلاَ أُصَلِّي بِكُمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى فَلَمْ يَرْفَعْ يَدَيْهِ إِلاَّ فِي أَوَّلِ مَرَّةٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الْبَرَاءِ بْنِ عَازِبٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ ‏.‏ وَبِهِ يَقُولُ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{257}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Alqamah narrated that :Abdullah bin Mas'ud said: "Shall I not demonstrate the Salat of Allah's Messenger to you?" Then he offered Salat and he did not raise his hands except while saying the first Takbir}}
\hadithdefcmd{tirmidhi}{258}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو حَصِينٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، قَالَ قَالَ لَنَا عُمَرُ بْنُ الْخَطَّابِ رضى الله عَنْهُ إِنَّ الرُّكَبَ سُنَّتْ لَكُمْ فَخُذُوا بِالرُّكَبِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ وَأَنَسٍ وَأَبِي حُمَيْدٍ وَأَبِي أُسَيْدٍ وَسَهْلِ بْنِ سَعْدٍ وَمُحَمَّدِ بْنِ مَسْلَمَةَ وَأَبِي مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ لاَ اخْتِلاَفَ بَيْنَهُمْ فِي ذَلِكَ إِلاَّ مَا رُوِيَ عَنِ ابْنِ مَسْعُودٍ وَبَعْضِ أَصْحَابِهِ أَنَّهُمْ كَانُوا يُطَبِّقُونَ ‏.‏ وَالتَّطْبِيقُ مَنْسُوخٌ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{258}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Abdur-Rahman As-Sulami said:"Umar bin Al-Khattab [may Allah be pleased with him] said to us: 'The knees are the Sunnah for you, so hold the knees}}
\hadithdefcmd{tirmidhi}{259}{قَالَ سَعْدُ بْنُ أَبِي وَقَّاصٍ كُنَّا نَفْعَلُ ذَلِكَ فَنُهِينَا عَنْهُ وَأُمِرْنَا أَنْ نَضَعَ الأَكُفَّ عَلَى الرُّكَبِ ‏.‏ قَالَ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا أَبُو عَوَانَةَ عَنْ أَبِي يَعْفُورٍ عَنْ مُصْعَبِ بْنِ سَعْدٍ عَنْ أَبِيهِ سَعْدٍ بِهَذَا ‏.‏ وَأَبُو حُمَيْدٍ السَّاعِدِيُّ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ الْمُنْذِرِ ‏.‏ وَأَبُو أُسَيْدٍ السَّاعِدِيُّ اسْمُهُ مَالِكُ بْنُ رَبِيعَةَ ‏.‏ وَأَبُو حَصِينٍ اسْمُهُ عُثْمَانُ بْنُ عَاصِمٍ الأَسَدِيُّ ‏.‏ وَأَبُو عَبْدِ الرَّحْمَنِ السُّلَمِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ حَبِيبٍ ‏.‏ وَأَبُو يَعْفُورٍ عَبْدُ الرَّحْمَنِ بْنُ عُبَيْدِ بْنِ نِسْطَاسٍ ‏.‏ وَأَبُو يَعْفُورٍ الْعَبْدِيُّ اسْمُهُ وَاقِدٌ وَيُقَالُ وَقْدَانُ وَهُوَ الَّذِي رَوَى عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ‏.‏ وَكِلاَهُمَا مِنْ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{259}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'd bin Abi Waqas said:"We would do that, but then we were prohibited from it, and we were ordered to put our hands on our knees}}
\hadithdefcmd{tirmidhi}{260}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، بُنْدَارٌ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبَّاسُ بْنُ سَهْلِ بْنِ سَعْدٍ، قَالَ اجْتَمَعَ أَبُو حُمَيْدٍ وَأَبُو أُسَيْدٍ وَسَهْلُ بْنُ سَعْدٍ وَمُحَمَّدُ بْنُ مَسْلَمَةَ فَذَكَرُوا صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ أَبُو حُمَيْدٍ أَنَا أَعْلَمُكُمْ بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكَعَ فَوَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ كَأَنَّهُ قَابِضٌ عَلَيْهِمَا وَوَتَّرَ يَدَيْهِ فَنَحَّاهُمَا عَنْ جَنْبَيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي حُمَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ أَهْلُ الْعِلْمِ أَنْ يُجَافِيَ الرَّجُلُ يَدَيْهِ عَنْ جَنْبَيْهِ فِي الرُّكُوعِ وَالسُّجُودِ ‏.‏\hadithno{260}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abbas bin Sahl [bin Sa'd] narrated:"Abu Humaid, Abu Usaid, Sahl bin Sa'd, and Muhammad bin Maslamah were once together and they were mentioning the Salat of Allah's Messenger. Abu Humaid said: 'I am the most knowledgeable among you of the Salat of Allah's Messenger: Allah's Messenger would bow and place his hands on his knees as if he was grasping them, and he would draw his forearms to hold them away from his sides}}
\hadithdefcmd{tirmidhi}{261}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ إِسْحَاقَ بْنِ يَزِيدَ الْهُذَلِيِّ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ مَسْعُودٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَكَعَ أَحَدُكُمْ فَقَالَ فِي رُكُوعِهِ سُبْحَانَ رَبِّيَ الْعَظِيمِ ثَلاَثَ مَرَّاتٍ فَقَدْ تَمَّ رُكُوعُهُ وَذَلِكَ أَدْنَاهُ ‏.‏ وَإِذَا سَجَدَ فَقَالَ فِي سُجُودِهِ سُبْحَانَ رَبِّيَ الأَعْلَى ثَلاَثَ مَرَّاتٍ فَقَدْ تَمَّ سُجُودُهُ وَذَلِكَ أَدْنَاهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حُذَيْفَةَ وَعُقْبَةَ بْنِ عَامِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ لَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏ عَوْنُ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ لَمْ يَلْقَ ابْنَ مَسْعُودٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ أَنْ لاَ يَنْقُصَ الرَّجُلُ فِي الرُّكُوعِ وَالسُّجُودِ مِنْ ثَلاَثِ تَسْبِيحَاتٍ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُ قَالَ أَسْتَحِبُّ لِلإِمَامِ أَنْ يُسَبِّحَ خَمْسَ تَسْبِيحَاتٍ لِكَىْ يُدْرِكَ مَنْ خَلْفَهُ ثَلاَثَ تَسْبِيحَاتٍ ‏.‏ وَهَكَذَا قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ ‏.‏\hadithno{261}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Mas'ud narrated that :the Prophet said: "When one of you bows then says while he is bowing: (Subhana Rabbiyal Azim) 'Glorious is my Lord the Magnificent' three times, then he has completed his bowing. And that is the least of it. And when he prostrates and says while prostrating: (Subhana Rabbiyal A'la) 'Glorious is my Lord the Most High' three times, then he has completed his prostrations, and that is the least of it}}
\hadithdefcmd{tirmidhi}{262}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ سَعْدَ بْنَ عُبَيْدَةَ، يُحَدِّثُ عَنِ الْمُسْتَوْرِدِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، أَنَّهُ صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم فَكَانَ يَقُولُ فِي رُكُوعِهِ ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏.‏ وَفِي سُجُودِهِ ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ‏.‏ وَمَا أَتَى عَلَى آيَةِ رَحْمَةٍ إِلاَّ وَقَفَ وَسَأَلَ وَمَا أَتَى عَلَى آيَةِ عَذَابٍ إِلاَّ وَقَفَ وَتَعَوَّذَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{262}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hudhaifah narrated that :he performed Salat with the Prophet, and that while he was bowing he would say: (Subhana Rabbiyal Azim); "Glorious is my Lord the Magnificent" and while prostrating: (Subhana Rabbiyal A'la) 'Glorious is my Lord the Most High.' And he would not recite an Ayah mentioning mercy, except that he would stop and ask (for mercy), and he would not recite an Ayah mentioning punishment, except that he would stop and seek refuge (with Allah from it)}}
\hadithdefcmd{tirmidhi}{263}{قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، نَحْوَهُ ‏.‏ وَقَدْ رُوِيَ عَنْ حُذَيْفَةَ، هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ أَنَّهُ صَلَّى بِاللَّيْلِ مَعَ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{263}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another similar narration) This Hadith has been narrated from Hudhaifah :from another route: "That he performed Salat during the night with the Prophet" and he mentioned the Hadith}}
\hadithdefcmd{tirmidhi}{264}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، ح وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الْقَسِّيِّ وَالْمُعَصْفَرِ وَعَنْ تَخَتُّمِ الذَّهَبِ وَعَنْ قِرَاءَةِ الْقُرْآنِ فِي الرُّكُوعِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ كَرِهُوا الْقِرَاءَةَ فِي الرُّكُوعِ وَالسُّجُودِ ‏.‏\hadithno{264}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali bin Abi Talib narrated:"The Prophet prohibited wearing Qassi, and that which is dyed with safflower, and from the gold ring, and from reciting the Quran while bowing}}
\hadithdefcmd{tirmidhi}{265}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ الْبَدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لا تُجْزِئُ صَلاَةٌ لاَ يُقِيمُ فِيهَا الرَّجُلُ يَعْنِي صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيِّ بْنِ شَيْبَانَ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَرِفَاعَةَ الزُّرَقِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي مَسْعُودٍ الأَنْصَارِيِّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ يَرَوْنَ أَنْ يُقِيمَ الرَّجُلُ صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ ‏.‏ وَقَالَ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ مَنْ لَمْ يُقِمْ صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ فَصَلاَتُهُ فَاسِدَةٌ لِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ تُجْزِئُ صَلاَةٌ لاَ يُقِيمُ الرَّجُلُ فِيهَا صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ ‏"‏ ‏.‏ وَأَبُو مَعْمَرٍ اسْمُهُ عَبْدُ اللَّهِ بْنُ سَخْبَرَةَ ‏.‏ وَأَبُو مَسْعُودٍ الأَنْصَارِيُّ الْبَدْرِيُّ اسْمُهُ عُقْبَةُ بْنُ عَمْرٍو ‏.‏\hadithno{265}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Mas'ud Al-Ansari [Al-Badri] narrated that :Allah's Messenger said: "The Salat is not acceptable if a man is not at rest - meaning his back - while bowing and prostrating}}
\hadithdefcmd{tirmidhi}{266}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ الْمَاجِشُونُ، حَدَّثَنِي عَمِّي، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا بَيْنَهُمَا وَمِلْءَ مَا شِئْتَ مِنْ شَيْءٍ بَعْدُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَابْنِ أَبِي أَوْفَى وَأَبِي جُحَيْفَةَ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ الشَّافِعِيُّ قَالَ يَقُولُ هَذَا فِي الْمَكْتُوبَةِ وَالتَّطَوُّعِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْكُوفَةِ يَقُولُ هَذَا فِي صَلاَةِ التَّطَوُّعِ وَلاَ يَقُولُهَا فِي صَلاَةِ الْمَكْتُوبَةِ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا يُقَالُ الْمَاجِشُونِيُّ لأَنَّهُ مِنْ وَلَدِ الْمَاجِشُونِ ‏.‏\hadithno{266}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ali bin Abi Talib narrated:"When Allah's Messenger would raise his head from bowing he would say: (Sami Allahi liman hamidal. Rabba na lakal-hamd, mil'as-samawati wa mil'al-ardi wa mil'a ma bainahuma wa mil'a ma shi'ia min shay'in ba'd) 'Allah listens to those who praise Him. O our Lord! And to You is the praise that fills the heavens and fills the earth, and fills what is between them, and fills whatever there is beyond that You will.' He said: There are narrations on this topic from Ibn Umar, Ibn Abbas, Ibn Abi Awfa, Abu Juhaifa, and Abu Sa'eed}}
\hadithdefcmd{tirmidhi}{267}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ أَنْ يَقُولَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏.‏ وَيَقُولُ مَنْ خَلْفَ الإِمَامِ رَبَّنَا وَلَكَ الْحَمْدُ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ ‏.‏ وَقَالَ ابْنُ سِيرِينَ وَغَيْرُهُ يَقُولُ مَنْ خَلْفَ الإِمَامِ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏.‏ مِثْلَ مَا يَقُولُ الإِمَامُ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَإِسْحَاقُ ‏.‏\hadithno{267}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "When the Imam says: (Sami Allahu liman hamidah) 'Allah listens to those who praise Him. Then (all of you) say: (Rabbana wa lakal-hamd) 'O our Lord! And to You is the praise for whoever's saying concurs with the saying of the angels, then his past sins will be forgiven}}
\hadithdefcmd{tirmidhi}{268}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، وَأَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَالْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ اللَّهِ بْنُ مُنِيرٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شَرِيكٌ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا سَجَدَ يَضَعُ رُكْبَتَيْهِ قَبْلَ يَدَيْهِ وَإِذَا نَهَضَ رَفَعَ يَدَيْهِ قَبْلَ رُكْبَتَيْهِ ‏.‏ قَالَ زَادَ الْحَسَنُ بْنُ عَلِيٍّ فِي حَدِيثِهِ قَالَ يَزِيدُ بْنُ هَارُونَ وَلَمْ يَرْوِ شَرِيكٌ عَنْ عَاصِمِ بْنِ كُلَيْبٍ إِلاَّ هَذَا الْحَدِيثَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُ أَحَدًا رَوَاهُ مِثْلَ هَذَا عَنْ شَرِيكٍ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ يَرَوْنَ أَنْ يَضَعَ الرَّجُلُ رُكْبَتَيْهِ قَبْلَ يَدَيْهِ وَإِذَا نَهَضَ رَفَعَ يَدَيْهِ قَبْلَ رُكْبَتَيْهِ ‏.‏ وَرَوَى هَمَّامٌ عَنْ عَاصِمٍ هَذَا مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ وَائِلَ بْنَ حُجْرٍ ‏.‏\hadithno{268}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Wa'il bin Hujr narrated:"I saw Allah's Messenger when he prostrated placing his knees (on the ground) before his hands, and when he got up, he raised his hands before his knees}}
\hadithdefcmd{tirmidhi}{269}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ حَسَنٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَعْمِدُ أَحَدُكُمْ فَيَبْرُكُ فِي صَلاَتِهِ بَرْكَ الْجَمَلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَبِي الزِّنَادِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ الْمَقْبُرِيُّ ضَعَّفَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَغَيْرُهُ ‏.‏\hadithno{269}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that :the Prophet said; "Is it that one of you intends to kneel in his Salat with the kneeling of the camel?}}
\hadithdefcmd{tirmidhi}{270}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، بُنْدَارٌ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنِي عَبَّاسُ بْنُ سَهْلٍ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا سَجَدَ أَمْكَنَ أَنْفَهُ وَجَبْهَتَهُ مِنَ الأَرْضِ وَنَحَّى يَدَيْهِ عَنْ جَنْبَيْهِ وَوَضَعَ كَفَّيْهِ حَذْوَ مَنْكِبَيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَوَائِلِ بْنِ حُجْرٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي حُمَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ أَنْ يَسْجُدَ الرَّجُلُ عَلَى جَبْهَتِهِ وَأَنْفِهِ فَإِنْ سَجَدَ عَلَى جَبْهَتِهِ دُونَ أَنْفِهِ فَقَدْ قَالَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ يُجْزِئُهُ ‏.‏ وَقَالَ غَيْرُهُمْ لاَ يُجْزِئُهُ حَتَّى يَسْجُدَ عَلَى الْجَبْهَةِ وَالأَنْفِ ‏.‏\hadithno{270}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Humaid As-Sa'idi narrated:"When the Prophet would prostrate, he placed his nose and his forehead on the ground, and he held his forearms away from his sides, and he placed his hands parallel to his shoulders}}
\hadithdefcmd{tirmidhi}{271}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الْحَجَّاجِ، عَنْ أَبِي إِسْحَاقَ، قَالَ قُلْتُ لِلْبَرَاءِ بْنِ عَازِبٍ أَيْنَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَضَعُ وَجْهَهُ إِذَا سَجَدَ فَقَالَ بَيْنَ كَفَّيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ وَائِلِ بْنِ حُجْرٍ وَأَبِي حُمَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ بَعْضُ أَهْلِ الْعِلْمِ أَنْ تَكُونَ يَدَاهُ قَرِيبًا مِنْ أُذُنَيْهِ ‏.‏\hadithno{271}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Ishaq narrated:"I said to Al-Bara bin Azib: 'Where would the Prophet place his face when he prostrated?' He said: 'Between his hands}}
\hadithdefcmd{tirmidhi}{272}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَجَدَ الْعَبْدُ سَجَدَ مَعَهُ سَبْعَةُ آرَابٍ وَجْهُهُ وَكَفَّاهُ وَرُكْبَتَاهُ وَقَدَمَاهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَجَابِرٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْعَبَّاسِ حَدِيثٌ حَسَنٌ صَحِيحٌ وَعَلَيْهِ الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{272}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Al-Abbas bin Abdul-Muttalib narrated that he heard :Allah's Messenger Saying: "When the worshipper prostrates with him: His face, his hands, his knees, and his feet}}
\hadithdefcmd{tirmidhi}{273}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ وَلاَ يَكُفَّ شَعْرَهُ وَلاَ ثِيَابَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{273}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"The Prophet ordered that one prostrate on seven bones and that he not gather his hair nor his garment}}
\hadithdefcmd{tirmidhi}{274}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ الأَقْرَمِ الْخُزَاعِيِّ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ أَبِي بِالْقَاعِ مِنْ نَمِرَةَ فَمَرَّتْ رَكَبَةٌ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يُصَلِّي ‏.‏ قَالَ فَكُنْتُ أَنْظُرُ إِلَى عُفْرَتَىْ إِبْطَيْهِ إِذَا سَجَدَ أَىْ بَيَاضِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَابْنِ بُحَيْنَةَ وَجَابِرٍ وَأَحْمَرَ بْنِ جَزْءٍ وَمَيْمُونَةَ وَأَبِي حُمَيْدٍ وَأَبِي مَسْعُودٍ وَأَبِي أُسَيْدٍ وَسَهْلِ بْنِ سَعْدٍ وَمُحَمَّدِ بْنِ مَسْلَمَةَ وَالْبَرَاءِ بْنِ عَازِبٍ وَعَدِيِّ بْنِ عَمِيرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى وَأَحْمَرُ بْنُ جَزْءٍ هَذَا رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم لَهُ حَدِيثٌ وَاحِدٌ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ أَقْرَمَ حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ دَاوُدَ بْنِ قَيْسٍ وَلاَ نَعْرِفُ لِعَبْدِ اللَّهِ بْنِ أَقْرَمَ الْخُزَاعِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ وَعَبْدُ اللَّهِ بْنُ أَقْرَمَ الْخُزَاعِيُّ إِنَّمَا لَهُ هَذَا الْحَدِيثُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَعَبْدُ اللَّهِ بْنُ أَرْقَمَ الزُّهْرِيُّ صَاحِبُ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهُوَ كَاتِبُ أَبِي بَكْرٍ الصِّدِّيقِ ‏.‏\hadithno{274}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ubaidallah bin Abdullah bin Arqam Al-Khuza'I narrated from his father (Abdullah bin Arqam), who said:"I was with my father at the plains of Namirah. I passed by a mount and saw Allah's Messenger standing in Salat." He said: "I was looking at the earthiness of his armpits when he prostrated." [That is]: "Whiteness}}
\hadithdefcmd{tirmidhi}{275}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَجَدَ أَحَدُكُمْ فَلْيَعْتَدِلْ وَلاَ يَفْتَرِشْ ذِرَاعَيْهِ افْتِرَاشَ الْكَلْبِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ شِبْلٍ وَأَنَسٍ وَالْبَرَاءِ وَأَبِي حُمَيْدٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ يَخْتَارُونَ الاِعْتِدَالَ فِي السُّجُودِ وَيَكْرَهُونَ الاِفْتِرَاشَ كَافْتِرَاشِ السَّبُعِ ‏.‏\hadithno{275}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated that :the Prophet said: "When one of you prostrates, then let him be balanced, and let him not lay his forearms down like the lying of the dog}}
\hadithdefcmd{tirmidhi}{276}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اعْتَدِلُوا فِي السُّجُودِ وَلاَ يَبْسُطَنَّ أَحَدُكُمْ ذِرَاعَيْهِ فِي الصَّلاَةِ بَسْطَ الْكَلْبِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{276}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas narrated that :Allah's Messenger said: "Be balanced in the prostration, and let one of you not spread his forearms (on the ground) in the Salat like the spreading of the dog}}
\hadithdefcmd{tirmidhi}{277}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِوَضْعِ الْيَدَيْنِ وَنَصْبِ الْقَدَمَيْنِ ‏.‏\hadithno{277}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan}\hadithtrans{Amir bin Sa'd [bin Abi Waqqas] narrated from his father:"The Prophet ordered placing the hands (on the ground) keeping the feet erect. (by resting feet on the toes and making the tips of the toes facing the Qiblah)}}
\hadithdefcmd{tirmidhi}{278}{قَالَ عَبْدُ اللَّهِ وَقَالَ مُعَلَّى بْنُ أَسَدٍ حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِوَضْعِ الْيَدَيْنِ فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَغَيْرُ وَاحِدٍ عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ عَنْ عَامِرِ بْنِ سَعْدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِوَضْعِ الْيَدَيْنِ وَنَصْبِ الْقَدَمَيْنِ ‏.‏ مُرْسَلٌ وَهَذَا أَصَحُّ مِنْ حَدِيثِ وُهَيْبٍ ‏.‏ وَهُوَ الَّذِي أَجْمَعَ عَلَيْهِ أَهْلُ الْعِلْمِ وَاخْتَارُوهُ ‏.‏\hadithno{278}\hadithgrade{Ahmad Muhammad Shakir: Hasan Lighairihi; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{(Another chain that) Amir bin Sa'd narrated:"The Prophet ordered placing the hands (on the ground)." And he mentioned in it: "From his father}}
\hadithdefcmd{tirmidhi}{279}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى الْمَرْوَزِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَإِذَا سَجَدَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ السُّجُودِ قَرِيبًا مِنَ السَّوَاءِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏\hadithno{279}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara bin Azib narrated:"The Salat of Allah's Messenger (was such that) when he bowed, and when he raised his head from bowing, and when he prostrated, and when he raised his head from prostration it (all) was nearly the same}}
\hadithdefcmd{tirmidhi}{280}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{280}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara bin Azib narrated:(Another chain) which is similar}}
\hadithdefcmd{tirmidhi}{281}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، حَدَّثَنَا الْبَرَاءُ، وَهُوَ غَيْرُ كَذُوبٍ قَالَ كُنَّا إِذَا صَلَّيْنَا خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ لَمْ يَحْنِ رَجُلٌ مِنَّا ظَهْرَهُ حَتَّى يَسْجُدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَسْجُدَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَمُعَاوِيَةَ وَابْنِ مَسْعَدَةَ صَاحِبِ الْجُيُوشِ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهِ يَقُولُ أَهْلُ الْعِلْمِ إِنَّ مَنْ خَلْفَ الإِمَامِ إِنَّمَا يَتْبَعُونَ الإِمَامَ فِيمَا يَصْنَعُ لاَ يَرْكَعُونَ إِلاَّ بَعْدَ رُكُوعِهِ وَلاَ يَرْفَعُونَ إِلاَّ بَعْدَ رَفْعِهِ ‏.‏ لاَ نَعْلَمُ بَيْنَهُمْ فِي ذَلِكَ اخْتِلاَفًا ‏.‏\hadithno{281}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara said:"When we performed Salat behind Allah's Messenger, he would raise his head from bowing, and no man among us would bend his back until Allah's Messenger prostrated, then we prostrated}}
\hadithdefcmd{tirmidhi}{282}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَلِيُّ أُحِبُّ لَكَ مَا أُحِبُّ لِنَفْسِي وَأَكْرَهُ لَكَ مَا أَكْرَهُ لِنَفْسِي لاَ تُقْعِ بَيْنَ السَّجْدَتَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عَلِيٍّ إِلاَّ مِنْ حَدِيثِ أَبِي إِسْحَاقَ عَنِ الْحَارِثِ عَنْ عَلِيٍّ ‏.‏ وَقَدْ ضَعَّفَ بَعْضُ أَهْلِ الْعِلْمِ الْحَارِثَ الأَعْوَرَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ يَكْرَهُونَ الإِقْعَاءَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{282}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated:"Allah's Messenger said to me: 'O Ali! I love for you what I love for myself, and I dislike for you what I dislike for myself. Do not squat between prostrations}}
\hadithdefcmd{tirmidhi}{283}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ طَاوُسًا، يَقُولُ قُلْنَا لاِبْنِ عَبَّاسٍ فِي الإِقْعَاءِ عَلَى الْقَدَمَيْنِ قَالَ هِيَ السُّنَّةُ ‏.‏ فَقُلْنَا إِنَّا لَنَرَاهُ جَفَاءً بِالرَّجُلِ قَالَ بَلْ هِيَ سُنَّةُ نَبِيِّكُمْ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا الْحَدِيثِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم لاَ يَرَوْنَ بِالإِقْعَاءِ بَأْسًا وَهُوَ قَوْلُ بَعْضِ أَهْلِ مَكَّةَ مِنْ أَهْلِ الْفِقْهِ وَالْعِلْمِ ‏.‏ قَالَ وَأَكْثَرُ أَهْلِ الْعِلْمِ يَكْرَهُونَ الإِقْعَاءَ بَيْنَ السَّجْدَتَيْنِ ‏.‏\hadithno{283}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Tawus said:"We asked Ibn Abbas about squatting (sitting) on the heels. He said: 'It is the Sunnah.' We said: 'We think that it is difficult for a man.' He said: 'Rather, it is Sunnah of your Prophet}}
\hadithdefcmd{tirmidhi}{284}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ كَامِلٍ أَبِي الْعَلاَءِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ بَيْنَ السَّجْدَتَيْنِ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَاجْبُرْنِي وَاهْدِنِي وَارْزُقْنِي ‏"‏ ‏.‏\hadithno{284}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"Between the two prostrations, the Prophet would say: (Allahummaghfir li, warhamni, wajburni, wahdini, warzuqni). 'O Allah! Pardon me, have mercy on me, help me, guide me, and grant me sustenance}}
\hadithdefcmd{tirmidhi}{285}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ الْحُلْوَانِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ زَيْدِ بْنِ حُبَابٍ، عَنْ كَامِلٍ أَبِي الْعَلاَءِ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَهَكَذَا رُوِيَ عَنْ عَلِيٍّ، ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ يَرَوْنَ هَذَا جَائِزًا فِي الْمَكْتُوبَةِ وَالتَّطَوُّعِ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ كَامِلٍ أَبِي الْعَلاَءِ مُرْسَلاً ‏.‏\hadithno{285}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:(Another chain) which is similar}}
\hadithdefcmd{tirmidhi}{286}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ اشْتَكَى بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم إِلَى النَّبِيِّ صلى الله عليه وسلم مَشَقَّةَ السُّجُودِ عَلَيْهِمْ إِذَا تَفَرَّجُوا فَقَالَ ‏ "‏ اسْتَعِينُوا بِالرُّكَبِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ اللَّيْثِ عَنِ ابْنِ عَجْلاَنَ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ سُفْيَانُ بْنُ عُيَيْنَةَ وَغَيْرُ وَاحِدٍ عَنْ سُمَىٍّ عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏ وَكَأَنَّ رِوَايَةَ هَؤُلاَءِ أَصَحُّ مِنْ رِوَايَةِ اللَّيْثِ ‏.‏\hadithno{286}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"[Some of] the Companions of the Prophet complained [to the Prophet] about the hardship of the prostration on them, when they were so spread out, so he said: 'Use your knees}}
\hadithdefcmd{tirmidhi}{287}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا هُشَيْمٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ اللَّيْثِيِّ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يُصَلِّي فَكَانَ إِذَا كَانَ فِي وِتْرٍ مِنْ صَلاَتِهِ لَمْ يَنْهَضْ حَتَّى يَسْتَوِيَ جَالِسًا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مَالِكِ بْنِ الْحُوَيْرِثِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ وَبِهِ يَقُولُ إِسْحَاقُ وَبَعْضُ أَصْحَابِنَا ‏.‏ وَمَالِكٌ يُكْنَى أَبَا سُلَيْمَانَ ‏.‏\hadithno{287}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Malik bin Al-Huwairith Al-Laithi narrated that he saw :Allah's Messenger performing Salat. When he was in an odd number of his Salat, he would not get up until he had sat completely}}
\hadithdefcmd{tirmidhi}{288}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا خَالِدُ بْنُ إِلْيَاسَ، عَنْ صَالِحٍ، مَوْلَى التَّوْأَمَةِ عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَنْهَضُ فِي الصَّلاَةِ عَلَى صُدُورِ قَدَمَيْهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ عَلَيْهِ الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ يَخْتَارُونَ أَنْ يَنْهَضَ الرَّجُلُ فِي الصَّلاَةِ عَلَى صُدُورِ قَدَمَيْهِ ‏.‏ وَخَالِدُ بْنُ إِلْيَاسَ هُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ قَالَ وَيُقَالُ خَالِدُ بْنُ إِيَاسٍ أَيْضًا ‏.‏ وَصَالِحٌ مَوْلَى التَّوْأَمَةِ هُوَ صَالِحُ بْنُ أَبِي صَالِحٍ ‏.‏ وَأَبُو صَالِحٍ اسْمُهُ نَبْهَانُ وَهُوَ مَدَنِيٌّ ‏.‏\hadithno{288}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"Allah's Messenger would get up during his Salat on the tips of his feet}}
\hadithdefcmd{tirmidhi}{289}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَعَدْنَا فِي الرَّكْعَتَيْنِ أَنْ نَقُولَ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَجَابِرٍ وَأَبِي مُوسَى وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ قَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَهُوَ أَصَحُّ حَدِيثٍ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي التَّشَهُّدِ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ عَنْ مَعْمَرٍ عَنْ خُصَيْفٍ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي الْمَنَامِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ النَّاسَ قَدِ اخْتَلَفُوا فِي التَّشَهُّدِ فَقَالَ ‏ "‏ عَلَيْكَ بِتَشَهُّدِ ابْنِ مَسْعُودٍ ‏"‏ ‏.‏\hadithno{289}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Mas'ud narrated:"Allah's Messenger taught us, that when we sit for every two Rak'ah we should say: (At-Tahyyatulillah, was-salawatu wattayybaat. As-salamu alaika ayyuhannabiyyu wa rahmatullahi wa barakatuhu, as-salamu alaina wa ala ibadillahis-salihin. Ashhadu an la ilaha illallah wa ashadu anna Muhammadan abduhu wa Rasuluh.) 'All greetings, prayers, and pure words are Allah. Peace be upon you O Prophet, and Allah's mercy and His blessings. Peace be upon us and all of the righteous worshippers of Allah. I testify that nne has the right to be worshipped but Allah, and I testify that Muhammad is Allah's servant and Messenger}}
\hadithdefcmd{tirmidhi}{290}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَطَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا الْقُرْآنَ فَكَانَ يَقُولُ ‏ "‏ التَّحِيَّاتُ الْمُبَارَكَاتُ الصَّلَوَاتُ الطَّيِّبَاتُ لِلَّهِ سَلاَمٌ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ سَلاَمٌ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى عَبْدُ الرَّحْمَنِ بْنُ حُمَيْدٍ الرُّؤَاسِيُّ هَذَا الْحَدِيثَ عَنْ أَبِي الزُّبَيْرِ نَحْوَ حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ ‏.‏ وَرَوَى أَيْمَنُ بْنُ نَابِلٍ الْمَكِّيُّ هَذَا الْحَدِيثَ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ وَهُوَ غَيْرُ مَحْفُوظٍ ‏.‏ وَذَهَبَ الشَّافِعِيُّ إِلَى حَدِيثِ ابْنِ عَبَّاسٍ فِي التَّشَهُّدِ ‏.‏\hadithno{290}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Abbas narrated:"Allah's Messenger would teach us the Tashah-hud just as he would teach us the Qur'an. He would say: (At-Tahiyyatu, al mubarakatu, as-salawatu at-tayyibatulillah. Salamun alaika ayyuhan-naibiyyu wa rahmatullahi wa barakatuhu, salamun alaina wa ala ibadalillahis-salihin. Ashhadu an la ilaha illallah, wa ashhadu anna Muhammadan abduhu wa Raduluh.) 'All greetings, goodness, prayers, and pure words are for Allah. Peace be upon you O Prophet, and Allah's mercy and His blessings, Peace be upon us and all of the righteous worshippers of Allah. I testify that there is none worthy of worship except Allah, and I testify that Muhammad is Allah's worshipper and Messenger}}
\hadithdefcmd{tirmidhi}{291}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ مِنَ السُّنَّةِ أَنْ يُخْفِيَ، التَّشَهُّدَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{291}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Mas`ud said:"It is from the Sunnah to say the Tashahhud quietly}}
\hadithdefcmd{tirmidhi}{292}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ الْجَرْمِيُّ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ قَدِمْتُ الْمَدِينَةَ قُلْتُ لأَنْظُرَنَّ إِلَى صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا جَلَسَ - يَعْنِي - لِلتَّشَهُّدِ افْتَرَشَ رِجْلَهُ الْيُسْرَى وَوَضَعَ يَدَهُ الْيُسْرَى يَعْنِي عَلَى فَخِذِهِ الْيُسْرَى وَنَصَبَ رِجْلَهُ الْيُمْنَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَابْنِ الْمُبَارَكِ ‏.‏\hadithno{292}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Wa'il bin Hujr said:"I arrived in Al-Madinah and I said, 'Let me look at the Salat of Allah's Messenger.' When he sat - meaning for At-Tashah-hud - he spread his left foot, and placed his left hand - meaning on his left thigh - and held his right foot erect}}
\hadithdefcmd{tirmidhi}{293}{حَدَّثَنَا بُنْدَارٌ، مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ الْمَدَنِيُّ، حَدَّثَنِي عَبَّاسُ بْنُ سَهْلٍ السَّاعِدِيُّ، قَالَ اجْتَمَعَ أَبُو حُمَيْدٍ وَأَبُو أُسَيْدٍ وَسَهْلُ بْنُ سَعْدٍ وَمُحَمَّدُ بْنُ مَسْلَمَةَ فَذَكَرُوا صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ أَبُو حُمَيْدٍ أَنَا أَعْلَمُكُمْ بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَلَسَ - يَعْنِي - لِلتَّشَهُّدِ فَافْتَرَشَ رِجْلَهُ الْيُسْرَى وَأَقْبَلَ بِصَدْرِ الْيُمْنَى عَلَى قِبْلَتِهِ وَوَضَعَ كَفَّهُ الْيُمْنَى عَلَى رُكْبَتِهِ الْيُمْنَى وَكَفَّهُ الْيُسْرَى عَلَى رُكْبَتِهِ الْيُسْرَى وَأَشَارَ بِأُصْبَعِهِ يَعْنِي السَّبَّابَةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهِ يَقُولُ بَعْضُ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا يَقْعُدُ فِي التَّشَهُّدِ الآخِرِ عَلَى وَرِكِهِ وَاحْتَجُّوا بِحَدِيثِ أَبِي حُمَيْدٍ وَقَالُوا يَقْعُدُ فِي التَّشَهُّدِ الأَوَّلِ عَلَى رِجْلِهِ الْيُسْرَى وَيَنْصِبُ الْيُمْنَى ‏.‏\hadithno{293}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abbas bin SAhl [bin Sa'd] narrated:"Abu Humaid, Abu Usaid, Sahl bin Sa'd, and Muhammad bin Maslamah were once together and they were mentioning the Salat of Allah's Messenger. Abu Humaid said: "I am the most knowledgeable among you of the Salat of Allah's Messenger: Indeed Allah's Messenger sat - meaning for Tashah-hud - he spread his left foot, and made the top of his right (foot) face the Qiblah, and he placed his right hand on his right knee, and his left hand on his left knee, and indicated with his finger - meaning the index finge}}
\hadithdefcmd{tirmidhi}{294}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَيَحْيَى بْنُ مُوسَى، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا جَلَسَ فِي الصَّلاَةِ وَضَعَ يَدَهُ الْيُمْنَى عَلَى رُكْبَتِهِ وَرَفَعَ إِصْبَعَهُ الَّتِي تَلِي الإِبْهَامَ الْيُمْنَى يَدْعُو بِهَا وَيَدُهُ الْيُسْرَى عَلَى رُكْبَتِهِ بَاسِطَهَا عَلَيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ وَنُمَيْرٍ الْخُزَاعِيِّ وَأَبِي هُرَيْرَةَ وَأَبِي حُمَيْدٍ وَوَائِلِ بْنِ حُجْرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ عُمَرَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ يَخْتَارُونَ الإِشَارَةَ فِي التَّشَهُّدِ وَهُوَ قَوْلُ أَصْحَابِنَا ‏.‏\hadithno{294}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Umar narrated:"When the Prophet would sit during the Salat, he would place his right hand on his knee, and raise his finger, the one that is next to the [right] thumb, supplicating with it, and his left hand was spread flat on his left knee}}
\hadithdefcmd{tirmidhi}{295}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ ‏ "‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ وَابْنِ عُمَرَ وَجَابِرِ بْنِ سَمُرَةَ وَالْبَرَاءِ وَأَبِي سَعِيدٍ وَعَمَّارٍ وَوَائِلِ بْنِ حُجْرٍ وَعَدِيِّ بْنِ عَمِيرَةَ وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{295}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah narrated:"The Prophet would say the Salam from his right and from his left (saying): (As-Salamu alaikum wa rahmatullah, as-Salamu alaikum wa rahmatullah) 'Peace be upon you, and Allah's mercy. Peace be upon you, and Allah's mercy}}
\hadithdefcmd{tirmidhi}{296}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ أَبُو حَفْصٍ التِّنِّيسِيُّ، عَنْ زُهَيْرِ بْنِ مُحَمَّدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُسَلِّمُ فِي الصَّلاَةِ تَسْلِيمَةً وَاحِدَةً تِلْقَاءَ وَجْهِهِ يَمِيلُ إِلَى الشِّقِّ الأَيْمَنِ شَيْئًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ عَائِشَةَ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ زُهَيْرُ بْنُ مُحَمَّدٍ أَهْلُ الشَّأْمِ يَرْوُونَ عَنْهُ مَنَاكِيرَ وَرِوَايَةُ أَهْلِ الْعِرَاقِ عَنْهُ أَشْبَهُ وَأَصَحُّ ‏.‏ قَالَ مُحَمَّدٌ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ كَأَنَّ زُهَيْرَ بْنَ مُحَمَّدٍ الَّذِي كَانَ وَقَعَ عِنْدَهُمْ لَيْسَ هُوَ هَذَا الَّذِي يُرْوَى عَنْهُ بِالْعِرَاقِ كَأَنَّهُ رَجُلٌ آخَرُ قَلَبُوا اسْمَهُ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ قَالَ بِهِ بَعْضُ أَهْلِ الْعِلْمِ فِي التَّسْلِيمِ فِي الصَّلاَةِ وَأَصَحُّ الرِّوَايَاتِ عَنِ النَّبِيِّ صلى الله عليه وسلم تَسْلِيمَتَانِ وَعَلَيْهِ أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمْ ‏.‏ وَرَأَى قَوْمٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ تَسْلِيمَةً وَاحِدَةً فِي الْمَكْتُوبَةِ ‏.‏ قَالَ الشَّافِعِيُّ إِنْ شَاءَ سَلَّمَ تَسْلِيمَةً وَاحِدَةً وَإِنْ شَاءَ سَلَّمَ تَسْلِيمَتَيْنِ ‏.‏\hadithno{296}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"Allah's Messenger would say one Taslim for the Salat while facing forward and turning to his right side a little}}
\hadithdefcmd{tirmidhi}{297}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، وَهِقْلُ بْنُ زِيَادٍ، عَنِ الأَوْزَاعِيِّ، عَنْ قُرَّةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ حَذْفُ السَّلاَمِ سُنَّةٌ ‏.‏ قَالَ عَلِيُّ بْنُ حُجْرٍ قَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ يَعْنِي أَنْ لاَ تَمُدَّهُ مَدًّا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي يَسْتَحِبُّهُ أَهْلُ الْعِلْمِ وَرُوِيَ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ أَنَّهُ قَالَ التَّكْبِيرُ جَزْمٌ وَالسَّلاَمُ جَزْمٌ ‏.‏ وَهِقْلٌ يُقَالُ كَانَ كَاتِبَ الأَوْزَاعِيِّ ‏.‏\hadithno{297}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"Hadhf the Salam is a Sunnah}}
\hadithdefcmd{tirmidhi}{298}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَلَّمَ لاَ يَقْعُدُ إِلاَّ مِقْدَارَ مَا يَقُولُ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{298}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"When Allah's Messenger said the Salam he would not remain seated except long enough to say: (Allahumma antas-salam, wa minkas-salam, tabarakta dhal jalali wal-Ikram) 'O Allah! You are the One free of defects, and perfection is from You. Blessed are You, Possessor of Majesty and Honor}}
\hadithdefcmd{tirmidhi}{299}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، وَأَبُو مُعَاوِيَةَ عَنْ عَاصِمٍ الأَحْوَلِ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَقَالَ ‏"‏ تَبَارَكْتَ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ ثَوْبَانَ وَابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ ‏.‏ وَالْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى خَالِدٌ الْحَذَّاءُ هَذَا الْحَدِيثَ مِنْ حَدِيثِ عَائِشَةَ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ نَحْوَ حَدِيثِ عَاصِمٍ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ بَعْدَ التَّسْلِيمِ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏ وَرُوِيَ عَنْهُ أَنَّهُ كَانَ يَقُولُ ‏"‏ سُبْحَانَ رَبِّكَ رَبِّ الْعِزَّةِ عَمَّا يَصِفُونَ وَسَلاَمٌ عَلَى الْمُرْسَلِينَ وَالْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏\hadithno{299}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:(Another chain) which is similar, but he said: (Tabarakta ya dhal-jalali wal-ikram) "Blessed are You, O Possessor of Majesty and Honor}}
\hadithdefcmd{tirmidhi}{300}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا الأَوْزَاعِيُّ، حَدَّثَنِي شَدَّادٌ أَبُو عَمَّارٍ، حَدَّثَنِي أَبُو أَسْمَاءَ الرَّحَبِيُّ، قَالَ حَدَّثَنِي ثَوْبَانُ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَنْصَرِفَ مِنْ صَلاَتِهِ اسْتَغْفَرَ اللَّهَ ثَلاَثَ مَرَّاتٍ ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو عَمَّارٍ اسْمُهُ شَدَّادُ بْنُ عَبْدِ اللَّهِ ‏.‏\hadithno{300}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thawban, the freed slave of Allah's Messenger, narrated that :Allah's Messenger said: "When Allah's Messenger wanted to turn from his Salat, he would seek forgiveness from Allah three times, then say: (Allahumma Antas-Salam, wa minkas-salam, tabarakta ya dhal-jalali wal-Ikram) 'O Allah! You are the One free of defects and perfection is from You. Blessed are You, O Possesor of Majesty and Honor}}
\hadithdefcmd{tirmidhi}{301}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ قَبِيصَةَ بْنِ هُلْبٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَؤُمُّنَا فَيَنْصَرِفُ عَلَى جَانِبَيْهِ جَمِيعًا عَلَى يَمِينِهِ وَعَلَى شِمَالِهِ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ هُلْبٍ حَدِيثٌ حَسَنٌ ‏.‏ وَعَلَيْهِ الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ يَنْصَرِفُ عَلَى أَىِّ جَانِبَيْهِ شَاءَ إِنْ شَاءَ عَنْ يَمِينِهِ وَإِنْ شَاءَ عَنْ يَسَارِهِ ‏.‏ وَقَدْ صَحَّ الأَمْرَانِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَيُرْوَى عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ أَنَّهُ قَالَ إِنْ كَانَتْ حَاجَتُهُ عَنْ يَمِينِهِ أَخَذَ عَنْ يَمِينِهِ وَإِنْ كَانَتْ حَاجَتُهُ عَنْ يَسَارِهِ أَخَذَ عَنْ يَسَارِهِ ‏.‏\hadithno{301}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Qabisah bin Hulb narrated that his father said:"When Allah's Messenger would lead us in Salat he would turn (to leave) from both sides, on his right and on his left}}
\hadithdefcmd{tirmidhi}{302}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ يَحْيَى بْنِ عَلِيِّ بْنِ يَحْيَى بْنِ خَلاَّدِ بْنِ رَافِعٍ الزُّرَقِيِّ، عَنْ جَدِّهِ، عَنْ رِفَاعَةَ بْنِ رَافِعٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَمَا هُوَ جَالِسٌ فِي الْمَسْجِدِ يَوْمًا قَالَ رِفَاعَةُ وَنَحْنُ مَعَهُ إِذْ جَاءَهُ رَجُلٌ كَالْبَدَوِيِّ فَصَلَّى فَأَخَفَّ صَلاَتَهُ ثُمَّ انْصَرَفَ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ فَارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَرَجَعَ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَيْهِ فَقَالَ ‏"‏ وَعَلَيْكَ فَارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَفَعَلَ ذَلِكَ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلُّ ذَلِكَ يَأْتِي النَّبِيَّ صلى الله عليه وسلم فَيُسَلِّمُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَيَقُولُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ فَارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَخَافَ النَّاسُ وَكَبُرَ عَلَيْهِمْ أَنْ يَكُونَ مَنْ أَخَفَّ صَلاَتَهُ لَمْ يُصَلِّ فَقَالَ الرَّجُلُ فِي آخِرِ ذَلِكَ فَأَرِنِي وَعَلِّمْنِي فَإِنَّمَا أَنَا بَشَرٌ أُصِيبُ وَأُخْطِئُ ‏.‏ فَقَالَ ‏"‏ أَجَلْ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَتَوَضَّأْ كَمَا أَمَرَكَ اللَّهُ ثُمَّ تَشَهَّدْ وَأَقِمْ فَإِنْ كَانَ مَعَكَ قُرْآنٌ فَاقْرَأْ وَإِلاَّ فَاحْمَدِ اللَّهَ وَكَبِّرْهُ وَهَلِّلْهُ ثُمَّ ارْكَعْ فَاطْمَئِنَّ رَاكِعًا ثُمَّ اعْتَدِلْ قَائِمًا ثُمَّ اسْجُدْ فَاعْتَدِلْ سَاجِدًا ثُمَّ اجْلِسْ فَاطْمَئِنَّ جَالِسًا ثُمَّ قُمْ فَإِذَا فَعَلْتَ ذَلِكَ فَقَدْ تَمَّتْ صَلاَتُكَ وَإِنِ انْتَقَصْتَ مِنْهُ شَيْئًا انْتَقَصْتَ مِنْ صَلاَتِكَ ‏"‏ ‏.‏ قَالَ وَكَانَ هَذَا أَهْوَنَ عَلَيْهِمْ مِنَ الأَوَّلِ أَنَّهُ مَنِ انْتَقَصَ مِنْ ذَلِكَ شَيْئًا انْتَقَصَ مِنْ صَلاَتِهِ وَلَمْ تَذْهَبْ ��ُلُّهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَمَّارِ بْنِ يَاسِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ رِفَاعَةَ بْنِ رَافِعٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنْ رِفَاعَةَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{302}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Rifa`ah bin Rafi` narrated:"One day Allah's Messenger was sitting in the Masjid" Rifa'ah said: "And we were with him. Then what appeared to be a Bedouin man entered to pray, but he performed his Salat in a very brief manner. He then got up and greeted the prophet with Salam. The Prophet said (returning the greeting): 'And upon you. Go back and perform Salat, for indeed you have no prayed.' So he returned to perform Salat then came and greeted the Prophet with Salam. So he (the Prophet) said (returning the greeting): 'And upon you. Go back and perform Salat, for indeed you have not prayed.' [He did that] two or three times, each time coming to the Prophet, greeted the Prophet with Salam and the Prophet saying: 'And upon you. Go back and perform Salat, for indeed you have not prayed.' - until the people got scared and became very worried that one whose prayer was so brief had not actually prayed. Then in the end the man said: 'Then show me, and teach me, for I am a human who has suffered and is mistaken.' So he said: 'Alright. When you stand for Salat then perform Wudu as Allah ordered you. Then say the Tashahhud, and the Iqamah as well. If you know any Quran then recite it, if not then praise Allah, mention His greatness, and the Tahlil. Then bow such that you are at rest in your bowing, then stand completely, then prostrate completely, then sit such that you are at rest while sitting them stand. When you have done that, then you have completed your Salat, and if you leave out something, then you have made your Salat deficient.' And this was easier on them than the first matter, because if some of this was deficient, It would only reduce the reward of his Salat, it would not have gone entirely}}
\hadithdefcmd{tirmidhi}{303}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْمَسْجِدَ فَدَخَلَ رَجُلٌ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَرَدَّ عَلَيْهِ السَّلاَمَ فَقَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَرَجَعَ الرَّجُلُ فَصَلَّى كَمَا كَانَ صَلَّى ثُمَّ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَلَّمَ عَلَيْهِ فَرَدَّ عَلَيْهِ السَّلاَمَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ حَتَّى فَعَلَ ذَلِكَ ثَلاَثَ مِرَارٍ فَقَالَ لَهُ الرَّجُلُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أُحْسِنُ غَيْرَ هَذَا فَعَلِّمْنِي ‏.‏ فَقَالَ ‏"‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَكَبِّرْ ثُمَّ اقْرَأْ بِمَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا وَافْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَقَدْ رَوَى ابْنُ نُمَيْرٍ هَذَا الْحَدِيثَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَرِوَايَةُ يَحْيَى بْنِ سَعِيدٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ أَصَحُّ ‏.‏ وَسَعِيدٌ الْمَقْبُرِيُّ قَدْ سَمِعَ مِنْ أَبِي هُرَيْرَةَ وَرَوَى عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ وَأَبُو سَعِيدٍ الْمَقْبُرِيُّ اسْمُهُ كَيْسَانُ وَسَعِيدٌ الْمَقْبُرِيُّ يُكْنَى أَبَا سَعْدٍ وَكَيْسَانُ عَبْدٌ كَانَ مُكَاتَبًا لِبَعْضِهِمْ ‏.‏\hadithno{303}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"Allah's Messenger entered the Masjid, and a man entered and offered Salat. Then he came to give Salam to the Propet. He returned the Salam to him and said: 'Go back and perform Salat, for indeed you have not prayed.' So the man returned to pray as he had prayed. Then he came to give Salam to the Prophet. He returned Salam to him, then [Allah's Messenger] said: 'Go back and perform Salat, for indeed you have not prayed' until he had done that three times. So the man said to him: 'By the One who sent you with the Truth, I do not know any better than this, so teach me.' So he said [to him]: 'When you stand for Salat then say the Takbir, then recite what is easy for you of the Quran. Then bow until you are at rest while bowing, then rise up until you are at rest sitting. Do that in all of your Salat}}
\hadithdefcmd{tirmidhi}{304}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ سَمِعْتُهُ وَهُوَ، فِي عَشَرَةٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَحَدُهُمْ أَبُو قَتَادَةَ بْنُ رِبْعِيٍّ يَقُولُ أَنَا أَعْلَمُكُمْ بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالُوا مَا كُنْتَ أَقْدَمَنَا لَهُ صُحْبَةً وَلاَ أَكْثَرَنَا لَهُ إِتْيَانًا قَالَ بَلَى ‏.‏ قَالُوا فَاعْرِضْ ‏.‏ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ اعْتَدَلَ قَائِمًا وَرَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ فَإِذَا أَرَادَ أَنْ يَرْكَعَ رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏ وَرَكَعَ ثُمَّ اعْتَدَلَ فَلَمْ يُصَوِّبْ رَأْسَهُ وَلَمْ يُقْنِعْ وَوَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ ثُمَّ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ وَرَفَعَ يَدَيْهِ وَاعْتَدَلَ حَتَّى يَرْجِعَ كُلُّ عَظْمٍ فِي مَوْضِعِهِ مُعْتَدِلاً ثُمَّ أَهْوَى إِلَى الأَرْضِ سَاجِدًا ثُمَّ قَالَ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏ ثُمَّ جَافَى عَضُدَيْهِ عَنْ إِبْطَيْهِ وَفَتَخَ أَصَابِعَ رِجْلَيْهِ ثُمَّ ثَنَى رِجْلَهُ الْيُسْرَى وَقَعَدَ عَلَيْهَا ثُمَّ اعْتَدَلَ حَتَّى يَرْجِعَ كُلُّ عَظْمٍ فِي مَوْضِعِهِ مُعْتَدِلاً ثُمَّ أَهْوَى سَاجِدًا ثُمَّ قَالَ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏ ثُمَّ ثَنَى رِجْلَهُ وَقَعَدَ وَاعْتَدَلَ حَتَّى يَرْجِعَ كُلُّ عَظْمٍ فِي مَوْضِعِهِ ثُمَّ نَهَضَ ثُمَّ صَنَعَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ حَتَّى إِذَا قَامَ مِنَ السَّجْدَتَيْنِ كَبَّرَ وَرَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا مَنْكِبَيْهِ كَمَا صَنَعَ حِينَ افْتَتَحَ الصَّلاَةَ ثُمَّ صَنَعَ كَذَلِكَ حَتَّى كَانَتِ الرَّكْعَةُ الَّتِي تَنْقَضِي فِيهَا صَلاَتُهُ أَخَّرَ رِجْلَهُ الْيُسْرَى وَقَعَدَ عَلَى شِقِّهِ مُتَوَرِّكًا ثُمَّ سَلَّمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَمَعْنَى قَوْلِهِ وَرَفَعَ يَدَيْهِ إِذَا قَامَ مِنَ السَّجْدَتَيْنِ يَعْنِي قَامَ مِنَ الرَّكْعَتَيْنِ ‏.‏\hadithno{304}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Amr bin Ata' narrated from Abu Humaid As-Saidi, :he (Muhammad) said: "I heard him saying - while he was among ten of the Companions of the Prophet, one of whom was Abu Qatadah bin Ribi - 'I am the most knowledgeable among you of the Salat of the Allah's Messenger.' They said: 'You did not precede us in his companionship, nor were you in his company more than us.' He said: 'Even still." They said: 'Go ahead.' So he said: 'When Allah's Messenger stood for Salat he would stand with his back straight and raise his hands until they were at the level of his shoulder. Then he would say: (Allahu Akbar) "Allah is Most Great" and bow. Then he would straighten (his back) so that he would not lower his head, nor raise it, and he placed his hands on his knees. Then he said: (Sami Allahu liman hamidah) "Allah listens to those who praise Him." And he raised his hands and stood up straight until all of his bones completely returned to their places. Then he went down to the ground prostrating, then he said: (Allahu Akbar) "Allah is Most Great." Then he held his upper arms away from his midsection, and opened his toes on his feet (facing the Qiblah), then he bend his left foot and sat on it then straightened up until all of his bones completely returned to their placed, then he went down to prostrate. Then he said: (Allahu Akbar) "Allah is Most Great," then he bent his foot and sat and straightened up until all of his bones completely returned to their places. Then he got up. Then in the second Rak'ah he did the same as that, such that when he stood from the two prostrations, he sad the Takbir and raised his hands until they were at the level of his shoulders as he did when he opened the Salat. Then he did like that until it was the Rak'ah in which his Salat was to end, when he moved his left foot over and sat on his side (in the Mutawarrik postion). Then he said the Taslim}}
\hadithdefcmd{tirmidhi}{305}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ الْحُلْوَانِيُّ، وَسَلَمَةُ بْنُ شَبِيبٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو عَاصِمٍ النَّبِيلُ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، قَالَ سَمِعْتُ أَبَا حُمَيْدٍ السَّاعِدِيَّ، فِي عَشَرَةٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو قَتَادَةَ بْنُ رِبْعِيٍّ فَذَكَرَ نَحْوَ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ بِمَعْنَاهُ وَزَادَ فِيهِ أَبُو عَاصِمٍ عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ هَذَا الْحَرْفَ قَالُوا صَدَقْتَ هَكَذَا صَلَّى النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى زَادَ أَبُو عَاصِمٍ الضَّحَّاكُ بْنُ مَخْلَدٍ فِي هَذَا الْحَدِيثِ عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ هَذَا الْحَرْفَ قَالُوا صَدَقْتَ هَكَذَا صَلَّى النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{305}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{(Another chain) that Muhammad bin Amir bin Ata narrated from Abu Humaid As-Saidi,:he (Muhammad) said: "I heard him saying - while he was among ten of the Companions of the Prophet, one of whom was Abu Qatadah bin Ribi}}
\hadithdefcmd{tirmidhi}{306}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ زِيَادِ بْنِ عَلاَقَةَ، عَنْ عَمِّهِ، قُطْبَةَ بْنِ مَالِكٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الْفَجْرِ ‏:‏ ‏(‏وَالنَّخْلَ بَاسِقَاتٍ ‏)‏ فِي الرَّكْعَةِ الأُولَى ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَمْرِو بْنِ حُرَيْثٍ وَجَابِرِ بْنِ سَمُرَةَ وَعَبْدِ اللَّهِ بْنِ السَّائِبِ وَأَبِي بَرْزَةَ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ قُطْبَةَ بْنِ مَالِكٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ فِي الصُّبْحِ بِالْوَاقِعَةِ ‏.‏ وَرُوِيَ عَنْهُ أَنَّهُ كَانَ يَقْرَأُ فِي الْفَجْرِ مِنْ سِتِّينَ آيَةً إِلَى مِائَةٍ ‏.‏ وَرُوِيَ عَنْهُ أَنَّهُ قَرَأَ ‏:‏ ‏(‏إِذََا الشَّمْسُ كُوِّرَتْ ‏)‏ ‏.‏ وَرُوِيَ عَنْ عُمَرَ أَنَّهُ كَتَبَ إِلَى أَبِي مُوسَى أَنِ اقْرَأْ فِي الصُّبْحِ بِطِوَالِ الْمُفَصَّلِ ‏.‏ قَالَ أَبُو عِيسَى وَعَلَى هَذَا الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ وَبِهِ قَالَ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ ‏.‏\hadithno{306}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Qutbah bin Malik narrated:"I heard Allah's Messenger reciting for Fajr: And tall date palms in the first Rak'ah}}
\hadithdefcmd{tirmidhi}{307}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ بِالسَّمَاءِ ذَاتِ الْبُرُوجِ وَالسَّمَاءِ وَالطَّارِقِ وَشِبْهِهِمَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ خَبَّابٍ وَأَبِي سَعِيدٍ وَأَبِي قَتَادَةَ وَزَيْدِ بْنِ ثَابِتٍ وَالْبَرَاءِ بْنِ عَازِبٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرِ بْنِ سَمُرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ فِي الظُّهْرِ قَدْرَ تَنْزِيلُ السَّجْدَةَ ‏.‏ وَرُوِيَ عَنْهُ أَنَّهُ كَانَ يَقْرَأُ فِي الرَّكْعَةِ الأُولَى مِنَ الظُّهْرِ قَدْرَ ثَلاَثِينَ آيَةً وَفِي الرَّكْعَةِ الثَّانِيَةِ قَدْرَ خَمْسَ عَشْرَةَ آيَةً ‏.‏ وَرُوِيَ عَنْ عُمَرَ أَنَّهُ كَتَبَ إِلَى أَبِي مُوسَى أَنِ اقْرَأْ فِي الظُّهْرِ بِأَوْسَاطِ الْمُفَصَّلِ ‏.‏ وَرَأَى بَعْضُ أَهْلِ الْعِلْمِ أَنَّ الْقِرَاءَةَ فِي صَلاَةِ الْعَصْرِ كَنَحْوِ الْقِرَاءَةِ فِي صَلاَةِ الْمَغْرِبِ يَقْرَأُ بِقِصَارِ الْمُفَصَّلِ ‏.‏ وَرُوِيَ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ أَنَّهُ قَالَ تَعْدِلُ صَلاَةُ الْعَصْرِ بِصَلاَةِ الْمَغْرِبِ فِي الْقِرَاءَةِ ‏.‏ وَقَالَ إِبْرَاهِيمُ تُضَاعَفُ صَلاَةُ الظُّهْرِ عَلَى صَلاَةِ الْعَصْرِ فِي الْقِرَاءَةِ أَرْبَعَ مِرَارٍ ‏.‏\hadithno{307}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Jabir bin Samurah narrated:"For Zuhr and Asr, Allah's Messenger would recite: By the heavens, holding the Buruj and (By the heavens and At-Tariq) and similar to them}}
\hadithdefcmd{tirmidhi}{308}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُمِّهِ أُمِّ الْفَضْلِ، قَالَتْ خَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَاصِبٌ رَأْسَهُ فِي مَرَضِهِ فَصَلَّى الْمَغْرِبَ فَقَرَأَ بِالْمُرْسَلاَتِ قَالَتْ فَمَا صَلاَّهَا بَعْدُ حَتَّى لَقِيَ اللَّهَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جُبَيْرِ بْنِ مُطْعِمٍ وَابْنِ عُمَرَ وَأَبِي أَيُّوبَ وَزَيْدِ بْنِ ثَابِتٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ الْفَضْلِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ فِي الْمَغْرِبِ بِالأَعْرَافِ فِي الرَّكْعَتَيْنِ كِلْتَيْهِمَا ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ فِي الْمَغْرِبِ بِالطُّورِ ‏.‏ وَرُوِيَ عَنْ عُمَرَ أَنَّهُ كَتَبَ إِلَى أَبِي مُوسَى أَنِ اقْرَأْ فِي الْمَغْرِبِ بِقِصَارِ الْمُفَصَّلِ ‏.‏ وَرُوِيَ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ أَنَّهُ قَرَأَ فِي الْمَغْرِبِ بِقِصَارِ الْمُفَصَّلِ ‏.‏ قَالَ وَعَلَى هَذَا الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ ابْنُ الْمُبَارَكِ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ الشَّافِعِيُّ وَذُكِرَ عَنْ مَالِكٍ أَنَّهُ كَرِهَ أَنْ يُقْرَأَ فِي صَلاَةِ الْمَغْرِبِ بِالسُّوَرِ الطُّوَلِ نَحْوِ الطُّورِ وَالْمُرْسَلاَتِ قَالَ الشَّافِعِيُّ لاَ أَكْرَهُ ذَلِكَ بَلْ أَسْتَحِبُّ أَنْ يُقْرَأَ بِهَذِهِ السُّوَرِ فِي صَلاَةِ الْمَغْرِبِ ‏.‏\hadithno{308}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Al-Fadl narrated:"Allah's Messenger came out to us with his head bandaged from his illness. He prayed Maghrib, reciting (Surat) Al-Mursalat." [She said:] "He did not pray it again until he met Allah the Might and Sublime}}
\hadithdefcmd{tirmidhi}{309}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ الْبَصْرِيُّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا حُسَيْنُ بْنُ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الْعِشَاءِ الآخِرَةِ بِالشَّمْسِ وَضُحَاهَا وَنَحْوِهَا مِنَ السُّوَرِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الْبَرَاءِ بْنِ عَازِبٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بُرَيْدَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ فِي الْعِشَاءِ الآخِرَةِ بِالتِّينِ وَالزَّيْتُونِ ‏.‏ وَرُوِيَ عَنْ عُثْمَانَ بْنِ عَفَّانَ أَنَّهُ كَانَ يَقْرَأُ فِي الْعِشَاءِ بِسُوَرٍ مِنْ أَوْسَاطِ الْمُفَصَّلِ نَحْوِ سُورَةِ الْمُنَافِقِينَ وَأَشْبَاهِهَا ‏.‏ وَرُوِيَ عَنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ أَنَّهُمْ قَرَءُوا بِأَكْثَرَ مِنْ هَذَا وَأَقَلَّ فَكَأَنَّ الأَمْرَ عِنْدَهُمْ وَاسِعٌ فِي هَذَا ‏.‏ وَأَحْسَنُ شَيْءٍ فِي ذَلِكَ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ بِالشَّمْسِ وَضُحَاهَا وَالتِّينِ وَالزَّيْتُونِ ‏.‏\hadithno{309}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Buraidah narrated that his father (Buraidah) said:"Allah's Messenger would recite: By the sun and its brightness, or similar Surah for the latter Isha (prayer)}}
\hadithdefcmd{tirmidhi}{310}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ فِي الْعِشَاءِ الآخِرَةِ بِالتِّينِ وَالزَّيْتُونِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{310}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara bin Azib narrated:"The Prophet would recite: By the fig and the olive for Isha}}
\hadithdefcmd{tirmidhi}{311}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مَكْحُولٍ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الصُّبْحَ فَثَقُلَتْ عَلَيْهِ الْقِرَاءَةُ فَلَمَّا انْصَرَفَ قَالَ ‏"‏ إِنِّي أَرَاكُمْ تَقْرَءُونَ وَرَاءَ إِمَامِكُمْ ‏"‏ ‏.‏ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِي وَاللَّهِ ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلُوا إِلاَّ بِأُمِّ الْقُرْآنِ فَإِنَّهُ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ وَأَنَسٍ وَأَبِي قَتَادَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُبَادَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى هَذَا الْحَدِيثَ الزُّهْرِيُّ عَنْ مَحْمُودِ بْنِ الرَّبِيعِ عَنْ عُبَادَةَ بْنِ الصَّامِتِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏ قَالَ وَهَذَا أَصَحُّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ فِي الْقِرَاءَةِ خَلْفَ الإِمَامِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ يَرَوْنَ الْقِرَاءَةَ خَلْفَ الإِمَامِ ‏.‏\hadithno{311}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Ubadah bin As-Samit narrated:"Allah's Messenger prayed the Subh prayer, and he had difficulty with the recitation. When turned (after finishing) he said: 'I think that you are reciting behind your Imam?'" He said: "We said: 'Yes, Messenger of Allah, by Allah!' He said: 'Do not do that, except for Umm Al-Kitab, for there is no Salat for one who does not recite it}}
\hadithdefcmd{tirmidhi}{312}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ أُكَيْمَةَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنْ صَلاَةٍ جَهَرَ فِيهَا بِالْقِرَاءَةِ فَقَالَ ‏"‏ هَلْ قَرَأَ مَعِي أَحَدٌ مِنْكُمْ آنِفًا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنِّي أَقُولُ مَا لِي أُنَازَعُ الْقُرْآنَ ‏"‏ ‏.‏ قَالَ فَانْتَهَى النَّاسُ عَنِ الْقِرَاءَةِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيمَا جَهَرَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الصَّلَوَاتِ بِالْقِرَاءَةِ حِينَ سَمِعُوا ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعِمْرَانَ بْنِ حُصَيْنٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَابْنُ أُكَيْمَةَ اللَّيْثِيُّ اسْمُهُ عُمَارَةُ ‏.‏ وَيُقَالُ عَمْرُو بْنُ أُكَيْمَةَ ‏.‏ وَرَوَى بَعْضُ أَصْحَابِ الزُّهْرِيِّ هَذَا الْحَدِيثَ وَذَكَرُوا هَذَا الْحَرْفَ قَالَ قَالَ الزُّهْرِيُّ فَانْتَهَى النَّاسُ عَنِ الْقِرَاءَةِ حِينَ سَمِعُوا ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَلَيْسَ فِي هَذَا الْحَدِيثِ مَا يَدْخُلُ عَلَى مَنْ رَأَى الْقِرَاءَةَ خَلْفَ الإِمَامِ لأَنَّ أَبَا هُرَيْرَةَ هُوَ الَّذِي رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثَ وَرَوَى أَبُو هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ صَلَّى صَلاَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَهِيَ خِدَاجٌ فَهِيَ خِدَاجٌ غَيْرُ تَمَامٍ ‏"‏ ‏.‏ فَقَالَ لَهُ حَامِلُ الْحَدِيثِ إِنِّي أَكُونُ أَحْيَانًا وَرَاءَ الإِمَامِ قَالَ اقْرَأْ بِهَا فِي نَفْسِكَ ‏.‏ وَرَوَى أَبُو عُثْمَانَ النَّهْدِيُّ عَنْ أَبِي هُرَيْرَةَ قَالَ أَمَرَنِي النَّبِيُّ صلى الله عليه وسلم أَنْ أُنَادِيَ أَنْ لاَ صَلاَةَ إِلاَّ بِقِرَاءَةِ فَاتِحَةِ الْكِتَابِ ‏.‏ وَاخْتَارَ أَكْثَرُ أَصْحَابِ الْحَدِيثِ أَنْ لاَ يَقْرَأَ الرَّجُلُ إِذَا جَهَرَ الإِمَامُ بِالْقِرَاءَةِ وَقَالُوا يَتَتَبَّعُ سَكَتَاتِ الإِمَامِ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْقِرَاءَةِ خَلْفَ الإِمَامِ فَرَأَى أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَمَنْ بَعْدَهُمُ الْقِرَاءَةَ خَلْفَ الإِمَامِ وَبِهِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُ قَالَ أَنَا أَقْرَأُ خَلْفَ الإِمَامِ وَالنَّاسُ يَقْرَءُونَ إِلاَّ قَوْمًا مِنَ الْكُوفِيِّينَ وَأَرَى أَنَّ مَنْ لَمْ يَقْرَأْ صَلاَتُهُ جَائِزَةٌ ‏.‏ وَشَدَّدَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ فِي تَرْكِ قِرَاءَةِ فَاتِحَةِ الْكِتَابِ وَإِنْ كَانَ خَلْفَ الإِمَامِ فَقَالُوا لاَ تُجْزِئُ صَلاَةٌ إِلاَّ بِقِرَاءَةِ فَاتِحَةِ الْكِتَابِ وَحْدَهُ كَانَ أَوْ خَلْفَ الإِمَامِ ‏.‏ وَذَهَبُوا إِلَى مَا رَوَى عُبَادَةُ بْنُ الصَّامِتِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَرَأَ عُبَادَةُ بْنُ الصَّامِتِ بَعْدَ النَّبِيِّ صلى الله عليه وسلم خَلْفَ الإِمَامِ وَتَأَوَّلَ قَوْلَ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ صَلاَةَ إِلاَّ بِقِرَاءَةِ فَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَإِسْحَاقُ وَغَيْرُهُمَا ‏.‏ وَأَمَّا أَحْمَدُ بْنُ حَنْبَلٍ فَقَالَ مَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏ إِذَا كَانَ وَحْدَهُ ‏.‏ وَاحْتَجَّ بِحَدِيثِ جَابِرِ بْنِ عَبْدِ اللَّهِ حَيْثُ قَالَ مَنْ صَلَّى رَكْعَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَلَمْ يُصَلِّ إِلاَّ أَنْ يَكُونَ وَرَاءَ الإِمَامِ ‏.‏ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ فَهَذَا رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم تَأَوَّلَ قَوْلَ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏ أَنَّ هَذَا إِذَا كَانَ وَحْدَهُ ‏.‏ وَاخْتَارَ أَحْمَدُ مَعَ هَذَا الْقِرَاءَةَ خَلْفَ الإِمَامِ وَأَنْ لاَ يَتْرُكَ الرَّجُلُ فَاتِحَةَ الْكِتَابِ وَإِنْ كَانَ خَلْفَ الإِمَامِ ‏.‏\hadithno{312}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated:"Allah's Messenger turned (after praying) from a Salat in which he recited aloud and said: 'Has any one of you recite along with me just now?' A man said: 'Yes, O Messenger of Allah.' He said: 'Indeed I said to myself: Why was I being contended with for the Quran?'" He (Az-Zuhri one of the narrators) said: "So when they heard that from Allah's Messenger, the people stopped reciting with Allah's Messenger in the prayers that Allah's Messenger recited aloud}}
\hadithdefcmd{tirmidhi}{313}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي نُعَيْمٍ، وَهْبِ بْنِ كَيْسَانَ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ مَنْ صَلَّى رَكْعَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَلَمْ يُصَلِّ إِلاَّ أَنْ يَكُونَ وَرَاءَ الإِمَامِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{313}\hadithgrade{Ahmad Muhammad Shakir: Sahih Muquf; Al-Albani: Sahih Muquf; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Nu'aim Wahb bin Kaisan narated that he heard Jabir bin 'Abdullah saying:"Whoever prayed a Rak'ah in which he did not recite Umm Al-Qur'an, then he did not pray except if he was behind an Imam." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{314}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ لَيْثٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَسَنِ، عَنْ أُمِّهِ، فَاطِمَةَ بِنْتِ الْحُسَيْنِ عَنْ جَدَّتِهَا، فَاطِمَةَ الْكُبْرَى قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ الْمَسْجِدَ صَلَّى عَلَى مُحَمَّدٍ وَسَلَّمَ وَقَالَ ‏"‏ رَبِّ اغْفِرْ لِي ذُنُوبِي وَافْتَحْ لِي أَبْوَابَ رَحْمَتِكَ ‏"‏ ‏.‏ وَإِذَا خَرَجَ صَلَّى عَلَى مُحَمَّدٍ وَسَلَّمَ وَقَالَ ‏"‏ رَبِّ اغْفِرْ لِي ذُنُوبِي وَافْتَحْ لِي أَبْوَابَ فَضْلِكَ ‏"‏ ‏.‏\hadithno{314}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Fatimah the Great narrated:"When Allah's Messenger entered the Masjid he said Salat and Salam upon Muhammad and then said: (Rabbighfirli dhunubi, waftahli abwaba rahmatik) 'O pardon my sins, and open the gates of Your mercy for me.' And when he exited he said Salat and Salam upon Muhammad, and then said: (Rabbighfirli dunubi, waftahli abwaba rakmatik) 'O Lord pardon my sins, and open the gates of Your blessings for me}}
\hadithdefcmd{tirmidhi}{315}{وَقَالَ عَلِيُّ بْنُ حُجْرٍ قَالَ إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ فَلَقِيتُ عَبْدَ اللَّهِ بْنَ الْحَسَنِ بِمَكَّةَ فَسَأَلْتُهُ عَنْ هَذَا الْحَدِيثِ، فَحَدَّثَنِي بِهِ، قَالَ كَانَ إِذَا دَخَلَ قَالَ ‏ "‏ رَبِّ افْتَحْ لِي بَابَ رَحْمَتِكَ وَإِذَا خَرَجَ $$قَالَ رَبِّ افْتَحْ لِي بَابَ فَضْلِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي حُمَيْدٍ وَأَبِي أُسَيْدٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ فَاطِمَةَ حَدِيثٌ حَسَنٌ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏ وَفَاطِمَةُ بِنْتُ الْحُسَيْنِ لَمْ تُدْرِكْ فَاطِمَةَ الْكُبْرَى إِنَّمَا عَاشَتْ فَاطِمَةُ بَعْدَ النَّبِيِّ صلى الله عليه وسلم أَشْهُرًا ‏.‏\hadithno{315}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ismail bin Ibrahim (a narrator in the chain of Hadith no. 314) said:"I met Abdullah bin al Husain in Makkah, so I asked him about this Hadith, so he narrated it to me, he said: 'When Allah's Messenger entered, he said (Rabbi aftahli abwaba rahmatik) 'O Lord, open the gates of Your mercy for me.' And when he exited he said: (Rabbi iftahli abwaba fadlik) 'O Lord, open the gates of Your blessings for me}}
\hadithdefcmd{tirmidhi}{316}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا جَاءَ أَحَدُكُمُ الْمَسْجِدَ فَلْيَرْكَعْ رَكْعَتَيْنِ قَبْلَ أَنْ يَجْلِسَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي أُمَامَةَ وَأَبِي هُرَيْرَةَ وَأَبِي ذَرٍّ وَكَعْبِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي قَتَادَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ مُحَمَّدُ بْنُ عَجْلاَنَ وَغَيْرُ وَاحِدٍ عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ نَحْوَ رِوَايَةِ مَالِكِ بْنِ أَنَسٍ ‏.‏ وَرَوَى سُهَيْلُ بْنُ أَبِي صَالِحٍ هَذَا الْحَدِيثَ عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا حَدِيثٌ غَيْرُ مَحْفُوظٍ وَالصَّحِيحُ حَدِيثُ أَبِي قَتَادَةَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَصْحَابِنَا اسْتَحَبُّوا إِذَا دَخَلَ الرَّجُلُ الْمَسْجِدَ أَنْ لاَ يَجْلِسَ حَتَّى يُصَلِّيَ رَكْعَتَيْنِ إِلاَّ أَنْ يَكُونَ لَهُ عُذْرٌ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ وَحَدِيثُ سُهَيْلِ بْنِ أَبِي صَالِحٍ خَطَأٌ أَخْبَرَنِي بِذَلِكَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ عَنْ عَلِيِّ بْنِ الْمَدِينِيِّ ‏.‏\hadithno{316}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Qatadah narrated that :Allah's Messenger said: "When one of you comes to the Masjid, then let him perform two Rak'ah before sitting}}
\hadithdefcmd{tirmidhi}{317}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَأَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ الْمَرْوَزِيُّ قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الأَرْضُ كُلُّهَا مَسْجِدٌ إِلاَّ الْمَقْبُرَةَ وَالْحَمَّامَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي هُرَيْرَةَ وَجَابِرٍ وَابْنِ عَبَّاسٍ وَحُذَيْفَةَ وَأَنَسٍ وَأَبِي أُمَامَةَ وَأَبِي ذَرٍّ قَالُوا إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ جُعِلَتْ لِيَ الأَرْضُ مَسْجِدًا وَطَهُورًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ قَدْ رُوِيَ عَنْ عَبْدِ الْعَزِيزِ بْنِ مُحَمَّدٍ رِوَايَتَيْنِ مِنْهُمْ مَنْ ذَكَرَهُ عَنْ أَبِي سَعِيدٍ وَمِنْهُمْ مَنْ لَمْ يَذْكُرْهُ ‏.‏ وَهَذَا حَدِيثٌ فِيهِ اضْطِرَابٌ ‏.‏ رَوَى سُفْيَانُ الثَّوْرِيُّ عَنْ عَمْرِو بْنِ يَحْيَى عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ ‏.‏ وَرَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ عَمْرِو بْنِ يَحْيَى عَنْ أَبِيهِ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ مُحَمَّدُ بْنُ إِسْحَاقَ عَنْ عَمْرِو بْنِ يَحْيَى عَنْ أَبِيهِ قَالَ وَكَانَ عَامَّةُ رِوَايَتِهِ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَكَأَنَّ رِوَايَةَ الثَّوْرِيِّ عَنْ عَمْرِو بْنِ يَحْيَى عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَثْبَتُ وَأَصَحُّ مُرْسَلاً ‏.‏\hadithno{317}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :Allah's Messenger said: "All of the earth is a Masjid except for the graveyard and the washroom}}
\hadithdefcmd{tirmidhi}{318}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ بَنَى لِلَّهِ مَسْجِدًا بَنَى اللَّهُ لَهُ مِثْلَهُ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ وَعُمَرَ وَعَلِيٍّ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَنَسٍ وَابْنِ عَبَّاسٍ وَعَائِشَةَ وَأُمِّ حَبِيبَةَ وَأَبِي ذَرٍّ وَعَمْرِو بْنِ عَبَسَةَ وَوَاثِلَةَ بْنِ الأَسْقَعِ وَأَبِي هُرَيْرَةَ وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُثْمَانَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَحْمُودُ بْنُ لَبِيدٍ قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم وَمَحْمُودُ بْنُ الرَّبِيعِ قَدْ رَأَى النَّبِيَّ صلى الله عليه وسلم وَهُمَا غُلاَمَانِ صَغِيرَانِ مَدَنِيَّانِ ‏.‏\hadithno{318}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Uthman bin Affan narrated that :he heard Allah's Messenger say: "Whoever builds a Masjid for (the sake of) Allah, then Allah will build a similar house for him in Paradise}}
\hadithdefcmd{tirmidhi}{319}{وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ بَنَى لِلَّهِ مَسْجِدًا صَغِيرًا كَانَ أَوْ كَبِيرًا بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا نُوحُ بْنُ قَيْسٍ عَنْ عَبْدِ الرَّحْمَنِ مَوْلَى قَيْسٍ عَنْ زِيَادٍ النُّمَيْرِيِّ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏\hadithno{319}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It has been related that :the Prophet said: "Whoever builds a Masjid for (the sake of) Allah, be it small or large, then Allah will build a house for him in Paradise}}
\hadithdefcmd{tirmidhi}{320}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ أَبِي صَالِحٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَائِرَاتِ الْقُبُورِ وَالْمَتَّخِذِينَ عَلَيْهَا الْمَسَاجِدَ وَالسُّرُجَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو صَالِحٍ هَذَا هُوَ مَوْلَى أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ وَاسْمُهُ بَاذَانُ وَيُقَالُ بَاذَامُ أَيْضًا ‏.‏\hadithno{320}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbbas narrated:"Allah's Messenger cursed the women who visit the graves, and those who use them as Masajid and put torches on them}}
\hadithdefcmd{tirmidhi}{321}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نَنَامُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ وَنَحْنُ شَبَابٌ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ فِي النَّوْمِ فِي الْمَسْجِدِ ‏.‏ قَالَ ابْنُ عَبَّاسٍ لاَ يَتَّخِذُهُ مَبِيتًا وَلاَ مَقِيلاً ‏.‏ وَقَوْمٌ مِنْ أَهْلِ الْعِلْمِ ذَهَبُوا إِلَى قَوْلِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{321}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"We would sleep in the Masjid during the time of Allah's Messenger and we were young men}}
\hadithdefcmd{tirmidhi}{322}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ تَنَاشُدِ الأَشْعَارِ فِي الْمَسْجِدِ وَعَنِ الْبَيْعِ وَالاِشْتِرَاءِ فِيهِ وَأَنْ يَتَحَلَّقَ النَّاسُ فِيهِ يَوْمَ الْجُمُعَةِ قَبْلَ الصَّلاَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَجَابِرٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ حَدِيثٌ حَسَنٌ ‏.‏ وَعَمْرُو بْنُ شُعَيْبٍ هُوَ ابْنُ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ رَأَيْتُ أَحْمَدَ وَإِسْحَاقَ وَذَكَرَ غَيْرَهُمَا يَحْتَجُّونَ بِحَدِيثِ عَمْرِو بْنِ شُعَيْبٍ ‏.‏ قَالَ مُحَمَّدٌ وَقَدْ سَمِعَ شُعَيْبُ بْنُ مُحَمَّدٍ مِنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى وَمَنْ تَكَلَّمَ فِي حَدِيثِ عَمْرِو بْنِ شُعَيْبٍ إِنَّمَا ضَعَّفَهُ لأَنَّهُ يُحَدِّثُ عَنْ صَحِيفَةِ جَدِّهِ كَأَنَّهُمْ رَأَوْا أَنَّهُ لَمْ يَسْمَعْ هَذِهِ الأَحَادِيثَ مِنْ جَدِّهِ ‏.‏ قَالَ عَلِيُّ بْنُ عَبْدِ اللَّهِ وَذُكِرَ عَنْ يَحْيَى بْنِ سَعِيدٍ أَنَّهُ قَالَ حَدِيثُ عَمْرِو بْنِ شُعَيْبٍ عِنْدَنَا وَاهِي ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ الْبَيْعَ وَالشِّرَاءَ فِي الْمَسْجِدِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَدْ رُوِيَ عَنْ بَعْضِ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ رُخْصَةٌ فِي الْبَيْعِ وَالشِّرَاءِ فِي الْمَسْجِدِ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي غَيْرِ حَدِيثٍ رُخْصَةٌ فِي إِنْشَادِ الشِّعْرِ فِي الْمَسْجِدِ ‏.‏\hadithno{322}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather (Abdullah bin Amr Al-As), that :Allah's Messenger prohibited the recitation of poetry in the Masjid, and from selling and buying in it, and (he prohibited) the people from forming circles in it on Friday before the Salat}}
\hadithdefcmd{tirmidhi}{323}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ أُنَيْسِ بْنِ أَبِي يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ امْتَرَى رَجُلٌ مِنْ بَنِي خُدْرَةَ وَرَجُلٌ مِنْ بَنِي عَمْرِو بْنِ عَوْفٍ فِي الْمَسْجِدِ الَّذِي أُسِّسَ عَلَى التَّقْوَى فَقَالَ الْخُدْرِيُّ هُوَ مَسْجِدُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَقَالَ الآخَرُ هُوَ مَسْجِدُ قُبَاءٍ ‏.‏ فَأَتَيَا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ فَقَالَ ‏ "‏ هُوَ هَذَا يَعْنِي مَسْجِدَهُ وَفِي ذَلِكَ خَيْرٌ كَثِيرٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ حَدَّثَنَا أَبُو بَكْرٍ عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ قَالَ سَأَلْتُ يَحْيَى بْنَ سَعِيدٍ عَنْ مُحَمَّدِ بْنِ أَبِي يَحْيَى الأَسْلَمِيِّ فَقَالَ لَمْ يَكُنْ بِهِ بَأْسٌ وَأَخُوهُ أُنَيْسُ بْنُ أَبِي يَحْيَى أَثْبَتُ مِنْهُ ‏.‏\hadithno{323}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated:"A man from Banu Khudrah and a man from Banu Amr bin Awf were disputing about the Masjid that was founded upon Taqwa. The man from Banu Khudrah said: 'It is the Masjid of Allah's Messenger.' The other one said that it was Masjid Qub. So they went to ask Allah's Messenger about that. He said: 'It is this - meaning his Masjid - 'and in that one (Masjid Quba) there is much good}}
\hadithdefcmd{tirmidhi}{324}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ أَبُو كُرَيْبٍ، وَسُفْيَانُ بْنُ وَكِيعٍ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا أَبُو الأَبْرَدِ، مَوْلَى بَنِي خَطْمَةَ أَنَّهُ سَمِعَ أُسَيْدَ بْنَ ظُهَيْرٍ الأَنْصَارِيَّ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّلاَةُ فِي مَسْجِدِ قُبَاءٍ كَعُمْرَةٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ حُنَيْفٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُسَيْدٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَلاَ نَعْرِفُ لأُسَيْدِ بْنِ ظُهَيْرٍ شَيْئًا يَصِحُّ غَيْرَ هَذَا الْحَدِيثِ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي أُسَامَةَ عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ ‏.‏ وَأَبُو الأَبْرَدِ اسْمُهُ زِيَادٌ مَدِينِيٌّ ‏.‏\hadithno{324}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Al-Abrad the freed slave of Banu Khatmah narrated that he heard Usaid bin Zuhair Al-Ansari - and he was one of the Companions of the Prophet - narrated that :the Prophet said: "The Salat in Masjid Quba is like Umrah}}
\hadithdefcmd{tirmidhi}{325}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ رَبَاحٍ، وَعُبَيْدِ اللَّهِ بْنِ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا خَيْرٌ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَلَمْ يَذْكُرْ قُتَيْبَةُ فِي حَدِيثِهِ عَنْ عُبَيْدِ اللَّهِ إِنَّمَا ذَكَرَ عَنْ زَيْدِ بْنِ رَبَاحٍ عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو عَبْدِ اللَّهِ الأَغَرُّ اسْمُهُ سَلْمَانُ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ مِنْ غَيْرِ وَجْهٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَمَيْمُونَةَ وَأَبِي سَعِيدٍ وَجُبَيْرِ بْنِ مُطْعِمٍ وَابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ وَأَبِي ذَرٍّ ‏.‏\hadithno{325}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Salat is this Masjid of mine is better than a thousand Salat in another, except for Masjid Al-Haram}}
\hadithdefcmd{tirmidhi}{326}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْحَرَامِ وَمَسْجِدِي هَذَا وَمَسْجِدِ الأَقْصَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{326}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :Allah's Messenger said: "A mount is not saddled (for a journey) except to three Masajid: Al-Masjid Al-Haram, this Masjid of mine, and Masjid Al-Aqsa." [Abu `Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{327}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَأْتُوهَا وَأَنْتُمْ تَسْعَوْنَ وَلَكِنِ ائْتُوهَا وَأَنْتُمْ تَمْشُونَ وَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي قَتَادَةَ وَأُبَىِّ بْنِ كَعْبٍ وَأَبِي سَعِيدٍ وَزَيْدِ بْنِ ثَابِتٍ وَجَابِرٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْمَشْىِ إِلَى الْمَسْجِدِ فَمِنْهُمْ مَنْ رَأَى الإِسْرَاعَ إِذَا خَافَ فَوْتَ التَّكْبِيرَةِ الأُولَى حَتَّى ذُكِرَ عَنْ بَعْضِهِمْ أَنَّهُ كَانَ يُهَرْوِلُ إِلَى الصَّلاَةِ ‏.‏ وَمِنْهُمْ مَنْ كَرِهَ الإِسْرَاعَ وَاخْتَارَ أَنْ يَمْشِيَ عَلَى تُؤَدَةٍ وَوَقَارٍ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ وَقَالاَ الْعَمَلُ عَلَى حَدِيثِ أَبِي هُرَيْرَةَ ‏.‏ وَقَالَ إِسْحَاقُ إِنْ خَافَ فَوْتَ التَّكْبِيرَةِ الأُولَى فَلاَ بَأْسَ أَنْ يُسْرِعَ فِي الْمَشْىِ ‏.‏\hadithno{327}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "When the Iqamah is called for Salat do not come to it rushing, rather come to it walking, and while you have tranquility. What you catch of it then pray it, and what you missed of it, then complete it}}
\hadithdefcmd{tirmidhi}{328}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ بِمَعْنَاهُ ‏.‏ هَكَذَا قَالَ عَبْدُ الرَّزَّاقِ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ يَزِيدَ بْنِ زُرَيْعٍ ‏.‏\hadithno{328}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{(Another chain with a similar narration) from Abu Hurairah :[from the Prophet]. And this is more correct than the Hadith of Yazid bin Zurai. (no)}}
\hadithdefcmd{tirmidhi}{329}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{329}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{(Another chain with a similar narration) from Abu Hurairah, :from the Prophet}}
\hadithdefcmd{tirmidhi}{330}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ أَحَدُكُمْ فِي صَلاَةٍ مَا دَامَ يَنْتَظِرُهَا وَلاَ تَزَالُ الْمَلاَئِكَةُ تُصَلِّي عَلَى أَحَدِكُمْ مَا دَامَ فِي الْمَسْجِدِ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ مَا لَمْ يُحْدِثْ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنْ حَضْرَمَوْتَ وَمَا الْحَدَثُ يَا أَبَا هُرَيْرَةَ قَالَ فُسَاءٌ أَوْ ضُرَاطٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي سَعِيدٍ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَسَهْلِ بْنِ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{330}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "One of you does not cease to be in Salat as long as he is waiting for it. And the angels do not cease praying for one of you as long as he remains in the Masjid (saying): 'Allah! Forgive him. O Allah! Have mercy upon him' - as long as he does not commit Hadath." A man from Hadramawt said: "And just what is Hadath Abu Hurairah?" He said: "Breaking wind, or passing gas}}
\hadithdefcmd{tirmidhi}{331}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى الْخُمْرَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ حَبِيبَةَ وَابْنِ عُمَرَ وَأُمِّ سُلَيْمٍ وَعَائِشَةَ وَمَيْمُونَةَ وَأُمِّ كُلْثُومٍ بِنْتِ أَبِي سَلَمَةَ بْنِ عَبْدِ الأَسَدِ وَلَمْ تَسْمَعْ مِنَ النَّبِيِّ صلى الله عليه وسلم وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهِ يَقُولُ بَعْضُ أَهْلِ الْعِلْمِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ قَدْ ثَبَتَ عَنِ النَّبِيِّ صلى الله عليه وسلم الصَّلاَةُ عَلَى الْخُمْرَةِ ‏.‏ قَالَ أَبُو عِيسَى وَالْخُمْرَةُ هُوَ حَصِيرٌ قَصِيرٌ ‏.‏\hadithno{331}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"Allah's Messenger performed Salat on a Khumrah}}
\hadithdefcmd{tirmidhi}{332}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى حَصِيرٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَالْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ ‏.‏ إِلاَّ أَنَّ قَوْمًا مِنْ أَهْلِ الْعِلْمِ اخْتَارُوا الصَّلاَةَ عَلَى الأَرْضِ اسْتِحْبَابًا ‏.‏ وَأَبُو سُفْيَانَ اسْمُهُ طَلْحَةُ بْنُ نَافِعٍ ‏.‏\hadithno{332}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Sa'eed narrated:"The Prophet performed Salat on a Hasir}}
\hadithdefcmd{tirmidhi}{333}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ الضُّبَعِيِّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُخَالِطُنَا حَتَّى إِنْ كَانَ يَقُولُ لأَخٍ لِي صَغِيرٍ ‏ "‏ يَا أَبَا عُمَيْرٍ مَا فَعَلَ النُّغَيْرُ ‏"‏ ‏.‏ قَالَ وَنُضِحَ بِسَاطٌ لَنَا فَصَلَّى عَلَيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ لَمْ يَرَوْا بِالصَّلاَةِ عَلَى الْبِسَاطِ وَالطُّنْفُسَةِ بَأْسًا ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَاسْمُ أَبِي التَّيَّاحِ يَزِيدُ بْنُ حُمَيْدٍ ‏.‏\hadithno{333}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"Allah's Messenger used to mingle with us such that he said to my younger brother: 'O Abu Umair! What did the Nughair do?'" He (Anas) said: "A Bisat of ours would be sprinkled (with water) to perform Salat on}}
\hadithdefcmd{tirmidhi}{334}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا الْحَسَنُ بْنُ أَبِي جَعْفَرٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ أَبِي الطُّفَيْلِ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَسْتَحِبُّ الصَّلاَةَ فِي الْحِيطَانِ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي الْبَسَاتِينَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مُعَاذٍ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْحَسَنِ بْنِ أَبِي جَعْفَرٍ ‏.‏ وَالْحَسَنُ بْنُ أَبِي جَعْفَرٍ قَدْ ضَعَّفَهُ يَحْيَى بْنُ سَعِيدٍ وَغَيْرُهُ وَأَبُو الزُّبَيْرِ اسْمُهُ مُحَمَّدُ بْنُ مُسْلِمِ بْنِ تَدْرُسَ وَأَبُو الطُّفَيْلِ اسْمُهُ عَامِرُ بْنُ وَاثِلَةَ ‏.‏\hadithno{334}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh ibn Jabal narrated:"The Prophet liked to perform Salat in Al-Hitan}}
\hadithdefcmd{tirmidhi}{335}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَضَعَ أَحَدُكُمْ بَيْنَ يَدَيْهِ مِثْلَ مُؤَخَّرَةِ الرَّحْلِ فَلْيُصَلِّ وَلاَ يُبَالِي مَنْ مَرَّ وَرَاءَ ذَلِكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَسَهْلِ بْنِ أَبِي حَثْمَةَ وَابْنِ عُمَرَ وَسَبْرَةَ بْنِ مَعْبَدٍ الْجُهَنِيِّ وَأَبِي جُحَيْفَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ طَلْحَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَقَالُوا سُتْرَةُ الإِمَامِ سُتْرَةٌ لِمَنْ خَلْفَهُ ‏.‏\hadithno{335}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Muba bin Talhah narrated from his father (Talhah) that :Allah's Messenger said: "When one of you placed something like the post (handle) of the camel saddle in front of him, then let him perform Salat and not concern himself with who passes beyond that}}
\hadithdefcmd{tirmidhi}{336}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، أَرْسَلَهُ إِلَى أَبِي جُهَيْمٍ يَسْأَلُهُ مَاذَا سَمِعَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَارِّ بَيْنَ يَدَىِ الْمُصَلِّي فَقَالَ أَبُو جُهَيْمٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ يَعْلَمُ الْمَارُّ بَيْنَ يَدَىِ الْمُصَلِّي مَاذَا عَلَيْهِ لَكَانَ أَنْ يَقِفَ أَرْبَعِينَ خَيْرٌ لَهُ مِنْ أَنْ يَمُرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو النَّضْرِ لاَ أَدْرِي قَالَ أَرْبَعِينَ يَوْمًا أَوْ شَهْرًا أَوْ سَنَةً قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ وَأَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي جُهَيْمٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لأَنْ يَقِفَ أَحَدُكُمْ مِائَةَ عَامٍ خَيْرٌ لَهُ مِنْ أَنْ يَمُرَّ بَيْنَ يَدَىْ أَخِيهِ وَهُوَ يُصَلِّي ‏"‏ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا الْمُرُورَ بَيْنَ يَدَىِ الْمُصَلِّي وَلَمْ يَرَوْا أَنَّ ذَلِكَ يَقْطَعُ صَلاَةَ الرَّجُلِ ‏.‏ وَاسْمُ أَبِي النَّضْرِ سَالِمٌ مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ الْمَدِينِيُّ ‏.‏\hadithno{336}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Zaid bin Khalid Al-Juhni sent a message to Abu Juhaim asking him what he had heard from Allah's Messenger about passing in front of a person who was performing Salat. Abu Juhaim said :that Allah's Messenger said: "If the one who passed in front of the person performing Salat knew what he was doing, then for him to stop (and wait for forty) would be better for him than to pass in front of him}}
\hadithdefcmd{tirmidhi}{337}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ رَدِيفَ الْفَضْلِ عَلَى أَتَانٍ فَجِئْنَا وَالنَّبِيُّ صلى الله عليه وسلم يُصَلِّي بِأَصْحَابِهِ بِمِنًى ‏.‏ قَالَ فَنَزَلْنَا عَنْهَا فَوَصَلْنَا الصَّفَّ فَمَرَّتْ بَيْنَ أَيْدِيهِمْ فَلَمْ تَقْطَعْ صَلاَتَهُمْ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَالْفَضْلِ بْنِ عَبَّاسٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ قَالُوا لاَ يَقْطَعُ الصَّلاَةَ شَيْءٌ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ ‏.‏\hadithno{337}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"I was a companion rider on a female donkey with Al-Fadl. We came while the Prophet and his Companions were performing Salat at Mina." He said: "We dismounted from it and joined the row. The donkey then passed in front of them, and this did not invalidate their Salat}}
\hadithdefcmd{tirmidhi}{338}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يُونُسُ بْنُ عُبَيْدٍ، وَمَنْصُورُ بْنُ زَاذَانَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، قَالَ سَمِعْتُ أَبَا ذَرٍّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا صَلَّى الرَّجُلُ وَلَيْسَ بَيْنَ يَدَيْهِ كَآخِرَةِ الرَّحْلِ أَوْ كَوَاسِطَةِ الرَّحْلِ قَطَعَ صَلاَتَهُ الْكَلْبُ الأَسْوَدُ وَالْمَرْأَةُ وَالْحِمَارُ ‏"‏ ‏.‏ فَقُلْتُ لأَبِي ذَرٍّ مَا بَالُ الأَسْوَدِ مِنَ الأَحْمَرِ مِنَ الأَبْيَضِ فَقَالَ يَا ابْنَ أَخِي سَأَلْتَنِي كَمَا سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ الْكَلْبُ الأَسْوَدُ شَيْطَانٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَالْحَكَمِ بْنِ عَمْرٍو الْغِفَارِيِّ وَأَبِي هُرَيْرَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي ذَرٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَيْهِ قَالُوا يَقْطَعُ الصَّلاَةَ الْحِمَارُ وَالْمَرْأَةُ وَالْكَلْبُ الأَسْوَدُ ‏.‏ قَالَ أَحْمَدُ الَّذِي لاَ أَشُكُّ فِيهِ أَنَّ الْكَلْبَ الأَسْوَدَ يَقْطَعُ الصَّلاَةَ وَفِي نَفْسِي مِنَ الْحِمَارِ وَالْمَرْأَةِ شَيْءٌ ‏.‏ قَالَ إِسْحَاقُ لاَ يَقْطَعُهَا شَيْءٌ إِلاَّ الْكَلْبُ الأَسْوَدُ ‏.‏\hadithno{338}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Dharr said that :Allah's Messenger said: "When a man performs Salat, and there is nothing in front of him like the post of a saddle, or a camel saddle, then his Salat is severed by (passing of) a black dog, a woman, and a donkey." It was said to Abu Dharr: "What is the problem with the black dog rather than the red or white one?" He said: "O my nephew! I asked Allah's Messenger just as you have asked me. He said: 'The black dog is a Shaitan (devil)}}
\hadithdefcmd{tirmidhi}{339}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي بَيْتِ أُمِّ سَلَمَةَ مُشْتَمِلاً فِي ثَوْبٍ وَاحِدٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَجَابِرٍ وَسَلَمَةَ بْنِ الأَكْوَعِ وَأَنَسٍ وَعَمْرِو بْنِ أَبِي أُسَيْدٍ وَعُبَادَةَ بْنِ الصَّامِتِ وَأَبِي سَعِيدٍ وَكَيْسَانَ وَابْنِ عَبَّاسٍ وَعَائِشَةَ وَأُمِّ هَانِئٍ وَعَمَّارِ بْنِ يَاسِرٍ وَطَلْقِ بْنِ عَلِيٍّ وَصَامِتٍ الأَنْصَارِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ بْنِ أَبِي سَلَمَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ وَغَيْرِهِمْ قَالُوا لاَ بَأْسَ بِالصَّلاَةِ فِي الثَّوْبِ الْوَاحِدِ ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ يُصَلِّي الرَّجُلُ فِي ثَوْبَيْنِ ‏.‏\hadithno{339}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umar bin Abi Salamah narrated that he saw :Allah's Messenger performing Salat in the house of Umm Salamah wrapped in one garment}}
\hadithdefcmd{tirmidhi}{340}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ صَلَّى نَحْوَ بَيْتِ الْمَقْدِسِ سِتَّةَ أَوْ سَبْعَةَ عَشَرَ شَهْرًا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ أَنْ يُوَجَّهَ إِلَى الْكَعْبَةِ فَأَنْزَلَ اللَّهُ تَعَالَىْ‏:‏ ‏(‏قَدْ نَرَى تَقَلُّبَ وَجْهِكَ فِي السَّمَاءِ فَلَنُوَلِّيَنَّكَ قِبْلَةً تَرْضَاهَا فَوَلِّ وَجْهَكَ شَطْرَ الْمَسْجِدِ الْحَرَامِ‏)‏ فَوُجِّهَ نَحْوَ الْكَعْبَةِ وَكَانَ يُحِبُّ ذَلِكَ فَصَلَّى رَجُلٌ مَعَهُ الْعَصْرَ ثُمَّ مَرَّ عَلَى قَوْمٍ مِنَ الأَنْصَارِ وَهُمْ رُكُوعٌ فِي صَلاَةِ الْعَصْرِ نَحْوَ بَيْتِ الْمَقْدِسِ فَقَالَ هُوَ يَشْهَدُ أَنَّهُ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَّهُ قَدْ وُجِّهَ إِلَى الْكَعْبَةِ ‏.‏ قَالَ فَانْحَرَفُوا وَهُمْ رُكُوعٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَعُمَارَةَ بْنِ أَوْسٍ وَعَمْرِو بْنِ عَوْفٍ الْمُزَنِيِّ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ عَنْ أَبِي إِسْحَاقَ ‏.‏\hadithno{340}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara bin Azib narrated:"When Allah's Messener arrived in Al-Madinah, he faced Bait Al-Maqdis in Salat for sixteen or seventeen months. Allah's Messenger longed to face the direction of the Ka'bah, so Allah Most High revealed: Verily! We have seen the turning of your face towards the heaven. Surely We shall turn you o a Qiblah that shall please you. So turn your face in the direction of Al-Masjid Al-Haram.So he faced the Ka'bah, and he liked that. A man performed the Asr prayer with him, then passed by some of the Ansar who were bowing in Salat for Asr while facing Bait Al-Maqdis." He told them that he had faced the direction of the Ka'bah, so they changed (their direction) while they were bowing." [He said:] There are narrations on this topic from Ibn Umar, Ibn Abbas, Umarah bin Aws, Amr bin Awf Al-Muzani and Anas}}
\hadithdefcmd{tirmidhi}{341}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانُوا رُكُوعًا فِي صَلاَةِ الصُّبْحِ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ ابْنِ عُمَرَ حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{341}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar said:"They were bowing during the Subh (Fajr) Prayer}}
\hadithdefcmd{tirmidhi}{342}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي مَعْشَرٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ قِبْلَةٌ ‏"‏ ‏.‏\hadithno{342}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "What is between the east and the west is Qiblah}}
\hadithdefcmd{tirmidhi}{343}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي مَعْشَرٍ، مِثْلَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ قَدْ رُوِيَ عَنْهُ، مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي أَبِي مَعْشَرٍ مِنْ قِبَلِ حِفْظِهِ وَاسْمُهُ نَجِيحٌ مَوْلَى بَنِي هَاشِمٍ ‏.‏ قَالَ مُحَمَّدٌ لاَ أَرْوِي عَنْهُ شَيْئًا وَقَدْ رَوَى عَنْهُ النَّاسُ ‏.‏ قَالَ مُحَمَّدٌ وَحَدِيثُ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ الْمَخْرَمِيِّ عَنْ عُثْمَانَ بْنِ مُحَمَّدٍ الأَخْنَسِيِّ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ أَقْوَى مِنْ حَدِيثِ أَبِي مَعْشَرٍ وَأَصَحُّ ‏.‏\hadithno{343}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated:(Another chain with a similar narration)}}
\hadithdefcmd{tirmidhi}{344}{حَدَّثَنَا الْحَسَنُ بْنُ بَكْرٍ الْمَرْوَزِيُّ، حَدَّثَنَا الْمُعَلَّى بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَخْرَمِيُّ، عَنْ عُثْمَانَ بْنِ مُحَمَّدٍ الأَخْنَسِيِّ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ قِبْلَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِنَّمَا قِيلَ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَخْرَمِيُّ لأَنَّهُ مِنْ وَلَدِ الْمِسْوَرِ بْنِ مَخْرَمَةَ ‏.‏ وَقَدْ رُوِيَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ قِبْلَةٌ ‏"‏ ‏.‏ مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَعَلِيُّ بْنُ أَبِي طَالِبٍ وَابْنُ عَبَّاسٍ ‏.‏ وَقَالَ ابْنُ عُمَرَ إِذَا جَعَلْتَ الْمَغْرِبَ عَنْ يَمِينِكَ وَالْمَشْرِقَ عَنْ يَسَارِكَ فَمَا بَيْنَهُمَا قِبْلَةٌ إِذَا اسْتَقْبَلْتَ الْقِبْلَةَ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ ‏"‏ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ قِبْلَةٌ ‏"‏ ‏.‏ هَذَا لأَهْلِ الْمَشْرِقِ ‏.‏ وَاخْتَارَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ التَّيَاسُرَ لأَهْلِ مَرْوٍ ‏.‏\hadithno{344}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain narrating that) Abu Hurairah narrated that :Allah's Messenger said: "What is between the east and the west is Qiblah}}
\hadithdefcmd{tirmidhi}{345}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَشْعَثُ بْنُ سَعِيدٍ السَّمَّانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فِي لَيْلَةٍ مُظْلِمَةٍ فَلَمْ نَدْرِ أَيْنَ الْقِبْلَةُ فَصَلَّى كُلُّ رَجُلٍ مِنَّا عَلَى حِيَالِهِ فَلَمَّا أَصْبَحْنَا ذَكَرْنَا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَنَزَلَ‏:‏ ‏(‏فَأَيْنَمَا تُولُّوا فَثَمَّ وَجْهُ الله‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِذَاكَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَشْعَثَ السَّمَّانِ ‏.‏ وَأَشْعَثُ بْنُ سَعِيدٍ أَبُو الرَّبِيعِ السَّمَّانُ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ وَقَدْ ذَهَبَ أَكْثَرُ أَهْلِ الْعِلْمِ إِلَى هَذَا ‏.‏ قَالُوا إِذَا صَلَّى فِي الْغَيْمِ لِغَيْرِ الْقِبْلَةِ ثُمَّ اسْتَبَانَ لَهُ بَعْدَ مَا صَلَّى أَنَّهُ صَلَّى لِغَيْرِ الْقِبْلَةِ فَإِنَّ صَلاَتَهُ جَائِزَةٌ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{345}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Amir bin Rabi'ah narrated from his father who said:"We were with the Prophet on a journey on a very dark night and we did not know the direction of the Qiblah. So each man among us prayed in his own direction. In the morning when we mentioned that to the Prophet, then the following was revealed: So where ever you turn, there is the Face of Allah}}
\hadithdefcmd{tirmidhi}{346}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا الْمُقْرِئُ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ زَيْدِ بْنِ جَبِيرَةَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُصَلَّى فِي سَبْعَةِ مَوَاطِنَ فِي الْمَزْبَلَةِ وَالْمَجْزَرَةِ وَالْمَقْبُرَةِ وَقَارِعَةِ الطَّرِيقِ وَفِي الْحَمَّامِ وَفِي مَعَاطِنِ الإِبِلِ وَفَوْقَ ظَهْرِ بَيْتِ اللَّهِ ‏"‏ ‏.‏\hadithno{346}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"The Prophet prohibited Salat from being performed in seven places: the dung heap, the slaughtering area, the graveyard, the commonly used road, the wash area, in the area that camels rest at, and above the House of Allah (the Ka'bah)}}
\hadithdefcmd{tirmidhi}{347}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا سُوَيْدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ زَيْدِ بْنِ جَبِيرَةَ، عَنْ دَاوُدَ بْنِ حُصَيْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي مَرْثَدٍ وَجَابِرٍ وَأَنَسٍ ‏.‏ أَبُو مَرْثَدٍ اسْمُهُ كَنَّازُ بْنُ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ ابْنِ عُمَرَ إِسْنَادُهُ لَيْسَ بِذَاكَ الْقَوِيِّ ‏.‏ وَقَدْ تُكُلِّمَ فِي زَيْدِ بْنِ جَبِيرَةَ مِنْ قِبَلِ حِفْظِهِ ‏.‏ قَالَ أَبُو عِيسَى وَزَيْدُ بْنُ جُبَيْرٍ الْكُوفِيُّ أَثْبَتُ مِنْ هَذَا وَأَقْدَمُ وَقَدْ سَمِعَ مِنَ ابْنِ عُمَرَ ‏.‏ وَقَدْ رَوَى اللَّيْثُ بْنُ سَعْدٍ هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ الْعُمَرِيِّ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنْ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ وَحَدِيثُ دَاوُدَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَشْبَهُ وَأَصَحُّ مِنْ حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ ‏.‏ وَعَبْدُ اللَّهِ بْنُ عُمَرَ الْعُمَرِيُّ ضَعَّفَهُ بَعْضُ أَهْلِ الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ مِنْهُمْ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ ‏.‏\hadithno{347}\hadithgrade{Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:(Another chain with a similar narration)}}
\hadithdefcmd{tirmidhi}{348}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلُّوا فِي مَرَابِضِ الْغَنَمِ وَلاَ تُصَلُّوا فِي أَعْطَانِ الإِبِلِ ‏"‏ ‏.‏\hadithno{348}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Perform Salat in sheep pens but do not perform Salat in the camels' resting area}}
\hadithdefcmd{tirmidhi}{349}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ أَوْ بِنَحْوِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ سَمُرَةَ وَالْبَرَاءِ وَسَبْرَةَ بْنِ مَعْبَدٍ الْجُهَنِيِّ وَعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ وَابْنِ عُمَرَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلَيْهِ الْعَمَلُ عِنْدَ أَصْحَابِنَا وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَحَدِيثُ أَبِي حَصِينٍ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَاهُ إِسْرَائِيلُ عَنْ أَبِي حَصِينٍ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ مَوْقُوفًا وَلَمْ يَرْفَعْهُ ‏.‏ وَاسْمُ أَبِي حَصِينٍ عُثْمَانُ بْنُ عَاصِمٍ الأَسَدِيُّ ‏.‏\hadithno{349}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) from Abu Hurairah, :from the Prophet and it is the same or similar}}
\hadithdefcmd{tirmidhi}{350}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ الضُّبَعِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي فِي مَرَابِضِ الْغَنَمِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو التَّيَّاحِ الضُّبَعِيُّ اسْمُهُ يَزِيدُ بْنُ حُمَيْدٍ ‏.‏\hadithno{350}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"The Prophet would perform Salat in sheep pens}}
\hadithdefcmd{tirmidhi}{351}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، وَيَحْيَى بْنُ آدَمَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم فِي حَاجَةٍ فَجِئْتُ وَهُوَ يُصَلِّي عَلَى رَاحِلَتِهِ نَحْوَ الْمَشْرِقِ وَالسُّجُودُ أَخْفَضُ مِنَ الرُّكُوعِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَابْنِ عُمَرَ وَأَبِي سَعِيدٍ وَعَامِرِ بْنِ رَبِيعَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ لاَ نَعْلَمُ بَيْنَهُمُ اخْتِلاَفًا ‏.‏ لاَ يَرَوْنَ بَأْسًا أَنْ يُصَلِّيَ الرَّجُلُ عَلَى رَاحِلَتِهِ تَطَوُّعًا حَيْثُمَا كَانَ وَجْهُهُ إِلَى الْقِبْلَةِ أَوْ غَيْرِهَا ‏.‏\hadithno{351}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated:"The Prophet dispatched me for something he needed. I came to him while he was performing Salat on his mount, heading east, he made the prostrations lower than the bowing}}
\hadithdefcmd{tirmidhi}{352}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى إِلَى بَعِيرِهِ أَوْ رَاحِلَتِهِ وَكَانَ يُصَلِّي عَلَى رَاحِلَتِهِ حَيْثُمَا تَوَجَّهَتْ بِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بِالصَّلاَةِ إِلَى الْبَعِيرِ بَأْسًا أَنْ يَسْتَتِرَ بِهِ ‏.‏\hadithno{352}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"The Prophet performed Salat towards his she-camel, or his mount, and he would perform Salat while on his mount, whichever direction it was facing}}
\hadithdefcmd{tirmidhi}{353}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا حَضَرَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عُمَرَ وَسَلَمَةَ بْنِ الأَكْوَعِ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلَيْهِ الْعَمَلُ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَابْنُ عُمَرَ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ يَقُولاَنِ يَبْدَأُ بِالْعَشَاءِ وَإِنْ فَاتَتْهُ الصَّلاَةُ فِي الْجَمَاعَةِ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ فِي هَذَا الْحَدِيثِ يَبْدَأُ بِالْعَشَاءِ إِذَا كَانَ طَعَامًا يُخَافُ فَسَادُهُ ‏.‏ وَالَّذِي ذَهَبَ إِلَيْهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَشْبَهُ بِالاِتِّبَاعِ وَإِنَّمَا أَرَادُوا أَنْ لاَ يَقُومَ الرَّجُلُ إِلَى الصَّلاَةِ وَقَلْبُهُ مَشْغُولٌ بِسَبَبِ شَيْءٍ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ أَنَّهُ قَالَ لاَ نَقُومُ إِلَى الصَّلاَةِ وَفِي أَنْفُسِنَا شَيْءٌ ‏.‏\hadithno{353}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas conveyed that :the Prophet said: "When supper is present and the Iqamah for Salat has been called, then begin with supper}}
\hadithdefcmd{tirmidhi}{354}{وَرُوِيَ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا وُضِعَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏ ‏.‏ قَالَ وَتَعَشَّى ابْنُ عُمَرَ وَهُوَ يَسْمَعُ قِرَاءَةَ الإِمَامِ ‏.‏ قَالَ حَدَّثَنَا بِذَلِكَ هَنَّادٌ حَدَّثَنَا عَبْدَةُ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{354}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that:the Prophet said: "When the supper is presented and the Iqamah is called for Salat, then begin with the supper}}
\hadithdefcmd{tirmidhi}{355}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ الْكِلاَبِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ وَهُوَ يُصَلِّي فَلْيَرْقُدْ حَتَّى يَذْهَبَ عَنْهُ النَّوْمُ فَإِنَّ أَحَدَكُمْ إِذَا صَلَّى وَهُوَ يَنْعَسُ لَعَلَّهُ يَذْهَبُ يَسْتَغْفِرُ فَيَسُبَّ نَفْسَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{355}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated that :Allah's Messenger said: "When one of you is sleepy and he is performing Salat, then let him lie down until the sleep is gone from him. For when one of you performs Salat while he is sleepy, perhaps he wants to seek forgiveness but he curses himself}}
\hadithdefcmd{tirmidhi}{356}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ أَبَانَ بْنِ يَزِيدَ الْعَطَّارِ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ الْعُقَيْلِيِّ، عَنْ أَبِي عَطِيَّةَ، رَجُلٍ مِنْهُمْ قَالَ كَانَ مَالِكُ بْنُ الْحُوَيْرِثِ يَأْتِينَا فِي مُصَلاَّنَا يَتَحَدَّثُ فَحَضَرَتِ الصَّلاَةُ يَوْمًا فَقُلْنَا لَهُ تَقَدَّمْ ‏.‏ فَقَالَ لِيَتَقَدَّمْ بَعْضُكُمْ حَتَّى أُحَدِّثَكُمْ لِمَ لاَ أَتَقَدَّمُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ زَارَ قَوْمًا فَلاَ يَؤُمَّهُمْ وَلْيَؤُمَّهُمْ رَجُلٌ مِنْهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ قَالُوا صَاحِبُ الْمَنْزِلِ أَحَقُّ بِالإِمَامَةِ مِنَ الزَّائِرِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا أَذِنَ لَهُ فَلاَ بَأْسَ أَنْ يُصَلِّيَ بِهِ ‏.‏ وَقَالَ إِسْحَاقُ بِحَدِيثِ مَالِكِ بْنِ الْحُوَيْرِثِ وَشَدَّدَ فِي أَنْ لاَ يُصَلِّيَ أَحَدٌ بِصَاحِبِ الْمَنْزِلِ وَإِنْ أَذِنَ لَهُ صَاحِبُ الْمَنْزِلِ ‏.‏ قَالَ وَكَذَلِكَ فِي الْمَسْجِدِ لاَ يُصَلِّي بِهِمْ فِي الْمَسْجِدِ إِذَا زَارَهُمْ يَقُولُ لِيُصَلِّ بِهِمْ رَجُلٌ مِنْهُمْ ‏.‏\hadithno{356}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Atiyyah narrated that :a man among them said: "Malik bin Al-Huwairith came to us in our Musalla to narrate. One day when it was time for Salat, we told him to go ahead (to lead the prayer). He said: 'Let one of you go forward, until I narrate to you why I would not go forward (to lead prayer): I heard Allah's Messenger saying: "Whoever visits a people, then he does not lead them, but a man among them leads them}}
\hadithdefcmd{tirmidhi}{357}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي حَبِيبُ بْنُ صَالِحٍ، عَنْ يَزِيدَ بْنِ شُرَيْحٍ، عَنْ أَبِي حَىٍّ الْمُؤَذِّنِ الْحِمْصِيِّ، عَنْ ثَوْبَانَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرِئٍ أَنْ يَنْظُرَ فِي جَوْفِ بَيْتِ امْرِئٍ حَتَّى يَسْتَأْذِنَ فَإِنْ نَظَرَ فَقَدْ دَخَلَ وَلاَ يَؤُمَّ قَوْمًا فَيَخُصَّ نَفْسَهُ بِدَعْوَةٍ دُونَهُمْ فَإِنْ فَعَلَ فَقَدْ خَانَهُمْ وَلاَ يَقُومُ إِلَى الصَّلاَةِ وَهُوَ حَقِنٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ثَوْبَانَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ عَنِ السَّفْرِ بْنِ نُسَيْرٍ عَنْ يَزِيدَ بْنِ شُرَيْحٍ عَنْ أَبِي أُمَامَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ هَذَا الْحَدِيثُ عَنْ يَزِيدَ بْنِ شُرَيْحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَكَأَنَّ حَدِيثَ يَزِيدَ بْنِ شُرَيْحٍ عَنْ أَبِي حَىٍّ الْمُؤَذِّنِ عَنْ ثَوْبَانَ فِي هَذَا أَجْوَدُ إِسْنَادًا وَأَشْهَرُ ‏.‏\hadithno{357}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Thawban narrated that :the Prophet said: "It is not allowed for a man to look into the interior of a man's house until he has been given permission, for if he looks, then he has entered. And one who leads people (in Salat) should not supplicate for himself alone with the exclusion of his congregation. If he does, then he has betrayed them. And one is not to stand for Salat while he has to urinate}}
\hadithdefcmd{tirmidhi}{358}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الْقَاسِمِ الأَسَدِيُّ، عَنِ الْفَضْلِ بْنِ دَلْهَمٍ، عَنِ الْحَسَنِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَةً رَجُلٌ أَمَّ قَوْمًا وَهُمْ لَهُ كَارِهُونَ وَامْرَأَةٌ بَاتَتْ وَزَوْجُهَا عَلَيْهَا سَاخِطٌ وَرَجُلٌ سَمِعَ حَىَّ عَلَى الْفَلاَحِ ثُمَّ لَمْ يُجِبْ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَطَلْحَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ لاَ يَصِحُّ لأَنَّهُ قَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الْحَسَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ ‏.‏ قَالَ أَبُو عِيسَى وَمُحَمَّدُ بْنُ الْقَاسِمِ تَكَلَّمَ فِيهِ أَحْمَدُ بْنُ حَنْبَلٍ وَضَعَّفَهُ وَلَيْسَ بِالْحَافِظِ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ أَنْ يَؤُمَّ الرَّجُلُ قَوْمًا وَهُمْ لَهُ كَارِهُونَ فَإِذَا كَانَ الإِمَامُ غَيْرَ ظَالِمٍ فَإِنَّمَا الإِثْمُ عَلَى مَنْ كَرِهَهُ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ فِي هَذَا إِذَا كَرِهَ وَاحِدٌ أَوِ اثْنَانِ أَوْ ثَلاَثَةٌ فَلاَ بَأْسَ أَنْ يُصَلِّيَ بِهِمْ حَتَّى يَكْرَهَهُ أَكْثَرُ الْقَوْمِ ‏.‏\hadithno{358}\hadithgrade{Ahmad Muhammad Shakir: Very Daif Isnaad; Al-Albani: Very Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated:"Allah's Messenger cursed three people: A man who leads people (in Salat) while they dislike him, a woman who spends a night while her husband is angry with her, and a man who hears: 'Hayya Alal Falah (come to success)' then does not respond}}
\hadithdefcmd{tirmidhi}{359}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ زِيَادِ بْنِ أَبِي الْجَعْدِ، عَنْ عَمْرِو بْنِ الْحَارِثِ بْنِ الْمُصْطَلِقِ، قَالَ كَانَ يُقَالُ أَشَدُّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ اثْنَانِ امْرَأَةٌ عَصَتْ زَوْجَهَا وَإِمَامُ قَوْمٍ وَهُمْ لَهُ كَارِهُونَ ‏.‏ قَالَ هَنَّادٌ قَالَ جَرِيرٌ قَالَ مَنْصُورٌ فَسَأَلْنَا عَنْ أَمْرِ الإِمَامِ فَقِيلَ لَنَا إِنَّمَا عَنَى بِهَذَا أَئِمَّةً ظَلَمَةً فَأَمَّا مَنْ أَقَامَ السُّنَّةَ فَإِنَّمَا الإِثْمُ عَلَى مَنْ كَرِهَهُ ‏.‏\hadithno{359}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{Amr bin Al-Harith Al-Mustaliq said:"It used to be said that the people with the worst punishment [on the Day of Judgment] are two: A woman who disobeyed her husband, and a people's Imam whom they dislike}}
\hadithdefcmd{tirmidhi}{360}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، حَدَّثَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، حَدَّثَنَا أَبُو غَالِبٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ تُجَاوِزُ صَلاَتُهُمْ آذَانَهُمُ الْعَبْدُ الآبِقُ حَتَّى يَرْجِعَ وَامْرَأَةٌ بَاتَتْ وَزَوْجُهَا عَلَيْهَا سَاخِطٌ وَإِمَامُ قَوْمٍ وَهُمْ لَهُ كَارِهُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو غَالِبٍ اسْمُهُ حَزَوَّرٌ ‏.‏\hadithno{360}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Umamah narrated that :Allah's Messenger said: "There are three whose Salat would not rise up beyond their ears: The runaway slave until he returns, a woman who spends a night while her husband is angry with her, and a people's Imam whom they dislike}}
\hadithdefcmd{tirmidhi}{361}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ خَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ فَرَسٍ فَجُحِشَ فَصَلَّى بِنَا قَاعِدًا فَصَلَّيْنَا مَعَهُ قُعُودًا ثُمَّ انْصَرَفَ فَقَالَ ‏ "‏ إِنَّمَا الإِمَامُ أَوْ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا أَجْمَعُونَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي هُرَيْرَةَ وَجَابِرٍ وَابْنِ عُمَرَ وَمُعَاوِيَةَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَنَسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَّ عَنْ فَرَسٍ فَجُحِشَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم إِلَى هَذَا الْحَدِيثِ مِنْهُمْ جَابِرُ بْنُ عَبْدِ اللَّهِ وَأُسَيْدُ بْنُ حُضَيْرٍ وَأَبُو هُرَيْرَةَ وَغَيْرُهُمْ ‏.‏ وَبِهَذَا الْحَدِيثِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا صَلَّى الإِمَامُ جَالِسًا لَمْ يُصَلِّ مَنْ خَلْفَهُ إِلاَّ قِيَامًا فَإِنْ صَلَّوْا قُعُودًا لَمْ تُجْزِهِمْ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ ‏.‏\hadithno{361}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"Allah's Messenger fell from a horse and got injured, so he led Salat sitting and we also offered Salat sitting. When he completed the Salat he said: "The Imam is appointed to be followed; when he says the Takbir then say the Takbir, when he bows, then bow, and when he raises his head, then raise your heads. When he says: "Sami' Allahu liman hamidah (Allah listens to those who praise him)" then say: "Rabbana wa lakal-hamd. (O our Lord! And all praise is Yours.)" and when he prostrates, then prostrate, and when he performs Salat sitting, then pray sitting altogether}}
\hadithdefcmd{tirmidhi}{362}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، عَنْ شُعْبَةَ، عَنْ نُعَيْمِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَ أَبِي بَكْرٍ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ قَاعِدًا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا صَلَّى الإِمَامُ جَالِسًا فَصَلُّوا جُلُوسًا ‏"‏ ‏.‏ وَرُوِيَ عَنْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ فِي مَرَضِهِ وَأَبُو بَكْرٍ يُصَلِّي بِالنَّاسِ فَصَلَّى إِلَى جَنْبِ أَبِي بَكْرٍ وَالنَّاسُ يَأْتَمُّونَ بِأَبِي بَكْرٍ وَأَبُو بَكْرٍ يَأْتَمُّ بِالنَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى خَلْفَ أَبِي بَكْرٍ قَاعِدًا ‏.‏ وَرُوِيَ عَنْ أَنَسِ بْنِ مَالِكٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى خَلْفَ أَبِي بَكْرٍ وَهُوَ قَاعِدٌ ‏.‏\hadithno{362}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated:"Allah's Messenger performed Salat behind Abu Bakr, during the illness from which he died, and he was sitting}}
\hadithdefcmd{tirmidhi}{363}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ حُمَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ خَلْفَ أَبِي بَكْرٍ قَاعِدًا فِي ثَوْبٍ مُتَوَشِّحًا بِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَهَكَذَا رَوَاهُ يَحْيَى بْنُ أَيُّوبَ عَنْ حُمَيْدٍ عَنْ ثَابِتٍ عَنْ أَنَسٍ ‏.‏ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ حُمَيْدٍ عَنْ أَنَسٍ وَلَمْ يَذْكُرُوا فِيهِ عَنْ ثَابِتٍ ‏.‏ وَمَنْ ذَكَرَ فِيهِ عَنْ ثَابِتٍ فَهُوَ أَصَحُّ ‏.‏\hadithno{363}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated:"Allah's Messenger performed Salat during his illness behind Abu Bakr while seated, wrapped in a garment}}
\hadithdefcmd{tirmidhi}{364}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا ابْنُ أَبِي لَيْلَى، عَنِ الشَّعْبِيِّ، قَالَ صَلَّى بِنَا الْمُغِيرَةُ بْنُ شُعْبَةَ فَنَهَضَ فِي الرَّكْعَتَيْنِ فَسَبَّحَ بِهِ الْقَوْمُ وَسَبَّحَ بِهِمْ فَلَمَّا صَلَّى بَقِيَّةَ صَلاَتِهِ سَلَّمَ ثُمَّ سَجَدَ سَجْدَتَىِ السَّهْوِ وَهُوَ جَالِسٌ ثُمَّ حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ بِهِمْ مِثْلَ الَّذِي فَعَلَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُقْبَةَ بْنِ عَامِرٍ وَسَعْدٍ وَعَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْمُغِيرَةِ بْنِ شُعْبَةَ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي ابْنِ أَبِي لَيْلَى مِنْ قِبَلِ حِفْظِهِ ‏.‏ قَالَ أَحْمَدُ لاَ يُحْتَجُّ بِحَدِيثِ ابْنِ أَبِي لَيْلَى ‏.‏ وَقَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ ابْنُ أَبِي لَيْلَى هُوَ صَدُوقٌ وَلاَ أَرْوِي عَنْهُ لأَنَّهُ لاَ يَدْرِي صَحِيحَ حَدِيثِهِ مِنْ سَقِيمِهِ وَكُلُّ مَنْ كَانَ مِثْلَ هَذَا فَلاَ أَرْوِي عَنْهُ شَيْئًا ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ رَوَاهُ سُفْيَانُ عَنْ جَابِرٍ عَنِ الْمُغِيرَةِ بْنِ شُبَيْلٍ عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏ وَجَابِرٌ الْجُعْفِيُّ قَدْ ضَعَّفَهُ بَعْضُ أَهْلِ الْعِلْمِ تَرَكَهُ يَحْيَى بْنُ سَعِيدٍ وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ وَغَيْرُهُمَا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الرَّجُلَ إِذَا قَامَ فِي الرَّكْعَتَيْنِ مَضَى فِي صَلاَتِهِ وَسَجَدَ سَجْدَتَيْنِ مِنْهُمْ مَنْ رَأَى قَبْلَ التَّسْلِيمِ وَمِنْهُمْ مَنْ رَأَى بَعْدَ التَّسْلِيمِ ‏.‏ وَمَنْ رَأَى قَبْلَ التَّسْلِيمِ فَحَدِيثُهُ أَصَحُّ لِمَا رَوَى الزُّهْرِيُّ وَيَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ ‏.‏\hadithno{364}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ash-Sha'bi narrated:"Al-Mughirah bin Shu'bah led us in Salat, and he continued after the two Rak'ah, so the people said: 'Subhan Allah' and he said: 'Subhan Allah' to them. When he finished his Salat he said the Taslim then performed two prostrations of As-Sahw while he was sitting. Then he narrated to them that Allah's Messenger did the same with them as he had done}}
\hadithdefcmd{tirmidhi}{365}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ الْمَسْعُودِيِّ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، قَالَ صَلَّى بِنَا الْمُغِيرَةُ بْنُ شُعْبَةَ فَلَمَّا صَلَّى رَكْعَتَيْنِ قَامَ وَلَمْ يَجْلِسْ فَسَبَّحَ بِهِ مَنْ خَلْفَهُ فَأَشَارَ إِلَيْهِمْ أَنْ قُومُوا فَلَمَّا فَرَغَ مِنْ صَلاَتِهِ سَلَّمَ وَسَجَدَ سَجْدَتَىِ السَّهْوِ وَسَلَّمَ وَقَالَ هَكَذَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{365}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ziyad bin Haqah narrated:"Al-Mughirah bin Shu'bah les us in Salat. When he prayed two Rak'ah he stood without sitting. Those who were behind him said 'Subhan Allah' and he indicated to them that they should stand. He said the Taslim when he had finished his Salat and he performed two prostrations of As-Sahw, and said the Taslim. He said that Allah's Messenger did this}}
\hadithdefcmd{tirmidhi}{366}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، - هُوَ الطَّيَالِسِيُّ حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا سَعْدُ بْنُ إِبْرَاهِيمَ، قَالَ سَمِعْتُ أَبَا عُبَيْدَةَ بْنَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا جَلَسَ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ كَأَنَّهُ عَلَى الرَّضْفِ ‏.‏ قَالَ شُعْبَةُ ثُمَّ حَرَّكَ سَعْدٌ شَفَتَيْهِ بِشَيْءٍ فَأَقُولُ حَتَّى يَقُومَ فَيَقُولُ حَتَّى يَقُومَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ إِلاَّ أَنَّ أَبَا عُبَيْدَةَ لَمْ يَسْمَعْ مِنْ أَبِيهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَخْتَارُونَ أَنْ لاَ يُطِيلَ الرَّجُلُ الْقُعُودَ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ وَلاَ يَزِيدَ عَلَى التَّشَهُّدِ شَيْئًا ‏.‏ وَقَالُوا إِنْ زَادَ عَلَى التَّشَهُّدِ فَعَلَيْهِ سَجْدَتَا السَّهْوِ ‏.‏ هَكَذَا رُوِيَ عَنِ الشَّعْبِيِّ وَغَيْرِهِ ‏.‏\hadithno{366}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ubaidullah bin Abdullah bin Mas'ud narrated from his father (Abdullah bin Mas'ud) that he said:"When Allah's Messenger sat for the first two Rak'ah it was as if he was on hot stones." Shu'bah (one of the narrators) said: "Then Sa'd's lips moved (saying) something. So I said: 'Until he stood?' He said: 'Until he stood}}
\hadithdefcmd{tirmidhi}{367}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ نَابِلٍ، صَاحِبِ الْعَبَاءِ عَنِ ابْنِ عُمَرَ، عَنْ صُهَيْبٍ، قَالَ مَرَرْتُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُصَلِّي فَسَلَّمْتُ عَلَيْهِ فَرَدَّ إِلَىَّ إِشَارَةً ‏.‏ وَقَالَ لاَ أَعْلَمُ إِلاَّ أَنَّهُ قَالَ إِشَارَةً بِإِصْبَعِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ بِلاَلٍ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَعَائِشَةَ ‏.‏\hadithno{367}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Suhaib narrated:"I passed by Allah's Messenger (S) while he was performing Salat, so I said greeted him with Salam, and he returned it by making signals." He said: "I do not know except that he said: 'He indicated with his finger}}
\hadithdefcmd{tirmidhi}{368}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قُلْتُ لِبِلاَلٍ كَيْفَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَرُدُّ عَلَيْهِمْ حِينَ كَانُوا يُسَلِّمُونَ عَلَيْهِ وَهُوَ فِي الصَّلاَةِ قَالَ كَانَ يُشِيرُ بِيَدِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ صُهَيْبٍ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ اللَّيْثِ عَنْ بُكَيْرٍ ‏.‏ وَقَدْ رُوِيَ عَنْ زَيْدِ بْنِ أَسْلَمَ عَنِ ابْنِ عُمَرَ قَالَ قُلْتُ لِبِلاَلٍ كَيْفَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصْنَعُ حَيْثُ كَانُوا يُسَلِّمُونَ عَلَيْهِ فِي مَسْجِدِ بَنِي عَمْرِو بْنِ عَوْفٍ قَالَ كَانَ يَرُدُّ إِشَارَةً ‏.‏ وَكِلاَ الْحَدِيثَيْنِ عِنْدِي صَحِيحٌ لأَنَّ قِصَّةَ حَدِيثِ صُهَيْبٍ غَيْرُ قِصَّةِ حَدِيثِ بِلاَلٍ ‏.‏ وَإِنْ كَانَ ابْنُ عُمَرَ رَوَى عَنْهُمَا فَاحْتَمَلَ أَنْ يَكُونَ سَمِعَ مِنْهُمَا جَمِيعًا ‏.‏\hadithno{368}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Umar narrated:"I said to Bilal: 'How did the Prophet (S) reply to them when they gave him Salams and he was performing Salat?' He said: 'He would motion with his hand}}
\hadithdefcmd{tirmidhi}{369}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَسَهْلِ بْنِ سَعْدٍ وَجَابِرٍ وَأَبِي سَعِيدٍ وَابْنِ عُمَرَ ‏.‏ وَقَالَ عَلِيٌّ كُنْتُ إِذَا اسْتَأْذَنْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يُصَلِّي سَبَّحَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{369}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger said: "The Tasbih is for the men and clapping is for the women}}
\hadithdefcmd{tirmidhi}{370}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ التَّثَاؤُبُ فِي الصَّلاَةِ مِنَ الشَّيْطَانِ فَإِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيَكْظِمْ مَا اسْتَطَاعَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ وَجَدِّ عَدِيِّ بْنِ ثَابِتٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ التَّثَاؤُبَ فِي الصَّلاَةِ ‏.‏ قَالَ إِبْرَاهِيمُ إِنِّي لأَرُدُّ التَّثَاؤُبَ بِالتَّنَحْنُحِ ‏.‏\hadithno{370}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Prophet (ﷺ) said:"Yawning in prayer (salah) is from the Shaitan, so when one of you yawns then let him suppress (it) as much as possible}}
\hadithdefcmd{tirmidhi}{371}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ الرَّجُلِ وَهُوَ قَاعِدٌ فَقَالَ ‏ "‏ مَنْ صَلَّى قَائِمًا فَهُوَ أَفْضَلُ وَمَنْ صَلَّى قَاعِدًا فَلَهُ نِصْفُ أَجْرِ الْقَائِمِ وَمَنْ صَلَّى نَائِمًا فَلَهُ نِصْفُ أَجْرِ الْقَاعِدِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَنَسٍ وَالسَّائِبِ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عِمْرَانَ بْنِ حُصَيْنٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{371}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Imran bin Husain narrated:"I asked Allah's Messenger (S) about the Salat for a man who is sitting. He said: 'Whoever performs Salat while standing then that is more virtuous. And whoever performs Salat while sitting, then he gets half the rewards of the one standing, and whoever performs Salat while lying down, then he gets half the rewards of the one sitting}}
\hadithdefcmd{tirmidhi}{372}{وَقَدْ رُوِيَ هَذَا الْحَدِيثُ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، بِهَذَا الإِسْنَادِ إِلاَّ أَنَّهُ يَقُولُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ الْمَرِيضِ فَقَالَ ‏"‏ صَلِّ قَائِمًا فَإِنْ لَمْ تَسْتَطِعْ فَقَاعِدًا فَإِنْ لَمْ تَسْتَطِعْ فَعَلَى جَنْبٍ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ هَنَّادٌ حَدَّثَنَا وَكِيعٌ عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ عَنْ حُسَيْنٍ الْمُعَلِّمِ بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو عِيسَى وَلاَ نَعْلَمُ أَحَدًا رَوَى عَنْ حُسَيْنٍ الْمُعَلِّمِ نَحْوَ رِوَايَةِ إِبْرَاهِيمَ بْنِ طَهْمَانَ ‏.‏ وَقَدْ رَوَى أَبُو أُسَامَةَ وَغَيْرُ وَاحِدٍ عَنْ حُسَيْنٍ الْمُعَلِّمِ نَحْوَ رِوَايَةِ عِيسَى بْنِ يُونُسَ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ فِي صَلاَةِ التَّطَوُّعِ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ عَنْ أَشْعَثَ بْنِ عَبْدِ الْمَلِكِ عَنِ الْحَسَنِ قَالَ إِنْ شَاءَ الرَّجُلُ صَلَّى صَلاَةَ التَّطَوُّعِ قَائِمًا وَجَالِسًا وَمُضْطَجِعًا ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي صَلاَةِ الْمَرِيضِ إِذَا لَمْ يَسْتَطِعْ أَنْ يُصَلِّيَ جَالِسًا فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ يُصَلِّي عَلَى جَنْبِهِ الأَيْمَنِ ‏.‏ وَقَالَ بَعْضُهُمْ يُصَلِّي مُسْتَلْقِيًا عَلَى قَفَاهُ وَرِجْلاَهُ إِلَى الْقِبْلَةِ ‏.‏ وَقَالَ سُفْيَانُ الثَّوْرِيُّ فِي هَذَا الْحَدِيثِ ‏"‏ مَنْ صَلَّى جَالِسًا فَلَهُ نِصْفُ أَجْرِ الْقَائِمِ ‏"‏ ‏.‏ قَالَ هَذَا لِلصَّحِيحِ وَلِمَنْ لَيْسَ لَهُ عُذْرٌ ‏.‏ يَعْنِي فِي النَّوَافِلِ فَأَمَّا مَنْ كَانَ لَهُ عُذْرٌ مِنْ مَرَضٍ أَوْ غَيْرِهِ فَصَلَّى جَالِسًا فَلَهُ مِثْلُ أَجْرِ الْقَائِمِ ‏.‏ وَقَدْ رُوِيَ فِي بَعْضِ هَذَا الْحَدِيثِ مِثْلُ قَوْلِ سُفْيَانَ الثَّوْرِيِّ ‏.‏\hadithno{372}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{This Hadith has been related from Ibrahim bin Tahman with this chain. Except that he said:"From Imran bin Husain who said: 'I asked Allah's Messenger (S) about Salat for a sick person. He said: "He performs Salat standing, if he is not able then sitting, if he is not able then on his side}}
\hadithdefcmd{tirmidhi}{373}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ السَّهْمِيِّ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي سُبْحَتِهِ قَاعِدًا حَتَّى كَانَ قَبْلَ وَفَاتِهِ صلى الله عليه وسلم بِعَامٍ فَإِنَّهُ كَانَ يُصَلِّي فِي سُبْحَتِهِ قَاعِدًا وَيَقْرَأُ بِالسُّورَةِ وَيُرَتِّلُهَا حَتَّى تَكُونَ أَطْوَلَ مِنْ أَطْوَلَ مِنْهَا ‏.‏ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ حَفْصَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يُصَلِّي مِنَ اللَّيْلِ جَالِسًا فَإِذَا بَقِيَ مِنْ قِرَاءَتِهِ قَدْرُ ثَلاَثِينَ أَوْ أَرْبَعِينَ آيَةً قَامَ فَقَرَأَ ثُمَّ رَكَعَ ثُمَّ صَنَعَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ ‏.‏ وَرُوِيَ عَنْهُ أَنَّهُ كَانَ يُصَلِّي قَاعِدًا فَإِذَا قَرَأَ وَهُوَ قَائِمٌ رَكَعَ وَسَجَدَ وَهُوَ قَائِمٌ وَإِذَا قَرَأَ وَهُوَ قَاعِدٌ رَكَعَ وَسَجَدَ وَهُوَ قَاعِدٌ ‏.‏ قَالَ أَحْمَدُ وَإِسْحَاقُ وَالْعَمَلُ عَلَى كِلاَ الْحَدِيثَيْنِ ‏.‏ كَأَنَّهُمَا رَأَيَا كِلاَ الْحَدِيثَيْنِ صَحِيحًا مَعْمُولاً بِهِمَا ‏.‏\hadithno{373}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Hafsah, the wife of the Prophet (S), narrated:"I did not see Allah's Messenger (S) praying voluntary prayers sitting until the year before he died. Then he would perform Salat for the voluntary prayers sitting, and he would recite a Surah and prolong it such that it would be longer than the longest of them}}
\hadithdefcmd{tirmidhi}{374}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي جَالِسًا فَيَقْرَأُ وَهُوَ جَالِسٌ فَإِذَا بَقِيَ مِنْ قِرَاءَتِهِ قَدْرُ مَا يَكُونُ ثَلاَثِينَ أَوْ أَرْبَعِينَ آيَةً قَامَ فَقَرَأَ وَهُوَ قَائِمٌ ثُمَّ رَكَعَ وَسَجَدَ ثُمَّ صَنَعَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{374}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"The Prophet (S) would perform Salat while sitting. And he would recite while sitting. When about thirty or forty Ayah of his recitation remained he would standup and recite while he was standing, then he would bow and prostrate. Then he would do the same in the second Rak'ah}}
\hadithdefcmd{tirmidhi}{375}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا خَالِدٌ، وَهُوَ الْحَذَّاءُ عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَ سَأَلْتُهَا عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ تَطَوُّعِهِ قَالَتْ كَانَ يُصَلِّي لَيْلاً طَوِيلاً قَائِمًا وَلَيْلاً طَوِيلاً قَاعِدًا فَإِذَا قَرَأَ وَهُوَ قَائِمٌ رَكَعَ وَسَجَدَ وَهُوَ قَائِمٌ وَإِذَا قَرَأَ وَهُوَ جَالِسٌ رَكَعَ وَسَجَدَ وَهُوَ جَالِسٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{375}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bun Shaqiq narrated from Aishah, he said:"I asked her about the voluntary Salat of Allah's Messenger (S), she said: 'He would pray long into the night standing, and long into the night sitting. So when he recited and he was standing, he would bow and prostrate whole he was standing, and when he recited while he was sitting, he bowed and prostrated while he was sitting}}
\hadithdefcmd{tirmidhi}{376}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَاللَّهِ إِنِّي لأَسْمَعُ بُكَاءَ الصَّبِيِّ وَأَنَا فِي الصَّلاَةِ فَأُخَفِّفُ مَخَافَةَ أَنْ تُفْتَتَنَ أُمُّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي قَتَادَةَ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{376}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that:Allah's Messenger said: "Indeed I hear the crying of a small boy while I am in Salat, so I shorten it in fear that his mother may be tormented}}
\hadithdefcmd{tirmidhi}{377}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا قَبِيصَةُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ قَتَادَةَ، عَنِ ابْنِ سِيرِينَ، عَنْ صَفِيَّةَ ابْنَةِ الْحَارِثِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُقْبَلُ صَلاَةُ الْحَائِضِ إِلاَّ بِخِمَارٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَقَوْلُهُ ‏"‏ الْحَائِضُ ‏"‏ ‏.‏ يَعْنِي الْمَرْأَةَ الْبَالِغَ يَعْنِي إِذَا حَاضَتْ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الْمَرْأَةَ إِذَا أَدْرَكَتْ فَصَلَّتْ وَشَيْءٌ مِنْ شَعْرِهَا مَكْشُوفٌ لاَ تَجُوزُ صَلاَتُهَا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ قَالَ لاَ تَجُوزُ صَلاَةُ الْمَرْأَةِ وَشَيْءٌ مِنْ جَسَدِهَا مَكْشُوفٌ ‏.‏ قَالَ الشَّافِعِيُّ وَقَدْ قِيلَ إِنْ كَانَ ظَهْرُ قَدَمَيْهَا مَكْشُوفًا فَصَلاَتُهَا جَائِزَةٌ ‏.‏\hadithno{377}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that:Allah's Messenger said: "The Salat of a women who has reached the age of menstruation is not accepted without a Khimar}}
\hadithdefcmd{tirmidhi}{378}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا قَبِيصَةُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عِسْلِ بْنِ سُفْيَانَ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ السَّدْلِ فِي الصَّلاَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي جُحَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عَطَاءٍ عَنْ أَبِي هُرَيْرَةَ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ عِسْلِ بْنِ سُفْيَانَ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي السَّدْلِ فِي الصَّلاَةِ فَكَرِهَ بَعْضُهُمُ السَّدْلَ فِي الصَّلاَةِ وَقَالُوا هَكَذَا تَصْنَعُ الْيَهُودُ ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّمَا كُرِهَ السَّدْلُ فِي الصَّلاَةِ إِذَا لَمْ يَكُنْ عَلَيْهِ إِلاَّ ثَوْبٌ وَاحِدٌ فَأَمَّا إِذَا سَدَلَ عَلَى الْقَمِيصِ فَلاَ بَأْسَ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَكَرِهَ ابْنُ الْمُبَارَكِ السَّدْلَ فِي الصَّلاَةِ ‏.‏\hadithno{378}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"Allah's Messenger (S) prohibited As-Sadl in the Salat}}
\hadithdefcmd{tirmidhi}{379}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا قَامَ أَحَدُكُمْ إِلَى الصَّلاَةِ فَلاَ يَمْسَحِ الْحَصَى فَإِنَّ الرَّحْمَةَ تُوَاجِهُهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مُعَيْقِيبٍ وَعَلِيِّ بْنِ أَبِي طَالِبٍ وَحُذَيْفَةَ وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي ذَرٍّ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَرِهَ الْمَسْحَ فِي الصَّلاَةِ وَقَالَ ‏"‏ إِنْ كُنْتَ لاَ بُدَّ فَاعِلاً فَمَرَّةً وَاحِدَةً ‏"‏ ‏.‏ كَأَنَّهُ رُوِيَ عَنْهُ رُخْصَةٌ فِي الْمَرَّةِ الْوَاحِدَةِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{379}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Dharr narrated that :the Prophet (S) said: "When one of you stands for Salat then he should not smoothen the pebbles, for indeed it is mercy that he is facing}}
\hadithdefcmd{tirmidhi}{380}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ مُعَيْقِيبٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ مَسْحِ الْحَصَى فِي الصَّلاَةِ فَقَالَ ‏ "‏ إِنْ كُنْتَ لاَ بُدَّ فَاعِلاً فَمَرَّةً وَاحِدَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{380}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Mu'aiqib narrated:"I asked Allah's Messenger (S) about smoothening the pebbles during Salat. He said: 'If you must do so, then let it be only once}}
\hadithdefcmd{tirmidhi}{381}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، أَخْبَرَنَا مَيْمُونٌ أَبُو حَمْزَةَ، عَنْ أَبِي صَالِحٍ، مَوْلَى طَلْحَةَ عَنْ أُمِّ سَلَمَةَ، قَالَتْ رَأَى النَّبِيُّ صلى الله عليه وسلم غُلاَمًا لَنَا يُقَالُ لَهُ أَفْلَحُ إِذَا سَجَدَ نَفَخَ فَقَالَ ‏ "‏ يَا أَفْلَحُ تَرِّبْ وَجْهَكَ ‏"‏ ‏.‏ قَالَ أَحْمَدُ بْنُ مَنِيعٍ وَكَرِهَ عَبَّادُ بْنُ الْعَوَّامِ النَّفْخَ فِي الصَّلاَةِ وَقَالَ إِنْ نَفَخَ لَمْ يَقْطَعْ صَلاَتَهُ ‏.‏ قَالَ أَحْمَدُ بْنُ مَنِيعٍ وَبِهِ نَأْخُذُ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى بَعْضُهُمْ عَنْ أَبِي حَمْزَةَ هَذَا الْحَدِيثَ وَقَالَ مَوْلًى لَنَا يُقَالُ لَهُ رَبَاحٌ ‏.‏\hadithno{381}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Umm Salamah narrated:"The Prophet (S) saw a boy of ours - called Aflah - blowing when he prostrated. So he said: 'O Aflah! Put your face in the dirt}}
\hadithdefcmd{tirmidhi}{382}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مَيْمُونٍ أَبِي حَمْزَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَقَالَ غُلاَمٌ لَنَا يُقَالُ لَهُ رَبَاحٌ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أُمِّ سَلَمَةَ إِسْنَادُهُ لَيْسَ بِذَاكَ ‏.‏ وَمَيْمُونٌ أَبُو حَمْزَةَ قَدْ ضَعَّفَهُ بَعْضُ أَهْلِ الْعِلْمِ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي النَّفْخِ فِي الصَّلاَةِ فَقَالَ بَعْضُهُمْ إِنْ نَفَخَ فِي الصَّلاَةِ اسْتَقْبَلَ الصَّلاَةَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ بَعْضُهُمْ يُكْرَهُ النَّفْخُ فِي الصَّلاَةِ وَإِنْ نَفَخَ فِي صَلاَتِهِ لَمْ تَفْسُدْ صَلاَتُهُ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{382}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) in which Abu Hamzah narrated:"A boy of ours named Rabah}}
\hadithdefcmd{tirmidhi}{383}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُصَلِّيَ الرَّجُلُ مُخْتَصِرًا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ الاِخْتِصَارَ فِي الصَّلاَةِ ‏.‏ وَكَرِهَ بَعْضُهُمْ أَنْ يَمْشِيَ الرَّجُلُ مُخْتَصِرًا ‏.‏ وَالاِخْتِصَارُ أَنْ يَضَعَ الرَّجُلُ يَدَهُ عَلَى خَاصِرَتِهِ فِي الصَّلاَةِ أَوْ يَضَعَ يَدَيْهِ جَمِيعًا عَلَى خَاصِرَتَيْهِ ‏.‏ وَيُرْوَى أَنَّ إِبْلِيسَ إِذَا مَشَى مَشَى مُخْتَصِرًا ‏.‏\hadithno{383}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"The Prophet (S) prohibited than a man to pray with his hands on his hip}}
\hadithdefcmd{tirmidhi}{384}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عِمْرَانَ بْنِ مُوسَى، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي رَافِعٍ، أَنَّهُ مَرَّ بِالْحَسَنِ بْنِ عَلِيٍّ وَهُوَ يُصَلِّي وَقَدْ عَقَصَ ضَفِرَتَهُ فِي قَفَاهُ فَحَلَّهَا فَالْتَفَتَ إِلَيْهِ الْحَسَنُ مُغْضَبًا فَقَالَ أَقْبِلْ عَلَى صَلاَتِكَ وَلاَ تَغْضَبْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ ذَلِكَ كِفْلُ الشَّيْطَانِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ وَعَبْدِ اللَّهِ بْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي رَافِعٍ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا أَنْ يُصَلِّيَ الرَّجُلُ وَهُوَ مَعْقُوصٌ شَعْرُهُ ‏.‏ قَالَ أَبُو عِيسَى وَعِمْرَانُ بْنُ مُوسَى هُوَ الْقُرَشِيُّ الْمَكِّيُّ وَهُوَ أَخُو أَيُّوبَ بْنِ مُوسَى ‏.‏\hadithno{384}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Rafi narrated that :He passed by Al-Hasan bin Ali while he was performing Salat and he had gathered his locks at the back of his head, so he (Abu Rafi) undid them, and Al-Hasan turned to him angrily. He said: "Resume your Salat and do not be angry, for indeed I heard Allah's Messenger (S) saying: 'That is the seat of Ash-Shaitan}}
\hadithdefcmd{tirmidhi}{385}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا اللَّيْثُ بْنُ سَعْدٍ، أَخْبَرَنَا عَبْدُ رَبِّهِ بْنُ سَعِيدٍ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ نَافِعِ ابْنِ الْعَمْيَاءِ، عَنْ رَبِيعَةَ بْنِ الْحَارِثِ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الصَّلاَةُ مَثْنَى مَثْنَى تَشَهَّدُ فِي كُلِّ رَكْعَتَيْنِ وَتَخَشَّعُ وَتَضَرَّعُ وَتَمَسْكَنُ وَتَذَرَّعُ وَتُقْنِعُ يَدَيْكَ يَقُولُ تَرْفَعُهُمَا إِلَى رَبِّكَ مُسْتَقْبِلاً بِبُطُونِهِمَا وَجْهَكَ وَتَقُولُ يَا رَبِّ يَا رَبِّ وَمَنْ لَمْ يَفْعَلْ ذَلِكَ فَهُوَ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَالَ غَيْرُ ابْنِ الْمُبَارَكِ فِي هَذَا الْحَدِيثِ ‏"‏ مَنْ لَمْ يَفْعَلْ ذَلِكَ فَهِيَ خِدَاجٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ رَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ فَأَخْطَأَ فِي مَوَاضِعَ فَقَالَ عَنْ أَنَسِ بْنِ أَبِي أَنَسٍ وَهُوَ عِمْرَانُ بْنُ أَبِي أَنَسٍ وَقَالَ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ وَإِنَّمَا هُوَ عَبْدُ اللَّهِ بْنُ نَافِعِ ابْنِ الْعَمْيَاءِ عَنْ رَبِيعَةَ بْنِ الْحَارِثِ ‏.‏ وَقَالَ شُعْبَةُ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ عَنِ الْمُطَّلِبِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَإِنَّمَا هُوَ عَنْ رَبِيعَةَ بْنِ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ عَنِ الْفَضْلِ بْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ مُحَمَّدٌ وَحَدِيثُ اللَّيْثِ بْنِ سَعْدٍ يَعْنِي أَصَحَّ مِنْ حَدِيثِ شُعْبَةَ ‏.‏\hadithno{385}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Fadl bin Al-`Abbas narrated that:Allah's Messenger (S) said: "As-Salat is two and two, with a Tashahhud for every two Rak`ah, with humility, imploring, having a sense of tranquility, pleading and showing helplessness and stretching out your hand" - he said: raising them - "to your Lord, with the insides of them facing your face, saying: 'O Lord! O Lord! And whoever does not do this, then it is like this or that}}
\hadithdefcmd{tirmidhi}{386}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ رَجُلٍ، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ أَحَدُكُمْ فَأَحْسَنَ وُضُوءَهُ ثُمَّ خَرَجَ عَامِدًا إِلَى الْمَسْجِدِ فَلاَ يُشَبِّكَنَّ بَيْنَ أَصَابِعِهِ فَإِنَّهُ فِي صَلاَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ كَعْبِ بْنِ عُجْرَةَ رَوَاهُ غَيْرُ وَاحِدٍ عَنِ ابْنِ عَجْلاَنَ مِثْلَ حَدِيثِ اللَّيْثِ ‏.‏ وَرَوَى شَرِيكٌ عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا الْحَدِيثِ وَحَدِيثُ شَرِيكٍ غَيْرُ مَحْفُوظٍ ‏.‏\hadithno{386}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ka'b bun Ujrah narrated that:Allah's Messenger (S) said: "When one of you performs Wudu and does so well, then he leaves intending to go to the Masjid, then let him not intertwine his fingers, for indeed he is in Salat}}
\hadithdefcmd{tirmidhi}{387}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم أَىُّ الصَّلاَةِ أَفْضَلُ قَالَ ‏ "‏ طُولُ الْقُنُوتِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ حُبْشِيٍّ وَأَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرِ بْنِ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏\hadithno{387}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated:"It was said to the Prophet (S): 'Which Salat is most virtuous?' He said: 'That with the longest Qunut}}
\hadithdefcmd{tirmidhi}{388}{حَدَّثَنَا أَبُو عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ، قَالَ وَحَدَّثَنَا أَبُو مُحَمَّدٍ، رَجَاءٌ قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ هِشَامٍ الْمُعَيْطِيُّ، قَالَ حَدَّثَنِي مَعْدَانُ بْنُ طَلْحَةَ الْيَعْمَرِيُّ، قَالَ لَقِيتُ ثَوْبَانَ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ دُلَّنِي عَلَى عَمَلٍ يَنْفَعُنِي اللَّهُ بِهِ وَيُدْخِلُنِي الْجَنَّةَ فَسَكَتَ عَنِّي مَلِيًّا ثُمَّ الْتَفَتَ إِلَىَّ فَقَالَ عَلَيْكَ بِالسُّجُودِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ يَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏\hadithno{388}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ma'dan bin Talhah Al Yamari said:"I met Thawban the freed slave of Allah's Messenger (S) and said to him, 'Guide me to a deed by which Allah benefit me, and for which Allah will admit me into Paradise.' He was silent for quite a while, then he turned to me and said: 'Perform prostrations, for I heard Allah's Messenger (S) saying: 'No worshipper performs a prostration to Allah except that by it, Allah will raise him a level, and erase a sin from him for it}}
\hadithdefcmd{tirmidhi}{389}{قَالَ مَعْدَانُ بْنُ طَلْحَةَ فَلَقِيتُ أَبَا الدَّرْدَاءِ فَسَأَلْتُهُ عَمَّا سَأَلْتُ عَنْهُ ثَوْبَانَ فَقَالَ عَلَيْكَ بِالسُّجُودِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ يَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏ قَالَ مَعْدَانُ بْنُ طَلْحَةَ الْيَعْمَرِيُّ وَيُقَالُ ابْنُ أَبِي طَلْحَةَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي أُمَامَةَ وَأَبِي فَاطِمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ثَوْبَانَ وَأَبِي الدَّرْدَاءِ فِي كَثْرَةِ الرُّكُوعِ وَالسُّجُودِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا الْبَابِ فَقَالَ بَعْضُهُمْ طُولُ الْقِيامِ فِي الصَّلاَةِ أَفْضَلُ مِنْ كَثْرَةِ الرُّكُوعِ وَالسُّجُودِ ‏.‏ وَقَالَ بَعْضُهُمْ كَثْرَةُ الرُّكُوعِ وَالسُّجُودِ أَفْضَلُ مِنْ طُولِ الْقِيَامِ ‏.‏ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ قَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا حَدِيثَانِ وَلَمْ يَقْضِ فِيهِ بِشَيْءٍ ‏.‏ وَقَالَ إِسْحَاقُ أَمَّا فِي النَّهَارِ فَكَثْرَةُ الرُّكُوعِ وَالسُّجُودِ وَأَمَّا بِاللَّيْلِ فَطُولُ الْقِيَامِ إِلاَّ أَنْ يَكُونَ رَجُلٌ لَهُ جُزْءٌ بِاللَّيْلِ يَأْتِي عَلَيْهِ فَكَثْرَةُ الرُّكُوعِ وَالسُّجُودِ فِي هَذَا أَحَبُّ إِلَىَّ لأَنَّهُ يَأْتِي عَلَى جُزْئِهِ وَقَدْ رَبِحَ كَثْرَةَ الرُّكُوعِ وَالسُّجُودِ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا قَالَ إِسْحَاقُ هَذَا لأَنَّهُ كَذَا وُصِفَ صَلاَةُ النَّبِيِّ صلى الله عليه وسلم بِاللَّيْلِ وَوُصِفَ طُولُ الْقِيَامِ وَأَمَّا بِالنَّهَارِ فَلَمْ يُوصَفْ مِنْ صَلاَتِهِ مِنْ طُولِ الْقِيَامِ مَا وُصِفَ بِاللَّيْلِ ‏.‏\hadithno{389}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Madan [bin Talhah] said:"I met Abu Ad-Darda, and I asked him what I had asked Thawban, so he said: 'Perform prostrations, for I heard Allah's Messenger saying: 'No worshipper performs a prostration to Allah except that by it Allah will raise him a level, and erase a sin from him for it}}
\hadithdefcmd{tirmidhi}{390}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، هُوَ ابْنُ إِبْرَاهِيمَ عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ ضَمْضَمِ بْنِ جَوْسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الأَسْوَدَيْنِ فِي الصَّلاَةِ الْحَيَّةُ وَالْعَقْرَبُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَكَرِهَ بَعْضُ أَهْلِ الْعِلْمِ قَتْلَ الْحَيَّةِ وَالْعَقْرَبِ فِي الصَّلاَةِ ‏.‏ وَقَالَ إِبْرَاهِيمُ إِنَّ فِي الصَّلاَةِ لَشُغْلاً ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{390}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated:"Allah's Messenger (S) ordered killing the two black things in Salat; the snake and the scorpion}}
\hadithdefcmd{tirmidhi}{391}{\hadithno{391}\hadithgrade{Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{391p2}{\hadithno{391.2}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{392}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الظُّهْرَ خَمْسًا فَقِيلَ لَهُ أَزِيدَ فِي الصَّلاَةِ فَسَجَدَ سَجْدَتَيْنِ بَعْدَ مَا سَلَّمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{392}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Masud narrated:"The Prophet (S) prayed five (Rakah) for Zuhr, so it was said to him: 'Has the prayer been added to, or have you merely forgotten?' So he (S) performed two prostrations after he had said the Salam}}
\hadithdefcmd{tirmidhi}{393}{حَدَّثَنَا هَنَّادٌ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَجَدَ سَجْدَتَىِ السَّهْوِ بَعْدَ الْكَلاَمِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مُعَاوِيَةَ وَعَبْدِ اللَّهِ بْنِ جَعْفَرٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{393}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah (bin Masud) narrated:"The Prophet (S) performed two prostrations for As-Sahw after talking}}
\hadithdefcmd{tirmidhi}{394}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَجَدَهُمَا بَعْدَ السَّلاَمِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ أَيُّوبُ وَغَيْرُ وَاحِدٍ عَنِ ابْنِ سِيرِينَ ‏.‏ وَحَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ قَالُوا إِذَا صَلَّى الرَّجُلُ الظُّهْرَ خَمْسًا فَصَلاَتُهُ جَائِزَةٌ وَسَجَدَ سَجْدَتَىِ السَّهْوِ وَإِنْ لَمْ يَجْلِسْ فِي الرَّابِعَةِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا صَلَّى الظُّهْرَ خَمْسًا وَلَمْ يَقْعُدْ فِي الرَّابِعَةِ مِقْدَارَ التَّشَهُّدِ فَسَدَتْ صَلاَتُهُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَبَعْضِ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{394}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"The Prophet (S) performed two prostrations after the Salam}}
\hadithdefcmd{tirmidhi}{395}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ أَخْبَرَنِي أَشْعَثُ، عَنِ ابْنِ سِيرِينَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِهِمْ فَسَهَا فَسَجَدَ سَجْدَتَيْنِ ثُمَّ تَشَهَّدَ ثُمَّ سَلَّمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثُ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى مُحَمَّدُ بْنُ سِيرِينَ عَنْ أَبِي الْمُهَلَّبِ وَهُوَ عَمُّ أَبِي قِلاَبَةَ غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَرَوَى مُحَمَّدٌ هَذَا الْحَدِيثَ عَنْ خَالِدٍ الْحَذَّاءِ عَنْ أَبِي قِلاَبَةَ عَنْ أَبِي الْمُهَلَّبِ ‏.‏ وَأَبُو الْمُهَلَّبِ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو وَيُقَالُ أَيْضًا مُعَاوِيَةُ بْنُ عَمْرٍو ‏.‏ وَقَدْ رَوَى عَبْدُ الْوَهَّابِ الثَّقَفِيُّ وَهُشَيْمٌ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ خَالِدٍ الْحَذَّاءِ عَنْ أَبِي قِلاَبَةَ بِطُولِهِ وَهُوَ حَدِيثُ عِمْرَانَ بْنِ حُصَيْنٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم سَلَّمَ فِي ثَلاَثِ رَكَعَاتٍ مِنَ الْعَصْرِ فَقَامَ رَجُلٌ يُقَالُ لَهُ الْخِرْبَاقُ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي التَّشَهُّدِ فِي سَجْدَتَىِ السَّهْوِ فَقَالَ بَعْضُهُمْ يَتَشَهَّدُ فِيهِمَا وَيُسَلِّمُ ‏.‏ وَقَالَ بَعْضُهُمْ لَيْسَ فِيهِمَا تَشَهُّدٌ وَتَسْلِيمٌ وَإِذَا سَجَدَهُمَا قَبْلَ السَّلاَمِ لَمْ يَتَشَهَّدْ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ قَالاَ إِذَا سَجَدَ سَجْدَتَىِ السَّهْوِ قَبْلَ السَّلاَمِ لَمْ يَتَشَهَّدْ ‏.‏\hadithno{395}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Al-Muhallab narrated from Imran bin Husain that :the Prophet (S) led them in Salat he forgot (something) so he performed two prostrations, then the Tashah-hud, then the Salam}}
\hadithdefcmd{tirmidhi}{396}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِيَاضٍ يَعْنِي ابْنَ هِلاَلٍ، قَالَ قُلْتُ لأَبِي سَعِيدٍ أَحَدُنَا يُصَلِّي فَلاَ يَدْرِي كَيْفَ صَلَّى فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا صَلَّى أَحَدُكُمْ فَلَمْ يَدْرِ كَيْفَ صَلَّى فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُثْمَانَ وَابْنِ مَسْعُودٍ وَعَائِشَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَبِي سَعِيدٍ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِذَا شَكَّ أَحَدُكُمْ فِي الْوَاحِدَةِ وَالثِّنْتَيْنِ فَلْيَجْعَلْهُمَا وَاحِدَةً وَإِذَا شَكَّ فِي الثِّنْتَيْنِ وَالثَّلاَثِ فَلْيَجْعَلْهُمَا ثِنْتَيْنِ وَيَسْجُدْ فِي ذَلِكَ سَجْدَتَيْنِ قَبْلَ أَنْ يُسَلِّمَ ‏"‏ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَصْحَابِنَا ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا شَكَّ فِي صَلاَتِهِ فَلَمْ يَدْرِ كَمْ صَلَّى فَلْيُعِدْ ‏.‏\hadithno{396}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Iyad bin Hilal said:"I said to Abu Sa'eed: 'One of us performs Salat and we do not know how (much) we prayed.' So he said: 'Allah's Messenger (S) said: "When one of you performs Salat and he does now know how (much) he prayed then let him perform two prostrations while he is sitting}}
\hadithdefcmd{tirmidhi}{397}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّيْطَانَ يَأْتِي أَحَدَكُمْ فِي صَلاَتِهِ فَيَلْبِسُ عَلَيْهِ حَتَّى لاَ يَدْرِي كَمْ صَلَّى فَإِذَا وَجَدَ ذَلِكَ أَحَدُكُمْ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{397}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger (S) said: "Indeed the Shaitan comes to one of you in his Salat confusing him until he does now know how much he has prayed. When one of you experiences that then let him perform two prostrations while sitting}}
\hadithdefcmd{tirmidhi}{398}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ ابْنُ عَثْمَةَ الْبَصْرِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مَكْحُولٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَهَا أَحَدُكُمْ فِي صَلاَتِهِ فَلَمْ يَدْرِ وَاحِدَةً صَلَّى أَوْ ثِنْتَيْنِ فَلْيَبْنِ عَلَى وَاحِدَةٍ فَإِنْ لَمْ يَدْرِ ثِنْتَيْنِ صَلَّى أَوْ ثَلاَثًا فَلْيَبْنِ عَلَى ثِنْتَيْنِ فَإِنْ لَمْ يَدْرِ ثَلاَثًا صَلَّى أَوْ أَرْبَعًا فَلْيَبْنِ عَلَى ثَلاَثٍ وَلْيَسْجُدْ سَجْدَتَيْنِ قَبْلَ أَنْ يُسَلِّمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ مِنْ غَيْرِ هَذَا الْوَجْهِ رَوَاهُ الزُّهْرِيُّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ عَنِ ابْنِ عَبَّاسٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{398}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdur-Rahman bi Awf narrated that he heard the Prophet (S) saying:"When one of you becomes forgetful in his Salat so that he does not know if he prayed one or two, then let him consider it one. When he does not know if he prayed three or four, then let him consider it three, and let him perform two prostrations before he says the Taslim}}
\hadithdefcmd{tirmidhi}{399}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ، وَهُوَ أَيُّوبُ السَّخْتِيَانِيُّ عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم انْصَرَفَ مِنَ اثْنَتَيْنِ فَقَالَ لَهُ ذُو الْيَدَيْنِ أَقُصِرَتِ الصَّلاَةُ أَمْ نَسِيتَ يَا رَسُولَ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالَ النَّاسُ نَعَمْ ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى اثْنَتَيْنِ أُخْرَيَيْنِ ثُمَّ سَلَّمَ ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ كَبَّرَ فَرَفَعَ ثُمَّ سَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَابْنِ عُمَرَ وَذِي الْيَدَيْنِ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا الْحَدِيثِ فَقَالَ بَعْضُ أَهْلِ الْكُوفَةِ إِذَا تَكَلَّمَ فِي الصَّلاَةِ نَاسِيًا أَوْ جَاهِلاً أَوْ مَا كَانَ فَإِنَّهُ يُعِيدُ الصَّلاَةَ وَاعْتَلُّوا بِأَنَّ هَذَا الْحَدِيثَ كَانَ قَبْلَ تَحْرِيمِ الْكَلاَمِ فِي الصَّلاَةِ ‏.‏ قَالَ وَأَمَّا الشَّافِعِيُّ فَرَأَى هَذَا حَدِيثًا صَحِيحًا فَقَالَ بِهِ وَقَالَ هَذَا أَصَحُّ مِنَ الْحَدِيثِ الَّذِي رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الصَّائِمِ إِذَا أَكَلَ نَاسِيًا فَإِنَّهُ لاَ يَقْضِي وَإِنَّمَا هُوَ رِزْقٌ رَزَقَهُ اللَّهُ ‏.‏ قَالَ الشَّافِعِيُّ وَفَرَّقُوا هَؤُلاَءِ بَيْنَ الْعَمْدِ وَالنِّسْيَانِ فِي أَكْلِ الصَّائِمِ بِحَدِيثِ أَبِي هُرَيْرَةَ ‏.‏ وَقَالَ أَحْمَدُ فِي حَدِيثِ أَبِي هُرَيْرَةَ إِنْ تَكَلَّمَ الإِمَامُ فِي شَيْءٍ مِنْ صَلاَتِهِ وَهُوَ يَرَى أَنَّهُ قَدْ أَكْمَلَهَا ثُمَّ عَلِمَ أَنَّهُ لَمْ يُكْمِلْهَا يُتِمُّ صَلاَتَهُ وَمَنْ تَكَلَّمَ خَلْفَ الإِمَامِ وَهُوَ يَعْلَمُ أَنَّ عَلَيْهِ بَقِيَّةً مِنَ الصَّلاَةِ فَعَلَيْهِ أَنْ يَسْتَقْبِلَهَا ‏.‏ وَاحْتَجَّ بِأَنَّ الْفَرَائِضَ كَانَتْ تُزَادُ وَتُنْقَصُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنَّمَا تَكَلَّمَ ذُو الْيَدَيْنِ وَهُوَ عَلَى يَقِينٍ مِنْ صَلاَتِهِ أَنَّهَا تَمَّتْ وَلَيْسَ هَكَذَا الْيَوْمَ لَيْسَ لأَحَدٍ أَنْ يَتَكَلَّمَ عَلَى مَعْنَى مَا تَكَلَّمَ ذُو الْيَدَيْنِ لأَنَّ الْفَرَائِضَ الْيَوْمَ لاَ يُزَادُ فِيهَا وَلاَ يُنْقَصُ ‏.‏ قَالَ أَحْمَدُ نَحْوًا مِنْ هَذَا الْكَلاَمِ ‏.‏ وَقَالَ إِسْحَاقُ نَحْوَ قَوْلِ أَحْمَدَ فِي الْبَابِ ‏.‏\hadithno{399}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"The Prophet (S) turned (finished the prayer) after two (Rak'ah), so Dhul-Yadain said: 'Has the prayer been shortened or have you forgotten O Messenger of Allah?" The Prophet (S) said: 'Is what Dhul-Yadain said the truth?' The people said yes, so Allah's Messenger (S) stood to perform the last two (Rakah) of Salat, then he said the Taslim. Then he said the Takbir and prostrated in a manner the same or longer than his (normal) prostrations}}
\hadithdefcmd{tirmidhi}{400}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ سَعِيدِ بْنِ يَزِيدَ أَبِي مَسْلَمَةَ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي نَعْلَيْهِ قَالَ نَعَمْ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَعَبْدِ اللَّهِ بْنِ أَبِي حَبِيبَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَمْرِو بْنِ حُرَيْثٍ وَشَدَّادِ بْنِ أَوْسٍ وَأَوْسٍ الثَّقَفِيِّ وَأَبِي هُرَيْرَةَ وَعَطَاءٍ رَجُلٍ مِنْ بَنِي شَيْبَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{400}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'eed bin Yazid Abu Maslamah said:"I said to Anas bin Malik: 'Would Allah's Messenger (S) perform Salat wearing his sandals?' He said: 'Yes}}
\hadithdefcmd{tirmidhi}{401}{حَدَّثَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا غُنْدَرٌ، مُحَمَّدُ بْنُ جَعْفَرٍ عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْنُتُ فِي صَلاَةِ الصُّبْحِ وَالْمَغْرِبِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَخُفَافِ بْنِ إِيمَاءَ بْنِ رَحْضَةَ الْغِفَارِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْقُنُوتِ فِي صَلاَةِ الْفَجْرِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ الْقُنُوتَ فِي صَلاَةِ الْفَجْرِ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ لاَ يَقْنُتُ فِي الْفَجْرِ إِلاَّ عِنْدَ نَازِلَةٍ تَنْزِلُ بِالْمُسْلِمِينَ فَإِذَا نَزَلَتْ نَازِلَةٌ فَلِلإِمَامِ أَنْ يَدْعُوَ لِجُيُوشِ الْمُسْلِمِينَ ‏.‏\hadithno{401}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Al-Bara bin Azib narrated:"The Prophet (S) would perform the Qunut in the Subh and Maghrib prayers}}
\hadithdefcmd{tirmidhi}{402}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، قَالَ قُلْتُ لأَبِي يَا أَبَةِ إِنَّكَ قَدْ صَلَّيْتَ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ وَعَلِيِّ بْنِ أَبِي طَالِبٍ هَا هُنَا بِالْكُوفَةِ نَحْوًا مِنْ خَمْسِ سِنِينَ أَكَانُوا يَقْنُتُونَ قَالَ أَىْ بُنَىَّ مُحْدَثٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ ‏.‏ وَقَالَ سُفْيَانُ الثَّوْرِيُّ إِنْ قَنَتَ فِي الْفَجْرِ فَحَسَنٌ وَإِنْ لَمْ يَقْنُتْ فَحَسَنٌ ‏.‏ وَاخْتَارَ أَنْ لاَ يَقْنُتَ ‏.‏ وَلَمْ يَرَ ابْنُ الْمُبَارَكِ الْقُنُوتَ فِي الْفَجْرِ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو مَالِكٍ الأَشْجَعِيُّ اسْمُهُ سَعْدُ بْنُ طَارِقِ بْنِ أَشْيَمَ ‏.‏\hadithno{402}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Malik Al-Ashjai narrated:"I said to my father: 'O my father! You offered Salat behind Allah's Messenger (S), Abu Bakr, Umar, Uthman, and Ali bin Abi Talib here in Al-Kufah for about five years. Did they say the Qunut?' He said: 'It is a newly invented matter my son}}
\hadithdefcmd{tirmidhi}{403}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ بِمَعْنَاهُ ‏.‏\hadithno{403}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{There is another narration from Abu Malik:There exists another narration from Abu Malik with similar meaning but with different chain}}
\hadithdefcmd{tirmidhi}{404}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا رِفَاعَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ رِفَاعَةَ بْنِ رَافِعٍ الزُّرَقِيُّ، عَنْ عَمِّ، أَبِيهِ مُعَاذِ بْنِ رِفَاعَةَ عَنْ أَبِيهِ، قَالَ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَطَسْتُ فَقُلْتُ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ مُبَارَكًا عَلَيْهِ كَمَا يُحِبُّ رَبُّنَا وَيَرْضَى ‏.‏ فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم انْصَرَفَ فَقَالَ ‏"‏ مَنِ الْمُتَكَلِّمُ فِي الصَّلاَةِ ‏"‏ ‏.‏ فَلَمْ يَتَكَلَّمْ أَحَدٌ ثُمَّ قَالَهَا الثَّانِيَةَ ‏"‏ مَنِ الْمُتَكَلِّمُ فِي الصَّلاَةِ ‏"‏ ‏.‏ فَلَمْ يَتَكَلَّمْ أَحَدٌ ثُمَّ قَالَهَا الثَّالِثَةَ ‏"‏ مَنِ الْمُتَكَلِّمُ فِي الصَّلاَةِ ‏"‏ ‏.‏ فَقَالَ رِفَاعَةُ بْنُ رَافِعِ ابْنِ عَفْرَاءَ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ مُبَارَكًا عَلَيْهِ كَمَا يُحِبُّ رَبُّنَا وَيَرْضَى فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدِ ابْتَدَرَهَا بِضْعَةٌ وَثَلاَثُونَ مَلَكًا أَيُّهُمْ يَصْعَدُ بِهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَوَائِلِ بْنِ حُجْرٍ وَعَامِرِ بْنِ رَبِيعَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ رِفَاعَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَكَأَنَّ هَذَا الْحَدِيثَ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنَّهُ فِي التَّطَوُّعِ لأَنَّ غَيْرَ وَاحِدٍ مِنَ التَّابِعِينَ قَالُوا إِذَا عَطَسَ الرَّجُلُ فِي الصَّلاَةِ الْمَكْتُوبَةِ إِنَّمَا يَحْمَدُ اللَّهَ فِي نَفْسِهِ وَلَمْ يُوَسِّعُوا فِي أَكْثَرَ مِنْ ذَلِكَ ‏.‏\hadithno{404}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muadh bin Rifa'ah narrated that his father said:"I prayed behind Allah's Messenger (S). I sneezed and said: Al-Hamdulillah, hamdan kathiran tayyiban mubarakan fih, mubarakan alaihi kama yuhibbu Rabbana Wa Yarda (All praise is due to Alah, many good blessed praises, blessings for Him as our Lord loves and is pleased with.) When Allah's Messenger (S) prayed and turned (after finishing) he said: 'Who was the speaker during the Salat?' No one spoke. Then he said it a second time: 'Who was the speaker during the Salat?' But no one spoke. Then he said it a third time: 'Who was the speaker during the Salat?'" So Rifa'ah bin Rafi bin Afra said: "It was I, O Messenger of Allah (S)." He said: "What did you say?" He said: "I said: 'Al-Hamdulillah, hamdan kathiran tayyiban mubarakan fih, mubarakan alaihi kama yuhibbu Rabbana Wa Yarda. The Prophet (S) said: "By the One in Whose Hand is my soul! I saw thirty-some angels competing over which of then would ascend with it}}
\hadithdefcmd{tirmidhi}{405}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ الْحَارِثِ بْنِ شُبَيْلٍ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كُنَّا نَتَكَلَّمُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الصَّلاَةِ يُكَلِّمُ الرَّجُلُ مِنَّا صَاحِبَهُ إِلَى جَنْبِهِ حَتَّى نَزَلَتْ ‏:‏ ‏(‏وَقُومُوا لِلَّهِ قَانِتِينَ ‏)‏ فَأُمِرْنَا بِالسُّكُوتِ وَنُهِينَا عَنِ الْكَلاَمِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَمُعَاوِيَةَ بْنِ الْحَكَمِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ أَرْقَمَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ ‏.‏ قَالُوا إِذَا تَكَلَّمَ الرَّجُلُ عَامِدًا فِي الصَّلاَةِ أَوْ نَاسِيًا أَعَادَ الصَّلاَةَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَأَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا تَكَلَّمَ عَامِدًا فِي الصَّلاَةِ أَعَادَ الصَّلاَةَ وَإِنْ كَانَ نَاسِيًا أَوْ جَاهِلاً أَجْزَأَهُ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ ‏.‏\hadithno{405}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Zaid bin Arqam narrated:"We used to talk behind Allah's Messenger (S) during the Salat, a man among us would talk to his companions next to him until (the following) was revealed: And stand before Allah with obedience. (2:238) So we were ordered to be silent and prohibited from talking}}
\hadithdefcmd{tirmidhi}{406}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُثْمَانَ بْنِ الْمُغِيرَةِ، عَنْ عَلِيِّ بْنِ رَبِيعَةَ، عَنْ أَسْمَاءَ بْنِ الْحَكَمِ الْفَزَارِيِّ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ إِنِّي كُنْتُ رَجُلاً إِذَا سَمِعْتُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا نَفَعَنِي اللَّهُ مِنْهُ بِمَا شَاءَ أَنْ يَنْفَعَنِي بِهِ وَإِذَا حَدَّثَنِي رَجُلٌ مِنْ أَصْحَابِهِ اسْتَحْلَفْتُهُ فَإِذَا حَلَفَ لِي صَدَّقْتُهُ وَإِنَّهُ حَدَّثَنِي أَبُو بَكْرٍ وَصَدَقَ أَبُو بَكْرٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ رَجُلٍ يُذْنِبُ ذَنْبًا ثُمَّ يَقُومُ فَيَتَطَهَّرُ ثُمَّ يُصَلِّي ثُمَّ يَسْتَغْفِرُ اللَّهَ إِلاَّ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ هَذِهِ الآيَةَ ‏:‏ ‏(‏وَالَّذِينَ إِذَا فَعَلُوا فَاحِشَةً أَوْ ظَلَمُوا أَنْفُسَهُمْ ذَكَرُوا اللَّهَ فَاسْتَغْفَرُوا لِذُنُوبِهِمْ وَمَنْ يَغْفِرُ الذُّنُوبَ إِلاَّ اللَّهُ وَلَمْ يُصِرُّوا عَلَى مَا فَعَلُوا وَهُمْ يَعْلَمُونَ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي الدَّرْدَاءِ وَأَنَسٍ وَأَبِي أُمَامَةَ وَمُعَاذٍ وَوَاثِلَةَ وَأَبِي الْيَسَرِ وَاسْمُهُ كَعْبُ بْنُ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عُثْمَانَ بْنِ الْمُغِيرَةِ ‏.‏ وَرَوَى عَنْهُ شُعْبَةُ وَغَيْرُ وَاحِدٍ فَرَفَعُوهُ مِثْلَ حَدِيثِ أَبِي عَوَانَةَ ‏.‏ وَرَوَاهُ سُفْيَانُ الثَّوْرِيُّ وَمِسْعَرٌ فَأَوْقَفَاهُ وَلَمْ يَرْفَعَاهُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ رُوِيَ عَنْ مِسْعَرٍ هَذَا الْحَدِيثُ مَرْفُوعًا أَيْضًا ‏.‏ وَلاَ نَعْرِفُ لأَسْمَاءَ بْنِ الْحَكَمِ حَدِيثًا مَرْفُوعًا إِلاَّ هَذَا ‏.‏\hadithno{406}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asma bin Al-Hakam Al-Fazari said:"I heard Ali saying: 'Indeed I am a man who, when I heard a Hadith from Allah's Messenger (S) then Allah causes me to benefit from it as much as He wills for me to benefit from it. When a man among his Companions narrated to me I ask him to swear an oath to me about it, and when he swears an oath to me I trust him. And Abu Bakr narrated to me - and Abu Bakr told the truth - he said: "I heard Allah's Messenger (S) saying: 'There is no man who commits a sin, then makes Wudu, then performs Salat, then seeks forgiveness from Allah, except that Allah forgives him.' Then he recited this Ayah: Those who when they have committed Fahishah or wronged themselves with eveil, remember Allah. (3:135) until the end of the Ayah}}
\hadithdefcmd{tirmidhi}{407}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا حَرْمَلَةُ بْنُ عَبْدِ الْعَزِيزِ بْنِ الرَّبِيعِ بْنِ سَبْرَةَ الْجُهَنِيُّ، عَنْ عَمِّهِ عَبْدِ الْمَلِكِ بْنِ الرَّبِيعِ بْنِ سَبْرَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلِّمُوا الصَّبِيَّ الصَّلاَةَ ابْنَ سَبْعِ سِنِينَ وَاضْرِبُوهُ عَلَيْهَا ابْنَ عَشْرٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَبْرَةَ بْنِ مَعْبَدٍ الْجُهَنِيِّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلَيْهِ الْعَمَلُ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالاَ مَا تَرَكَ الْغُلاَمُ بَعْدَ الْعَشْرِ مِنَ الصَّلاَةِ فَإِنَّهُ يُعِيدُ ‏.‏ قَالَ أَبُو عِيسَى وَسَبْرَةُ هُوَ ابْنُ مَعْبَدٍ الْجُهَنِيُّ وَيُقَالَ هُوَ ابْنُ عَوْسَجَةَ ‏.‏\hadithno{407}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Sabrah bin Ma'bad al-Juhni) narrated that:Allah's Messenger (S) said: "Teach the boy Salat when he is seven years old, and beat him (if he does not pray) when he is ten}}
\hadithdefcmd{tirmidhi}{408}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى الْمُلَقَّبُ، مَرْدَوَيْهِ قَالَ أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ زِيَادِ بْنِ أَنْعُمَ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ رَافِعٍ، وَبَكْرَ بْنَ سَوَادَةَ، أَخْبَرَاهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَحْدَثَ - يَعْنِي الرَّجُلَ - وَقَدْ جَلَسَ فِي آخِرِ صَلاَتِهِ قَبْلَ أَنْ يُسَلِّمَ فَقَدْ جَازَتْ صَلاَتُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِسْنَادُهُ لَيْسَ بِذَاكَ الْقَوِيِّ وَقَدِ اضْطَرَبُوا فِي إِسْنَادِهِ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا ‏.‏ قَالُوا إِذَا جَلَسَ مِقْدَارَ التَّشَهُّدِ وَأَحْدَثَ قَبْلَ أَنْ يُسَلِّمَ فَقَدْ تَمَّتْ صَلاَتُهُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا أَحْدَثَ قَبْلَ أَنْ يَتَشَهَّدَ وَقَبْلَ أَنْ يُسَلِّمَ أَعَادَ الصَّلاَةَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ وَقَالَ أَحْمَدُ إِذَا لَمْ يَتَشَهَّدْ وَسَلَّمَ أَجْزَأَهُ لِقَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ وَتَحْلِيلُهَا التَّسْلِيمُ ‏"‏ وَالتَّشَهُّدُ أَهْوَنُ قَامَ النَّبِيُّ صلى الله عليه وسلم فِي اثْنَتَيْنِ فَمَضَى فِي صَلاَتِهِ وَلَمْ يَتَشَهَّدْ ‏.‏ وَقَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ إِذَا تَشَهَّدَ وَلَمْ يُسَلِّمْ أَجْزَأَهُ ‏.‏ وَاحْتَجَّ بِحَدِيثِ ابْنِ مَسْعُودٍ حِينَ عَلَّمَهُ النَّبِيُّ صلى الله عليه وسلم التَّشَهُّدَ فَقَالَ ‏"‏ إِذَا فَرَغْتَ مِنْ هَذَا فَقَدْ قَضَيْتَ مَا عَلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَعَبْدُ الرَّحْمَنِ بْنُ زِيَادِ بْنِ أَنْعُمٍ هُوَ الإِفْرِيقِيُّ وَقَدْ ضَعَّفَهُ بَعْضُ أَهْلِ الْحَدِيثِ مِنْهُمْ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَأَحْمَدُ بْنُ حَنْبَلٍ ‏.‏\hadithno{408}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Amr narrated that:Allah's Messenger (S) said: "When he commits Hadath - meaning a man - and he is sitting in the end of his Salat before saying the Taslim, then his Salat is acceptable}}
\hadithdefcmd{tirmidhi}{409}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ الْبَصْرِيُّ حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَأَصَابَنَا مَطَرٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ شَاءَ فَلْيُصَلِّ فِي رَحْلِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَسَمُرَةَ وَأَبِي الْمَلِيحِ عَنْ أَبِيهِ وَعَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ أَهْلُ الْعِلْمِ فِي الْقُعُودِ عَنِ الْجَمَاعَةِ وَالْجُمُعَةِ فِي الْمَطَرِ وَالطِّينِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ أَبَا زُرْعَةَ يَقُولُ رَوَى عَفَّانُ بْنُ مُسْلِمٍ عَنْ عَمْرِو بْنِ عَلِيٍّ حَدِيثًا ‏.‏ وَقَالَ أَبُو زُرْعَةَ لَمْ نَرَ بِالْبَصْرَةِ أَحْفَظَ مِنْ هَؤُلاَءِ الثَّلاَثَةِ عَلِيِّ بْنِ الْمَدِينِيِّ وَابْنِ الشَّاذَكُونِيِّ وَعَمْرِو بْنِ عَلِيٍّ ‏.‏ وَأَبُو الْمَلِيحِ اسْمُهُ عَامِرٌ وَيُقَالُ زَيْدُ بْنُ أُسَامَةَ بْنِ عُمَيْرٍ الْهُذَلِيُّ ‏.‏\hadithno{409}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Jabir narrated:"We were with the Prophet (S) on a journey when it started to rain on us, so the Prophet (S) said: 'Whoever wishes, let him perform Salat in his place}}
\hadithdefcmd{tirmidhi}{410}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبِ بْنِ الشَّهِيدِ الْبَصْرِيُّ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا عَتَّابُ بْنُ بَشِيرٍ، عَنْ خُصَيْفٍ، عَنْ مُجَاهِدٍ، وَعِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ الْفُقَرَاءُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّ الأَغْنِيَاءَ يُصَلُّونَ كَمَا نُصَلِّي وَيَصُومُونَ كَمَا نَصُومُ وَلَهُمْ أَمْوَالٌ يُعْتِقُونَ وَيَتَصَدَّقُونَ قَالَ ‏"‏ فَإِذَا صَلَّيْتُمْ فَقُولُوا سُبْحَانَ اللَّهِ ثَلاَثًا وَثَلاَثِينَ مَرَّةً وَالْحَمْدُ لِلَّهِ ثَلاَثًا وَثَلاَثِينَ مَرَّةً وَاللَّهُ أَكْبَرُ أَرْبَعًا وَثَلاَثِينَ مَرَّةً وَلاَ إِلَهَ إِلاَّ اللَّهُ عَشْرَ مَرَّاتٍ فَإِنَّكُمْ تُدْرِكُونَ بِهِ مَنْ سَبَقَكُمْ وَلاَ يَسْبِقُكُمْ مَنْ بَعْدَكُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ كَعْبِ بْنِ عُجْرَةَ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَزَيْدِ بْنِ ثَابِتٍ وَأَبِي الدَّرْدَاءِ وَابْنِ عُمَرَ وَأَبِي ذَرٍّ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ أَيْضًا عَنْ أَبِي هُرَيْرَةَ وَالْمُغِيرَةِ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ خَصْلَتَانِ لاَ يُحْصِيهِمَا رَجُلٌ مُسْلِمٌ إِلاَّ دَخَلَ الْجَنَّةَ يُسَبِّحُ اللَّهَ فِي دُبُرِ كُلِّ صَلاَةٍ عَشْرًا وَيَحْمَدُهُ عَشْرًا وَيُكَبِّرُهُ عَشْرًا وَيُسَبِّحُ اللَّهَ عِنْدَ مَنَامِهِ ثَلاَثًا وَثَلاَثِينَ وَيَحْمَدُهُ ثَلاَثًا وَثَلاَثِينَ وَيُكَبِّرُهُ أَرْبَعًا وَثَلاَثِينَ ‏"‏ ‏.‏\hadithno{410}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"Some of the poor people came to Allah's Messenger (S) and said: 'O Messenger of Allah (S)! The rich pray as we pray, they fast as we fast, but they have wealth with which they free slaves and which they give in charity.' He said: 'When you perform Salat, then say: 'Subhan Allah' thirty-three times, and: 'Al-Hamdulillah' thirty-three times, and: 'Allahu Akbar' thirty-four times, and 'La ilaha illallah' ten times. With that you will have surprassed them, and none would surpass you afterwards}}
\hadithdefcmd{tirmidhi}{411}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، حَدَّثَنَا عُمَرُ بْنُ الرَّمَّاحِ الْبَلْخِيُّ، عَنْ كَثِيرِ بْنِ زِيَادٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ بْنِ يَعْلَى بْنِ مُرَّةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُمْ كَانُوا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي مَسِيرٍ فَانْتَهَوْا إِلَى مَضِيقٍ وَحَضَرَتِ الصَّلاَةُ فَمُطِرُوا السَّمَاءُ مِنْ فَوْقِهِمْ وَالْبِلَّةُ مِنْ أَسْفَلَ مِنْهُمْ فَأَذَّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى رَاحِلَتِهِ وَأَقَامَ - أَوْ أَقَامَ - فَتَقَدَّمَ عَلَى رَاحِلَتِهِ فَصَلَّى بِهِمْ يُومِئُ إِيمَاءً يَجْعَلُ السُّجُودَ أَخْفَضَ مِنَ الرُّكُوعِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ تَفَرَّدَ بِهِ عُمَرُ بْنُ الرَّمَّاحِ الْبَلْخِيُّ لاَ يُعْرَفُ إِلاَّ مِنْ حَدِيثِهِ ‏.‏ وَقَدْ رَوَى عَنْهُ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ ‏.‏ وَكَذَلِكَ رُوِيَ عَنْ أَنَسِ بْنِ مَالِكٍ أَنَّهُ صَلَّى فِي مَاءٍ وَطِينٍ عَلَى دَابَّتِهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{411}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Uthman bin Ya'la bin Murrah narrated from his father, from his grand-father that :They were with the Prophet (S) on a journey. They wound up in a narrow area when Salat became due. Then it began raining from the sky above them, and it was wet beneath them. So Allah's Messenger (S) called the Adhan while he was on his mount, and then the Iqamah, going forward on his mount. He let them in Salat by making gestures, making his prostrations lower than his bowing}}
\hadithdefcmd{tirmidhi}{412}{حَدَّثَنَا قُتَيْبَةُ، وَبِشْرُ بْنُ مُعَاذٍ الْعَقَدِيُّ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى انْتَفَخَتْ قَدَمَاهُ فَقِيلَ لَهُ أَتَتَكَلَّفُ هَذَا وَقَدْ غُفِرَ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ قَالَ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْمُغِيرَةِ بْنِ شُعْبَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{412}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Mughirah bin Shu'bah narrated:"Allah's Messenger (S) performed Salat until his feet were swollen, so it was said to him: 'You burden yourself like this, while your past and future sins have been forgiven?' He said: 'Shouldn't I be a grateful worshipper?}}
\hadithdefcmd{tirmidhi}{413}{حَدَّثَنَا عَلِيُّ بْنُ نَصْرِ بْنِ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا سَهْلُ بْنُ حَمَّادٍ، حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنِي قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ حُرَيْثِ بْنِ قَبِيصَةَ، قَالَ قَدِمْتُ الْمَدِينَةَ فَقُلْتُ اللَّهُمَّ يَسِّرْ لِي جَلِيسًا صَالِحًا ‏.‏ قَالَ فَجَلَسْتُ إِلَى أَبِي هُرَيْرَةَ فَقُلْتُ إِنِّي سَأَلْتُ اللَّهَ أَنْ يَرْزُقَنِي جَلِيسًا صَالِحًا فَحَدِّثْنِي بِحَدِيثٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَعَلَّ اللَّهَ أَنْ يَنْفَعَنِي بِهِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَوَّلَ مَا يُحَاسَبُ بِهِ الْعَبْدُ يَوْمَ الْقِيَامَةِ مِنْ عَمَلِهِ صَلاَتُهُ فَإِنْ صَلُحَتْ فَقَدْ أَفْلَحَ وَأَنْجَحَ وَإِنْ فَسَدَتْ فَقَدْ خَابَ وَخَسِرَ فَإِنِ انْتَقَصَ مِنْ فَرِيضَتِهِ شَيْءٌ قَالَ الرَّبُّ عَزَّ وَجَلَّ انْظُرُوا هَلْ لِعَبْدِي مِنْ تَطَوُّعٍ فَيُكَمَّلَ بِهَا مَا انْتَقَصَ مِنَ الْفَرِيضَةِ ثُمَّ يَكُونُ سَائِرُ عَمَلِهِ عَلَى ذَلِكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ تَمِيمٍ الدَّارِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَبِي هُرَيْرَةَ وَقَدْ رَوَى بَعْضُ أَصْحَابِ الْحَسَنِ عَنِ الْحَسَنِ عَنْ قَبِيصَةَ بْنِ حُرَيْثٍ غَيْرَ هَذَا الْحَدِيثِ وَالْمَشْهُورُ هُوَ قَبِيصَةُ بْنُ حُرَيْثٍ ‏.‏ وَرُوِيَ عَنْ أَنَسِ بْنِ حَكِيمٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏\hadithno{413}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Huraith bin Qabisah narrated:"I arrived in Al-Madinah and said: 'O Allah! Facilitate me to be in a righteous gathering.'" He said: "I sat with Abu Hurairah and said: 'Indeed I asked Allah to provide me with a righteous gathering. So narrate a hadith to me which you heard from Allah's Messenger (ﷺ) so that perhaps Allah would cause me to benefit from it.' He said: 'I heard Allah's Messenger (ﷺ) say: "Indeed the first deed by which a servant will be called to account on the Day of Resurrection is his Salat. If it is complete, he is successful and saved, but if it is defective, he has failed and lost. So if something is deficient in his obligatory (prayers) then the Lord, Mighty and Sublime says: 'Look! Are there any voluntary (prayers) for my worshipper?' So with them, what was deficient in his obligatory (prayers) will be completed. Then the rest of his deeds will be treated like that}}
\hadithdefcmd{tirmidhi}{414}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ النَّيْسَابُورِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ الرَّازِيُّ، حَدَّثَنَا الْمُغِيرَةُ بْنُ زِيَادٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ ثَابَرَ عَلَى ثِنْتَىْ عَشْرَةَ رَكْعَةً مِنَ السُّنَّةِ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ أَرْبَعِ رَكَعَاتٍ قَبْلَ الظُّهْرِ وَرَكْعَتَيْنِ بَعْدَهَا وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ وَرَكْعَتَيْنِ قَبْلَ الْفَجْرِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ حَبِيبَةَ وَأَبِي هُرَيْرَةَ وَأَبِي مُوسَى وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمُغِيرَةُ بْنُ زِيَادٍ قَدْ تَكَلَّمَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{414}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated that Allah's Messenger (S) said:"Whoever is regular with twelve Rak'ah of Sunnah (prayer), Allah will build a house for him in Paradise: Four Rak'ah before Zuhr, two Rak'ah after it, two Rak'ah after Maghrib, two Rak'ah after Isha, and two Rak'ah before Fajr}}
\hadithdefcmd{tirmidhi}{415}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا مُؤَمَّلٌ، - هُوَ ابْنُ إِسْمَاعِيلَ حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى فِي يَوْمٍ وَلَيْلَةٍ ثِنْتَىْ عَشْرَةَ رَكْعَةً بُنِيَ لَهُ بَيْتٌ فِي الْجَنَّةِ أَرْبَعًا قَبْلَ الظُّهْرِ وَرَكْعَتَيْنِ بَعْدَهَا وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ وَرَكْعَتَيْنِ قَبْلَ صَلاَةِ الْفَجْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ عَنْبَسَةَ عَنْ أُمِّ حَبِيبَةَ فِي هَذَا الْبَابِ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْ عَنْبَسَةَ مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{415}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Habibah narrated that Allah's Messenger (S) sad:"Whoever prays twelve Rak'ah in a day and night, a house will be built from him in Paradise: Four Rak'ah before Zuhr, two Rak'ah after it, two Rak'ah after Maghrib, two Rak'ah after Isha, and two Rak'ah before Fajr in the morning Salat}}
\hadithdefcmd{tirmidhi}{416}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ التِّرْمِذِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَكْعَتَا الْفَجْرِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى أَحْمَدُ بْنُ حَنْبَلٍ عَنْ صَالِحِ بْنِ عَبْدِ اللَّهِ التِّرْمِذِيِّ حَدِيثَ عَائِشَةَ ‏.‏\hadithno{416}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated that :Allah's Messenger (S) said: "The two Rak'ah of Fajr are better than the world and what is in it}}
\hadithdefcmd{tirmidhi}{417}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَأَبُو عَمَّارٍ قَالاَ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَمَقْتُ النَّبِيَّ صلى الله عليه وسلم شَهْرًا فَكَانَ يَقْرَأُ فِي الرَّكْعَتَيْنِ قَبْلَ الْفَجْرِ بِـْ ‏:‏ ‏(‏يَا أَيُّهَا الْكَافِرُونَ ‏)‏ وَ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ‏)‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَنَسٍ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَحَفْصَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ وَلاَ نَعْرِفُهُ مِنْ حَدِيثِ الثَّوْرِيِّ عَنْ أَبِي إِسْحَاقَ إِلاَّ مِنْ حَدِيثِ أَبِي أَحْمَدَ وَالْمَعْرُوفُ عِنْدَ النَّاسِ حَدِيثُ إِسْرَائِيلَ عَنْ أَبِي إِسْحَاقَ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي أَحْمَدَ عَنْ إِسْرَائِيلَ هَذَا الْحَدِيثُ أَيْضًا ‏.‏ وَأَبُو أَحْمَدَ الزُّبَيْرِيُّ ثِقَةٌ حَافِظٌ ‏.‏ قَالَ سَمِعْتُ بُنْدَارًا يَقُولُ مَا رَأَيْتُ أَحَدًا أَحْسَنَ حِفْظًا مِنْ أَبِي أَحْمَدَ الزُّبَيْرِيِّ ‏.‏ وَأَبُو أَحْمَدَ اسْمُهُ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ الْكُوفِيُّ الأَسَدِيُّ ‏.‏\hadithno{417}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"I watched the Prophet (S) for a month. In the two Rak'ah before Fajr he would recite: Say: "O you disbelievers!" and Say: "Allah is One}}
\hadithdefcmd{tirmidhi}{418}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ سَمِعْتُ مَالِكَ بْنَ أَنَسٍ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى رَكْعَتَىِ الْفَجْرِ فَإِنْ كَانَتْ لَهُ إِلَىَّ حَاجَةٌ كَلَّمَنِي وَإِلاَّ خَرَجَ إِلَى الصَّلاَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ الْكَلاَمَ بَعْدَ طُلُوعِ الْفَجْرِ حَتَّى يُصَلِّيَ صَلاَةَ الْفَجْرِ إِلاَّ مَا كَانَ مِنْ ذِكْرِ اللَّهِ أَوْ مِمَّا لاَ بُدَّ مِنْهُ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{418}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated:"When Allah's Messenger (S) prayed the two Rak'ah (before) Fajr if he needed something from me he would talk to me, if not, he would go to Salat}}
\hadithdefcmd{tirmidhi}{419}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ قُدَامَةَ بْنِ مُوسَى، عَنْ مُحَمَّدِ بْنِ الْحُصَيْنِ، عَنْ أَبِي عَلْقَمَةَ، عَنْ يَسَارٍ، مَوْلَى ابْنِ عُمَرَ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ بَعْدَ الْفَجْرِ إِلاَّ سَجْدَتَيْنِ ‏"‏ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ إِنَّمَا يَقُولُ لاَ صَلاَةَ بَعْدَ طُلُوعِ الْفَجْرِ إِلاَّ رَكْعَتَىِ الْفَجْرِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَحَفْصَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ قُدَامَةَ بْنِ مُوسَى وَرَوَى عَنْهُ غَيْرُ وَاحِدٍ ‏.‏ وَهُوَ مَا اجْتَمَعَ عَلَيْهِ أَهْلُ الْعِلْمِ كَرِهُوا أَنْ يُصَلِّيَ الرَّجُلُ بَعْدَ طُلُوعِ الْفَجْرِ إِلاَّ رَكْعَتَىِ الْفَجْرِ ‏.‏\hadithno{419}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated that:Allah's Messenger (S) said: "There is no Salat after Al-Fajr (begins) except two prostrations}}
\hadithdefcmd{tirmidhi}{420}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الْعَقَدِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ رَكْعَتَىِ الْفَجْرِ فَلْيَضْطَجِعْ عَلَى يَمِينِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ عَنْ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا صَلَّى رَكْعَتَىِ الْفَجْرِ فِي بَيْتِهِ اضْطَجَعَ عَلَى يَمِينِهِ ‏.‏ وَقَدْ رَأَى بَعْضُ أَهْلِ الْعِلْمِ أَنْ يُفْعَلَ هَذَا اسْتِحْبَابًا ‏.‏\hadithno{420}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger (S) said: "When one of you prays the two Rak'ah of Fajr then let him lay down on his right (side)}}
\hadithdefcmd{tirmidhi}{421}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ عَطَاءَ بْنَ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ صَلاَةَ إِلاَّ الْمَكْتُوبَةُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ بُحَيْنَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَبْدِ اللَّهِ بْنِ سَرْجِسَ وَابْنِ عَبَّاسٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَهَكَذَا رَوَى أَيُّوبُ وَوَرْقَاءُ بْنُ عُمَرَ وَزِيَادُ بْنُ سَعْدٍ وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ وَمُحَمَّدُ بْنُ جُحَادَةَ عَنْ عَمْرِو بْنِ دِينَارٍ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى حَمَّادُ بْنُ زَيْدٍ وَسُفْيَانُ بْنُ عُيَيْنَةَ عَنْ عَمْرِو بْنِ دِينَارٍ فَلَمْ يَرْفَعَاهُ ‏.‏ وَالْحَدِيثُ الْمَرْفُوعُ أَصَحُّ عِنْدَنَا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِذَا أُقِيمَتِ الصَّلاَةُ أَنْ لاَ يُصَلِّيَ الرَّجُلُ إِلاَّ الْمَكْتُوبَةَ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ هَذَا الْوَجْهِ رَوَاهُ عَيَّاشُ بْنُ عَبَّاسٍ الْقِتْبَانِيُّ الْمِصْرِيُّ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏\hadithno{421}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger (S) said: "When the Iqamah has been called for the Salat then there is no Salat except the obligatory}}
\hadithdefcmd{tirmidhi}{422}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو السَّوَّاقُ الْبَلْخِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سَعْدِ بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ جَدِّهِ، قَيْسٍ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأُقِيمَتِ الصَّلاَةُ فَصَلَّيْتُ مَعَهُ الصُّبْحَ ثُمَّ انْصَرَفَ النَّبِيُّ صلى الله عليه وسلم فَوَجَدَنِي أُصَلِّي فَقَالَ ‏"‏ مَهْلاً يَا قَيْسُ أَصَلاَتَانِ مَعًا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي لَمْ أَكُنْ رَكَعْتُ رَكْعَتَىِ الْفَجْرِ ‏.‏ قَالَ ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مُحَمَّدِ بْنِ إِبْرَاهِيمَ لاَ نَعْرِفُهُ مِثْلَ هَذَا إِلاَّ مِنْ حَدِيثِ سَعْدِ بْنِ سَعِيدٍ ‏.‏ وَقَالَ سُفْيَانُ بْنُ عُيَيْنَةَ سَمِعَ عَطَاءُ بْنُ أَبِي رَبَاحٍ مِنْ سَعْدِ بْنِ سَعِيدٍ هَذَا الْحَدِيثَ ‏.‏ وَإِنَّمَا يُرْوَى هَذَا الْحَدِيثُ مُرْسَلاً ‏.‏ وَقَدْ قَالَ قَوْمٌ مِنْ أَهْلِ مَكَّةَ بِهَذَا الْحَدِيثِ لَمْ يَرَوْا بَأْسًا أَنْ يُصَلِّيَ الرَّجُلُ الرَّكْعَتَيْنِ بَعْدَ الْمَكْتُوبَةِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ ‏.‏ قَالَ أَبُو عِيسَى وَسَعْدُ بْنُ سَعِيدٍ هُوَ أَخُو يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ ‏.‏ قَالَ وَقَيْسٌ هُوَ جَدُّ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ وَيُقَالُ هُوَ قَيْسُ بْنُ عَمْرٍو وَيُقَالُ هُوَ قَيْسُ بْنُ قَهْدٍ ‏.‏ وَإِسْنَادُ هَذَا الْحَدِيثِ لَيْسَ بِمُتَّصِلٍ مُحَمَّدُ بْنُ إِبْرَاهِيمَ التَّيْمِيُّ لَمْ يَسْمَعْ مِنْ قَيْسٍ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ سَعْدِ بْنِ سَعِيدٍ عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ فَرَأَى قَيْسًا ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ عَبْدِ الْعَزِيزِ عَنْ سَعْدِ بْنِ سَعِيدٍ ‏.‏\hadithno{422}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qais narrated:"Allah's Messenger (S) went out and the Iqamah was called for the Salat so I prayed As-Subh with him. Then the Prophet (S) turned and found me performing Salat so he said: 'Easy O Qais! Are there two prayers together?' I said: 'O Messenger of Allah! I did not perform the two Rak'ah (before) Fajr.' He said: 'Then there is no harm}}
\hadithdefcmd{tirmidhi}{423}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ الْبَصْرِيُّ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ لَمْ يُصَلِّ رَكْعَتَىِ الْفَجْرِ فَلْيُصَلِّهِمَا بَعْدَ مَا تَطْلُعُ الشَّمْسُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عُمَرَ أَنَّهُ فَعَلَهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالَ وَلاَ نَعْلَمُ أَحَدًا رَوَى هَذَا الْحَدِيثَ عَنْ هَمَّامٍ بِهَذَا الإِسْنَادِ نَحْوَ هَذَا إِلاَّ عَمْرَو بْنَ عَاصِمٍ الْكِلاَبِيَّ ‏.‏ وَالْمَعْرُوفُ مِنْ حَدِيثِ قَتَادَةَ عَنِ النَّضْرِ بْنِ أَنَسٍ عَنْ بَشِيرِ بْنِ نَهِيكٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَدْرَكَ رَكْعَةً مِنْ صَلاَةِ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ الصُّبْحَ ‏"‏ ‏.‏\hadithno{423}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger (S) said: "Whoever did not pray the two Rak'ah (before) Fajr then let him pray them after the sun has risen}}
\hadithdefcmd{tirmidhi}{424}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي قَبْلَ الظُّهْرِ أَرْبَعًا وَبَعْدَهَا رَكْعَتَيْنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأُمِّ حَبِيبَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ ‏.‏ قَالَ أَبُو بَكْرٍ الْعَطَّارُ قَالَ عَلِيُّ بْنُ عَبْدِ اللَّهِ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ سُفْيَانَ قَالَ كُنَّا نَعْرِفُ فَضْلَ حَدِيثِ عَاصِمِ بْنِ ضَمْرَةَ عَلَى حَدِيثِ الْحَارِثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ يَخْتَارُونَ أَنْ يُصَلِّيَ الرَّجُلُ قَبْلَ الظُّهْرِ أَرْبَعَ رَكَعَاتٍ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَإِسْحَاقَ وَأَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ صَلاَةُ اللَّيْلِ وَالنَّهَارِ مَثْنَى مَثْنَى يَرَوْنَ الْفَصْلَ بَيْنَ كُلِّ رَكْعَتَيْنِ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ ‏.‏\hadithno{424}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ali narrated:"The Prophet (S) would pray four Rak'ah before Az-Zuhr and two Rak'ah after it}}
\hadithdefcmd{tirmidhi}{425}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم رَكْعَتَيْنِ قَبْلَ الظُّهْرِ وَرَكْعَتَيْنِ بَعْدَهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{425}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated:"I prayed two Rak'ah with the Prophet (S) before Az-Zuhr and two Rak'ah after it}}
\hadithdefcmd{tirmidhi}{426}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عُبَيْدِ اللَّهِ الْعَتَكِيُّ الْمَرْوَزِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا لَمْ يُصَلِّ أَرْبَعًا قَبْلَ الظُّهْرِ صَلاَّهُنَّ بَعْدَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ ابْنِ الْمُبَارَكِ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَاهُ قَيْسُ بْنُ الرَّبِيعِ عَنْ شُعْبَةَ عَنْ خَالِدٍ الْحَذَّاءِ نَحْوَ هَذَا ‏.‏ وَلاَ نَعْلَمُ أَحَدًا رَوَاهُ عَنْ شُعْبَةَ غَيْرَ قَيْسِ بْنِ الرَّبِيعِ وَقَدْ رُوِيَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏\hadithno{426}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated:"When the Prophet (S) would not perform the four Rak'ah before Az-Zuhr he would pray them after it}}
\hadithdefcmd{tirmidhi}{427}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ الشُّعَيْثِيِّ، عَنْ أَبِيهِ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى قَبْلَ الظُّهْرِ أَرْبَعًا وَبَعْدَهَا أَرْبَعًا حَرَّمَهُ اللَّهُ عَلَى النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{427}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Habibah narrated that:Allah's Messenger (S) said: "Whoever prays four before Az-Zuhr and four after, Allah makes him prohibited for the Fire}}
\hadithdefcmd{tirmidhi}{428}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ إِسْحَاقَ الْبَغْدَادِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ التِّنِّيسِيُّ الشَّأْمِيُّ، حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، أَخْبَرَنِي الْعَلاَءُ، هُوَ ابْنُ الْحَارِثِ عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، قَالَ سَمِعْتُ أُخْتِي أُمَّ حَبِيبَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ حَافَظَ عَلَى أَرْبَعِ رَكَعَاتٍ قَبْلَ الظُّهْرِ وَأَرْبَعٍ بَعْدَهَا حَرَّمَهُ اللَّهُ عَلَى النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْقَاسِمُ هُوَ ابْنُ عَبْدِ الرَّحْمَنِ يُكْنَى أَبَا عَبْدِ الرَّحْمَنِ وَهُوَ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ خَالِدِ بْنِ يَزِيدَ بْنِ مُعَاوِيَةَ وَهُوَ ثِقَةٌ شَأْمِيٌّ وَهُوَ صَاحِبُ أَبِي أُمَامَةَ ‏.‏\hadithno{428}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Habibah the wife of the Prophet (S) narrated that:She heard Allah's Messenger (S) saying: "Whoever maintains four Rak'ah before Az-Zuhr and four after it, Allah makes him prohibited for the Fire}}
\hadithdefcmd{tirmidhi}{429}{حَدَّثَنَا بُنْدَارٌ، مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا أَبُو عَامِرٍ، هُوَ الْعَقَدِيُّ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي قَبْلَ الْعَصْرِ أَرْبَعَ رَكَعَاتٍ يَفْصِلُ بَيْنَهُنَّ بِالتَّسْلِيمِ عَلَى الْمَلاَئِكَةِ الْمُقَرَّبِينَ وَمَنْ تَبِعَهُمْ مِنَ الْمُسْلِمِينَ وَالْمُؤْمِنِينَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ ‏.‏ وَاخْتَارَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ أَنْ لاَ يُفْصَلَ فِي الأَرْبَعِ قَبْلَ الْعَصْرِ وَاحْتَجَّ بِهَذَا الْحَدِيثِ ‏.‏ وَقَالَ إِسْحَاقُ وَمَعْنَى أَنَّهُ يَفْصِلُ بَيْنَهُنَّ بِالتَّسْلِيمِ يَعْنِي التَّشَهُّدَ ‏.‏ وَرَأَى الشَّافِعِيُّ وَأَحْمَدُ صَلاَةَ اللَّيْلِ وَالنَّهَارِ مَثْنَى مَثْنَى يَخْتَارَانِ الْفَصْلَ فِي الأَرْبَعِ قَبْلَ الْعَصْرِ ‏.‏\hadithno{429}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ali narrated:"Allah's Messenger (S) would pray four Rak'ah before Al-Asr separating between them with At-Taslim upon the angels that are close (to Allah) and those who follow them among the Muslims and the believers}}
\hadithdefcmd{tirmidhi}{430}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، وَمَحْمُودُ بْنُ غَيْلاَنَ، وَأَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمِ بْنِ مِهْرَانَ، سَمِعَ جَدَّهُ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رَحِمَ اللَّهُ امْرَأً صَلَّى قَبْلَ الْعَصْرِ أَرْبَعًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ حَسَنٌ ‏.‏\hadithno{430}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Umar narrated that :The Prophet (S) said: "May Allah have mercy upon a man who prays four before Al-Asr}}
\hadithdefcmd{tirmidhi}{431}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مَعْدَانَ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّهُ قَالَ مَا أُحْصِي مَا سَمِعْتُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الرَّكْعَتَيْنِ بَعْدَ الْمَغْرِبِ وَفِي الرَّكْعَتَيْنِ قَبْلَ صَلاَةِ الْفَجْرِ بِـ ‏:‏‏(‏قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ وَ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ مَسْعُودٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الْمَلِكِ بْنِ مَعْدَانَ عَنْ عَاصِمٍ ‏.‏\hadithno{431}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated:"I can not enumerate (how many times) I heard Allah's Messenger (S) reciting - in the two Rak'ah after Al-Maghrib and the two Rak'ah before Salatul-Fajr with: Say: "O you disbelievers!" and Say: "He is Allah the One}}
\hadithdefcmd{tirmidhi}{432}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم رَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ فِي بَيْتِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ رَافِعِ بْنِ خَدِيجٍ وَكَعْبِ بْنِ عُجْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{432}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated:"I prayed two Rak'ah after Al-Maghrib with the Prophet (S) in his house}}
\hadithdefcmd{tirmidhi}{433}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ حَفِظْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم عَشْرَ رَكَعَاتٍ كَانَ يُصَلِّيهَا بِاللَّيْلِ وَالنَّهَارِ رَكْعَتَيْنِ قَبْلَ الظُّهْرِ وَرَكْعَتَيْنِ بَعْدَهَا وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ الآخِرَةِ ‏.‏ قَالَ وَحَدَّثَتْنِي حَفْصَةُ أَنَّهُ كَانَ يُصَلِّي قَبْلَ الْفَجْرِ رَكْعَتَيْنِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{433}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated:"I memorized ten Rak'ah from Allah's Messenger (S) which he would pray in a night and a day: Two Rak'ah before Az-Zuhr, two after it; two Rak'ah after Al-Maghrib and two Rak'ah after the latter Isha." He said: "And Hafsah narrated to me that he (S) would pray two Rak'ah before Al-Fajr}}
\hadithdefcmd{tirmidhi}{434}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{434}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar :has a similar narration}}
\hadithdefcmd{tirmidhi}{435}{حَدَّثَنَا أَبُو كُرَيْبٍ، - يَعْنِي مُحَمَّدَ بْنَ الْعَلاَءِ الْهَمْدَانِيَّ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا عُمَرُ بْنُ أَبِي خَثْعَمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَلَّى بَعْدَ الْمَغْرِبِ سِتَّ رَكَعَاتٍ لَمْ يَتَكَلَّمْ فِيمَا بَيْنَهُنَّ بِسُوءٍ عُدِلْنَ لَهُ بِعِبَادَةِ ثِنْتَىْ عَشْرَةَ سَنَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ صَلَّى بَعْدَ الْمَغْرِبِ عِشْرِينَ رَكْعَةً بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ زَيْدِ بْنِ الْحُبَابِ عَنْ عُمَرَ بْنِ أَبِي خَثْعَمٍ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ عُمَرُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي خَثْعَمٍ مُنْكَرُ الْحَدِيثِ ‏.‏ وَضَعَّفَهُ جِدًّا ‏.‏\hadithno{435}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger (S) said: "Whoever prays six Rak'ah after Al-Maghrib, and he does not speak about anything between them, then they will be counted for him as twelve years of worship}}
\hadithdefcmd{tirmidhi}{436}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كَانَ يُصَلِّي قَبْلَ الظُّهْرِ رَكْعَتَيْنِ وَبَعْدَهَا رَكْعَتَيْنِ وَبَعْدَ الْمَغْرِبِ ثِنْتَيْنِ وَبَعْدَ الْعِشَاءِ رَكْعَتَيْنِ وَقَبْلَ الْفَجْرِ ثِنْتَيْنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ شَقِيقٍ عَنْ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{436}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Shaqiq said:"I asked Aishah about the Salat of Allah's Messenger (S). She said: 'He would pray four Rak'ah before Az-Zuhr and two Rak'ah after it, and two after Al-Maghrib, and two Rak'ah after Al-Isha, and two before Al-Fajr}}
\hadithdefcmd{tirmidhi}{437}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى فَإِذَا خِفْتَ الصُّبْحَ فَأَوْتِرْ بِوَاحِدَةٍ وَاجْعَلْ آخِرَ صَلاَتِكَ وِتْرًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَمْرِو بْنِ عَبَسَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ صَلاَةَ اللَّيْلِ مَثْنَى مَثْنَى ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ ‏.‏ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{437}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated that:The Prophet (S) said: "Salat in the night is two by two. So when you fear the dawn (is near) then make it odd by one, and make that the last of your Salat odd}}
\hadithdefcmd{tirmidhi}{438}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصِّيَامِ بَعْدَ شَهْرِ رَمَضَانَ شَهْرُ اللَّهِ الْمُحَرَّمُ وَأَفْضَلُ الصَّلاَةِ بَعْدَ الْفَرِيضَةِ صَلاَةُ اللَّيْلِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَبِلاَلٍ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو بِشْرٍ اسْمُهُ جَعْفَرُ بْنُ أَبِي وَحْشِيَّةَ وَاسْمُ أَبِي وَحْشِيَّةَ إِيَاسٌ ‏.‏\hadithno{438}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger (S) said: "The most virtuous fasting after the month of Ramadan is that of Allah's month of Al-Muharram. And the most virtuous Salat after the obligatory is the night prayer}}
\hadithdefcmd{tirmidhi}{439}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَأَلَ عَائِشَةَ كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّيْلِ فِي رَمَضَانَ فَقَالَتْ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَزِيدُ فِي رَمَضَانَ وَلاَ فِي غَيْرِهِ عَلَى إِحْدَى عَشْرَةَ رَكْعَةً يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ ثُمَّ يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ ثُمَّ يُصَلِّي ثَلاَثًا ‏.‏ فَقَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتَنَامُ قَبْلَ أَنْ تُوتِرَ فَقَالَ ‏ "‏ يَا عَائِشَةُ إِنَّ عَيْنَىَّ تَنَامَانِ وَلاَ يَنَامُ قَلْبِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{439}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'eed bin Abi Sa'eed Al-Maqburi narrated that:Sa'eed bin Abi Sa'eed Al-Maqburi narrated that Abu Salamah informed him that he had asked Aishah: "How was the Salat of Allah's Messenger (A) [at night] during Ramadan?" She said: "Allah's Messenger (S) would pray - neither in Ramadan nor in any other month - more than eleven Rak'ah. He would pray four, and do not ask about their excellence or length, then he would pray four, and do not ask about their excellence or length, then he would pray three." Aishah said: "I asked: 'O Messenger of Allah! Do you sleep before having performed Witr?" He said: 'O Aishah! Indeed my eyes sleep but my heart does not sleep}}
\hadithdefcmd{tirmidhi}{440}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي مِنَ اللَّيْلِ إِحْدَى عَشْرَةَ رَكْعَةً يُوتِرُ مِنْهَا بِوَاحِدَةٍ فَإِذَا فَرَغَ مِنْهَا اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ ‏.‏\hadithno{440}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"Allah's Messenger (S) would pray eleven Rak'ah at night, making them off with one. When he finished them he would lay down on his right side}}
\hadithdefcmd{tirmidhi}{441}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{441}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrator mot mentioned:Another chain with similar narration}}
\hadithdefcmd{tirmidhi}{442}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ أَبِي جَمْرَةَ الضُّبَعِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو جَمْرَةَ الضُّبَعِيُّ اسْمُهُ نَصْرُ بْنُ عِمْرَانَ الضُّبَعِيُّ ‏.‏\hadithno{442}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"The Prophet (S) would pray thirteen Rak'ah at night}}
\hadithdefcmd{tirmidhi}{443}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ تِسْعَ رَكَعَاتٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ وَالْفَضْلِ بْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{443}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"The Prophet (S) would pray nine Rak'ah in the night}}
\hadithdefcmd{tirmidhi}{444}{وَرَوَاهُ سُفْيَانُ الثَّوْرِيُّ عَنِ الأَعْمَشِ، نَحْوَ هَذَا حَدَّثَنَا بِذَلِكَ، مَحْمُودُ بْنُ غَيْلاَنَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، ‏.‏ قَالَ أَبُو عِيسَى وَأَكْثَرُ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي صَلاَةِ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً مَعَ الْوِتْرِ وَأَقَلُّ مَا وُصِفَ مِنْ صَلاَتِهِ بِاللَّيْلِ تِسْعُ رَكَعَاتٍ ‏.‏\hadithno{444}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Narrator not mentioned:(Another chain with similar narration)}}
\hadithdefcmd{tirmidhi}{445}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا لَمْ يُصَلِّ مِنَ اللَّيْلِ - مَنَعَهُ مِنْ ذَلِكَ النَّوْمُ أَوْ غَلَبَتْهُ عَيْنَاهُ صَلَّى مِنَ النَّهَارِ ثِنْتَىْ عَشْرَةَ رَكْعَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَسَعْدُ بْنُ هِشَامٍ هُوَ ابْنُ عَامِرٍ الأَنْصَارِيُّ وَهِشَامُ بْنُ عَامِرٍ هُوَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا عَبَّاسٌ هُوَ ابْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ حَدَّثَنَا عَتَّابُ بْنُ الْمُثَنَّى عَنْ بَهْزِ بْنِ حَكِيمٍ قَالَ كَانَ زُرَارَةُ بْنُ أَوْفَى قَاضِيَ الْبَصْرَةِ وَكَانَ يَؤُمُّ فِي بَنِي قُشَيْرٍ فَقَرَأَ يَوْمًا فِي صَلاَةِ الصُّبْحِ‏:‏ ‏(‏فَإِذَا نُقِرَ فِي النَّاقُورِ * فَذَلِكَ يَوْمَئِذٍ يَوْمٌ عَسِيرٌ ‏)‏ فَخَرَّ مَيِّتًا فَكُنْتُ فِيمَنِ احْتَمَلَهُ إِلَى دَارِهِ ‏.‏\hadithno{445}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"When the Prophet (S) did not pray at night because he was prevented from it by sleep or being sleepy then he would pray twelve Rak'ah during the daytime}}
\hadithdefcmd{tirmidhi}{446}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الإِسْكَنْدَرَانِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَنْزِلُ اللَّهُ إِلَى السَّمَاءِ الدُّنْيَا كُلَّ لَيْلَةٍ حِينَ يَمْضِي ثُلُثُ اللَّيْلِ الأَوَّلُ فَيَقُولُ أَنَا الْمَلِكُ مَنْ ذَا الَّذِي يَدْعُونِي فَأَسْتَجِيبَ لَهُ مَنْ ذَا الَّذِي يَسْأَلُنِي فَأُعْطِيَهُ مَنْ ذَا الَّذِي يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ فَلاَ يَزَالُ كَذَلِكَ حَتَّى يُضِيءَ الْفَجْرُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ وَأَبِي سَعِيدٍ وَرِفَاعَةَ الْجُهَنِيِّ وَجُبَيْرِ بْنِ مُطْعِمٍ وَابْنِ مَسْعُودٍ وَأَبِي الدَّرْدَاءِ وَعُثْمَانَ بْنِ أَبِي الْعَاصِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ أَوْجُهٍ كَثِيرَةٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنْهُ أَنَّهُ قَالَ ‏"‏ يَنْزِلُ اللَّهُ عَزَّ وَجَلَّ حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ ‏"‏ ‏.‏ وَهُوَ أَصَحُّ الرِّوَايَاتِ ‏.‏\hadithno{446}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that:Allah's Messenger (S) said: "Allah, Blessed and Exalted is He, descends to the earth's heaven every night when the first third of the night has passed. He says: "I am the Sovereign. Is there any who calls upon Me so that I may respond to him? Is there any who asks of Me that I may give him? Is there any who seeks forgiveness from Me so that I may forgive him?' He continues in that until the illumination of Al-Fajr}}
\hadithdefcmd{tirmidhi}{447}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ، هُوَ السَّالَحِينِيُّ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ الأَنْصَارِيِّ، عَنْ أَبِي قَتَادَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأَبِي بَكْرٍ ‏"‏ مَرَرْتُ بِكَ وَأَنْتَ تَقْرَأُ وَأَنْتَ تَخْفِضُ مِنْ صَوْتِكَ ‏"‏ ‏.‏ فَقَالَ إِنِّي أَسْمَعْتُ مَنْ نَاجَيْتُ ‏.‏ قَالَ ‏"‏ ارْفَعْ قَلِيلاً ‏"‏ ‏.‏ وَقَالَ لِعُمَرَ ‏"‏ مَرَرْتُ بِكَ وَأَنْتَ تَقْرَأُ وَأَنْتَ تَرْفَعُ صَوْتَكَ ‏"‏ ‏.‏ قَالَ إِنِّي أُوقِظُ الْوَسْنَانَ وَأَطْرُدُ الشَّيْطَانَ قَالَ ‏"‏ اخْفِضْ قَلِيلاً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأُمِّ هَانِئٍ وَأَنَسٍ وَأُمِّ سَلَمَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَإِنَّمَا أَسْنَدَهُ يَحْيَى بْنُ إِسْحَاقَ عَنْ حَمَّادِ بْنِ سَلَمَةَ وَأَكْثَرُ النَّاسِ إِنَّمَا رَوَوْا هَذَا الْحَدِيثَ عَنْ ثَابِتٍ عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ مُرْسَلاً ‏.‏\hadithno{447}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Qatadah narrated that :The Prophet (S) said to Abu Bakr: "I passed by you while you were reciting and your voice was low." He said: "I let He who, I was consulting hear." He said: "Raise your voice." Then he said to Umar: "I passed by while you were reciting and your voice was loud." So he said: "I repel drowsiness and keep Ash-Shaitan away." So he said: "Lower your voice}}
\hadithdefcmd{tirmidhi}{448}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ نَافِعٍ الْبَصْرِيُّ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ الْعَبْدِيِّ، عَنْ أَبِي الْمُتَوَكِّلِ النَّاجِيِّ، عَنْ عَائِشَةَ، قَالَتْ قَامَ النَّبِيُّ صلى الله عليه وسلم بِآيَةٍ مِنَ الْقُرْآنِ لَيْلَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{448}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated:"The Prophet (S) stood (in prayer) with an Ayah from the Qur'an at night}}
\hadithdefcmd{tirmidhi}{449}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، قَالَ سَأَلْتُ عَائِشَةَ كَيْفَ كَانَ قِرَاءَةُ النَّبِيِّ صلى الله عليه وسلم بِاللَّيْلِ أَكَانَ يُسِرُّ بِالْقِرَاءَةِ أَمْ يَجْهَرُ فَقَالَتْ كُلُّ ذَلِكَ قَدْ كَانَ يَفْعَلُ رُبَّمَا أَسَرَّ بِالْقِرَاءَةِ وَرُبَّمَا جَهَرَ ‏.‏ فَقُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{449}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Abi Qais narrated:"I asked Aishah how the recitation of the Prophet (S) was at night. [Would he recite silently o audibly?] So she said: 'He would do both of those. Sometimes he was silent with his recitation and sometimes it was audible.' So I said: 'All praise is due to Allah, the One who made the matter broad}}
\hadithdefcmd{tirmidhi}{450}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْضَلُ صَلاَتِكُمْ فِي بُيُوتِكُمْ إِلاَّ الْمَكْتُوبَةَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ بْنِ الْخَطَّابِ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ سَعْدٍ وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ ثَابِتٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدِ اخْتَلَفَ النَّاسُ فِي رِوَايَةِ هَذَا الْحَدِيثِ فَرَوَاهُ مُوسَى بْنُ عُقْبَةَ وَإِبْرَاهِيمُ بْنُ أَبِي النَّضْرِ عَنْ أَبِي النَّضْرِ مَرْفُوعًا وَرَوَاهُ مَالِكُ بْنُ أَنَسٍ عَنْ أَبِي النَّضْرِ وَلَمْ يَرْفَعْهُ وَأَوْقَفَهُ بَعْضُهُمْ وَالْحَدِيثُ الْمَرْفُوعُ أَصَحُّ ‏.‏\hadithno{450}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Zaid bin Thabit narrated that:The Prophet (S) said: "The most virtuous prayer of yours is in your homes, except for the obligatory}}
\hadithdefcmd{tirmidhi}{451}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلُّوا فِي بُيُوتِكُمْ وَلاَ تَتَّخِذُوهَا قُبُورًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{451}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that :The Prophet (S) said: "Offer Salat in your homes and do not turn them into graves}}
