% Auto-generated chapter 12 for nasai
% Hadiths in this chapter: 150

\hadithdefcmd{nasai}{1029}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ إِبْرَاهِيمَ، يُحَدِّثُ عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، أَنَّهُمَا كَانَا مَعَ عَبْدِ اللَّهِ فِي بَيْتِهِ فَقَالَ أَصَلَّى هَؤُلاَءِ قُلْنَا نَعَمْ ‏.‏ فَأَمَّهُمَا وَقَامَ بَيْنَهُمَا بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ ‏.‏ قَالَ إِذَا كُنْتُمْ ثَلاَثَةً فَاصْنَعُوا هَكَذَا وَإِذَا كُنْتُمْ أَكْثَرَ مِنْ ذَلِكَ فَلْيَؤُمَّكُمْ أَحَدُكُمْ وَلْيَفْرِشْ كَفَّيْهِ عَلَى فَخِذَيْهِ فَكَأَنَّمَا أَنْظُرُ إِلَى اخْتِلاَفِ أَصَابِعِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1029}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Alqamah and Al-Aswad that:They were with 'Abdullah in his house and he said: "Have these people prayed?" We said: "Yes." So he led them in prayer and stood between them, with no Adhan and no Iqamah, and said: "If you are three then do this, and if you are more than that then let one of you lead the others in prayer, and let him lay his hands on his thighs. It is as if I can see the fingers of the Messenger of Allah (ﷺ), interlaced}}
\hadithdefcmd{nasai}{1030}{أَخْبَرَنِي أَحْمَدُ بْنُ سَعِيدٍ الرِّبَاطِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، قَالَ أَنْبَأَنَا عَمْرٌو، - وَهُوَ ابْنُ أَبِي قَيْسٍ - عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، قَالاَ صَلَّيْنَا مَعَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ فِي بَيْتِهِ فَقَامَ بَيْنَنَا فَوَضَعْنَا أَيْدِيَنَا عَلَى رُكَبِنَا فَنَزَعَهَا فَخَالَفَ بَيْنَ أَصَابِعِنَا وَقَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏\hadithno{1030}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Alqamah and Al-Aswad said:"We prayed with Abdullah bin Mas'ud in his house. He stood between us and we placed our hands on our knees, but he took them off and made us interlace our fingers, and said: "I saw the Messenger of Allah (ﷺ) do that}}
\hadithdefcmd{nasai}{1031}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ، قَالَ أَنْبَأَنَا ابْنُ إِدْرِيسَ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ فَقَامَ فَكَبَّرَ فَلَمَّا أَرَادَ أَنْ يَرْكَعَ طَبَّقَ يَدَيْهِ بَيْنَ رُكْبَتَيْهِ وَرَكَعَ فَبَلَغَ ذَلِكَ سَعْدًا فَقَالَ صَدَقَ أَخِي قَدْ كُنَّا نَفْعَلُ هَذَا ثُمَّ أُمِرْنَا بِهَذَا يَعْنِي الإِمْسَاكَ بِالرُّكَبِ ‏.‏\hadithno{1031}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abdullah said:"The Messenger of Allah (ﷺ) taught us the prayer. He stood up and said the takbir, and when he wanted to bow, he put his hands together and put his hands between his knees and bowed." News of that reached Sa'd and he said: "My brother has spoken the truth. We used to do that, then we were commanded to do this," meaning to hold the knees}}
\hadithdefcmd{nasai}{1032}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي يَعْفُورٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ صَلَّيْتُ إِلَى جَنْبِ أَبِي وَجَعَلْتُ يَدَىَّ بَيْنَ رُكْبَتَىَّ فَقَالَ لِي اضْرِبْ بِكَفَّيْكَ عَلَى رُكْبَتَيْكَ ‏.‏ قَالَ ثُمَّ فَعَلْتُ ذَلِكَ مَرَّةً أُخْرَى فَضَرَبَ يَدِي وَقَالَ إِنَّا قَدْ نُهِينَا عَنْ هَذَا وَأُمِرْنَا أَنْ نَضْرِبَ بِالأَكُفِّ عَلَى الرُّكَبِ ‏.‏\hadithno{1032}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Mus'ab bin Sa'd said:"I prayed beside my father and I put my hands between my knees, and he told me: 'Put your hands on your knees.' Then I did that again and he struck my hands and said: 'We were forbidden to do that, and we were commanded to put our hands on our knees}}
\hadithdefcmd{nasai}{1033}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ رَكَعْتُ فَطَبَّقْتُ فَقَالَ أَبِي إِنَّ هَذَا شَىْءٌ كُنَّا نَفْعَلُهُ ثُمَّ ارْتَفَعْنَا إِلَى الرُّكَبِ ‏.‏\hadithno{1033}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mus'ab bin Sa'd said:"I bowed and put my hands together, and my father said: 'This is something that we used to do, then we brought them up to our knees}}
\hadithdefcmd{nasai}{1034}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنِي أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عُمَرَ، قَالَ سُنَّتْ لَكُمُ الرُّكَبُ فَأَمْسِكُوا بِالرُّكَبِ ‏.‏\hadithno{1034}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Umar said:"It is established for you to hold the knees, so hold the knees}}
\hadithdefcmd{nasai}{1035}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، قَالَ قَالَ عُمَرُ إِنَّمَا السُّنَّةُ الأَخْذُ بِالرُّكَبِ ‏.‏\hadithno{1035}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdur-Rahman As-Sulami said:" 'Umar said: 'The Sunnah is to hold the knees}}
\hadithdefcmd{nasai}{1036}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي الأَحْوَصِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَالِمٍ، قَالَ أَتَيْنَا أَبَا مَسْعُودٍ فَقُلْنَا لَهُ حَدِّثْنَا عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَامَ بَيْنَ أَيْدِينَا وَكَبَّرَ فَلَمَّا رَكَعَ وَضَعَ رَاحَتَيْهِ عَلَى رُكْبَتَيْهِ وَجَعَلَ أَصَابِعَهُ أَسْفَلَ مِنْ ذَلِكَ وَجَافَى بِمِرْفَقَيْهِ حَتَّى اسْتَوَى كُلُّ شَىْءٍ مِنْهُ ثُمَّ قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقَامَ حَتَّى اسْتَوَى كُلُّ شَىْءٍ مِنْهُ ‏.‏\hadithno{1036}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Salim said:"We came to Abu Mas'ud and said to him: 'Tell us about the prayer of the Messenger of Allah (ﷺ).' He stood in front of us and said the takbir, then when he bowed he placed his palms on his knees and put his fingers lower than that, and he held his elbows out from his sides until every part of him had settled. Then he said: Sami' Allahu liman hamidah, Rabbana wa lakal-hamd (Allah hears those who praise Him, our Lord, and to You be the praise), then he stood up until every part of him had settled}}
\hadithdefcmd{nasai}{1037}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ الرَّهَاوِيُّ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ عَطَاءٍ، عَنْ سَالِمٍ أَبِي عَبْدِ اللَّهِ، عَنْ عُقْبَةَ بْنِ عَمْرٍو، قَالَ أَلاَ أُصَلِّي لَكُمْ كَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فَقُلْنَا بَلَى ‏.‏ فَقَامَ فَلَمَّا رَكَعَ وَضَعَ رَاحَتَيْهِ عَلَى رُكْبَتَيْهِ وَجَعَلَ أَصَابِعَهُ مِنْ وَرَاءِ رُكْبَتَيْهِ وَجَافَى إِبْطَيْهِ حَتَّى اسْتَقَرَّ كُلُّ شَىْءٍ مِنْهُ ثُمَّ رَفَعَ رَأْسَهُ فَقَامَ حَتَّى اسْتَوَى كُلُّ شَىْءٍ مِنْهُ ثُمَّ سَجَدَ فَجَافَى إِبْطَيْهِ حَتَّى اسْتَقَرَّ كُلُّ شَىْءٍ مِنْهُ ثُمَّ قَعَدَ حَتَّى اسْتَقَرَّ كُلُّ شَىْءٍ مِنْهُ ثُمَّ سَجَدَ حَتَّى اسْتَقَرَّ كُلُّ شَىْءٍ مِنْهُ ثُمَّ صَنَعَ كَذَلِكَ أَرْبَعَ رَكَعَاتٍ ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَهَكَذَا كَانَ يُصَلِّي بِنَا ‏.‏\hadithno{1037}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"Shall I not show you how I saw the Messenger of Allah (ﷺ) pray?" We said: "Yes." So he stood up and when he bowed, he placed his palms on his knees and put his fingers behind his knees, and held his arms out from his sides, until every part of him settled. Then he raised his head and stood up until every part of him settled. Then he prostrated and held his arms out from his sides, until every part of him settled. Then he sat up until every part of him settled. Then he prostrated again until every part of him settled. Then he did four rak'ahs like that. Then he said: "This is how I saw the Messenger of Allah (ﷺ) pray, and this is how he used to lead us in prayer}}
\hadithdefcmd{nasai}{1038}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عُلَيَّةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَالِمٍ الْبَرَّادِ، قَالَ قَالَ أَبُو مَسْعُودٍ أَلاَ أُرِيكُمْ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي قُلْنَا بَلَى ‏.‏ فَقَامَ فَكَبَّرَ فَلَمَّا رَكَعَ جَافَى بَيْنَ إِبْطَيْهِ حَتَّى لَمَّا اسْتَقَرَّ كُلُّ شَىْءٍ مِنْهُ رَفَعَ رَأْسَهُ فَصَلَّى أَرْبَعَ رَكَعَاتٍ هَكَذَا وَقَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي ‏.‏\hadithno{1038}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Salim Al- Barrad said:"Abu Mus'ad said: 'Shall I not show you how the Messenger of Allah (ﷺ) prayed?' We said: 'Yes.' So he stood up and said the takbir, and when he bowed, he held his arms out from his sides until, when every part of him settled, he raised his head. He prayed four rak'ahs like that, and said: 'This is how I saw the Messenger of Allah (ﷺ) praying}}
\hadithdefcmd{nasai}{1039}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا رَكَعَ اعْتَدَلَ فَلَمْ يَنْصِبْ رَأْسَهُ وَلَمْ يُقْنِعْهُ وَوَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ ‏.‏\hadithno{1039}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari}\hadithtrans{It was narrated that Abu Humaid As-Sa'idi said:"When the Prophet (ﷺ) bowed he was balanced, he did not make his head higher or lower than his back, and he put his hands on his knees}}
\hadithdefcmd{nasai}{1040}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنْ أَشْعَثَ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، قَالَ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنِ الْقَسِّيِّ وَالْحَرِيرِ وَخَاتَمِ الذَّهَبِ وَأَنْ أَقْرَأَ وَأَنَا رَاكِعٌ وَقَالَ مَرَّةً أُخْرَى وَأَنْ أَقْرَأَ رَاكِعًا ‏.‏\hadithno{1040}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Ali said:"The Prophet (ﷺ) forbade me from wearing A-Qassi and silk, and gold rings, and from reciting Qur'an when bowing}}
\hadithdefcmd{nasai}{1041}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ عَجْلاَنَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَلِيٍّ، قَالَ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنْ خَاتَمِ الذَّهَبِ وَعَنِ الْقِرَاءَةِ رَاكِعًا وَعَنِ الْقَسِّيِّ وَالْمُعَصْفَرِ ‏.‏\hadithno{1041}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ali said:"The Prophet (ﷺ) forbade me from wearing gold rings, from reciting the Qur'an when bowing, and from wearing Al-Qassi, and clothes dyed with safflower}}
\hadithdefcmd{nasai}{1042}{أَخْبَرَنَا الْحَسَنُ بْنُ دَاوُدَ الْمُنْكَدِرِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ إِبْرَاهِيمَ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ أَقُولُ نَهَاكُمْ عَنْ تَخَتُّمِ الذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيِّ وَعَنْ لُبْسِ الْمُفَدَّمِ وَالْمُعَصْفَرِ وَعَنِ الْقِرَاءَةِ فِي الرُّكُوعِ ‏.‏\hadithno{1042}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ali said:"The Messenger of Allah (ﷺ) forbade me-but I do not say he forbade you- from wearing gold rings, Al-Qassi, and from wearing Al-Mufaddam, and from wearing clothes dyed with safflower, and from reciting Qur'an when bowing}}
\hadithdefcmd{nasai}{1043}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، زُغْبَةُ عَنِ اللَّيْثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ إِبْرَاهِيمَ بْنَ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، حَدَّثَهُ أَنَّ أَبَاهُ حَدَّثَهُ أَنَّهُ، سَمِعَ عَلِيًّا، يَقُولُ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ خَاتَمِ الذَّهَبِ وَعَنْ لَبُوسِ الْقِسِّيِّ وَالْمُعَصْفَرِ وَقِرَاءَةِ الْقُرْآنِ وَأَنَا رَاكِعٌ ‏.‏\hadithno{1043}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah (ﷺ) forbade me from wearing gold rings, and Al-Qassi, and clothes dyed with safflower, and reciting Qur'an while I am bowing}}
\hadithdefcmd{nasai}{1044}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسِ الْقَسِّيِّ وَالْمُعَصْفَرِ وَعَنْ تَخَتُّمِ الذَّهَبِ وَعَنِ الْقِرَاءَةِ فِي الرُّكُوعِ ‏.‏\hadithno{1044}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ali said:"The Messenger of Allah (ﷺ) forbade me from wearing Al-Qassi, and clothes dyed from safflower, and from wearing gold rings, and from reciting Qura'n while bowing}}
\hadithdefcmd{nasai}{1045}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ بْنِ سُحَيْمٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَشَفَ النَّبِيُّ صلى الله عليه وسلم السِّتَارَةَ وَالنَّاسُ صُفُوفٌ خَلْفَ أَبِي بَكْرٍ - رضى الله عنه - فَقَالَ ‏ "‏ أَيُّهَا النَّاسُ إِنَّهُ لَمْ يَبْقَ مِنْ مُبَشِّرَاتِ النُّبُوَّةِ إِلاَّ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الْمُسْلِمُ أَوْ تُرَى لَهُ - ثُمَّ قَالَ - أَلاَ إِنِّي نُهِيتُ أَنْ أَقْرَأَ رَاكِعًا أَوْ سَاجِدًا فَأَمَّا الرُّكُوعُ فَعَظِّمُوا فِيهِ الرَّبَّ وَأَمَّا السُّجُودُ فَاجْتَهِدُوا فِي الدُّعَاءِ قَمِنٌ أَنْ يُسْتَجَابَ لَكُمْ ‏"‏ ‏.‏\hadithno{1045}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Prophet (ﷺ) drew back the curtain when the people were in rows behind Abu Bakr, may Allah be pleased with him, and said: 'O people, there is nothing left of the features of Prophethood except a good dream that a Muslim sees or is seen by others for him.' Then he said: 'Verily, I have been forbidden from reciting the Qur'an when bowing or prostrating. As for bowing, glorify the Lord therein, and as for prostration, strive hard in supplication for it is more deserving of a response}}
\hadithdefcmd{nasai}{1046}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْمُسْتَوْرِدِ بْنِ الأَحْنَفِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَكَعَ فَقَالَ فِي رُكُوعِهِ ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏.‏ وَفِي سُجُودِهِ ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ‏.‏\hadithno{1046}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hudhaifah said:"I prayed with the Messenger of Allah (ﷺ), and he bowed and said when bowing: 'Subhana Rabbial-azim (Glory be to my Lord Almighty).' And when prostrating: 'Subhana Rabbial-'Ala (Glory be to my Lord Most High)}}
\hadithdefcmd{nasai}{1047}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، وَيَزِيدُ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ أَنْ يَقُولَ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبْحَانَكَ رَبَّنَا وَبِحَمْدِكَ اللَّهُمَّ اغْفِرْ لِي ‏"‏ ‏.‏\hadithno{1047}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) often used to say when bowing and prostrating: 'Subhanaka Rabbana wa bi Hamdika, Allahumm aghfirli (Glorfy and praise be to You, our Lord. O Allah, forgive me)}}
\hadithdefcmd{nasai}{1048}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَنْبَأَنِي قَتَادَةُ، عَنْ مُطَرِّفٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي رُكُوعِهِ ‏ "‏ سُبُّوحٌ قُدُّوسٌ رَبُّ الْمَلاَئِكَةِ وَالرُّوحِ ‏"‏ ‏.‏\hadithno{1048}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah (ﷺ) used to say when bowing: 'Subbuhun Quddusun Rabbul-mala'ikati war-ruh (Perfect, Most Holy, is the Lord of the angels and the spirit)}}
\hadithdefcmd{nasai}{1049}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، - يَعْنِي النَّسَائِيَّ - قَالَ حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ مُعَاوِيَةَ، - يَعْنِي ابْنَ صَالِحٍ - عَنْ أَبِي قَيْسٍ الْكِنْدِيِّ، - وَهُوَ عَمْرُو بْنُ قَيْسٍ - قَالَ سَمِعْتُ عَاصِمَ بْنَ حُمَيْدٍ، قَالَ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ، يَقُولُ قُمْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةً فَلَمَّا رَكَعَ مَكَثَ قَدْرَ سُورَةِ الْبَقَرَةِ يَقُولُ فِي رُكُوعِهِ ‏ "‏ سُبْحَانَ ذِي الْجَبَرُوتِ وَالْمَلَكُوتِ وَالْكِبْرِيَاءِ وَالْعَظَمَةِ ‏"‏ ‏.‏\hadithno{1049}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Asim bin Humaid said:"I heard 'Awf bin Malik say: 'I prayed Qiyam with the Messenger of Allah (ﷺ) one night, and when he bowed, he stayed as long as it takes to recite Surat Al-Baqarah, saying: "Subhana Dhil-jabaruti wal-malakuti wal-kibriya' wal-'azamah (Glory be to the One Who has all power, sovereignty, magnificence and might)}}
\hadithdefcmd{nasai}{1050}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، قَالَ حَدَّثَنَا عَمِّي الْمَاجِشُونُ بْنُ أَبِي سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا رَكَعَ قَالَ ‏ "‏ اللَّهُمَّ لَكَ رَكَعْتُ وَلَكَ أَسْلَمْتُ وَبِكَ آمَنْتُ خَشَعَ لَكَ سَمْعِي وَبَصَرِي وَعِظَامِي وَمُخِّي وَعَصَبِي ‏"‏ ‏.‏\hadithno{1050}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ali bin Abi Talib that:When the Messenger of Allah (ﷺ) bowed, he said: "Allahumma laka rak`atu was laka aslamtu wa bika amantu, khasha`a laka sam`i wa basri wa `izami wa mukhi wa `asabi (O Allah, to You I have bowed and to You I have submitted and in You I have believed. My hearing, sight, bones, brain and sinews are humbled before You)}}
\hadithdefcmd{nasai}{1051}{أَخْبَرَنَا يَحْيَى بْنُ عُثْمَانَ الْحِمْصِيُّ، قَالَ حَدَّثَنَا أَبُو حَيْوَةَ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم كَانَ إِذَا رَكَعَ قَالَ ‏ "‏ اللَّهُمَّ لَكَ رَكَعْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ وَعَلَيْكَ تَوَكَّلْتُ أَنْتَ رَبِّي خَشَعَ سَمْعِي وَبَصَرِي وَدَمِي وَلَحْمِي وَعَظْمِي وَعَصَبِي لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏\hadithno{1051}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:When the Prophet (ﷺ) bowed, he said: "Allahumma laka rak'atu wa bika amantu wa laka aslamtu wa alayka tawwakaltu, anta Rabbi, khasha'a sam'i wa basri wa dammi wa lahmi wa 'azmi wa 'asabi Lillahi Rabbil-'Alamin ( O Allah, to You I have bowed, in You I believe, to You I have submitted and in You I put my trust. You are my Lord. My hearing, my sight, my blood, my flesh, my bones and sinews are humbled before Allah, the Lord of the Worlds)}}
\hadithdefcmd{nasai}{1052}{أَخْبَرَنَا يَحْيَى بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا ابْنُ حِمْيَرٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَذَكَرَ، آخَرَ قَبْلَهُ عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ مُحَمَّدِ بْنِ مَسْلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ يُصَلِّي تَطَوُّعًا يَقُولُ إِذَا رَكَعَ ‏ "‏ اللَّهُمَّ لَكَ رَكَعْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ وَعَلَيْكَ تَوَكَّلْتُ أَنْتَ رَبِّي خَشَعَ سَمْعِي وَبَصَرِي وَلَحْمِي وَدَمِي وَمُخِّي وَعَصَبِي لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏\hadithno{1052}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Muhammad bin Maslamah that:When the Messenger of Allah (ﷺ) stood to offer a voluntary prayer, he would say when he bowed: "Allahumma laka rak'atu wa bika amantu wa laka aslamtu wa alayka tawwakaltu, anta Rabbi, khasha'a sam'i wa basri wa lahmi wa dammi wa mukhi wa 'asabi Lillahi Rabbil-'Alamin ( O Allah, to You I have bowed, in You I believe, to You I have submitted and in You I put my trust. You are my Lord. My hearing, my sight, my flesh, my blood, my brain and my sinews are humbled before Allah, the Lord of the Worlds)}}
\hadithdefcmd{nasai}{1053}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَلِيِّ بْنِ يَحْيَى الزُّرَقِيِّ، عَنْ أَبِيهِ، عَنْ عَمِّهِ، رِفَاعَةَ بْنِ رَافِعٍ وَكَانَ بَدْرِيًّا قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ دَخَلَ رَجُلٌ الْمَسْجِدَ فَصَلَّى وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَرْمُقُهُ وَلاَ يَشْعُرُ ثُمَّ انْصَرَفَ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ عَلَيْهِ فَرَدَّ عَلَيْهِ السَّلاَمَ ثُمَّ قَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ قَالَ لاَ أَدْرِي فِي الثَّانِيَةِ أَوْ فِي الثَّالِثَةِ قَالَ وَالَّذِي أَنْزَلَ عَلَيْكَ الْكِتَابَ لَقَدْ جَهِدْتُ فَعَلِّمْنِي وَأَرِنِي ‏.‏ قَالَ ‏"‏ إِذَا أَرَدْتَ الصَّلاَةَ فَتَوَضَّأْ فَأَحْسِنِ الْوُضُوءَ ثُمَّ قُمْ فَاسْتَقْبِلِ الْقِبْلَةَ ثُمَّ كَبِّرْ ثُمَّ اقْرَأْ ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ رَأْسَكَ حَتَّى تَطْمَئِنَّ قَاعِدًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا فَإِذَا صَنَعْتَ ذَلِكَ فَقَدْ قَضَيْتَ صَلاَتَكَ وَمَا انْتَقَصْتَ مِنْ ذَلِكَ فَإِنَّمَا تَنْقُصُهُ مِنْ صَلاَتِكَ ‏"‏ ‏.‏\hadithno{1053}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rifa'ah bin Rafi'- who had been present at Badr- said:"We were with the Messenger of Allah (ﷺ) when a man entered the Masjid and prayed. The Messenger of Allah (ﷺ) watched him without him realizing, then he finished, came to the Messenger of Allah (ﷺ) and greeted him with salam. He returned the salam and said: "Go back and pray, for you have not prayed.'" He (the narrator) said: "I do not know if it was the second or third time,- "(the man) said: 'By the One Who revealed the Book to you, I have tried my best. Teach me and show me.' He said: 'When you want to pray, perform wudu' and do it well, then stand up and face the qiblah. Then say the takbir, then recite, then bow until you are at ease in bowing. Then stand up until you are standing up straight. Then prostrate until you are at ease in prostration, then raise your head until you are at ease in sitting, then prostrate until you are at ease in prostration. If you do that then you will have done your prayer properly, and whatever you failed to do properly is going to detract from your prayer}}
\hadithdefcmd{nasai}{1054}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَتِمُّوا الرُّكُوعَ وَالسُّجُودَ إِذَا رَكَعْتُمْ وَسَجَدْتُمْ ‏"‏ ‏.‏\hadithno{1054}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Qatadah said:"I heard Anas narrate that the Prophet (ﷺ) said: "Bow and prostrate properly when you bow and prostrate}}
\hadithdefcmd{nasai}{1055}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ قَيْسِ بْنِ سُلَيْمٍ الْعَنْبَرِيِّ، قَالَ حَدَّثَنِي عَلْقَمَةُ بْنُ وَائِلٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُهُ يَرْفَعُ يَدَيْهِ إِذَا افْتَتَحَ الصَّلاَةَ وَإِذَا رَكَعَ وَإِذَا قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ هَكَذَا وَأَشَارَ قَيْسٌ إِلَى نَحْوِ الأُذُنَيْنِ ‏.‏\hadithno{1055}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Alqamah bin Wa'il said:"My father told me: 'I prayed behind the Messenger of Allah (ﷺ) and I saw him raise his hands when he started to pray, and when he bowed, and when he said: Sami' Allahu liman hamidah (Allah hears the one who praises Him)" like this.'" And (one of the narrators) Qais pointed towards his ears}}
\hadithdefcmd{nasai}{1056}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، أَنَّهُ حَدَّثَهُمْ عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْفَعُ يَدَيْهِ إِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ حَتَّى يُحَاذِيَ بِهِمَا فُرُوعَ أُذُنَيْهِ ‏"‏ ‏.‏\hadithno{1056}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Malik bin Al-Huwairith that:He saw the Prophet (ﷺ) raise his hands when he bowed, and when he raised his head from bowing, until they were in level with the highest part of his ears}}
\hadithdefcmd{nasai}{1057}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَرْفَعُ يَدَيْهِ إِذَا دَخَلَ فِي الصَّلاَةِ حَذْوَ مَنْكِبَيْهِ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَعَلَ مِثْلَ ذَلِكَ وَإِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ قَالَ ‏"‏ رَبَّنَا لَكَ الْحَمْدُ ‏"‏ ‏.‏ وَكَانَ لاَ يَرْفَعُ يَدَيْهِ بَيْنَ السَّجْدَتَيْنِ ‏.‏\hadithno{1057}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim, from his father, that:The Messenger of Allah (ﷺ) used to raise his hands until they were in level with his shoulders when he started to pray, and when he raised his head from bowing he did likewise, and when he said: Sami' Allahu liman hamidah (Allah hears the one who praises Him)" he said: "Rabbana wa lakal-hamd (Our Lord, to You be praise)" and he did not raise his hands between the two prostrations}}
\hadithdefcmd{nasai}{1058}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ قَالَ أَلاَ أُصَلِّي بِكُمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى فَلَمْ يَرْفَعْ يَدَيْهِ إِلاَّ مَرَّةً وَاحِدَةً ‏.‏\hadithno{1058}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdullah that he said:"Shall I not show you how the Messenger of Allah (ﷺ) prayed?" So he prayed, and he only raised his hands once}}
\hadithdefcmd{nasai}{1059}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا افْتَتَحَ الصَّلاَةَ رَفَعَ يَدَيْهِ حَذْوَ مَنْكِبَيْهِ وَإِذَا كَبَّرَ لِلرُّكُوعِ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَهُمَا كَذَلِكَ أَيْضًا وَقَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ وَكَانَ لاَ يَفْعَلُ ذَلِكَ فِي السُّجُودِ ‏.‏\hadithno{1059}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:When the Messenger of Allah (ﷺ) started to pray, he raised his hands until they were in level with his shoulders, and when he said the takbir before bowing, and when he raised his head from bowing he raised (his hands) likewise, and said: "Sami Allahu liman hamidah Rabbana wa lakal-hamd (Allah hears the one who praises Him; Our Lord, and to You be praise)," and he did not do that when prostrating}}
\hadithdefcmd{nasai}{1060}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏ "‏ اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{1060}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"When the Prophet (ﷺ) raised his head from bowing, he said: 'Allahumma Rabbana wa lakal-hamd (O Allah, our Lord and to You be the praise)}}
\hadithdefcmd{nasai}{1061}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَقَطَ مِنْ فَرَسٍ عَلَى شِقِّهِ الأَيْمَنِ فَدَخَلُوا عَلَيْهِ يَعُودُونَهُ فَحَضَرَتِ الصَّلاَةُ فَلَمَّا قَضَى الصَّلاَةَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{1061}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Prophet (ﷺ) fell from a horse onto his right side, and they entered upon him to visit him. The time for prayer came, and when he had finished praying he said: "The Imam is appointed to be followed, so when he bows, then bow, and when he stands up, then stand up, and when he says: 'Sami' Allahu liman hamidah (Allah hears the one who praises Him)' then say: 'Rabbana wa lakal-hamd (Our Lord, and to You be the praise)}}
\hadithdefcmd{nasai}{1062}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي نُعَيْمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَلِيِّ بْنِ يَحْيَى الزُّرَقِيِّ، عَنْ أَبِيهِ، عَنْ رِفَاعَةَ بْنِ رَافِعٍ، قَالَ كُنَّا يَوْمًا نُصَلِّي وَرَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَفَعَ رَأْسَهُ مِنَ الرَّكْعَةِ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ قَالَ رَجُلٌ وَرَاءَهُ رَبَّنَا وَلَكَ الْحَمْدُ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ ‏.‏ فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ الْمُتَكَلِّمُ آنِفًا ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ رَأَيْتُ بِضْعَةً وَثَلاَثِينَ مَلَكًا يَبْتَدِرُونَهَا أَيُّهُمْ يَكْتُبُهَا أَوَّلاً ‏"‏ ‏.‏\hadithno{1062}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Rifa'ah bin Rafi said:"We were praying behind the Messenger of Allah (ﷺ) one day and when he raised his head from bowing he said: 'Sami Allahu liman hamidah (Allah hears the one who praises Him).' A man behind him said: 'Rabbana wa lakal-hamd, hamdan kathiran tayyiban mubarakan fih. (O our Lord, and to You be praise, much blessed and pure praise.)' When the Messenger of Allah (ﷺ) had finished, he said: "Who is the one who spoke just now?" The man said: 'I did, O Messenger of Allah.' The Messenger of Allah (ﷺ) said: 'I saw thirty-some angels rushing to see which of them would write it down first}}
\hadithdefcmd{nasai}{1063}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ فَإِنَّ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{1063}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "When the Imam says: 'Sami Allahu liman hamidah (Allah hears the one who praises Him),' then say: 'Rabbana wa lakal-hamd,' (Our Lord, and to You be the praise).' Whoever says that and it coincides with the angels saying it, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{1064}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، أَنَّهُ حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا مُوسَى، قَالَ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم خَطَبَنَا وَبَيَّنَ لَنَا سُنَّتَنَا وَعَلَّمَنَا صَلاَتَنَا فَقَالَ ‏"‏ إِذَا صَلَّيْتُمْ فَأَقِيمُوا صُفُوفَكُمْ ثُمَّ لْيَؤُمَّكُمْ أَحَدُكُمْ فَإِذَا كَبَّرَ الإِمَامُ فَكَبِّرُوا وَإِذَا قَرَأَ ‏\{‏ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ فَقُولُوا آمِينَ يُجِبْكُمُ اللَّهُ وَإِذَا كَبَّرَ وَرَكَعَ فَكَبِّرُوا وَارْكَعُوا فَإِنَّ الإِمَامَ يَرْكَعُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ يَسْمَعِ اللَّهُ لَكُمْ فَإِنَّ اللَّهَ قَالَ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَإِذَا كَبَّرَ وَسَجَدَ فَكَبِّرُو وَاسْجُدُوا فَإِنَّ الإِمَامَ يَسْجُدُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ فَإِذَا كَانَ عِنْدَ الْقَعْدَةِ فَلْيَكُنْ مِنْ أَوَّلِ قَوْلِ أَحَدِكُمُ التَّحِيَّاتُ الطَّيِّبَاتُ الصَّلَوَاتُ لِلَّهِ سَلاَمٌ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ سَلاَمٌ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ سَبْعَ كَلِمَاتٍ وَهِيَ تَحِيَّةُ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1064}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hittan bin 'Abdullah that:He heard Abu Musa say: "The Prophet of Allah (ﷺ) addressed us and taught us our Sunnah and our prayer. He said: 'When you pray, make your rows straight and let one of you lead you in prayer. When the Imam says the takbir, then say the takbir. When he recites 'Not (the way) of those who earned Your anger, nor those who went astray' then say: "Amin" and Allah will answer you. When he says the takbir and bows, then say the takbir and bow. The Imam bows before you do and stands up before you do.' The Prophet of Allah (ﷺ) said: 'This makes up for that. And when he says: "'Sami Allahu liman hamidah (Allah hears the one who praises Him),' then say: "Allahumma Rabbana wa lakal-hamd (O Allah, our Lord, and to You be the praise), " Allah will hear you, for Allah has said on the lips of His Prophet (ﷺ): "Allah hears the one who praises Him." And when he (the Imam) says the takbir and prostrates, then say the takbir and prostrate. The Imam prostrates before you do and sits up before you do.' The Prophet of Allah (ﷺ) said: 'This makes up for that. And when he is sitting, let the first thing that any one of you says be: At-tahiyaatut-tayyibatus-salawatuLillah, salamun 'alayka ayyuhanabiyyu wa rahmatullahi wa barakatuhu, salamun 'alayna wa 'ala 'ibadillahis-salihin, ashhadu an la ilaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluh (All compliments, good words and prayers are due to Allah, peace be upon you O Prophet, and the mercy of Allah and His blessings. Peace be upon us and upon the righteous slaves of Allah. I bear witness that there is none worthy of worship except Allah and I bear witness that Muhammad is His slave and Messenger)- seven phrases which are the greeting of the prayer}}
\hadithdefcmd{nasai}{1065}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ رُكُوعُهُ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَسُجُودُهُ وَمَا بَيْنَ السَّجْدَتَيْنِ قَرِيبًا مِنَ السَّوَاءِ ‏.‏\hadithno{1065}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Al-Bara' bin 'Azib that:The bowing of the Messenger of Allah (ﷺ), and when he raised his head from bowing, and his prostration, and the time between the two prostration, were almost equal in length}}
\hadithdefcmd{nasai}{1066}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ الْحَرَّانِيُّ قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ ‏"‏ ‏.‏\hadithno{1066}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that:When the Prophet (ﷺ) said: "Sami Allahu liman hamidah (Allah hears the one who praises Him),' he said: "Allahumma Rabbana wa lakal-hamd, mil'as-samawati wa mil'al-ardi wa mil'ama shi'ta min shai'in ba'd ( O Allah, our Lord, to You be the Praise, filling the heavens, filling the Earth, and filling whatever else You will)}}
\hadithdefcmd{nasai}{1067}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنْ وَهْبِ بْنِ مِينَاسٍ الْعَدَنِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ السُّجُودَ بَعْدَ الرَّكْعَةِ يَقُولُ ‏ "‏ اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ ‏"‏ ‏.‏\hadithno{1067}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that:When the Prophet (ﷺ) wanted to prostrate after bowing, he would say: "Allahumma, Rabbana wa lakal-hamd, mil'as-samawati wa mil'al-ardi wa mil'ama shi'ta min shai'in ba'd ( O Allah, our Lord, to You be the Praise, filling the heavens, filling the Earth, and filling whatever else You will)}}
\hadithdefcmd{nasai}{1068}{أَخْبَرَنِي عَمْرُو بْنُ هِشَامٍ أَبُو أُمَيَّةَ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا مَخْلَدٌ، عَنْ سَعِيدِ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَطِيَّةَ بْنِ قَيْسٍ، عَنْ قَزَعَةَ بْنِ يَحْيَى، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ حِينَ يَقُولُ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ أَهْلَ الثَّنَاءِ وَالْمَجْدِ خَيْرُ مَا قَالَ الْعَبْدُ وَكُلُّنَا لَكَ عَبْدٌ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1068}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa'eed that:The Messenger of Allah (ﷺ) used to say: "Sami Allahu liman hamidah, Rabbana wa lakal-hamd, mil'as-samawati wa mil'al-ardi wa mil'ama shi'ta min shai'in ba'd. Athlath-thana'i wal-majdi khairu ma qalal-'abdu wa kulluna laka 'abdun la mani'a lima a'taita wa la yanfa'u dhal-jaddi minkal-jadd (Allah hears the one who praises Him; Our Lord, to You be the Praise, filling the heavens, filling the Earth, and filling whatever else You will, Lord of Glory and Majesty, the truest thing a slave had said, and we are all slaves to You. None can withhold what You grant, nor can the possession of an owner benefit him before You)}}
\hadithdefcmd{nasai}{1069}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي حَمْزَةَ، عَنْ رَجُلٍ، مِنْ بَنِي عَبْسٍ عَنْ حُذَيْفَةَ، أَنَّهُ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَسَمِعَهُ حِينَ كَبَّرَ قَالَ ‏"‏ اللَّهُ أَكْبَرُ ذَا الْجَبَرُوتِ وَالْمَلَكُوتِ وَالْكِبْرِيَاءِ وَالْعَظَمَةِ ‏"‏ ‏.‏ وَكَانَ يَقُولُ فِي رُكُوعِهِ ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏.‏ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏"‏ لِرَبِّي الْحَمْدُ لِرَبِّي الْحَمْدُ ‏"‏ ‏.‏ وَفِي سُجُودِهِ ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ‏.‏ وَبَيْنَ السَّجْدَتَيْنِ ‏"‏ رَبِّ اغْفِرْ لِي رَبِّ اغْفِرْ لِي ‏"‏ ‏.‏ وَكَانَ قِيَامُهُ وَرُكُوعُهُ ‏.‏ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَسُجُودُهُ وَمَا بَيْنَ السَّجْدَتَيْنِ قَرِيبًا مِنَ السَّوَاءِ ‏.‏\hadithno{1069}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Hudhaifah that:He prayed with the Messenger of Allah (ﷺ) one night and he heard him say when he said the takbir: "Allahu Akbara dhal-jabaruti wal-malakuti wal-kibriya'i wal-'azamah (Allah is Most Great, the One Who has all power, sovereignty, magnificence and might.)" When bowing he would say: "Subhana Rabbial-'Azim (Glory be to my Lord Almighty)." When he raised his head from bowing he would say: "Lirabbil-hamd, Lirabbil-hamd (To my Lord be praise, to my Lord be praise)." And when he prostrated (he said): "Subhana Rabbial-A'la (Glory be to my Lord Most High)." And between the two prostrations (he said): "Rabbighfirli, Rabbighfirli (Lord forgive me, Lord forgive me)." His standing, his bowing, when he raised his head from bowing, his prostration and the time between the two prostrations, were almost the same}}
\hadithdefcmd{nasai}{1070}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي مِجْلَزٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا بَعْدَ الرُّكُوعِ يَدْعُو عَلَى رِعْلٍ وَذَكْوَانَ وَعُصَيَّةَ عَصَتِ اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{1070}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) prayed (saying the) Qunut after bowing for a month, supplicating against Ri'l, Dhakwan and 'Usayyah who had disobeyed Allah and His Messenger." (Sahih)}}
\hadithdefcmd{nasai}{1071}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، أَنَّ أَنَسَ بْنَ مَالِكٍ، سُئِلَ هَلْ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةِ الصُّبْحِ قَالَ نَعَمْ ‏.‏ فَقِيلَ لَهُ قَبْلَ الرُّكُوعِ أَوْ بَعْدَهُ قَالَ بَعْدَ الرُّكُوعِ ‏.‏\hadithno{1071}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik was asked:"Did the Messenger of Allah (ﷺ) say the Qunut in Subh prayer?" He said: "Yes." He was asked: "Was that before bowing or after?" He said: "After bowing}}
\hadithdefcmd{nasai}{1072}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ يُونُسَ، عَنِ ابْنِ سِيرِينَ، قَالَ حَدَّثَنِي بَعْضُ، مَنْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ فَلَمَّا قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ فِي الرَّكْعَةِ الثَّانِيَةِ قَامَ هُنَيْهَةً ‏.‏\hadithno{1072}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Sirin said:"Some of those who prayed the Subh prayer with the Messenger of Allah (ﷺ) narrated to me that when he said: Sami'Allahu liman hamidah (Allah hears those who praise Him)' in the second rak'ah, he stood for a while}}
\hadithdefcmd{nasai}{1073}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنَ الزُّهْرِيِّ عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا رَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَأْسَهُ مِنَ الرَّكْعَةِ الثَّانِيَةِ مِنْ صَلاَةِ الصُّبْحِ قَالَ ‏ "‏ اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ وَسَلَمَةَ بْنَ هِشَامٍ وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ وَالْمُسْتَضْعَفِينَ بِمَكَّةَ اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ وَاجْعَلْهَا عَلَيْهِمْ سِنِينَ كَسِنِي يُوسُفَ ‏"‏ ‏.‏\hadithno{1073}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"When the Messenger of Allah (ﷺ) raised his head in the second rak'ah of the subh prayer, he said: 'O Allah, save Al-Walid bin Al-Walid and Salamah bin Hisham and 'Ayyshah bin Abi Rabi'ah and those who are weak and oppressed in Makkah. O Allah, intensify Your punishment in Mudar and give them years (of famine) like the years of Yusuf}}
\hadithdefcmd{nasai}{1074}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنِ ابْنِ أَبِي حَمْزَةَ، قَالَ حَدَّثَنِي مُحَمَّدٌ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فِي الصَّلاَةِ حِينَ يَقُولُ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ يَقُولُ وَهُوَ قَائِمٌ قَبْلَ أَنْ يَسْجُدَ ‏"‏ اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ وَسَلَمَةَ بْنَ هِشَامٍ وَعَيَّاشَ بْنَ أَبِي رَبِيعَةَ وَالْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ وَاجْعَلْهَا عَلَيْهِمْ كَسِنِي يُوسُفَ ‏"‏ ‏.‏ ثُمَّ يَقُولُ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏ فَيَسْجُدُ وَضَاحِيَةُ مُضَرَ يَوْمَئِذٍ مُخَالِفُونَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1074}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :The Messenger of Allah (ﷺ) used to supplicate in prayer when he said: "Sami' Allahu liman hamidah, Rabbana wa lakal-hamd (Allah hears those who praise Him; O our Lord, and to You be praise),"then he said while standing, before he prostrated: "O Allah, save Al-Walid bin Al-Walid and Salamah bin Hisham and 'Ayyshah bin Abi Rabi'ah and those who are weak and oppressed in Makkah. O Allah, intensify Your punishment in Mudar and give them years (of famine) like the years of Yusuf." Then he would say: "Allah is Most Great" and then he prostrated. The people of Mudar and their environs were opposed to the Messenger of Allah (ﷺ) at the time}}
\hadithdefcmd{nasai}{1075}{أَخْبَرَنَا سُلَيْمَانُ بْنُ سَلْمٍ الْبَلْخِيُّ، قَالَ حَدَّثَنَا النَّضْرُ، قَالَ أَنْبَأَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لأُقَرِّبَنَّ لَكُمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَكَانَ أَبُو هُرَيْرَةَ يَقْنُتُ فِي الرَّكْعَةِ الآخِرَةِ مِنْ صَلاَةِ الظُّهْرِ ‏.‏ وَصَلاَةِ الْعِشَاءِ الآخِرَةِ وَصَلاَةِ الصُّبْحِ بَعْدَ مَا يَقُولُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَيَدْعُو لِلْمُؤْمِنِينَ وَيَلْعَنُ الْكَفَرَةَ ‏.‏\hadithno{1075}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Salamah, that Abu Hurairah said:"I shall explain to you the prayer of the Messenger of Allah (ﷺ)." He said: "Abu Hurairah used to say the Qunut in the last rak'ah of the Zuhr prayer, and the later Isha' prayer, and the Subh, after saying 'Sami Allahu liman hamidah.' He would pray for the believers and curse the disbelievers}}
\hadithdefcmd{nasai}{1076}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ سُفْيَانَ، وَشُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، ح وَأَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، وَسُفْيَانَ، قَالاَ حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْنُتُ فِي الصُّبْحِ وَالْمَغْرِبِ ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1076}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Al-Bara' bin 'Azib that:The Prophet (ﷺ) used to say the Qunut in Subh and Maghrib. (One of the narrators) 'Ubaidullah said: "Allah's Messenger (ﷺ) used to}}
\hadithdefcmd{nasai}{1077}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، وَهِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَنَتَ شَهْرًا - قَالَ شُعْبَةُ لَعَنَ رِجَالاً وَقَالَ هِشَامٌ يَدْعُو عَلَى أَحْيَاءٍ مِنْ أَحْيَاءِ الْعَرَبِ - ثُمَّ تَرَكَهُ بَعْدَ الرُّكُوعِ ‏.‏ هَذَا قَوْلُ هِشَامٍ وَقَالَ شُعْبَةُ عَنْ قَتَادَةَ عَنْ أَنَسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَنَتَ شَهْرًا يَلْعَنُ رِعْلاً وَذَكْوَانَ وَلِحْيَانَ ‏.‏\hadithno{1077}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas:"The Messenger of Allah (ﷺ) said the Qunut for a month."- (One of the narrators) Shu'bah said: "He cursed some men." Hisham said: "He supplicated against some of the tribes of Arabs."-"Then he stopped doing that after bowing." This is what Hisham said. Shu'bah said, narrating from Qatadah, from Anas that the Prophet (ﷺ) said the Qunut for a month, cursing Ri'l, Dhawkan and Lihyan}}
\hadithdefcmd{nasai}{1078}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم حِينَ رَفَعَ رَأْسَهُ مِنْ صَلاَةِ الصُّبْحِ مِنَ الرَّكْعَةِ الآخِرَةِ قَالَ ‏"‏ اللَّهُمَّ الْعَنْ فُلاَنًا وَفُلاَنًا ‏"‏ ‏.‏ يَدْعُو عَلَى أُنَاسٍ مِنَ الْمُنَافِقِينَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لَيْسَ لَكَ مِنَ الأَمْرِ شَىْءٌ أَوْ يَتُوبَ عَلَيْهِمْ أَوْ يُعَذِّبَهُمْ فَإِنَّهُمْ ظَالِمُونَ ‏\}‏ ‏.‏\hadithno{1078}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Salim, from his father, that:He heard the Prophet (ﷺ), when he raised his head in the last rak'ah of the subh prayer, say: "O Allah, curse so-and-so and so-and-so," supplicating against some of the hypocrites. Then Allah revealed the words: "Not for you is the decision; whether He turns in mercy to (pardon) them or punishes them; verily, they are the wrongdoers}}
\hadithdefcmd{nasai}{1079}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَنَتَ شَهْرًا يَدْعُو عَلَى حَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ ثُمَّ تَرَكَهُ ‏.‏\hadithno{1079}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Messenger of Allah (ﷺ) said the Qunut for one month, supplicating against one of the 'Arab tribes, then he stopped doing that}}
\hadithdefcmd{nasai}{1080}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ خَلَفٍ، - وَهُوَ ابْنُ خَلِيفَةَ - عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ أَبِيهِ، قَالَ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يَقْنُتْ وَصَلَّيْتُ خَلْفَ أَبِي بَكْرٍ فَلَمْ يَقْنُتْ وَصَلَّيْتُ خَلْفَ عُمَرَ فَلَمْ يَقْنُتْ وَصَلَّيْتُ خَلْفَ عُثْمَانَ فَلَمْ يَقْنُتْ وَصَلَّيْتُ خَلْفَ عَلِيٍّ فَلَمْ يَقْنُتْ ثُمَّ قَالَ يَا بُنَىَّ إِنَّهَا بِدْعَةٌ ‏.‏\hadithno{1080}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Malik Al-Ashja'i that his father said:"I prayed behind the Messenger of Allah (ﷺ) and he did not say the Qunut, and I prayed behind Abu Bakr and he did not say the Qunut, and I prayed behind Umar and he did not say the Qunut, and I prayed behind Uthman and he did not say the Qunut, and I prayed behind Ali and he did not say the Qunut." Then he said: "O my son, this is an innovation}}
\hadithdefcmd{nasai}{1081}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الظُّهْرَ فَآخُذُ قَبْضَةً مِنْ حَصًى فِي كَفِّي أُبَرِّدُهُ ثُمَّ أُحَوِّلُهُ فِي كَفِّي الآخَرِ فَإِذَا سَجَدْتُ وَضَعْتُهُ لِجَبْهَتِي ‏.‏\hadithno{1081}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"We used to pray Zuhr with the Messenger of Allah (ﷺ) and I would take a handful of pebbles in my hand to cool them down, then I would pass them from one hand to the other, and when I prostrated I would put them down to lay my forehead on them}}
\hadithdefcmd{nasai}{1082}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ مُطَرِّفٍ، قَالَ صَلَّيْتُ أَنَا وَعِمْرَانُ بْنُ حُصَيْنٍ، خَلْفَ عَلِيِّ بْنِ أَبِي طَالِبٍ فَكَانَ إِذَا سَجَدَ كَبَّرَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ السُّجُودِ كَبَّرَ وَإِذَا نَهَضَ مِنَ الرَّكْعَتَيْنِ كَبَّرَ فَلَمَّا قَضَى صَلاَتَهُ أَخَذَ عِمْرَانُ بِيَدِي فَقَالَ لَقَدْ ذَكَّرَنِي هَذَا - قَالَ كَلِمَةً يَعْنِي - صَلاَةَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{1082}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Mutarrif said:"Imran bin Husain and I prayed behind Ali bin Abi Talib. When he prostrated he said the Takbir, and when he raised his head from prostration he said the takbir, and when he stood up following two rak'ahs he said the takbir, and when he had finished praying, 'Imran took my hand and said: 'This reminded me of- he said a word meaning- the prayer of Muhammad (ﷺ)}}
\hadithdefcmd{nasai}{1083}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُعَاذٌ، وَيَحْيَى، قَالاَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكَبِّرُ فِي كُلِّ خَفْضٍ وَرَفْعٍ وَيُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ يَسَارِهِ وَكَانَ أَبُو بَكْرٍ وَعُمَرُ - رضى الله عنهما - يَفْعَلاَنِهِ ‏.‏\hadithno{1083}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abdullah bin Mas'ud said:"The Messenger of Allah (ﷺ) used to say the takbir every time he went down and came up, and he would say the Salam to his right and his left. And Abu Bakr and 'Umar used to do likewise}}
\hadithdefcmd{nasai}{1084}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، قَالَ سَمِعْتُ يُوسُفَ، - وَهُوَ ابْنُ مَاهِكٍ - يُحَدِّثُ عَنْ حَكِيمٍ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ لاَ أَخِرَّ إِلاَّ قَائِمًا ‏.‏\hadithno{1084}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Bushr said:"I heard Yusuf-meaning Ibn Mahak- narrating that Hakim said: 'I gave my pledge of allegiance to the Messenger of Allah (ﷺ), pledging that I would go down (in prostration) only after standing up from bowing}}
\hadithdefcmd{nasai}{1085}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم رَفَعَ يَدَيْهِ فِي صَلاَتِهِ وَإِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَإِذَا سَجَدَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ السُّجُودِ حَتَّى يُحَاذِيَ بِهِمَا فُرُوعَ أُذُنَيْهِ ‏.‏\hadithno{1085}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Malik bin Al-Huwairith that:He saw the Prophet (ﷺ) raise his hands when praying, when he bowed, when he raised his head from bowing, when he prostrated and when he raised his head from prostrating, until they were in level with the top part of his ears}}
\hadithdefcmd{nasai}{1086}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم رَفَعَ يَدَيْهِ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{1086}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Malik bin Al-Huwairith that:He saw the Prophet (ﷺ) raise his hands, a similar report}}
\hadithdefcmd{nasai}{1087}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ فِي الصَّلاَةِ فَذَكَرَ نَحْوَهُ وَزَادَ فِيهِ وَإِذَا رَكَعَ فَعَلَ مِثْلَ ذَلِكَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَعَلَ مِثْلَ ذَلِكَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ السُّجُودِ فَعَلَ مِثْلَ ذَلِكَ ‏.‏\hadithno{1087}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Malik bin Al-Huwairith that:He saw the Prophet of Allah (ﷺ) raise his hands when he started to pray, and he narrated a similar report and added: "When he bowed he did likewise, and when he raised his head from bowing he did likewise, and when he raised his head from prostration he did likewise}}
\hadithdefcmd{nasai}{1088}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْكُوفِيُّ الْمُحَارِبِيُّ، قَالَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْفَعُ يَدَيْهِ إِذَا افْتَتَحَ الصَّلاَةَ وَإِذَا رَكَعَ وَإِذَا رَفَعَ وَكَانَ لاَ يَفْعَلُ ذَلِكَ فِي السُّجُودِ ‏.‏\hadithno{1088}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) used to raise his hands when he started to pray, and when he bowed, and when he stood up, but he did not do that when he prostrated}}
\hadithdefcmd{nasai}{1089}{أَخْبَرَنَا الْحُسَيْنُ بْنُ عِيسَى الْقُومَسِيُّ الْبَسْطَامِيُّ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا سَجَدَ وَضَعَ رُكْبَتَيْهِ قَبْلَ يَدَيْهِ وَإِذَا نَهَضَ رَفَعَ يَدَيْهِ قَبْلَ رُكْبَتَيْهِ ‏.‏\hadithno{1089}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Wa'il bin Hujr said:"I saw the Messenger of Allah (ﷺ) when he prostrated, he lowered his knees before his hands, and when he came up he raised his hands before his knees}}
\hadithdefcmd{nasai}{1090}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ حَسَنٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَعْمِدُ أَحَدُكُمْ فِي صَلاَتِهِ فَيَبْرُكَ كَمَا يَبْرُكُ الْجَمَلُ ‏"‏ ‏.‏\hadithno{1090}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Is there any one of you who kneel as a camel kneels when praying?}}
\hadithdefcmd{nasai}{1091}{أَخْبَرَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، مِنْ كِتَابِهِ قَالَ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَسَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَجَدَ أَحَدُكُمْ فَلْيَضَعْ يَدَيْهِ قَبْلَ رُكْبَتَيْهِ وَلاَ يَبْرُكْ بُرُوكَ الْبَعِيرِ ‏"‏ ‏.‏\hadithno{1091}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'When one of you prostrates, let him put his hands down before his knees, and not kneel like a camel}}
\hadithdefcmd{nasai}{1092}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، دَلُّويَهْ قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رَفَعَهُ قَالَ ‏ "‏ إِنَّ الْيَدَيْنِ تَسْجُدَانِ كَمَا يَسْجُدُ الْوَجْهُ فَإِذَا وَضَعَ أَحَدُكُمْ وَجْهَهُ فَلْيَضَعْ يَدَيْهِ وَإِذَا رَفَعَهُ فَلْيَرْفَعْهُمَا ‏"‏ ‏.‏\hadithno{1092}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar in a Marfu' report that:The hands prostrate as the face prostrates, so when one of you puts his face down he should put his hands down, and when he raises (the face) he should raise (the hands) too}}
\hadithdefcmd{nasai}{1093}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعَةِ أَعْضَاءٍ وَلاَ يَكُفَّ شَعْرَهُ وَلاَ ثِيَابَهُ ‏.‏\hadithno{1093}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Prophet (ﷺ) was commanded to prostrate on seven parts of his body and not to tuck up his hair or his garment}}
\hadithdefcmd{nasai}{1094}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرٌ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَجَدَ الْعَبْدُ سَجَدَ مِنْهُ سَبْعَةُ آرَابٍ وَجْهُهُ وَكَفَّاهُ وَرُكْبَتَاهُ وَقَدَمَاهُ ‏"‏ ‏.‏\hadithno{1094}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Al 'Abbas bin 'Abdul-Muttalib that :He heard the Messenger of Allah (ﷺ) say: "When a person prostrates, seven parts of his body prostrate: his face, his two palms, his two knees and his two feet}}
\hadithdefcmd{nasai}{1095}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَصُرَتْ عَيْنَاىَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى جَبِينِهِ وَأَنْفِهِ أَثَرُ الْمَاءِ وَالطِّينِ مِنْ صُبْحِ لَيْلَةِ إِحْدَى وَعِشْرِينَ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{1095}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"My two eyes saw the traces of water and mud on the forehead and nose of the Messenger of Allah (ﷺ), from his praying Qiyam on the night of the twenty-first}}
\hadithdefcmd{nasai}{1096}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةٍ - لاَ أَكُفَّ الشَّعْرَ وَلاَ الثِّيَابَ - الْجَبْهَةِ وَالأَنْفِ وَالْيَدَيْنِ وَالرُّكْبَتَيْنِ وَالْقَدَمَيْنِ ‏"‏ ‏.‏\hadithno{1096}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that :The Messenger of Allah (ﷺ) said: "I have been commanded to prostrate on seven, and not to tuck up my hair nor my garment: the forehead, the nose, the hands, the knees and the feet}}
\hadithdefcmd{nasai}{1097}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ النَّسَائِيُّ، قَالَ حَدَّثَنَا الْمُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ عَلَى الْجَبْهَةِ وَأَشَارَ بِيَدِهِ عَلَى الأَنْفِ وَالْيَدَيْنِ وَالرُّكْبَتَيْنِ وَأَطْرَافِ الْقَدَمَيْنِ ‏"‏ ‏.‏\hadithno{1097}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet (ﷺ) said: "I have been commanded to prostrate on seven bones: on the forehead"- and he pointed with his hand- "on the nose, the hands, the knees and the ends of the feet}}
\hadithdefcmd{nasai}{1098}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الْمَكِّيُّ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الزُّهْرِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعٍ - وَنُهِيَ أَنْ يَكْفِتَ الشَّعْرَ وَالثِّيَابَ - عَلَى يَدَيْهِ وَرُكْبَتَيْهِ وَأَطْرَافِ أَصَابِعِهِ ‏.‏ قَالَ سُفْيَانُ قَالَ لَنَا ابْنُ طَاوُسٍ وَوَضَعَ يَدَيْهِ عَلَى جَبْهَتِهِ وَأَمَرَّهَا عَلَى أَنْفِهِ ‏.‏ قَالَ هَذَا وَاحِدٌ وَاللَّفْظُ لِمُحَمَّدٍ ‏.‏\hadithno{1098}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas:"The Prophet (ﷺ) was commanded to prostrate on seven-and he was forbidden to tuck up his hair and garment-on his hands, his knees, the edges of his feet." Sufyan said: "Ibn Tawus said to us: 'He put his hand on his forehead and moved it down to his nose and said: This one thing}}
\hadithdefcmd{nasai}{1099}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، قَالَ أَنْبَأَنَا ابْنُ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ عَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَجَدَ الْعَبْدُ سَجَدَ مَعَهُ سَبْعَةُ آرَابٍ وَجْهُهُ وَكَفَّاهُ وَرُكْبَتَاهُ وَقَدَمَاهُ ‏"‏ ‏.‏\hadithno{1099}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abbas bin 'Abdul-Muttalib that:He heard the Messenger of Allah (ﷺ) say: "When a person prostrates, seven parts of his body prostrate with him: his forehead, his two hands, his two knees and his two feet}}
\hadithdefcmd{nasai}{1100}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَانْتَهَيْتُ إِلَيْهِ وَهُوَ سَاجِدٌ وَقَدَمَاهُ مَنْصُوبَتَانِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَبِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَبِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏\hadithno{1100}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I noticed the Messenger of Allah (ﷺ) was missing one night, and I found him when he was prostrating with his feet held upright, and he was saying: 'Allahumma, inni a'udhu biridaka min sakhatik, wa bimu'afatika min 'uqubatik, wa bika minka la uhsi thana'an 'alaika anta kama athnaita 'ala nafsik (O Allah, I seek refuge with Your pleasure from Your wrath, in Your forgiveness from Your punishment and in You from You. I cannot praise You enough, You are as You have praised Yourself)}}
\hadithdefcmd{nasai}{1101}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَطَاءٍ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَهْوَى إِلَى الأَرْضِ سَاجِدًا جَافَى عَضُدَيْهِ عَنْ إِبْطَيْهِ وَفَتَخَ أَصَابِعَ رِجْلَيْهِ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{1101}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Humaid As-Sa'idi said:"When the Prophet (ﷺ) fell to the ground during prostration, he held his arms away from his sides and bent his toes}}
\hadithdefcmd{nasai}{1102}{أَخْبَرَنِي أَحْمَدُ بْنُ نَاصِحٍ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ عَاصِمَ بْنَ كُلَيْبٍ، يَذْكُرُ عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ قَدِمْتُ الْمَدِينَةَ فَقُلْتُ لأَنْظُرَنَّ إِلَى صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَبَّرَ وَرَفَعَ يَدَيْهِ حَتَّى رَأَيْتُ إِبْهَامَيْهِ قَرِيبًا مِنْ أُذُنَيْهِ فَلَمَّا أَرَادَ أَنْ يَرْكَعَ كَبَّرَ وَرَفَعَ يَدَيْهِ ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ كَبَّرَ وَسَجَدَ فَكَانَتْ يَدَاهُ مِنْ أُذُنَيْهِ عَلَى الْمَوْضِعِ الَّذِي اسْتَقْبَلَ بِهِمَا الصَّلاَةَ ‏.‏\hadithno{1102}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Wa'il bin Hujr said:"I came to Al-Madinah and said: 'I am going to watch the Messenger of Allah (ﷺ) pray. He said the takbir and raised his hands until I saw his thumbs near his ears. When he wanted to bow, he said the takbir and raised his hands. Then he raised his head and said: 'Sami Allahu liman hamidah (Allah hears the one who praises Him).' Then he said the takbir and prostrated, and his hands were in the same position in relation to his ears as when he started the prayer}}
\hadithdefcmd{nasai}{1103}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - قَالَ حَدَّثَنَا أَبُو الْعَلاَءِ، - وَاسْمُهُ أَيُّوبُ بْنُ أَبِي مِسْكِينٍ - عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَفْتَرِشْ أَحَدُكُمْ ذِرَاعَيْهِ فِي السُّجُودِ افْتِرَاشَ الْكَلْبِ ‏"‏ ‏.‏\hadithno{1103}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Messenger of Allah (ﷺ) said: "Do not rest your forearms on the ground like a dog when prostrating}}
\hadithdefcmd{nasai}{1104}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ الْمَرْوَزِيُّ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، قَالَ وَصَفَ لَنَا الْبَرَاءُ السُّجُودَ فَوَضَعَ يَدَيْهِ بِالأَرْضِ وَرَفَعَ عَجِيزَتَهُ وَقَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{1104}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Ishaq said:"Al-Bara' described the prostration to us. He places his hands on the ground and raised his posterior and said: 'This is what I saw the Messenger of Allah (ﷺ) doing}}
\hadithdefcmd{nasai}{1105}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ الْمَرْوَزِيُّ، قَالَ أَنْبَأَنَا ابْنُ شُمَيْلٍ، - هُوَ النَّضْرُ - قَالَ أَنْبَأَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا صَلَّى جَخَّى ‏.‏\hadithno{1105}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Bara' that:When the Messenger of Allah (ﷺ) prayed he would Jakhkha}}
\hadithdefcmd{nasai}{1106}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرٌ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكِ ابْنِ بُحَيْنَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا صَلَّى فَرَّجَ بَيْنَ يَدَيْهِ حَتَّى يَبْدُوَ بَيَاضُ إِبْطَيْهِ ‏.‏\hadithno{1106}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abdullah bin Malik bin Buhainah that:When the Messenger of Allah (ﷺ) prayed he held his arms out so much that the whiteness of his armpits appeared}}
\hadithdefcmd{nasai}{1107}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ عِمْرَانَ، عَنْ أَبِي مِجْلَزٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَوْ كُنْتُ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم لأَبْصَرْتُ إِبْطَيْهِ ‏.‏ قَالَ أَبُو مِجْلَزٍ كَأَنَّهُ قَالَ ذَلِكَ لأَنَّهُ فِي صَلاَةٍ ‏.‏\hadithno{1107}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"If I were in front of the Messenger of Allah (ﷺ) I would be able to see the whiteness of his armpits." (One of the narrators) Abu Mijlaz said: "It is as if he said that because he was praying}}
\hadithdefcmd{nasai}{1108}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَقْرَمَ، عَنْ أَبِيهِ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكُنْتُ أَرَى عُفْرَةَ إِبْطَيْهِ إِذَا سَجَدَ ‏.‏\hadithno{1108}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ubaidullah bin Abdullah bin Aqram that his father said:"I prayed with the Messenger of Allah (ﷺ) and I used to see the whiteness of his armpits when he prostrated}}
\hadithdefcmd{nasai}{1109}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ الأَصَمِّ - عَنْ عَمِّهِ، يَزِيدَ - وَهُوَ ابْنُ الأَصَمِّ - عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا سَجَدَ جَافَى يَدَيْهِ حَتَّى لَوْ أَنَّ بَهْمَةً أَرَادَتْ أَنْ تَمُرَّ تَحْتَ يَدَيْهِ مَرَّتْ ‏.‏\hadithno{1109}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Maimunah that:When the Prophet (ﷺ) prostrated he would hold his arms out from his sides so that if a lamb wanted to pass beneath his arms it would be able to do so}}
\hadithdefcmd{nasai}{1110}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، ح وَأَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ خَالِدٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اعْتَدِلُوا فِي السُّجُودِ وَلاَ يَبْسُطْ أَحَدُكُمْ ذِرَاعَيْهِ انْبِسَاطَ الْكَلْبِ ‏"‏ ‏.‏ اللَّفْظُ لإِسْحَاقَ ‏.‏\hadithno{1110}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qatadah said:"I heard Anas (narrate) that the Messenger of Allah (ﷺ) said: 'Be moderate in prostration and do not rest your forearms along the ground like a dog}}
\hadithdefcmd{nasai}{1111}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ الْمَرْوَزِيُّ، قَالَ أَنْبَأَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ - عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُجْزِئُ صَلاَةٌ لاَ يُقِيمُ الرَّجُلُ فِيهَا صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ ‏"‏ ‏.‏\hadithno{1111}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Mas'ud said:"The Messenger of Allah (ﷺ) said: 'No prayer is valid in which a man does not maintain his back (at ease) when bowing and prostrating}}
\hadithdefcmd{nasai}{1112}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ جَعْفَرِ بْنِ عَبْدِ اللَّهِ، أَنَّ تَمِيمَ بْنَ مَحْمُودٍ، أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ شِبْلٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَلاَثٍ عَنْ نَقْرَةِ الْغُرَابِ وَافْتِرَاشِ السَّبُعِ وَأَنْ يُوَطِّنَ الرَّجُلُ الْمُقَامَ لِلصَّلاَةِ كَمَا يُوَطِّنُ الْبَعِيرُ ‏.‏\hadithno{1112}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abdur-Rahman bin Shibl said:The Messenger of Allah (ﷺ) forbade three things: "Pecking like a crow, resting one's forearms on the ground like a predator, and allocating the same place for prayer like a camel gets used to a certain place}}
\hadithdefcmd{nasai}{1113}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ الْبَصْرِيُّ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا شُعْبَةُ، وَرَوْحٌ، - يَعْنِي ابْنَ الْقَاسِمِ - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةٍ وَلاَ أَكُفَّ شَعْرًا وَلاَ ثَوْبًا ‏"‏ ‏.‏\hadithno{1113}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that :The Messenger of Allah (ﷺ) said: "I have been commanded to prostrate on seven and not to tuck up my hair or garment}}
\hadithdefcmd{nasai}{1114}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو السَّرْحِيُّ، - مِنْ وَلَدِ عَبْدِ اللَّهِ بْنِ سَعْدِ بْنِ أَبِي سَرْحٍ - قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ كُرَيْبًا مَوْلَى ابْنِ عَبَّاسٍ حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ رَأَى عَبْدَ اللَّهِ بْنَ الْحَارِثِ يُصَلِّي وَرَأْسُهُ مَعْقُوصٌ مِنْ وَرَائِهِ فَقَامَ فَجَعَلَ يَحُلُّهُ فَلَمَّا انْصَرَفَ أَقْبَلَ إِلَى ابْنِ عَبَّاسٍ فَقَالَ مَا لَكَ وَرَأْسِي قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا مَثَلُ هَذَا مَثَلُ الَّذِي يُصَلِّي وَهُوَ مَكْتُوفٌ ‏"‏ ‏.‏\hadithno{1114}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that:He saw 'Abdullah bin Al-Harith praying with his hair bound behind him. He stopped and started to undo it. When he finished he turned to Ibn 'Abbas and said: "What were you doing to my head?" He said: "I heard the Messenger of Allah (ﷺ) say: 'The likeness of this is that of one who prays with his hands tie behind his neck}}
\hadithdefcmd{nasai}{1115}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الْمَكِّيُّ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ وَنُهِيَ أَنْ يَكُفَّ الشَّعْرَ وَالثِّيَابَ ‏.‏\hadithno{1115}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Prophet (ﷺ) was commanded to prostrate on seven bones and was forbidden to tuck up his hair and garment}}
\hadithdefcmd{nasai}{1116}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ خَالِدِ بْنِ عَبْدِ الرَّحْمَنِ، - هُوَ السَّلَمِيُّ - قَالَ حَدَّثَنِي غَالِبٌ الْقَطَّانُ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنْ أَنَسٍ، قَالَ كُنَّا إِذَا صَلَّيْنَا خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالظَّهَائِرِ سَجَدْنَا عَلَى ثِيَابِنَا اتِّقَاءَ الْحَرِّ ‏.‏\hadithno{1116}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"When he prayed Zuhr behind the Messenger of Allah (ﷺ) we would prostrate on our garments because of the heat}}
\hadithdefcmd{nasai}{1117}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَتِمُّوا الرُّكُوعَ وَالسُّجُودَ فَوَاللَّهِ إِنِّي لأَرَاكُمْ مِنْ خَلْفِ ظَهْرِي فِي رُكُوعِكُمْ وَسُجُودِكُمْ ‏"‏ ‏.‏\hadithno{1117}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Messenger of Allah (ﷺ) said: "Bow and prostrate properly, for by Allah (SWT) I can see you from behind my back when you bow and prostrate}}
\hadithdefcmd{nasai}{1118}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، وَعُثْمَانُ بْنُ عُمَرَ، قَالَ أَبُو عَلِيٍّ حَدَّثَنَا وَقَالَ، عُثْمَانُ أَنْبَأَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، - رضى الله عنه - قَالَ نَهَانِي حِبِّي صلى الله عليه وسلم عَنْ ثَلاَثٍ - لاَ أَقُولُ نَهَى النَّاسَ - نَهَانِي عَنْ تَخَتُّمِ الذَّهَبِ وَعَنْ لُبْسِ الْقَسِّيِّ وَعَنِ الْمُعَصْفَرِ الْمُفَدَّمَةِ وَلاَ أَقْرَأُ سَاجِدًا وَلاَ رَاكِعًا ‏"‏ ‏.‏\hadithno{1118}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali bin Abi Talib said:"My beloved (ﷺ) forbade me from doing three things, but I do not say that he forbade the people. He forbade me from wearing gold rings, wearing Qassi, wearing clothes dyed with safflower Mufaddamah, and from reciting the Quran when prostrating or bowing}}
\hadithdefcmd{nasai}{1119}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَلِيًّا، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقْرَأَ رَاكِعًا أَوْ سَاجِدًا ‏.‏\hadithno{1119}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ali said:"The Messenger of Allah (ﷺ) forbade me from reciting the Quran when bowing or prostrating}}
\hadithdefcmd{nasai}{1120}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ الْمَرْوَزِيُّ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، - هُوَ ابْنُ جَعْفَرٍ - قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ سُحَيْمٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كَشَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم السِّتْرَ وَرَأْسُهُ مَعْصُوبٌ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ فَقَالَ ‏ "‏ اللَّهُمَّ قَدْ بَلَّغْتُ - ثَلاَثَ مَرَّاتٍ - إِنَّهُ لَمْ يَبْقَ مِنْ مُبَشِّرَاتِ النُّبُوَّةِ إِلاَّ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الْعَبْدُ أَوْ تُرَى لَهُ أَلاَ وَإِنِّي قَدْ نُهِيتُ عَنِ الْقِرَاءَةِ فِي الرُّكُوعِ وَالسُّجُودِ فَإِذَا رَكَعْتُمْ فَعَظِّمُوا رَبَّكُمْ وَإِذَا سَجَدْتُمْ فَاجْتَهِدُوا فِي الدُّعَاءِ فَإِنَّهُ قَمِنٌ أَنْ يُسْتَجَابَ لَكُمْ ‏"‏ ‏.‏\hadithno{1120}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin 'Abbas said:"The Messenger of Allah (ﷺ) drew aside the curtain when he had a cloth wrapped around his head during his final illness, and said: 'O Allah, I have conveyed (the Message)' three times. 'There is nothing left of the features of Prophethood except a good dream that a person sees or is seen by others for him. But I have been forbidden to recite the Qur'an when bowing and prostrating, so when you bow, then glorify your Lord and when you prostrate, then strive hard in supplication, for it is more deserving of a response}}
\hadithdefcmd{nasai}{1121}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي رِشْدِينَ، - وَهُوَ كُرَيْبٌ - عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ بِنْتِ الْحَارِثِ وَبَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَهَا فَرَأَيْتُهُ قَامَ لِحَاجَتِهِ فَأَتَى الْقِرْبَةَ فَحَلَّ شِنَاقَهَا ثُمَّ تَوَضَّأَ وُضُوءًا بَيْنَ الْوُضُوءَيْنِ ثُمَّ أَتَى فِرَاشَهُ فَنَامَ ثُمَّ قَامَ قَوْمَةً أُخْرَى فَأَتَى الْقِرْبَةَ فَحَلَّ شِنَاقَهَا ثُمَّ تَوَضَّأَ وُضُوءًا هُوَ الْوُضُوءُ ثُمَّ قَامَ يُصَلِّي وَكَانَ يَقُولُ فِي سُجُودِهِ ‏ "‏ اللَّهُمَّ اجْعَلْ فِي قَلْبِي نُورًا وَاجْعَلْ فِي سَمْعِي نُورًا وَاجْعَلْ فِي بَصَرِي نُورًا وَاجْعَلْ مِنْ تَحْتِي نُورًا وَاجْعَلْ مِنْ فَوْقِي نُورًا وَعَنْ يَمِينِي نُورًا وَعَنْ يَسَارِي نُورًا وَاجْعَلْ أَمَامِي نُورًا وَاجْعَلْ خَلْفِي نُورًا وَأَعْظِمْ لِي نُورًا ‏"‏ ‏.‏ ثُمَّ نَامَ حَتَّى نَفَخَ فَأَتَاهُ بِلاَلٌ فَأَيْقَظَهُ لِلصَّلاَةِ ‏.‏\hadithno{1121}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I stayed overnight with my maternal aunt Maimunah bin Al-Harith, and the Messenger of Allah (ﷺ) stayed overnight with her. I saw him get up to relieve himself and he went to the waterskin and undid its string, then he performed wudu and that was moderate (in the amount of water used). Then he went to his bed and slept. Then he got up again and went to the waterskin and undid its string, and performed wudu again, like the first time. Then he stood and prayed, and when he prostrated he said: 'Allahummaj'al fi qalbi nuran waj'al fi sami' nuran waj'al fi basri nuran, waj'al min tahti nuran waj'al min fawqi nuran, wa 'an yamii nuran wa 'an yasari nuran waj'al amami nuran, waj'al khalfi nuran wa a'zimli nura (O Allah, place light in my heart, and place light in my hearing, and place light in my seeing, and place light beneath me, and place light above me, and light on my right, and light on my left, and place light behind me, and make the light greater for me.') Then he slept until he started to snore, then Bilal came and woke him up for the prayer}}
\hadithdefcmd{nasai}{1122}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ رَبَّنَا وَبِحَمْدِكَ اللَّهُمَّ اغْفِرْ لِي ‏"‏ ‏.‏ يَتَأَوَّلُ الْقُرْآنَ ‏.‏\hadithno{1122}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used to say when bowing and prostrating: 'Subhanakallahumma, Rabbana wa bihamdik. Allahumma-ghfirli (Glory be to You O Allah, Our Lord, and praise. O Allah, forgive me," following the command of the Quran)}}
\hadithdefcmd{nasai}{1123}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ رَبَّنَا وَبِحَمْدِكَ اللَّهُمَّ اغْفِرْ لِي ‏"‏ ‏.‏ يَتَأَوَّلُ الْقُرْآنَ ‏.‏\hadithno{1123}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used to say when bowing and prostrating: 'Subhanaka Allahumma, Rabbana wa bihamdik. Allahumma-ghfirli (Glory be to You O Allah, Our Lord, and praise. O Allah, forgive me," following the command of the Quran)}}
\hadithdefcmd{nasai}{1124}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، قَالَ قَالَتْ عَائِشَةُ رضى الله عنها فَقَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ مَضْجَعِهِ فَجَعَلْتُ أَلْتَمِسُهُ وَظَنَنْتُ أَنَّهُ أَتَى بَعْضَ جَوَارِيهِ فَوَقَعَتْ يَدِي عَلَيْهِ وَهُوَ سَاجِدٌ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي مَا أَسْرَرْتُ وَمَا أَعْلَنْتُ ‏"‏ ‏.‏\hadithno{1124}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:"I noticed that the Messenger of Allah (ﷺ) was missing from bed, so I started to look for him, and I thought that he had gone to one of his concubines. Then my hand fell on him when he was prostrating and saying: "Allahummaghfirli ma asrartu wa ma a'lant (O Allah, forgive me for what (sin) I have concealed and what I have done openly}}
\hadithdefcmd{nasai}{1125}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ فَقَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَظَنَنْتُ أَنَّهُ أَتَى بَعْضَ جَوَارِيهِ فَطَلَبْتُهُ فَإِذَا هُوَ سَاجِدٌ يَقُولُ ‏ "‏ رَبِّ اغْفِرْ لِي مَا أَسْرَرْتُ وَمَا أَعْلَنْتُ ‏"‏ ‏.‏\hadithno{1125}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Aishah said:"I noticed that the Messenger of Allah (ﷺ) was missing and I thought he had gone to visit one of his concubines, so I looked for him and found him prostrating and saying: 'Rabbighfirli ma asrartu wa ma a'lant (O Allah, forgive me for what (sin) I have concealed and what I have done openly}}
\hadithdefcmd{nasai}{1126}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - هُوَ ابْنُ مَهْدِيٍّ - قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، قَالَ حَدَّثَنِي عَمِّي الْمَاجِشُونُ بْنُ أَبِي سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَجَدَ يَقُولُ ‏ "‏ اللَّهُمَّ لَكَ سَجَدْتُ وَلَكَ أَسْلَمْتُ وَبِكَ آمَنْتُ سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَصَوَّرَهُ فَأَحْسَنَ صُورَتَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ تَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏\hadithno{1126}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Ali that:When the Messenger of Allah (ﷺ) prostrated he would say: "Allahumma laka sajadtu wa laka aslamtu wa bika amantu sajada wajhi lilladhi khalaqahu wa sawwarahu fa ahsana suratahu wa shaqqa sam'ahu wa basarahu, tabarak Allahu ahsanul-khaliqin ( O Allah, to You I have prostrated and to You I have submitted, and in You I have believed. My face has prostrated to the One Who created it and shaped it and shaped it well, and brought forth its hearing and sight. Blessed be Allah the best of Creators)}}
\hadithdefcmd{nasai}{1127}{أَخْبَرَنَا يَحْيَى بْنُ عُثْمَانَ، قَالَ أَنْبَأَنَا أَبُو حَيْوَةَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم كَانَ يَقُولُ فِي سُجُودِهِ ‏ "‏ اللَّهُمَّ لَكَ سَجَدْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ وَأَنْتَ رَبِّي سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَصَوَّرَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ تَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏\hadithno{1127}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:The Prophet (ﷺ) used to say when prostrating: "Allahumma laka sajadtu wa laka aslamtu wa anta Rabbi, sajada wajhi lilladhi khalaqahu wa sawwarahu wa shaqqa sam'ahu wa basarahu, tabarak Allahu ahsanul-khaliqin ( O Allah, to You I have prostrated and in You I have believed and to You I have submitted, and You are my Lord. My face has prostrated to the One Who created it and formed it, and brought forth its hearing and sight. Blessed be Allah the best of Creators)}}
\hadithdefcmd{nasai}{1128}{أَخْبَرَنَا يَحْيَى بْنُ عُثْمَانَ، قَالَ أَنْبَأَنَا ابْنُ حِمْيَرٍ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَذَكَرَ، آخَرَ قَبْلَهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ الأَعْرَجِ، عَنْ مُحَمَّدِ بْنِ مَسْلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ مِنَ اللَّيْلِ يُصَلِّي تَطَوُّعًا قَالَ إِذَا سَجَدَ ‏ "‏ اللَّهُمَّ لَكَ سَجَدْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ اللَّهُمَّ أَنْتَ رَبِّي سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَصَوَّرَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ تَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏\hadithno{1128}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Muhammad bin Maslamah that:When the Messenger of Allah (ﷺ) got up to offer voluntary prayers at night, he would say when he prostrated: "Allahumma laka sajadtu wa bika amantu wa laka aslamtu, Allahumma anta Rabbi, sajada wajhi lilladhi khalaqahu wa sawwarahu wa shaqqa sam'ahu wa basarahu, tabarak Allahu ahsanul-khaliqin ( O Allah, to You I have prostrated and in You I have believed and to You I have submitted. O Allah, You are my Lord. My face has prostrated to the One Who created it and formed it, and brought forth its hearing and sight. Blessed be Allah the best of Creators)}}
\hadithdefcmd{nasai}{1129}{أَخْبَرَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ بْنِ سَوَّارٍ الْقَاضِي، وَمُحَمَّدُ بْنُ بَشَّارٍ، عَنْ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي الْعَالِيَةِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ فِي سُجُودِ الْقُرْآنِ بِاللَّيْلِ ‏ "‏ سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ بِحَوْلِهِ وَقُوَّتِهِ ‏"‏ ‏.‏\hadithno{1129}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aishah that:The Prophet (ﷺ) used to say, when he did a prostration that was required when reciting Quran at night: "Sajada wajhi lilladhi khalaqahu wa sawwarahu wa shaqqa sam'ahu wa basarahu bihawlihi wa quwwatih (My face has prostrated to the One Who created it and formed it, and brought forth its hearing and sight by His power and strength)}}
\hadithdefcmd{nasai}{1130}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَوَجَدْتُهُ وَهُوَ سَاجِدٌ وَصُدُورُ قَدَمَيْهِ نَحْوَ الْقِبْلَةِ فَسَمِعْتُهُ يَقُولُ ‏ "‏ أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَأَعُوذُ بِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏\hadithno{1130}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I noticed the Messenger of Allah (ﷺ) was missing one night and I found him prostrating with the tops of his feet facing toward the Qiblah. I heard him saying: 'A'udhu biridaka min sakhatika, wa a'udhu bimu 'afatika min 'uqubatika wa a'udhu bika minka la uhsi thana'an 'alaika anta kama athnaita 'ala nafsik (I seek refuge in Your pleasure from Your wrath; I seek refuge in Your forgiveness from Your punishment; I seek refuge in You from You. I cannot praise You enough, You are as You have praised Yourself)}}
\hadithdefcmd{nasai}{1131}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ الْمِصِّيصِيُّ الْمِقْسَمِيُّ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَظَنَنْتُ أَنَّهُ ذَهَبَ إِلَى بَعْضِ نِسَائِهِ فَتَحَسَّسْتُهُ فَإِذَا هُوَ رَاكِعٌ أَوْ سَاجِدٌ يَقُولُ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ فَقُلْتُ بِأَبِي أَنْتَ وَأُمِّي إِنِّي لَفِي شَأْنٍ وَإِنَّكَ لَفِي آخَرَ ‏.‏\hadithno{1131}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"I noticed that the Messenger of Allah (ﷺ) was missing one night, and I thought he had gone to one of his other wives. I tried to feel for him, and I found him bowing or prostrating and saying: 'SubhanakAllahumma wa bihamdika la ilaha ila ant (Glory and praise be to You, O Allah, there is none worthy of worship but You.)'" She said: "May my father and mother be ransomed for you. I thought you were doing one thing and you were doing something else altogether}}
\hadithdefcmd{nasai}{1132}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ سَوَّارٍ، قَالَ حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَمْرِو بْنِ قَيْسٍ الْكِنْدِيِّ، أَنَّهُ سَمِعَ عَاصِمَ بْنَ حُمَيْدٍ، يَقُولُ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ، يَقُولُ قُمْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَبَدَأَ فَاسْتَاكَ وَتَوَضَّأَ ثُمَّ قَامَ فَصَلَّى فَبَدَأَ فَاسْتَفْتَحَ مِنَ الْبَقَرَةِ لاَ يَمُرُّ بِآيَةِ رَحْمَةٍ إِلاَّ وَقَفَ وَسَأَلَ وَلاَ يَمُرُّ بِآيَةِ عَذَابٍ إِلاَّ وَقَفَ يَتَعَوَّذُ ثُمَّ رَكَعَ فَمَكَثَ رَاكِعًا بِقَدْرِ قِيَامِهِ يَقُولُ فِي رُكُوعِهِ ‏"‏ سُبْحَانَ ذِي الْجَبَرُوتِ وَالْمَلَكُوتِ وَالْكِبْرِيَاءِ وَالْعَظَمَةِ ‏"‏ ‏.‏ ثُمَّ سَجَدَ بِقَدْرِ رُكُوعِهِ يَقُولُ فِي سُجُودِهِ ‏"‏ سُبْحَانَ ذِي الْجَبَرُوتِ وَالْمَلَكُوتِ وَالْكِبْرِيَاءِ وَالْعَظَمَةِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ آلَ عِمْرَانَ ثُمَّ سُورَةً ثُمَّ سُورَةً فَعَلَ مِثْلَ ذَلِكَ ‏.‏\hadithno{1132}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Awf bin Malik said:"I prayed Qiyam with the Prophet (ﷺ). He started by using the Siwak and performing wudu, then he stood and prayed. He started reciting Al-Baqarah and he did not come to any verse that spoke of mercy but he paused and asked for mercy, and he did not come to any verse that spoke of punishment but he paused (and sought refuge with Allah from that). Then he bowed and he stayed bowing for as long as he had stood,a nd he said while bowing: 'Subhanaka Dhil-jabaraut wal-malakut wal-kibriya' wal-'azamah (Glory be to the One Who has all power, sovereignty, magnificence and might.)' Then he prostrated for as long as he had bowed, saying while prostrating: 'Subhana Dhil-jabarut wal-malakut wal-kibriya' wal-'azamah (Glory be to the One Who has all power, sovereignty, magnificence and might.)' Then he recited Al Imran, then another surah and another, doing that each time}}
\hadithdefcmd{nasai}{1133}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْمُسْتَوْرِدِ بْنِ الأَحْنَفِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَاسْتَفْتَحَ بِسُورَةِ الْبَقَرَةِ فَقَرَأَ بِمِائَةِ آيَةٍ لَمْ يَرْكَعْ فَمَضَى قُلْتُ يَخْتِمُهَا فِي الرَّكْعَتَيْنِ فَمَضَى قُلْتُ يَخْتِمُهَا ثُمَّ يَرْكَعُ فَمَضَى حَتَّى قَرَأَ سُورَةَ النِّسَاءِ ثُمَّ قَرَأَ سُورَةَ آلِ عِمْرَانَ ثُمَّ رَكَعَ نَحْوًا مِنْ قِيَامِهِ يَقُولُ فِي رُكُوعِهِ ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ سُبْحَانَ رَبِّيَ الْعَظِيمِ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏.‏ ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا لَكَ الْحَمْدُ ‏"‏ ‏.‏ وَأَطَالَ الْقِيَامَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ يَقُولُ فِي سُجُودِهِ ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى سُبْحَانَ رَبِّيَ الأَعْلَى سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ‏.‏ لاَ يَمُرُّ بِآيَةِ تَخْوِيفٍ أَوْ تَعْظِيمٍ لِلَّهِ عَزَّ وَجَلَّ إِلاَّ ذَكَرَهُ ‏.‏\hadithno{1133}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hudhaifah said:"I prayed with the Messenger of Allah (ﷺ) one night. He started reciting Surat Al-Baqarah and he recited one hundred verses, then did not bow, rather he continued. I thought: 'He will complete it in two rak'ahs, but he continued.' I thought: 'He will complete it and then bow,' but he continued until he recited Surat An-Nisa', then Al Imran. Then he bowed for almost as long as he had stood, saying while bowing: 'Subhan Rabbial-azim, Subhan Rabbial-azim, Subhan Rabbial-azim ( Glory be to my Lord Almighty, Glory be to my Lord Almighty, Glory be to my Lord Almighty).' Then he raised his head and said: 'Sami Allahu liman hamidah (Allah hears the one who praises Him). Then he prostrated and made his prostration lengthy, saying: "Subhan Rabbial-A'la, Subhan Rabbial-A'la, Subhan Rabbial-A'la (Glory be to my Lord Most High, Glory be to my Lord Most High, Glory be to my Lord Most High). And he did not come to any verse that spoke of fear or glorifying Allah, the Mighty and Sublime, but he said something appropriate}}
\hadithdefcmd{nasai}{1134}{أَخْبَرَنَا بُنْدَارٌ، مُحَمَّدُ بْنُ بَشَّارٍ قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، وَابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، قَالاَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبُّوحٌ قُدُّوسٌ رَبُّ الْمَلاَئِكَةِ وَالرُّوحِ ‏"‏ ‏.‏\hadithno{1134}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) said when bowing and prostrating: 'Subbuhun Quddusun Rabbul-mala'ikati war'ruh (Perfect, Most Holy, Lord of the Angels and the Spirit)}}
\hadithdefcmd{nasai}{1135}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِبْرَاهِيمَ بْنِ عُمَرَ بْنِ كَيْسَانَ، قَالَ حَدَّثَنِي أَبِي، عَنْ وَهْبِ بْنِ مَانُوسٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ مَا رَأَيْتُ أَحَدًا أَشْبَهَ صَلاَةً بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ هَذَا الْفَتَى - يَعْنِي عُمَرَ بْنَ عَبْدِ الْعَزِيزِ - فَحَزَرْنَا فِي رُكُوعِهِ عَشْرَ تَسْبِيحَاتٍ وَفِي سُجُودِهِ عَشْرَ تَسْبِيحَاتٍ ‏.‏\hadithno{1135}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas bin Malik said:"I have never seen anyone whose prayer more closely resembles the prayer of the Messenger of Allah (ﷺ) than this young man- meaning 'Umar bin Abdul-aziz. And we estimated that when bowing he said the Tasbih ten times and when prostrating he said the Tasbih ten times}}
\hadithdefcmd{nasai}{1136}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ أَبُو يَحْيَى، بِمَكَّةَ - وَهُوَ بَصْرِيٌّ - قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّ عَلِيَّ بْنَ يَحْيَى بْنِ خَلاَّدِ بْنِ مَالِكِ بْنِ رَافِعِ بْنِ مَالِكٍ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَمِّهِ، رِفَاعَةَ بْنِ رَافِعٍ قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ وَنَحْنُ حَوْلَهُ إِذْ دَخَلَ رَجُلٌ فَأَتَى الْقِبْلَةَ فَصَلَّى فَلَمَّا قَضَى صَلاَتَهُ جَاءَ فَسَلَّمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَى الْقَوْمِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ اذْهَبْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَذَهَبَ فَصَلَّى فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْمُقُ صَلاَتَهُ وَلاَ يَدْرِي مَا يَعِيبُ مِنْهَا فَلَمَّا قَضَى صَلاَتَهُ جَاءَ فَسَلَّمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَى الْقَوْمِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ اذْهَبْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَأَعَادَهَا مَرَّتَيْنِ أَوْ ثَلاَثًا فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ مَا عِبْتَ مِنْ صَلاَتِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا لَمْ تَتِمَّ صَلاَةُ أَحَدِكُمْ حَتَّى يُسْبِغَ الْوُضُوءَ كَمَا أَمَرَهُ اللَّهُ عَزَّ وَجَلَّ فَيَغْسِلَ وَجْهَهُ وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ وَيَمْسَحَ بِرَأْسِهِ وَرِجْلَيْهِ إِلَى الْكَعْبَيْنِ ثُمَّ يُكَبِّرَ اللَّهَ عَزَّ وَجَلَّ وَيَحْمَدَهُ وَيُمَجِّدَهُ ‏"‏ ‏.‏ قَالَ هَمَّامٌ وَسَمِعْتُهُ يَقُولُ ‏"‏ وَيَحْمَدَ اللَّهَ وَيُمَجِّدَهُ وَيُكَبِّرَهُ ‏"‏ ‏.‏ قَالَ فَكِلاَهُمَا قَدْ سَمِعْتُهُ يَقُولُ قَالَ ‏"‏ وَيَقْرَأَ مَا تَيَسَّرَ مِنَ الْقُرْآنِ مِمَّا عَلَّمَهُ اللَّهُ وَأَذِنَ لَهُ فِيهِ ثُمَّ يُكَبِّرَ وَيَرْكَعَ حَتَّى تَطْمَئِنَّ مَفَاصِلُهُ وَتَسْتَرْخِيَ ثُمَّ يَقُولَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ثُمَّ يَسْتَوِيَ قَائِمًا حَتَّى يُقِيمَ صُلْبَهُ ثُمَّ يُكَبِّرَ وَيَسْجُدَ حَتَّى يُمَكِّنَ وَجْهَهُ ‏"‏ ‏.‏ وَقَدْ سَمِعْتُهُ يَقُولُ ‏"‏ جَبْهَتَهُ حَتَّى تَطْمَئِنَّ مَفَاصِلُهُ وَتَسْتَرْخِيَ وَيُكَبِّرَ فَيَرْفَعَ حَتَّى يَسْتَوِيَ قَاعِدًا عَلَى مَقْعَدَتِهِ وَيُقِيمَ صُلْبَهُ ثُمَّ يُكَبِّرَ فَيَسْجُدَ حَتَّى يُمَكِّنَ وَجْهَهُ وَيَسْتَرْخِيَ فَإِذَا لَمْ يَفْعَلْ هَكَذَا لَمْ تَتِمَّ صَلاَتُهُ ‏"‏ ‏.‏\hadithno{1136}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Rifa'ah bin Rafi' said:"While the Messenger of Allah (ﷺ) was sitting with us around him, a man came in, turned towards the Qiblah and prayed. When he had finished his prayer, he came and greeted the Messenger of Allah (ﷺ) and the people with Salam. The Messenger of Allah (ﷺ) said to him: 'And also to you. Go and pray, for you have not prayed.' So he went and prayed, and the Messenger of Allah (ﷺ) started watching him, and he (the man) did not know what was wrong with it. When he had finished the prayer, he came and greeted the Messenger of Allah (ﷺ) and the people with salam. The Messenger of Allah (ﷺ) said to him: 'And also to you. Go and pray, for you have not prayed.' He repeated it two or three times, then the man said: 'O Messenger of Allah, what is wrong with my prayer?' The Messenger of Allah (ﷺ) said: 'The prayer of any of you is not complete unless he performs wudu properly as enjoined by Allah, the Mighty and Sublime. So he should wash his face, his arms up to the elbows, and wipe his head, and (wash) his feet up to the ankles. Then he should magnify Allah (SWT) and praise Him and glorify Him.'" - (One of the narrators) Hammam said: "I heard him say: 'He should praise Allah and glorify Him and magnify Him." He said: "I heard both of them." -"He (the Prophet (ﷺ)) said: 'He should recite whatever is easy for him of the Quran that Allah has taught him and permitted him in it (the prayer). Then he should say the Takbir and bow until his joints settle and he is relaxed. Then he should say: 'Sami Allahu liman hamidah (Allah hears the one who praises Him)' and stand up straight until his backbone is straight (and at ease). Then he should say Takbir and prostrate until he has placed his face firmly on the ground." "I heard him say: his forehead, until his joints settle and he is relaxed. Then he should say the Takbir and sit up until his backbone is straight (and at ease). Then he should prostrate until he has placed his face firmly on the ground and he is relaxed. If he does not do that then he has not completed his prayer}}
\hadithdefcmd{nasai}{1137}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرٍو، - يَعْنِي ابْنَ الْحَارِثِ - عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ سُمَىٍّ، أَنَّهُ سَمِعَ أَبَا صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَقْرَبُ مَا يَكُونُ الْعَبْدُ مِنْ رَبِّهِ عَزَّ وَجَلَّ وَهُوَ سَاجِدٌ فَأَكْثِرُوا الدُّعَاءَ ‏"‏ ‏.‏\hadithno{1137}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "The closest that a person can be to his Lord, the Mighty and Sublime, is when he is prostrating, so increase in supplication then}}
\hadithdefcmd{nasai}{1138}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، عَنْ هِقْلِ بْنِ زِيَادٍ الدِّمَشْقِيِّ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي رَبِيعَةُ بْنُ كَعْبٍ الأَسْلَمِيُّ، قَالَ كُنْتُ آتِي رَسُولَ اللَّهِ صلى الله عليه وسلم بِوَضُوئِهِ وَبِحَاجَتِهِ فَقَالَ ‏"‏ سَلْنِي ‏"‏ ‏.‏ قُلْتُ مُرَافَقَتَكَ فِي الْجَنَّةِ ‏.‏ قَالَ ‏"‏ أَوَغَيْرَ ذَلِكَ ‏"‏ ‏.‏ قُلْتُ هُوَ ذَاكَ قَالَ ‏"‏ فَأَعِنِّي عَلَى نَفْسِكَ بِكَثْرَةِ السُّجُودِ ‏"‏ ‏.‏\hadithno{1138}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Rabi'ah bin Ka'b Al-Aslami said:"I used to bring to the Messenger of Allah (ﷺ) water for wudu and serve him. He said: 'Ask of me.' I said: 'I want to be with you in Paradise.' He said: 'Is there anything else?' I said: 'That is all.' He said: 'Help me to fulfill your wish by prostrating a great deal}}
\hadithdefcmd{nasai}{1139}{أَخْبَرَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ هِشَامٍ الْمُعَيْطِيُّ، قَالَ حَدَّثَنِي مَعْدَانُ بْنُ طَلْحَةَ الْيَعْمَرِيُّ، قَالَ لَقِيتُ ثَوْبَانَ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ دُلَّنِي عَلَى عَمَلٍ يَنْفَعُنِي أَوْ يُدْخِلُنِي الْجَنَّةَ فَسَكَتَ عَنِّي مَلِيًّا ثُمَّ الْتَفَتَ إِلَىَّ فَقَالَ عَلَيْكَ بِالسُّجُودِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ عَبْدٍ يَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ رَفَعَهُ اللَّهُ عَزَّ وَجَلَّ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏ قَالَ مَعْدَانُ ثُمَّ لَقِيتُ أَبَا الدَّرْدَاءِ فَسَأَلْتُهُ عَمَّا سَأَلْتُ عَنْهُ ثَوْبَانَ فَقَالَ لِي عَلَيْكَ بِالسُّجُودِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ عَبْدِ يَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏\hadithno{1139}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ma'dan bin Talha Al-Ya'muri said:"I met Thawban, the freed slave of the Messenger of Allah (ﷺ) and said: "Tell me of an action that will benefit me or gain me admittance to Paradise.' He remained silent for a while, then he turned to me and said: 'You should prostrate, because I heard the Messenger of Allah (ﷺ) say: "There is no one who prostrated once to Allah, the Mighty and Sublime, except that Allah will raise him one degree in status thereby, and erase one sin thereby." Ma'dan said: "Then I met Abu Ad-Darda' and asked him the same question I had asked Thawban." He said to me: "You should prostrate, for I heard the Messenger of Allah (ﷺ) say: "There is no one who prostrates once to Allah (SWT), but Allah (SWT) will raise him one degree thereby and erase one sin thereby}}
\hadithdefcmd{nasai}{1140}{أَخْبَرَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، لُوَيْنٌ بِالْمَصِّيصَةِ عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ مَعْمَرٍ، وَالنُّعْمَانِ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، قَالَ كُنْتُ جَالِسًا إِلَى أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ فَحَدَّثَ أَحَدُهُمَا، حَدِيثَ الشَّفَاعَةِ وَالآخَرُ مُنْصِتٌ قَالَ فَتَأْتِي الْمَلاَئِكَةُ فَتَشْفَعُ وَتَشْفَعُ الرُّسُلُ وَذَكَرَ الصِّرَاطَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَأَكُونُ أَوَّلَ مَنْ يُجِيزُ فَإِذَا فَرَغَ اللَّهُ عَزَّ وَجَلَّ مِنَ الْقَضَاءِ بَيْنَ خَلْقِهِ وَأَخْرَجَ مِنَ النَّارِ مَنْ يُرِيدُ أَنْ يُخْرِجَ أَمَرَ اللَّهُ الْمَلاَئِكَةَ وَالرُّسُلَ أَنْ تَشْفَعَ فَيُعْرَفُونَ بِعَلاَمَاتِهِمْ إِنَّ النَّارَ تَأْكُلُ كُلَّ شَىْءٍ مِنِ ابْنِ آدَمَ إِلاَّ مَوْضِعَ السُّجُودِ فَيُصَبُّ عَلَيْهِمْ مِنْ مَاءِ الْجَنَّةِ فَيَنْبُتُونَ كَمَا تَنْبُتُ الْحِبَّةُ فِي حَمِيلِ السَّيْلِ ‏"‏ ‏.‏\hadithno{1140}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ata bin Yazid said:"I was sitting with Abu Hurairah and Abu Sa'eed. One of them narrated the hadith about intercession and the other was listening. He said: 'Then the angels will come and intercede, and the messengers will intercede.' And he mentioned the Sirat, and said: "The Messenger of Allah (ﷺ) said: 'I will be the first one to cross it, and when Allah has finished passing judgment among His creation, and has brought forth from the Fire those whom He wants to bring forth, Allah will command the angels and the messengers to intercede, and they will be recognized by their signs, for the Fire will consume all of the son of Adam apart from the place of prostration. Then the water of life will be poured on them, and they will grow like seeds on the banks of a rainwater stream}}
\hadithdefcmd{nasai}{1141}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي يَعْقُوبَ الْبَصْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ أَبِيهِ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي إِحْدَى صَلاَتَىِ الْعِشَاءِ وَهُوَ حَامِلٌ حَسَنًا أَوْ حُسَيْنًا فَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَوَضَعَهُ ثُمَّ كَبَّرَ لِلصَّلاَةِ فَصَلَّى فَسَجَدَ بَيْنَ ظَهْرَانَىْ صَلاَتِهِ سَجْدَةً أَطَالَهَا ‏.‏ قَالَ أَبِي فَرَفَعْتُ رَأْسِي وَإِذَا الصَّبِيُّ عَلَى ظَهْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ سَاجِدٌ فَرَجَعْتُ إِلَى سُجُودِي فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ قَالَ النَّاسُ يَا رَسُولَ اللَّهِ إِنَّكَ سَجَدْتَ بَيْنَ ظَهْرَانَىْ صَلاَتِكَ سَجْدَةً أَطَلْتَهَا حَتَّى ظَنَنَّا أَنَّهُ قَدْ حَدَثَ أَمْرٌ أَوْ أَنَّهُ يُوحَى إِلَيْكَ ‏.‏ قَالَ ‏ "‏ كُلُّ ذَلِكَ لَمْ يَكُنْ وَلَكِنَّ ابْنِي ارْتَحَلَنِي فَكَرِهْتُ أَنْ أُعَجِّلَهُ حَتَّى يَقْضِيَ حَاجَتَهُ ‏"‏ ‏.‏\hadithno{1141}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin Shaddad, this his father said:"The Messenger of Allah (ﷺ) came out to us for one of the nighttime prayers, and he was carrying Hasan or Husain. The Messenger of Allah (ﷺ) came forward and put him down, then he said the Takbir and started to pray. He prostrated during his prayer, and made the prostration lengthy." My father said: "I raised my head and saw the child on the back of the Messenger of Allah (ﷺ) while he was prostrating so I went back to my prostration. When the Messenger of Allah (ﷺ) finished praying, the people said: "O Messenger of Allah (ﷺ), you prostrated during the prayer for so long that we thought that something had happened or that you were receiving a revelation.' He said: 'No such thing happened. But my son was riding on my back and I did not like to disturb him until he had enough}}
\hadithdefcmd{nasai}{1142}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ دُكَيْنٍ، وَيَحْيَى بْنُ آدَمَ، قَالاَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، وَعَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُكَبِّرُ فِي كُلِّ خَفْضٍ وَرَفْعٍ وَقِيَامٍ وَقُعُودٍ وَيُسَلِّمُ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ ‏ "‏ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ حَتَّى يُرَى بَيَاضُ خَدِّهِ ‏.‏ قَالَ وَرَأَيْتُ أَبَا بَكْرٍ وَعُمَرَ - رضى الله عنهما - يَفْعَلاَنِ ذَلِكَ ‏.‏\hadithno{1142}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin Al-Aswad from his father-and Alqamah-that:Abdullah said: "I saw the Messenger of Allah (ﷺ) say the Takbir every time he went down and got up, or stood or sat; he said the Salam on his right and his left: 'As-salamu alaykum wa rahmatulah (peace be upon you and the mercy of Allah ),' until the whiteness of his cheek could be seen." He said: "And I saw Abu Bakr and 'Umar, may Allah (SWT) be pleased with them both, doing the same}}
\hadithdefcmd{nasai}{1143}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ فِي الصَّلاَةِ رَفَعَ يَدَيْهِ وَإِذَا رَكَعَ فَعَلَ مِثْلَ ذَلِكَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَعَلَ مِثْلَ ذَلِكَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ السُّجُودِ فَعَلَ مِثْلَ ذَلِكَ كُلَّهُ يَعْنِي رَفْعَ يَدَيْهِ ‏.‏\hadithno{1143}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Malik bin Al-Huwairith that:When the Prophet of Allah (ﷺ) started to pray, he raised his hands, and when he bowed, he did likewise, and when he raised his head from bowing he did likewise, and when he raised his head from prostration, he did likewise, meaning he raised his hands}}
\hadithdefcmd{nasai}{1144}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ كَبَّرَ وَرَفَعَ يَدَيْهِ وَإِذَا رَكَعَ وَبَعْدَ الرُّكُوعِ وَلاَ يَرْفَعُ بَيْنَ السَّجْدَتَيْنِ ‏.‏\hadithno{1144}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim that his father said:"When the Prophet (ﷺ) started to pray he said the takbir and raised his hands, and when he bowed, and after bowing, but he did not raise them between the two prostrations}}
\hadithdefcmd{nasai}{1145}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي حَمْزَةَ، سَمِعَهُ يُحَدِّثُ، عَنْ رَجُلٍ، مِنْ عَبْسٍ عَنْ حُذَيْفَةَ، أَنَّهُ انْتَهَى إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَامَ إِلَى جَنْبِهِ فَقَالَ ‏"‏ اللَّهُ أَكْبَرُ ذُو الْمَلَكُوتِ وَالْجَبَرُوتِ وَالْكِبْرِيَاءِ وَالْعَظَمَةِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ بِالْبَقَرَةِ ثُمَّ رَكَعَ فَكَانَ رُكُوعُهُ نَحْوًا مِنْ قِيَامِهِ فَقَالَ فِي رُكُوعِهِ ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏.‏ وَقَالَ حِينَ رَفَعَ رَأْسَهُ ‏"‏ لِرَبِّيَ الْحَمْدُ لِرَبِّيَ الْحَمْدُ ‏"‏ ‏.‏ وَكَانَ يَقُولُ فِي سُجُودِهِ ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ‏.‏ وَكَانَ يَقُولُ بَيْنَ السَّجْدَتَيْنِ ‏"‏ رَبِّ اغْفِرْ لِي رَبِّ اغْفِرْ لِي ‏"‏ ‏.‏\hadithno{1145}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{A man from (the tribe of) 'Abs narrated from Hudhaifah that:He came to the Prophet (ﷺ) and stood by his side, and he said: "Allahu Akbar Dhul-malakut wal-jabarut wal-kibriya' wal 'azamah (Allah is Most Great, the One Who has all sovereignty, power, magnificence, and might.)" Then he recited Al-Baqarah, then he bowed, and his bowing lasted almost as long as his standing, and he said when bowing: 'Subahana Rabbial-'azim, Subhana Rabbial-'azim (Glory be to my Lord Almighty, Glory be to my Lord Almighty)." When he raised his head he said: "Li Rabbial-hamd, Li Rabbial-hamd (To my Lord be praise, to my Lord be praise)." And when he prostrated he said: "Subahana Rabbial-A'la, Subahna Rabbial-A'la (Glory be to my Lord Most High, glory be to my Lord Most High)." And between the two prostrations he would say: "Rabbighfirli, Rabbighfirli (Lord forgive me, Lord forgive me)}}
\hadithdefcmd{nasai}{1146}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ اللَّهِ بْنِ مُوسَى الْبَصْرِيُّ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ كَثِيرٍ أَبُو سَهْلٍ الأَزْدِيُّ، قَالَ صَلَّى إِلَى جَنْبِي عَبْدُ اللَّهِ بْنُ طَاوُسٍ بِمِنًى فِي مَسْجِدِ الْخَيْفِ فَكَانَ إِذَا سَجَدَ السَّجْدَةَ الأُولَى فَرَفَعَ رَأْسَهُ مِنْهَا رَفَعَ يَدَيْهِ تِلْقَاءَ وَجْهِهِ فَأَنْكَرْتُ أَنَا ذَلِكَ فَقُلْتُ لِوُهَيْبِ بْنِ خَالِدٍ إِنَّ هَذَا يَصْنَعُ شَيْئًا لَمْ أَرَ أَحَدًا يَصْنَعُهُ ‏.‏ فَقَالَ لَهُ وُهَيْبٌ تَصْنَعُ شَيْئًا لَمْ نَرَ أَحَدًا يَصْنَعُهُ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ طَاوُسٍ رَأَيْتُ أَبِي يَصْنَعُهُ وَقَالَ أَبِي رَأَيْتُ ابْنَ عَبَّاسٍ يَصْنَعُهُ وَقَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُهُ ‏.‏\hadithno{1146}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{An-Nadr bin Kathir Abu Sahl Al-Aszidi said:"Abdullah bin Tawus prayed beside me at Mina, in Masjid Al-Khaif, and when he made the first prostration he raised his head and raised his hands up to his face. I found that strange and I said to Wuhaib bin Khalid: "This man does something that I have never seen anyone do." Wuhaib said to him: 'You do something that I have never seen anyone do.' Abdullah bin Tawus said: 'I saw my father do it, and my father said: "I saw Ibn 'Abbas do it and 'Abullah bin Abbas said: 'I saw the Messenger of Allah (ﷺ) doing it}}
\hadithdefcmd{nasai}{1147}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، دُحَيْمٌ قَالَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ الأَصَمِّ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ الأَصَمِّ، عَنْ مَيْمُونَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَجَدَ خَوَّى بِيَدَيْهِ حَتَّى يُرَى وَضَحُ إِبْطَيْهِ مِنْ وَرَائِهِ وَإِذَا قَعَدَ اطْمَأَنَّ عَلَى فَخِذِهِ الْيُسْرَى ‏.‏\hadithno{1147}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Maimunah said:"When the Messenger of Allah (ﷺ) prostrated, he would hold his arms out to his sides, so that the whiteness of his armpits could be seen from behind. And when he sat he rested on his left thigh}}
\hadithdefcmd{nasai}{1148}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو قُدَامَةَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي الْحَكَمُ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ، قَالَ كَانَ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم رُكُوعُهُ وَسُجُودُهُ وَقِيَامُهُ بَعْدَ مَا يَرْفَعُ رَأْسَهُ مِنَ الرُّكُوعِ وَبَيْنَ السَّجْدَتَيْنِ قَرِيبًا مِنَ السَّوَاءِ ‏.‏\hadithno{1148}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Al-Bara' said:"In the prayer of the Messenger of Allah (ﷺ), his bowing, his prostration, standing after he raised his head from bowing and (sitting) between the two prostrations, were almost the same}}
\hadithdefcmd{nasai}{1149}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكَبِّرُ فِي كُلِّ رَفْعٍ وَوَضْعٍ وَقِيَامٍ وَقُعُودٍ وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ رضى الله عنهم ‏.‏\hadithno{1149}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abdullah said:"The Messenger of Allah (ﷺ) used to say the takbir every time he got up, went down, stood and sat. Abu Bakr, 'Umar, and 'Uthman (did likewise)}}
\hadithdefcmd{nasai}{1150}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا حُجَيْنٌ، - وَهُوَ ابْنُ الْمُثَنَّى - قَالَ حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ يُكَبِّرُ حِينَ يَقُومُ ثُمَّ يُكَبِّرُ حِينَ يَرْكَعُ ثُمَّ يَقُولُ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ حِينَ يَرْفَعُ صُلْبَهُ مِنَ الرَّكْعَةِ ثُمَّ يَقُولُ وَهُوَ قَائِمٌ ‏"‏ رَبَّنَا لَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ يُكَبِّرُ حِينَ يَهْوِي سَاجِدًا ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ ثُمَّ يُكَبِّرُ حِينَ يَسْجُدُ ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ ثُمَّ يَفْعَلُ ذَلِكَ فِي الصَّلاَةِ كُلِّهَا حَتَّى يَقْضِيَهَا وَيُكَبِّرُ حِينَ يَقُومُ مِنَ الثِّنْتَيْنِ بَعْدَ الْجُلُوسِ ‏.‏\hadithno{1150}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:"When the Messenger of Allah (ﷺ) stood to pray, he said the takbir, when he (started), then he said the takbir when he bowed, then he said: 'Sami Allahu liman hamidah (Allah hears the one who praises Him)', when he stood up from bowing. Then he said when he was standing: 'Rabbana lakal-hamd.' Then he said the takbir when he went down in prostration, then he said the takbir when he raised his head, and he did that throughout the entire prayer until he finished it, and he said the takbir when he stood up after the first two rak'ahs, after sitting}}
\hadithdefcmd{nasai}{1151}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، قَالَ جَاءَنَا أَبُو سُلَيْمَانَ مَالِكُ بْنُ الْحُوَيْرِثِ إِلَى مَسْجِدِنَا فَقَالَ أُرِيدُ أَنْ أُرِيَكُمْ كَيْفَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي ‏.‏ قَالَ فَقَعَدَ فِي الرَّكْعَةِ الأُولَى حِينَ رَفَعَ رَأْسَهُ مِنَ السَّجْدَةِ الآخِرَةِ ‏.‏\hadithno{1151}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abi Qibalah said:"Abu Sulaiman Malik bin Al-Huwairith came to our masjid and said: "I want to show you how I saw the Messenger of Allah (ﷺ) pray.'" He said: "He sat during the first Rak'ah when he raised his head from the second prostration}}
\hadithdefcmd{nasai}{1152}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا هُشَيْمٌ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فَإِذَا كَانَ فِي وَتْرٍ مِنْ صَلاَتِهِ لَمْ يَنْهَضْ حَتَّى يَسْتَوِيَ جَالِسًا ‏.‏\hadithno{1152}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Malik bin Al-Huwairith said:"I saw the Messenger of Allah (ﷺ) pray, and when he was in an odd-numbered rak'ah, he did not get up until he had settled in a sitting position}}
\hadithdefcmd{nasai}{1153}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، قَالَ كَانَ مَالِكُ بْنُ الْحُوَيْرِثِ يَأْتِينَا فَيَقُولُ أَلاَ أُحَدِّثُكُمْ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَيُصَلِّي فِي غَيْرِ وَقْتِ الصَّلاَةِ فَإِذَا رَفَعَ رَأْسَهُ مِنَ السَّجْدَةِ الثَّانِيَةِ فِي أَوَّلِ الرَّكْعَةِ اسْتَوَى قَاعِدًا ثُمَّ قَامَ فَاعْتَمَدَ عَلَى الأَرْضِ ‏.‏\hadithno{1153}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Qibalah said:"Malik bin Al-Huwairith used to come to us and say: "Shall I not tell you about the prayer of the Messenger of Allah (ﷺ)?" He was praying at a time other than the time of prayer, and when he raised his head from the second prostration in the first rak'ah, he settled in a seated position, then he stood up, and he supported himself on the ground (while doing so)}}
\hadithdefcmd{nasai}{1154}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا سَجَدَ وَضَعَ رُكْبَتَيْهِ قَبْلَ يَدَيْهِ وَإِذَا نَهَضَ رَفَعَ يَدَيْهِ قَبْلَ رُكْبَتَيْهِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لَمْ يَقُلْ هَذَا عَنْ شَرِيكٍ غَيْرُ يَزِيدَ بْنِ هَارُونَ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{1154}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Wa'il bin Hujr said:'I saw the Messenger of Allah (ﷺ) when he prostrated, place his knees on the ground before his hands, and when he got up, he lifted his hands before his knees}}
\hadithdefcmd{nasai}{1155}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ يُصَلِّي بِهِمْ فَيُكَبِّرُ كُلَّمَا خَفَضَ وَرَفَعَ فَإِذَا انْصَرَفَ قَالَ وَاللَّهِ إِنِّي لأَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1155}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Salamah :That Abu Hurairah used to lead them in prayer, and he said the takbir when he went down and came up. When he had finished he said: 'By Allah (SWT), I am the one among you whose prayer most closely resembles that of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{1156}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، وَسَوَّارُ بْنُ عَبْدِ اللَّهِ بْنِ سَوَّارٍ، قَالاَ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، وَعَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُمَا صَلَّيَا خَلْفَ أَبِي هُرَيْرَةَ - رضى الله عنه - فَلَمَّا رَكَعَ كَبَّرَ فَلَمَّا رَفَعَ رَأْسَهُ قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ثُمَّ سَجَدَ وَكَبَّرَ وَرَفَعَ رَأْسَهُ وَكَبَّرَ ثُمَّ كَبَّرَ حِينَ قَامَ مِنَ الرَّكْعَةِ ثُمَّ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَقْرَبُكُمْ شَبَهًا بِرَسُولِ اللَّهِ صلى الله عليه وسلم مَا زَالَتْ هَذِهِ صَلاَتُهُ حَتَّى فَارَقَ الدُّنْيَا ‏.‏ وَاللَّفْظُ لِسَوَّارٍ ‏.‏\hadithno{1156}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Bakr bin 'Abdur-Rahman and from Abu Salamah bin 'Abdur-Rahman that:They prayed behind Abu Hurairah, may Allah (SWT) be pleased with him, and he when he bowed, he said the Takbir, when he raised his head he said: 'Sami Allahu liman hamidah, Rabbana wa lakal-hamd. Then he prostrated and said the takbir, then he raised his head and said the takbir, then he said the takbir when he stood up following that Rak'ah. Then he said: 'By the One in Whose Hand is my soul, I am the one among you whose prayer most closely resembles that of the Messenger of Allah (ﷺ). And this is how he continued to pray until he left this world}}
\hadithdefcmd{nasai}{1157}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ إِنَّ مِنْ سُنَّةِ الصَّلاَةِ أَنْ تُضْجِعَ رِجْلَكَ الْيُسْرَى وَتَنْصِبَ الْيُمْنَى ‏.‏\hadithno{1157}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin 'Abdullah bin 'Umar that his father said:"One of the sunnahs of the prayer is to spread your left foot beneath you, and hold your right foot upright}}
\hadithdefcmd{nasai}{1158}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرِ بْنِ مُضَرَ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ يَحْيَى، أَنَّ الْقَاسِمَ، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ - عَنْ أَبِيهِ، قَالَ مِنْ سُنَّةِ الصَّلاَةِ أَنْ تَنْصِبَ، الْقَدَمَ الْيُمْنَى وَاسْتِقْبَالُهُ بِأَصَابِعِهَا الْقِبْلَةَ وَالْجُلُوسُ عَلَى الْيُسْرَى ‏.‏\hadithno{1158}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Al-Qasim who narrated from 'Abdullah-he is Ibn Abdullah bin 'Umar- that:His father (Ibn 'Umar) said: "One of the sunnahs of the prayer is to hold the right foot upright and point its toes toward the Qiblah, and to sit on the left foot}}
\hadithdefcmd{nasai}{1159}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُهُ يَرْفَعُ يَدَيْهِ إِذَا افْتَتَحَ الصَّلاَةَ حَتَّى يُحَاذِيَ مَنْكِبَيْهِ وَإِذَا أَرَادَ أَنْ يَرْكَعَ وَإِذَا جَلَسَ فِي الرَّكْعَتَيْنِ أَضْجَعَ الْيُسْرَى وَنَصَبَ الْيُمْنَى وَوَضَعَ يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَنَصَبَ أُصْبُعَهُ لِلدُّعَاءِ وَوَضَعَ يَدَهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى ‏.‏ قَالَ ثُمَّ أَتَيْتُهُمْ مِنْ قَابِلٍ فَرَأَيْتُهُمْ يَرْفَعُونَ أَيْدِيَهُمْ فِي الْبَرَانِسِ ‏.‏\hadithno{1159}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Wa'il bin Hujr said:"I came to the Messenger of Allah (ﷺ) and I saw him raising his hands when he started to pray until they were in level with his shoulders, and when he wanted to bow. When he sat following the first two rak'ahs, he sat on his left foot and held the right foot upright. He placed his right hand on his right thigh and raised his finger for the supplication, and he placed his left hand on his left thigh." He said: "Then I came the following year and I saw them raising their hands inside their Baranis}}
\hadithdefcmd{nasai}{1160}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ عَلِيِّ بْنِ عَبْدِ الرَّحْمَنِ الْمَعَافِرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ رَأَى رَجُلاً يُحَرِّكُ الْحَصَى بِيَدِهِ وَهُوَ فِي الصَّلاَةِ فَلَمَّا انْصَرَفَ قَالَ لَهُ عَبْدُ اللَّهِ لاَ تُحَرِّكِ الْحَصَى وَأَنْتَ فِي الصَّلاَةِ فَإِنَّ ذَلِكَ مِنَ الشَّيْطَانِ وَلَكِنِ اصْنَعْ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏ قَالَ وَكَيْفَ كَانَ يَصْنَعُ قَالَ فَوَضَعَ يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَأَشَارَ بِأُصْبُعِهِ الَّتِي تَلِي الإِبْهَامَ فِي الْقِبْلَةِ وَرَمَى بِبَصَرِهِ إِلَيْهَا أَوْ نَحْوِهَا ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏\hadithno{1160}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:He saw a man moving pebbles with his hand while praying. When he finished, 'Abdullah said to him: "Do not move the pebbles while you are praying, for that is from Shaitan. Rather do what the Messenger of Allah (ﷺ) used to do." He said: "What did he used to do?" He said: "He would put his right hand on his right thigh, and point with the finger that is next to the thumb toward the Qiblah, and he would look at it, or thereabouts." Then he said: "This is what I saw the Messenger of Allah (ﷺ) doing}}
\hadithdefcmd{nasai}{1161}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى السِّجْزِيُّ، - يُعْرَفُ بِخَيَّاطِ السُّنَّةِ نَزَلَ بِدِمَشْقَ أَحَدُ الثِّقَاتِ - قَالَ حَدَّثَنَا الْحَسَنُ بْنُ عِيسَى قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ قَالَ حَدَّثَنَا مَخْرَمَةُ بْنُ بُكَيْرٍ قَالَ أَنْبَأَنَا عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنْ أَبِيهِ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا جَلَسَ فِي الثِّنْتَيْنِ أَوْ فِي الأَرْبَعِ يَضَعُ يَدَيْهِ عَلَى رُكْبَتَيْهِ ثُمَّ أَشَارَ بِأُصْبُعِهِ ‏.‏\hadithno{1161}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amr bin 'Abdullah bin Az-Zubair narrated that:His father said: "When the Messenger of Allah (ﷺ) sat in the second or fourth rak'ah, he would place his hands on his knees and point with his finger}}
\hadithdefcmd{nasai}{1162}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، عَنِ الأَشْجَعِيِّ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَقُولَ إِذَا جَلَسْنَا فِي الرَّكْعَتَيْنِ ‏ "‏ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1162}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah (ﷺ) taught us to say when we sat following two rak'ahs: 'At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1163}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا لاَ نَدْرِي مَا نَقُولُ فِي كُلِّ رَكْعَتَيْنِ غَيْرَ أَنْ نُسَبِّحَ وَنُكَبِّرَ وَنَحْمَدَ رَبَّنَا وَأَنَّ مُحَمَّدًا صلى الله عليه وسلم عُلِّمَ فَوَاتِحَ الْخَيْرِ وَخَوَاتِمَهُ فَقَالَ ‏ "‏ إِذَا قَعَدْتُمْ فِي كُلِّ رَكْعَتَيْنِ فَقُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ وَلْيَتَخَيَّرْ أَحَدُكُمْ مِنَ الدُّعَاءِ أَعْجَبَهُ إِلَيْهِ فَلْيَدْعُ اللَّهَ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{1163}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah said:"We used not to know what we should say in each rak'ah apart from glorifying, magnifying and praising our Lord. But Muhammad (ﷺ) taught us everything about what is good. He said: "When you sit following every two rak'ahs, then say: At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger), then choose any supplication that you like and call upon Allah the Mighty and Sublime with it}}
\hadithdefcmd{nasai}{1164}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم التَّشَهُّدَ فِي الصَّلاَةِ وَالتَّشَهُّدَ فِي الْحَاجَةِ فَأَمَّا التَّشَهُّدُ فِي الصَّلاَةِ ‏ "‏ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ إِلَى آخِرِ التَّشَهُّدِ ‏.‏\hadithno{1164}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah (ﷺ) taught us the tashahhud for prayer and the tashahhud for Al-Hajah. The tashahhud for prayer is: At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger).' (to the end of the tashahhud)}}
\hadithdefcmd{nasai}{1165}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ آدَمَ - قَالَ سَمِعْتُ سُفْيَانَ، يَتَشَهَّدُ بِهَذَا فِي الْمَكْتُوبَةِ وَالتَّطَوُّعِ وَيَقُولُ حَدَّثَنَا أَبُو إِسْحَاقَ عَنْ أَبِي الأَحْوَصِ عَنْ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا مَنْصُورٌ وَحَمَّادٌ عَنْ أَبِي وَائِلٍ عَنْ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1165}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Yahya-Ibn Adam- said:"I heard Sufyan reciting this tashahhud in the obligatory and voluntary prayers, and he said: 'Abu Ishaq narrated to us from Abu Al-Ahwas from Abdullah, from the Prophet (ﷺ).'" And Mansur and Hammad narrated to us from Abu Wa'il, from Abdullah, from the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{1166}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ زَيْدَ بْنَ أَبِي أُنَيْسَةَ الْجَزَرِيَّ، حَدَّثَهُ أَنَّ أَبَا إِسْحَاقَ حَدَّثَهُ عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نَعْلَمُ شَيْئًا فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُولُوا فِي كُلِّ جَلْسَةٍ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1166}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Aswad and 'Alqamah, that Abdullah bin Mas'ud said:"We were with the Messenger of Allah (ﷺ) and we did not know anything, then the Messenger of Allah (ﷺ) said to us: "Every time you sit (in prayer), say: At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1167}{أَخْبَرَنِي مُحَمَّدُ بْنُ جَبَلَةَ الرَّافِقِيُّ، قَالَ حَدَّثَنَا الْعَلاَءُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، - وَهُوَ ابْنُ عَمْرٍو - عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ حَمَّادٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ قَيْسٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا لاَ نَدْرِي مَا نَقُولُ إِذَا صَلَّيْنَا فَعَلَّمَنَا نَبِيُّ اللَّهِ صلى الله عليه وسلم جَوَامِعَ الْكَلِمِ فَقَالَ لَنَا ‏ "‏ قُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ عُبَيْدُ اللَّهِ قَالَ زَيْدٌ عَنْ حَمَّادٍ عَنْ إِبْرَاهِيمَ عَنْ عَلْقَمَةَ قَالَ لَقَدْ رَأَيْتُ ابْنَ مَسْعُودٍ يُعَلِّمُنَا هَؤُلاَءِ الْكَلِمَاتِ كَمَا يُعَلِّمُنَا الْقُرْآنَ ‏.‏\hadithno{1167}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Alqamah bin Qais that 'Abdullah said:"We used not to know what to say when we prayed, then the Messenger of Allah (ﷺ) taught us some eloquent and concise words. He said to us: 'Say: "At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger)." (One of the narrators) 'Ubaidullah said: "Zaid bin Hammad said, narrating from Ibrahim, that 'Alqamah said: 'I saw Ibn Mas'ud teaching us these words just as he taught us the Quran}}
\hadithdefcmd{nasai}{1168}{أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ الرَّقِّيُّ، قَالَ حَدَّثَنَا حَارِثُ بْنُ عَطِيَّةَ، - وَكَانَ مِنْ زُهَّادِ النَّاسِ - عَنْ هِشَامٍ، عَنْ حَمَّادٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ كُنَّا إِذَا صَلَّيْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَقُولُ السَّلاَمُ عَلَى اللَّهِ السَّلاَمُ عَلَى جِبْرِيلَ السَّلاَمُ عَلَى مِيكَائِيلَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُولُوا السَّلاَمُ عَلَى اللَّهِ فَإِنَّ اللَّهَ هُوَ السَّلاَمُ وَلَكِنْ قُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1168}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Mas'ud said:"When we prayed with the Messenger of Allah (ﷺ), we used to say: "Peace (As-Salam) be upon Allah (SWT), peace be upon Jibril, peace be upon Mika'il.' The Messenger of Allah (ﷺ) said: 'Do not say "Peace (As-Salam) be upon Allah, for Allah is As-Salam." Rather say: "At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1169}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، - هُوَ الدَّسْتَوَائِيُّ - عَنْ حَمَّادٍ، عَنْ أَبِي وَائِلٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَقُولُ السَّلاَمُ عَلَى اللَّهِ السَّلاَمُ عَلَى جِبْرِيلَ السَّلاَمُ عَلَى مِيكَائِيلَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُولُوا السَّلاَمُ عَلَى اللَّهِ فَإِنَّ اللَّهَ هُوَ السَّلاَمُ وَلَكِنْ قُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1169}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Mas'ud said:"We used to pray with the Messenger of Allah (ﷺ) and we would say: "Peace (As-Salam) be upon Allah (SWT), peace be upon Jibril, peace be upon Mika'il.' The Messenger of Allah (ﷺ) said: 'Do not say "Peace (As-Salam) be upon Allah, for Allah is As-Salam." Rather say: "At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1170}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ الْعَسْكَرِيُّ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، وَمَنْصُورٍ، وَحَمَّادٍ، وَمُغِيرَةَ، وَأَبِي، هَاشِمٍ عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فِي التَّشَهُّدِ ‏ "‏ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو هَاشِمٍ غَرِيبٌ ‏.‏\hadithno{1170}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah that :The Prophet (ﷺ) said in the tashahhud: "At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1171}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ دُكَيْنٍ، قَالَ حَدَّثَنَا سَيْفٌ الْمَكِّيُّ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ حَدَّثَنِي أَبُو مَعْمَرٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ، يَقُولُ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ وَكَفُّهُ بَيْنَ يَدَيْهِ ‏ "‏ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1171}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah said:"The Messenger of Allah (ﷺ) taught us the tashahhud just as he taught us a surah from the Quran: "At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1172}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو قُدَامَةَ السَّرْخَسِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنِي قَتَادَةُ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، أَنَّ الأَشْعَرِيَّ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَنَا فَعَلَّمَنَا سُنَّتَنَا وَبَيَّنَ لَنَا صَلاَتَنَا فَقَالَ ‏"‏ أَقِيمُوا صُفُوفَكُمْ ثُمَّ لْيَؤُمَّكُمْ أَحَدُكُمْ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَالَ ‏\{‏ وَلاَ الضَّالِّينَ ‏\}‏ فَقُولُوا آمِينَ يُجِبْكُمُ اللَّهُ وَإِذَا كَبَّرَ الإِمَامُ وَرَكَعَ فَكَبِّرُوا وَارْكَعُوا فَإِنَّ الإِمَامَ يَرْكَعُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا لَكَ الْحَمْدُ يَسْمَعِ اللَّهُ لَكُمْ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَالَ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ثُمَّ إِذَا كَبَّرَ الإِمَامُ وَسَجَدَ فَكَبِّرُوا وَاسْجُدُوا فَإِنَّ الإِمَامَ يَسْجُدُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ فَإِذَا كَانَ عِنْدَ الْقَعْدَةِ فَلْيَكُنْ مِنْ أَوَّلِ قَوْلِ أَحَدِكُمْ أَنْ يَقُولَ التَّحِيَّاتُ الطَّيِّبَاتُ الصَّلَوَاتُ لِلَّهِ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1172}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hittan bin 'Abdullah that Al-Ash'ari said:"The Messenger of Allah (ﷺ) addressed us and taught us our Sunnahs and our prayer. He said: 'Make your rows straight, then let one of you lead the others. When he says the takbir, then say the takbir; when he says: "Wa lad-dallin" then say "Amin" and Allah (SWT) will answer you. When the Imam says the takbir and bows, then say the takbir and bow, for the Imam bows before you and stands up before you.' The Prophet of Allah (ﷺ) said: 'This makes up for that. When he says: 'Sami Allahu liman hamidah (Allah hears the one who praises Him), say: "Rabbana wa lakal-hamd (Our Lord, to You be praise)," Allah (SWT) will hear you, for indeed Allah, the Mighty and Sublime, has said on the tongue of His Prophet (ﷺ): "Allah hears the one who praises Him." Then when the Imam says the takbir and prostrates, say the takbir and prostrate, for the Imam prostrates before you and rises before you.' The Prophet of Allah (ﷺ) said: 'This makes up for that. Then when you are sitting, let the first thing that any one of you says be: At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1173}{أَخْبَرَنَا أَبُو الأَشْعَثِ، أَحْمَدُ بْنُ الْمِقْدَامِ الْعِجْلِيُّ الْبَصْرِيُّ قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ قَتَادَةَ، عَنْ أَبِي غَلاَّبٍ، - وَهُوَ يُونُسُ بْنُ جُبَيْرٍ - عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، أَنَّهُمْ صَلَّوْا مَعَ أَبِي مُوسَى فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ عِنْدَ الْقَعْدَةِ فَلْيَكُنْ مِنْ أَوَّلِ قَوْلِ أَحَدِكُمُ التَّحِيَّاتُ لِلَّهِ الطَّيِّبَاتُ الصَّلَوَاتُ لِلَّهِ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1173}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hittan bin Abdullah that:They prayed with Abu Musa and he said: "The Messenger of Allah (ﷺ) said: 'When you are sitting then let the first words that any of you says be: At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1174}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَطَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا الْقُرْآنَ وَكَانَ يَقُولُ ‏ "‏ التَّحِيَّاتُ الْمُبَارَكَاتُ الصَّلَوَاتُ الطَّيِّبَاتُ لِلَّهِ سَلاَمٌ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ سَلاَمٌ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{1174}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) used to teach us the tashahhud as he taught us the Quran, and he used to say: : 'At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa barakatuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ash-hadu an la ilaha ill-Allah wa ash-hadu anna Muhammadan 'abduhu wa rasuluhu (All compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger}}
\hadithdefcmd{nasai}{1175}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَيْمَنَ، - وَهُوَ ابْنُ نَابِلٍ - يَقُولُ حَدَّثَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ ‏ "‏ بِسْمِ اللَّهِ وَبِاللَّهِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ أَسْأَلُ اللَّهَ الْجَنَّةَ وَأَعُوذُ بِاللَّهِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{1175}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) used to teach us the tashahhud just as he would teach us a surah of the Quran: "Bismillah, wa billahi. At-tahiyyatu lillahi was-salawatu wat-tayyibat, as-salamu 'alaika ayyuhan-Nabiyyu wa rahmatAllahi wa baraktuhu. As-salamu 'alaina wa 'ala 'ibad illahis-salihin, ashahdu an la illaha ill-Allah wa ashhadu anna Muhammadan 'abduhu wa rasuluhu. A'sal Allahal-jannah wa a'udhu Billahi min an-nar (Allah compliments, prayers and pure words are due to Allah. Peace be upon you, O Prophet, and the mercy of Allah (SWT) and his blessings. Peace be upon us and upon the righteous slaves of Allah (SWT). I bear witness that none has the right to be worshipped except Allah and I bear witness that Muhammad is His slave and Messenger. I ask Allah for Paradise and I seek refuge with Allah from the Fire}}
\hadithdefcmd{nasai}{1176}{أَخْبَرَنَا الْهَيْثَمُ بْنُ أَيُّوبَ الطَّالْقَانِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ أَبِي عُبَيْدَةَ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الرَّكْعَتَيْنِ كَأَنَّهُ عَلَى الرَّضْفِ ‏.‏ قُلْتُ حَتَّى يَقُومَ قَالَ ذَلِكَ يُرِيدُ ‏.‏\hadithno{1176}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"In the first two rak'ahs the Prophet (ﷺ) was as if he were on stones heated by fire}}
\hadithdefcmd{nasai}{1177}{أَخْبَرَنِي يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنِ ابْنِ بُحَيْنَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى فَقَامَ فِي الشَّفْعِ الَّذِي كَانَ يُرِيدُ أَنْ يَجْلِسَ فِيهِ فَمَضَى فِي صَلاَتِهِ حَتَّى إِذَا كَانَ فِي آخِرِ صَلاَتِهِ سَجَدَ سَجْدَتَيْنِ قَبْلَ أَنْ يُسَلِّمَ ثُمَّ سَلَّمَ ‏.‏\hadithno{1177}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Buhainah that:The Prophet (ﷺ) prayed, then he stood up after two rak'ahs while he was supposed to sit, and he continued his prayer. Then at the end of his prayer, he performed two prostrations before the Salam, then he said the Salam}}
\hadithdefcmd{nasai}{1178}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنِ ابْنِ بُحَيْنَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى فَقَامَ فِي الرَّكْعَتَيْنِ فَسَبَّحُوا فَمَضَى فَلَمَّا فَرَغَ مِنْ صَلاَتِهِ سَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1178}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Buhainah that:The Prophet (ﷺ) prayed and stood up following the first two rak'ahs, and they said (SubhanAllah). He carried on, then when he finished his prayer he performed two prostrations, then he said the Salam}}
