% Auto-generated chapter 20 for malik
% Hadiths in this chapter: 251

\hadithdefcmd{malik}{705}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ، أَنَّهَا وَلَدَتْ مُحَمَّدَ بْنَ أَبِي بَكْرٍ بِالْبَيْدَاءِ فَذَكَرَ ذَلِكَ أَبُو بَكْرٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مُرْهَا فَلْتَغْتَسِلْ ثُمَّ لِتُهِلَّ ‏"‏ ‏.‏\hadithno{705}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father from Asma bint Umays that she gave birth to Muhammad ibn Abi Bakr at al-Bayda. Abu Bakr mentioned this to the Messenger of Allah, may Allah bless him and grant him peace, and he said, "Tell her to do ghusl and then enter ihram}}
\hadithdefcmd{malik}{706}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَسْمَاءَ بِنْتَ عُمَيْسٍ، وَلَدَتْ، مُحَمَّدَ بْنَ أَبِي بَكْرٍ بِذِي الْحُلَيْفَةِ فَأَمَرَهَا أَبُو بَكْرٍ أَنْ تَغْتَسِلَ، ثُمَّ تُهِلَّ ‏.‏\hadithno{706}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Said ibn al-Musayyab that Asma bint Umays gave birth to Muhammad ibn Abi Bakr at Dhu'l-Hulayfa and Abu Bakr told her to do ghusl and then enter ihram}}
\hadithdefcmd{malik}{707}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَغْتَسِلُ لإِحْرَامِهِ قَبْلَ أَنْ يُحْرِمَ وَلِدُخُولِهِ مَكَّةَ وَلِوُقُوفِهِ عَشِيَّةَ عَرَفَةَ ‏.‏\hadithno{707}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi' that 'Abdullah ibn Umar used to do ghusl for ihram before he entered ihram, and for entering Makka, and for standing on the afternoon of 'Arafa}}
\hadithdefcmd{malik}{708}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، اخْتَلَفَا بِالأَبْوَاءِ فَقَالَ عَبْدُ اللَّهِ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ ‏.‏ وَقَالَ الْمِسْوَرُ بْنُ مَخْرَمَةَ لاَ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ ‏.‏ قَالَ فَأَرْسَلَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ إِلَى أَبِي أَيُّوبَ الأَنْصَارِيِّ فَوَجَدْتُهُ يَغْتَسِلُ بَيْنَ الْقَرْنَيْنِ وَهُوَ يُسْتَرُ بِثَوْبٍ فَسَلَّمْتُ عَلَيْهِ فَقَالَ مَنْ هَذَا فَقُلْتُ أَنَا عَبْدُ اللَّهِ بْنُ حُنَيْنٍ أَرْسَلَنِي إِلَيْكَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ أَسْأَلُكَ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْسِلُ رَأْسَهُ وَهُوَ مُحْرِمٌ قَالَ فَوَضَعَ أَبُو أَيُّوبَ يَدَهُ عَلَى الثَّوْبِ فَطَأْطَأَهُ حَتَّى بَدَا لِي رَأْسُهُ ثُمَّ قَالَ لإِنْسَانٍ يَصُبُّ عَلَيْهِ اصْبُبْ ‏.‏ فَصَبَّ عَلَى رَأْسِهِ ثُمَّ حَرَّكَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{708}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ibrahim ibn Abdullah ibn Hunayn from his father Abdullah ibn Hunayn that Abdullah ibn Abbas and al-Miswar ibn Makhrama once had a disagreement at al-Abwa. Abdullah said that some one in ihram could wash his head, and al Miswar ibn Makhrama maintained that some one in ihram could not wash his head. Abdullah ibn Hunayn continued, "Abdullah ibn Abbas sent me to Abu Ayyub al-Ansari, and I found him doing ghusl between the posts of a well, screened by a garment. I greeted him and hesaid, 'Who is that?' I replied, 'I am 'Abdullah ibn Hunayn. 'Abdullah ibn Abbas sent me to you to ask how the Messenger of Allah, may Allah bless him and grant him peace, used to wash his head when he was in ihram.' " He continued, "Abu Ayyub put his hand on the garment and pulled it down until I could see his head. He said to the man who was pouring out the water for him, 'Pour,' and he poured some over his head. Then he passed his hands over his head from the front to the back and then to the front again, and then said, 'I saw the Messenger of Allah, may Allah bless him and grant him peace, doing it like this}}
\hadithdefcmd{malik}{709}{وَحَدَّثَنِي مَالِكٌ، عَنْ حُمَيْدِ بْنِ قَيْسٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لِيَعْلَى ابْنِ مُنْيَةَ وَهُوَ يَصُبُّ عَلَى عُمَرَ بْنِ الْخَطَّابِ مَاءً وَهُوَ يَغْتَسِلُ اصْبُبْ عَلَى رَأْسِي ‏.‏ فَقَالَ يَعْلَى أَتُرِيدُ أَنْ تَجْعَلَهَا بِي إِنْ أَمَرْتَنِي صَبَبْتُ ‏.‏ فَقَالَ لَهُ عُمَرُ بْنُ الْخَطَّابِ اصْبُبْ فَلَنْ يَزِيدَهُ الْمَاءُ إِلاَّ شَعَثًا ‏.‏\hadithno{709}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Malik related to me from Humayd ibn Qays from Ata ibn Abi Rabah that 'Umar ibn alKhattab once asked Yala ibn Munya, who was pouring out water for him while he was having a ghusl, to pour some on his head. Ya'la said, "Are you trying to make me responsible? I will only pour it out if you tell me to do so." Umar ibn al-Khattab said, "Pour. It will only make (my head) more unkempt}}
\hadithdefcmd{malik}{710}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا دَنَا مِنْ مَكَّةَ بَاتَ بِذِي طُوًى بَيْنَ الثَّنِيَّتَيْنِ حَتَّى يُصْبِحَ ثُمَّ يُصَلِّي الصُّبْحَ ثُمَّ يَدْخُلُ مِنَ الثَّنِيَّةِ الَّتِي بِأَعْلَى مَكَّةَ وَلاَ يَدْخُلُ إِذَا خَرَجَ حَاجًّا أَوْ مُعْتَمِرًا حَتَّى يَغْتَسِلَ قَبْلَ أَنْ يَدْخُلَ مَكَّةَ إِذَا دَنَا مِنْ مَكَّةَ بِذِي طُوًى وَيَأْمُرُ مَنْ مَعَهُ فَيَغْتَسِلُونَ قَبْلَ أَنْ يَدْخُلُوا ‏.‏\hadithno{710}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that Abdullah ibn Umar would spend the night between the two trails in the valley of Dhu Tuwa when he was approaching Makka. Then he would pray subh, and after that he would enter Makka by the trail which is at the highest part of Makka. He would never enter Makka, if he was coming for hajj or umra, without doing ghusl beforehand when he was near Makka at Dhu Tuwa, and he would tell whoever was with him to do likewise}}
\hadithdefcmd{malik}{711}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَغْسِلُ رَأْسَهُ وَهُوَ مُحْرِمٌ إِلاَّ مِنَ الاِحْتِلاَمِ ‏.‏ قَالَ مَالِكٌ سَمِعْتُ أَهْلَ الْعِلْمِ يَقُولُونَ لاَ بَأْسَ أَنْ يَغْسِلَ الرَّجُلُ الْمُحْرِمُ رَأْسَهُ بِالْغَسُولِ بَعْدَ أَنْ يَرْمِيَ جَمْرَةَ الْعَقَبَةِ وَقَبْلَ أَنْ يَحْلِقَ رَأْسَهُ وَذَلِكَ أَنَّهُ إِذَا رَمَى جَمْرَةَ الْعَقَبَةِ فَقَدْ حَلَّ لَهُ قَتْلُ الْقَمْلِ وَحَلْقُ الشَّعْرِ وَإِلْقَاءُ التَّفَثِ وَلُبْسُ الثِّيَابِ ‏.‏\hadithno{711}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar would never wash his head while he was in ihram except if he had to do ghusl because of a wet dream. Malik said, "I have heard the people of knowledge say that there is no harm in someone who is in ihram rubbing his head with certain kinds of plants after he has stoned the Jamrat al-Aqaba but before he has shaved his head, because once he has finished stoning the Jamrat al-Aqaba it is halal for him to kill lice, to shave his head, to clean himself of body hair, and to wear normal clothes}}
\hadithdefcmd{malik}{712}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَلْبَسُوا الْقُمُصَ وَلاَ الْعَمَائِمَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْبَرَانِسَ وَلاَ الْخِفَافَ إِلاَّ أَحَدٌ لاَ يَجِدُ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا مِنَ الثِّيَابِ شَيْئًا مَسَّهُ الزَّعْفَرَانُ وَلاَ الْوَرْسُ ‏.‏\hadithno{712}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that a man once asked the Messenger of Allah, may Allah bless him and grant him peace, what clothes someone in ihram could wear, and the Messenger of Allah, may Allah bless him and grant him peace, said, "Do not wear shirts, turbans, trousers, burnouses, or leather socks, except if you cannot find sandals. In that case you can wear leather socks, but cut them off below the ankles. Do not wear any clothes that have been touched by saffron or yellow dye." Yahya said that Malik was asked about the hadith attributed to the Prophet, may Allah bless him and grant him peace, "Whoever cannot find a waist wrapper should wear trousers," and he said, "I have never heard this, and I do not think that some one who is in ihram can wear trousers, because among the things which the Prophet, may Allah bless him and grant him peace, forbade some one in ihram to wear were trousers, and he did not make any exception for them although he did make an exception for leather socks." 20.4 Wearing Clothes when in Ihram}}
\hadithdefcmd{malik}{713}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَلْبَسَ الْمُحْرِمُ ثَوْبًا مَصْبُوغًا بِزَعْفَرَانٍ أَوْ وَرْسٍ وَقَالَ ‏ "‏ مَنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسْ خُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏\hadithno{713}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from 'Abdullah ibn Dinar that Abdullah ibn Umar said, "The Messenger of Allah, may Allah bless him and grant him peace, forbade anyone in ihram to wear a garment which had been dyed with saffron or yellow dye, and said, 'Anyone that cannot find sandals can wear leather socks, but he should cut them off below the ankles}}
\hadithdefcmd{malik}{714}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ سَمِعَ أَسْلَمَ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ يُحَدِّثُ عَبْدَ اللَّهِ بْنَ عُمَرَ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رَأَى عَلَى طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ ثَوْبًا مَصْبُوغًا وَهُوَ مُحْرِمٌ فَقَالَ عُمَرُ مَا هَذَا الثَّوْبُ الْمَصْبُوغُ يَا طَلْحَةُ فَقَالَ طَلْحَةُ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّمَا هُوَ مَدَرٌ ‏.‏ فَقَالَ عُمَرُ إِنَّكُمْ أَيُّهَا الرَّهْطُ أَئِمَّةٌ يَقْتَدِي بِكُمُ النَّاسُ فَلَوْ أَنَّ رَجُلاً جَاهِلاً رَأَى هَذَا الثَّوْبَ لَقَالَ إِنَّ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ كَانَ يَلْبَسُ الثِّيَابَ الْمُصَبَّغَةَ فِي الإِحْرَامِ فَلاَ تَلْبَسُوا أَيُّهَا الرَّهْطُ شَيْئًا مِنْ هَذِهِ الثِّيَابِ الْمُصَبَّغَةِ ‏.‏\hadithno{714}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that he had heard Aslam, the mawla of Umar ibn al-Khattab, telling 'Abdullah ibn Umar that Umar ibn al-Khattab once saw a dyed garment on Talha ibn Ubaydullah while he was in ihram and Umar said, "What is this dyed garment, Talha?", and Talha said, "Amir al-muminin, it is only mud.'' Umar said, "You and your like are taken by people as imams, and if an ignorant man were to see this garment he would say that Talha ibn Ubaydullah used to wear a dyed robe while he was in ihram. So do not wear any form of dyed clothes}}
\hadithdefcmd{malik}{715}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا كَانَتْ تَلْبَسُ الثِّيَابَ الْمُعَصْفَرَاتِ الْمُشَبَّعَاتِ وَهِيَ مُحْرِمَةٌ لَيْسَ فِيهَا زَعْفَرَانٌ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَنْ ثَوْبٍ مَسَّهُ طِيبٌ ثُمَّ ذَهَبَ مِنْهُ رِيحُ الطِّيبِ هَلْ يُحْرِمُ فِيهِ فَقَالَ نَعَمْ مَا لَمْ يَكُنْ فِيهِ صِبَاغٌ زَعْفَرَانٌ أَوْ وَرْسٌ ‏.‏\hadithno{715}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Asma bint Abi Bakr had worn clothes that were completely dyed with safflower while she was in ihram, though there was not any saffron in them. Yahya said that Malik was asked if a garment which had been perfumed could be used for ihram if the smell of the perfume had gone, and he said, "Yes, as long as there is no saffron or yellow dye in it}}
\hadithdefcmd{malik}{716}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَكْرَهُ لُبْسَ الْمِنْطَقَةِ لِلْمُحْرِمِ ‏.‏\hadithno{716}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that 'Abdullah ibn 'Umar used to disapprove of anybody wearing a belt or girdle while in ihram}}
\hadithdefcmd{malik}{717}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ فِي الْمِنْطَقَةِ يَلْبَسُهَا الْمُحْرِمُ تَحْتَ ثِيَابِهِ أَنَّهُ لاَ بَأْسَ بِذَلِكَ إِذَا جَعَلَ طَرَفَيْهَا جَمِيعًا سُيُورًا يَعْقِدُ بَعْضَهَا إِلَى بَعْضٍ ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{717}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Sa'id that he heard Said ibn al Musayyab say, about the girdle worn by some one in ihram under his clothes, "There is no harm in it if he ties the ends together as a belt." Malik said, "This is what I like most out of what I have heard about the matter}}
\hadithdefcmd{malik}{718}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ قَالَ أَخْبَرَنِي الْفُرَافِصَةُ بْنُ عُمَيْرٍ الْحَنَفِيُّ، أَنَّهُ رَأَى عُثْمَانَ بْنَ عَفَّانَ بِالْعَرْجِ يُغَطِّي وَجْهَهُ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{718}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that al-Qasim ibn Muhammad said that al-Furafisa ibn Umayr al-Hanafi saw Uthman ibn Affan at al-Arj, and he was covering his face while in ihram}}
\hadithdefcmd{malik}{719}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ مَا فَوْقَ الذَّقَنِ مِنَ الرَّأْسِ فَلاَ يُخَمِّرْهُ الْمُحْرِمُ ‏.‏\hadithno{719}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say that a man in ihram should not veil anything above his chin}}
\hadithdefcmd{malik}{720}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَفَّنَ ابْنَهُ وَاقِدَ بْنَ عَبْدِ اللَّهِ وَمَاتَ بِالْجُحْفَةِ مُحْرِمًا وَخَمَّرَ رَأْسَهُ وَوَجْهَهُ وَقَالَ لَوْلاَ أَنَّا حُرُمٌ لَطَيَّبْنَاهُ ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا يَعْمَلُ الرَّجُلُ مَا دَامَ حَيًّا فَإِذَا مَاتَ فَقَدِ انْقَضَى الْعَمَلُ ‏.‏\hadithno{720}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar shrouded his son Waqid ibn Abdullah, who had died at al-Juhfa while in ihram, and he veiled his head and face and said, "If we had not been in ihram we would have perfumed him. " Malik said, "A man can only do things while he is alive. When he is dead, his actions stop}}
\hadithdefcmd{malik}{721}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ لاَ تَنْتَقِبُ الْمَرْأَةُ الْمُحْرِمَةُ وَلاَ تَلْبَسُ الْقُفَّازَيْنِ ‏.‏\hadithno{721}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say that a woman in ihram should wear neither a veil nor gloves}}
\hadithdefcmd{malik}{722}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، أَنَّهَا قَالَتْ كُنَّا نُخَمِّرُ وُجُوهَنَا وَنَحْنُ مُحْرِمَاتٌ وَنَحْنُ مَعَ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ الصِّدِّيقِ ‏.‏\hadithno{722}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that Fatima bint al-Mundhir said, "We used to veil our faces when we were in ihram in the company of Asma bint Abi Bakr as-Siddiq." 20.7 Wearing Perfume during Hajj}}
\hadithdefcmd{malik}{723}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم لإِحْرَامِهِ قَبْلَ أَنْ يُحْرِمَ وَلِحِلِّهِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{723}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "I perfumed the Messenger of Allah, may Allah bless him and grant him peace, for his ihram before he entered ihram, and when he came out of ihram before he did tawaf of the House}}
\hadithdefcmd{malik}{724}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّ أَعْرَابِيًّا، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ بِحُنَيْنٍ وَعَلَى الأَعْرَابِيِّ قَمِيصٌ وَبِهِ أَثَرُ صُفْرَةٍ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَهْلَلْتُ بِعُمْرَةٍ فَكَيْفَ تَأْمُرُنِي أَنْ أَصْنَعَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ انْزِعْ قَمِيصَكَ وَاغْسِلْ هَذِهِ الصُّفْرَةَ عَنْكَ وَافْعَلْ فِي عُمْرَتِكَ مَا تَفْعَلُ فِي حَجِّكَ ‏"‏ ‏.‏\hadithno{724}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Humayd ibn Qays from Ata ibn Rabah that a bedouin came to the Messenger of Allah, may Allah bless him and grant him peace, when he was at Hunayn, and he was wearing a shirt with traces of yellow on it. He said, "Messenger of Allah, I have entered ihram for umra. What should I do?" The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Take off your shirt and wash off this yellowness and do in umra as you would do on hajj}}
\hadithdefcmd{malik}{725}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ أَسْلَمَ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَجَدَ رِيحَ طِيبٍ وَهُوَ بِالشَّجَرَةِ فَقَالَ مِمَّنْ رِيحُ هَذَا الطِّيبِ فَقَالَ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ مِنِّي يَا أَمِيرَ الْمُؤْمِنِينَ ‏.‏ فَقَالَ مِنْكَ لَعَمْرُ اللَّهِ فَقَالَ مُعَاوِيَةُ إِنَّ أُمَّ حَبِيبَةَ طَيَّبَتْنِي يَا أَمِيرَ الْمُؤْمِنِينَ ‏.‏ فَقَالَ عُمَرُ عَزَمْتُ عَلَيْكَ لَتَرْجِعَنَّ فَلْتَغْسِلَنَّهُ ‏.‏\hadithno{725}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Nafi from Aslam, the mawla of Umar ibn al Khattab, that Umar ibn al-Khattab discovered the smell of perfume while he was at ash-Shajara, and he asked, "Who is this smell of perfume coming from?" Muawiya ibn Abi Sufyan answered, "From me, amir al-muminin." Umar said, "From you? By the life of Allah!" Muawiya explained, "Umm Habiba perfumed me, amir al-muminin. "'Umar then said, "You must go back and wash it off}}
\hadithdefcmd{malik}{726}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الصَّلْتِ بْنِ زُيَيْدٍ، عَنْ غَيْرِ، وَاحِدٍ، مِنْ أَهْلِهِ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَجَدَ رِيحَ طِيبٍ وَهُوَ بِالشَّجَرَةِ وَإِلَى جَنْبِهِ كَثِيرُ بْنُ الصَّلْتِ فَقَالَ عُمَرُ مِمَّنْ رِيحُ هَذَا الطِّيبِ فَقَالَ كَثِيرٌ مِنِّي يَا أَمِيرَ الْمُؤْمِنِينَ لَبَّدْتُ رَأْسِي وَأَرَدْتُ أَنْ لاَ أَحْلِقَ ‏.‏ فَقَالَ عُمَرُ فَاذْهَبْ إِلَى شَرَبَةٍ فَادْلُكْ رَأْسَكَ حَتَّى تُنَقِّيَهُ ‏.‏ فَفَعَلَ كَثِيرُ بْنُ الصَّلْتِ ‏.‏ قَالَ مَالِكٌ الشَّرَبَةُ حَفِيرٌ تَكُونُ عِنْدَ أَصْلِ النَّخْلَةِ ‏.‏\hadithno{726}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from as-Salt ibn Zubayd from more than one of his family that Umar ibn al-Khattab discovered the smell of perfume while he was at ash-Shajara. Kathir ibn as-Salt was at his side, and Umar asked, "Who is this smell of perfume coming from?", and Kathir said, "From me, amir al-muminin. I matted my hair with perfume and I intended not to shave it.'' Umar said, "Go to a sharaba and rub your head until it is clean," and Kathir did so. Malik explained, "A sharaba is the ditch at the base of a date-palm}}
\hadithdefcmd{malik}{727}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَعَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، وَرَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ الْوَلِيدَ بْنَ عَبْدِ الْمَلِكِ، سَأَلَ سَالِمَ بْنَ عَبْدِ اللَّهِ وَخَارِجَةَ بْنَ زَيْدِ بْنِ ثَابِتٍ بَعْدَ أَنْ رَمَى الْجَمْرَةَ، وَحَلَقَ، رَأْسَهُ وَقَبْلَ أَنْ يُفِيضَ عَنِ الطِّيبِ فَنَهَاهُ سَالِمٌ وَأَرْخَصَ لَهُ خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ ‏.‏ قَالَ مَالِكٌ لاَ بَأْسَ أَنْ يَدَّهِنَ الرَّجُلُ بِدُهْنٍ لَيْسَ فِيهِ طِيبٌ قَبْلَ أَنْ يُحْرِمَ وَقَبْلَ أَنْ يُفِيضَ مِنْ مِنًى بَعْدَ رَمْىِ الْجَمْرَةِ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَنْ طَعَامٍ فِيهِ زَعْفَرَانٌ هَلْ يَأْكُلُهُ الْمُحْرِمُ فَقَالَ أَمَّا مَا تَمَسُّهُ النَّارُ مِنْ ذَلِكَ فَلاَ بَأْسَ بِهِ أَنْ يَأْكُلَهُ الْمُحْرِمُ وَأَمَّا مَا لَمْ تَمَسَّهُ النَّارُ مِنْ ذَلِكَ فَلاَ يَأْكُلُهُ الْمُحْرِمُ ‏.‏\hadithno{727}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said and 'Abdullah ibn Abi Bakr and Rabia ibn Abi Abd ar-Rahman that al-Walid ibn Abd al- Malik asked Salim ibn Abdullah and Kharija ibn Zayd ibn Thabit if he could use perfume after he had stoned the jamra and shaved his head, but before he had left for the tawafal-ifada. Salim forbade him to do so, but Kharija ibn Zayd ibn Thabit said that he could. Malik said, "There is no harm in a man oiling himself with an oil which does not have any perfume in it, either before he enters ihram, or before he leaves Mina for the tawaf al-ifada, if he has stoned the jamra." Yahya said that Malik was asked whether someone in ihram could eat food with saffron in it, and he said, "There is no harm in some one in ihram eating it if it has been cooked. If, however, it has not been cooked he should not eat it}}
\hadithdefcmd{malik}{728}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَيُهِلُّ أَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَيُهِلُّ أَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ وَبَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{728}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "The people of Madina should enter ihram at Dhu'l-Hulayfa, the people of Syria should do so at al-Juhfa, and the people of Najd should do so at Qarn." Abdullah ibn Umar added, "I have heard that the Messenger of Allah, may Allah bless him and grant him peace, said, 'The people of Yemen should enter ihram at Yalamlam}}
\hadithdefcmd{malik}{729}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَهْلَ الْمَدِينَةِ أَنْ يُهِلُّوا مِنْ ذِي الْحُلَيْفَةِ وَأَهْلَ الشَّامِ مِنَ الْجُحْفَةِ وَأَهْلَ نَجْدٍ مِنْ قَرْنٍ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَمَّا هَؤُلاَءِ الثَّلاَثُ فَسَمِعْتُهُنَّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأُخْبِرْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَيُهِلُّ أَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏"‏ ‏.‏\hadithno{729}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that Abdullah ibn Umar said, "The Messenger of Allah, may Allah bless him and grant him peace, told the people of Madina to enter ihram at Dhu'l-Hulayfa, the people of Syria to do so at al-Juhfa, and the people of Najd to do so at Qarn.' Abdullah ibn Umar said, "I heard these three from the Messenger of Allah, may Allah bless him and grant him peace. I was also told that the Messenger of Allah, may Allah bless him and grant him peace, said, 'The people of Yemen should enter ihram at Yalamlam}}
\hadithdefcmd{malik}{730}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَهَلَّ مِنَ الْفُرْعِ ‏.‏\hadithno{730}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar once entered ihram at al-Fur}}
\hadithdefcmd{malik}{731}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الثِّقَةِ، عِنْدَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَهَلَّ مِنْ إِيلْيَاءَ ‏.‏\hadithno{731}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from a reliable source that Abdullah ibn Umar once entered ihram at Ilya (Jerusalem)}}
\hadithdefcmd{malik}{732}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهَلَّ مِنَ الْجِعِرَّانَةِ بِعُمْرَةٍ ‏.‏\hadithno{732}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, once entered ihram at al-Jiirrana (near Makka) for an umra}}
\hadithdefcmd{malik}{733}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ تَلْبِيَةَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَزِيدُ فِيهَا لَبَّيْكَ لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ بِيَدَيْكَ لَبَّيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏\hadithno{733}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Umar that the talbiya of the Messenger of Allah, may Allah bless him and grant him peace, was, "I am at Your service, O Allah, I am at Your service. You have no partner. I am at Your service. Praise and blessing belong to You, and the Kingdom. You have no partner." Labayk, Allahumma labayk, la sharika laka labayk. Inna'l-hamda wa'n-nimata laka wa'l-mulk, la sharika lak. Malik said that Abdullah ibn Umar used to add, "I am at Your service, I am at Your service. I am at Your service and at Your call. Good is in Your hands, and I am at Your service. Our desire is for You, and our action ." Labayk, labayk, labayk wa sadayka wa'l-khayr biyadayka labayk wa'r-raghba'u ilayka wa'l-amalu}}
\hadithdefcmd{malik}{734}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي فِي مَسْجِدِ ذِي الْحُلَيْفَةِ رَكْعَتَيْنِ فَإِذَا اسْتَوَتْ بِهِ رَاحِلَتُهُ أَهَلَّ ‏.‏\hadithno{734}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, used to pray two rakas in the mosque at Dhu'l-Hulayfa, and then, when he had got on to his camel and it had stood up, he would begin doing talbiya}}
\hadithdefcmd{malik}{735}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَاهُ، يَقُولُ بَيْدَاؤُكُمْ هَذِهِ الَّتِي تَكْذِبُونَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا مَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ مِنْ عِنْدِ الْمَسْجِدِ يَعْنِي مَسْجِدَ ذِي الْحُلَيْفَةِ ‏.‏\hadithno{735}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Musa ibn Uqba that Salim ibn Abdullah heard his father say, "Your claim that the Messenger of Allah, may Allah bless him and grant him peace, entered ihram from this desert of yours is not true, because he only entered ihram from the mosque, i.e. the mosque of Dhu'l-Hulayfa}}
\hadithdefcmd{malik}{736}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عُبَيْدِ بْنِ جُرَيْجٍ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ يَا أَبَا عَبْدِ الرَّحْمَنِ رَأَيْتُكَ تَصْنَعُ أَرْبَعًا لَمْ أَرَ أَحَدًا مِنْ أَصْحَابِكَ يَصْنَعُهَا ‏.‏ قَالَ وَمَا هُنَّ يَا ابْنَ جُرَيْجٍ قَالَ رَأَيْتُكَ لاَ تَمَسُّ مِنَ الأَرْكَانِ إِلاَّ الْيَمَانِيَيْنِ وَرَأَيْتُكَ تَلْبَسُ النِّعَالَ السِّبْتِيَّةَ وَرَأَيْتُكَ تَصْبُغُ بِالصُّفْرَةِ وَرَأَيْتُكَ إِذَا كُنْتَ بِمَكَّةَ أَهَلَّ النَّاسُ إِذَا رَأَوُا الْهِلاَلَ وَلَمْ تُهْلِلْ أَنْتَ حَتَّى يَكُونَ يَوْمُ التَّرْوِيَةِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَمَّا الأَرْكَانُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمَسُّ إِلاَّ الْيَمَانِيَّيْنِ وَأَمَّا النِّعَالُ السِّبْتِيَّةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْبَسُ النِّعَالَ الَّتِي لَيْسَ فِيهَا شَعَرٌ وَيَتَوَضَّأُ فِيهَا فَأَنَا أُحِبُّ أَنْ أَلْبَسَهَا وَأَمَّا الصُّفْرَةُ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْبُغُ بِهَا فَأَنَا أُحِبُّ أَنْ أَصْبُغَ بِهَا وَأَمَّا الإِهْلاَلُ فَإِنِّي لَمْ أَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُهِلُّ حَتَّى تَنْبَعِثَ بِهِ رَاحِلَتُهُ ‏.‏\hadithno{736}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Abi Said al-Maqburi that Ubayd ibn Jurayj once said to Abdullah ibn Umar, "Abu Abd ar- Rahman, I have seen you doing four things which I have never seen any of your companions doing." He said, "What are they, Ibn Jurayj?" and he replied, "I have seen you touching only the twoYamani corners, I have seen you wearing hairless sandals, I have seen you using yellow dye, and, when you were at Makka and everybody had started doing talbiya after seeing the new moon, I saw that you did not do so until the eighth of Dhu'l-Hijja." Abdullah ibn Umar replied, "As for the corners, I only ever saw the Messenger of Allah, may Allah bless him and grant him peace, touching the two Yamani corners. As for the sandals, I saw the Messenger of Allah, may Allah bless him and grant him peace, wearing hairless sandals and doing wudu in them, and I like wearing them. As for using yellow dye, I saw the Messenger of Allah, may Allah bless him and grant him peace, using it, and I also like to use it for dyeing things with. As for doing talbiya, I never saw the Messenger of Allah, may Allah bless him and grant him peace, begin doing so until he had set out on the animal he was riding on (i.e. for Mina and Arafa)}}
\hadithdefcmd{malik}{737}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُصَلِّي فِي مَسْجِدِ ذِي الْحُلَيْفَةِ\hadithno{737}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to pray in the mosque of Dhu'l-Hulayfa, and then go outside and get on his camel and when his camel had stood up he would begin to do talbiya}}
\hadithdefcmd{malik}{738}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ الْمَلِكِ بْنَ مَرْوَانَ، أَهَلَّ مِنْ عِنْدِ مَسْجِدِ ذِي الْحُلَيْفَةِ حِينَ اسْتَوَتْ بِهِ رَاحِلَتُهُ وَأَنَّ أَبَانَ بْنَ عُثْمَانَ أَشَارَ عَلَيْهِ بِذَلِكَ ‏.‏\hadithno{738}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abd al- Malik ibn Marwan had started to do talbiya at the mosque of Dhu'l-Hulayfa, after the animal he was riding on had stood up, and that Aban ibn Uthman had told him to do this}}
\hadithdefcmd{malik}{739}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ خَلاَّدِ بْنِ السَّائِبِ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَتَانِي جِبْرِيلُ فَأَمَرَنِي أَنْ آمُرَ أَصْحَابِي أَوْ مَنْ مَعِي أَنْ يَرْفَعُوا أَصْوَاتَهُمْ بِالتَّلْبِيَةِ أَوْ بِالإِهْلاَلِ ‏"‏ ‏.‏ يُرِيدُ أَحَدَهُمَا ‏.‏\hadithno{739}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from 'Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm from Abd al-Malik ibn Abi Bakr ibn al-Harith ibn Hisham from Khallad ibn as-Sa'ib al-Ansari from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "Jibril came to me and told me to tell my companions, or whoever was with me, to raise their voices when doing talbiya}}
\hadithdefcmd{malik}{740}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِحَجَّةٍ وَعُمْرَةٍ وَمِنَّا مَنْ أَهَلَّ بِالْحَجِّ وَأَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحَجِّ فَأَمَّا مَنْ أَهَلَّ بِعُمْرَةٍ فَحَلَّ وَأَمَّا مَنْ أَهَلَّ بِحَجٍّ أَوْ جَمَعَ الْحَجَّ وَالْعُمْرَةَ فَلَمْ يُحِلُّوا حَتَّى كَانَ يَوْمُ النَّحْرِ ‏.‏\hadithno{740}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard the people of knowledge say, "Women do not have to raise their voices when they are doing talbiya, and a woman should only speak loudly enough to hear herself." Malik said, "Some one who is in ihram should not raise his voice when doing talbiya if he is in a mosque where there are groups of people. He should only speak loudly enough for himself and those who are near him to be able to hear, except in the Masjid alHaram and the mosque at Mina, where he should raise his voice." Malik said, "I have heard some of the people of knowledge recommending (people to do) talbiya at the end of every prayer and at every rise on the route." Yahya related to me from Malik, from Abu'l-Aswad Muhammad ibn Abd ar-Rahman, fromUrwa ibn az-Zubayr, that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "We set out with the Messenger of Allah, may Allah bless him and grant him peace, in the year of the farewell hajj, and some of us went into ihram to do umra, some of us went into ihram to do hajj and umra, and some of us went into ihram to do hajj on its own. The Messenger of Allah, may Allah bless him and grant him peace, went into ihram to do hajj on its own. Those who had gone into ihram to do umra came out of ihram (after doing umra). Those who had gone into ihram to do hajj (on its own), or to do both hajj and umra, did not come out of ihram until the day of the sacrifice}}
\hadithdefcmd{malik}{741}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْرَدَ الْحَجَّ ‏.‏\hadithno{741}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik, from Abd ar-Rahman ibn al-Qasim, from his father, from A'isha, umm al-muminin, that the Messenger of Allah, may Allah bless him and grant him peace, did hajj on its own}}
\hadithdefcmd{malik}{742}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ قَالَ وَكَانَ يَتِيمًا فِي حَجْرِ عُرْوَةَ بْنِ الزُّبَيْرِ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْرَدَ الْحَجَّ ‏.‏\hadithno{742}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik, from Abu'l-Aswad Muhammad ibn 'Abd ar-Rahman, from Urwa ibn az-Zubayr, from A'isha, umm al-muminin, that the Messenger of Allah, may Allah bless him and grant him peace, did hajj on its own}}
\hadithdefcmd{malik}{743}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ الْمِقْدَادَ بْنَ الأَسْوَدِ، دَخَلَ عَلَى عَلِيِّ بْنِ أَبِي طَالِبٍ بِالسُّقْيَا وَهُوَ يَنْجَعُ بَكَرَاتٍ لَهُ دَقِيقًا وَخَبَطًا فَقَالَ هَذَا عُثْمَانُ بْنُ عَفَّانَ يَنْهَى عَنْ أَنْ يُقْرَنَ بَيْنَ الْحَجِّ وَالْعُمْرَةِ ‏.‏ فَخَرَجَ عَلِيُّ بْنُ أَبِي طَالِبٍ وَعَلَى يَدَيْهِ أَثَرُ الدَّقِيقِ وَالْخَبَطِ - فَمَا أَنْسَى أَثَرَ الدَّقِيقِ وَالْخَبَطِ عَلَى ذِرَاعَيْهِ - حَتَّى دَخَلَ عَلَى عُثْمَانَ بْنِ عَفَّانَ فَقَالَ أَنْتَ تَنْهَى عَنْ أَنْ يُقْرَنَ بَيْنَ الْحَجِّ وَالْعُمْرَةِ فَقَالَ عُثْمَانُ ذَلِكَ رَأْيِي ‏.‏ فَخَرَجَ عَلِيٌّ مُغْضَبًا وَهُوَ يَقُولُ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ بِحَجَّةٍ وَعُمْرَةٍ مَعًا ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّ مَنْ قَرَنَ الْحَجَّ وَالْعُمْرَةَ لَمْ يَأْخُذْ مِنْ شَعَرِهِ شَيْئًا وَلَمْ يَحْلِلْ مِنْ شَىْءٍ حَتَّى يَنْحَرَ هَدْيًا إِنْ كَانَ مَعَهُ وَيَحِلُّ بِمِنًى يَوْمَ النَّحْرِ ‏.‏\hadithno{743}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard the people of knowledge say, "If someone goes into ihram to do hajj on its own, he cannot then go into ihram to do umra.'' Malik said, "This is what I have found the people of knowledge in our city doing." Yahya related to me from Malik, from Jafar ibn Muhammad, from his father, that al-Miqdad ibn al-Aswad once went to see AIi ibn Abi Talibat as-Suqya, where he was feeding some young camels of his with a mash of meal and leaves, and he said to him, "This man Uthman ibn Affan is telling people that they cannot do hajj and umra together." Al-Miqdad said, "Ali ibn Abi Talib went off with bits of meal and leaves on his forearms - and I shall never forget the sight of the meal and the leaves on his arms - and went to see Uthman ibn Affan and asked him, 'Are you saying then that people cannot do hajj and umra together?' Uthman replied, 'That is my opinion.' Whereupon AIi got angry and went out saying, 'I am at your service, O Allah, I am at your service for a hajj and an umra together.' " Malik said, "Our position (here in Madina) is that someone who does hajj and umra together should not remove any of his hair, nor should he come out of ihram in any way until he has sacrificed an animal, if he has one. He should come out of ihram at Mina, on the day of the sacrifice}}
\hadithdefcmd{malik}{744}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ خَرَجَ إِلَى الْحَجِّ فَمِنْ أَصْحَابِهِ مَنْ أَهَلَّ بِحَجٍّ وَمِنْهُمْ مَنْ جَمَعَ الْحَجَّ وَالْعُمْرَةَ وَمِنْهُمْ مَنْ أَهَلَّ بِعُمْرَةٍ فَأَمَّا مَنْ أَهَلَّ بِحَجٍّ أَوْ جَمَعَ الْحَجَّ وَالْعُمْرَةَ فَلَمْ يَحْلِلْ وَأَمَّا مَنْ كَانَ أَهَلَّ بِعُمْرَةٍ فَحَلُّوا ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ أَنَّهُ سَمِعَ بَعْضَ أَهْلِ الْعِلْمِ يَقُولُونَ مَنْ أَهَلَّ بِعُمْرَةٍ ثُمَّ بَدَا لَهُ أَنْ يُهِلَّ بِحَجٍّ مَعَهَا فَذَلِكَ لَهُ مَا لَمْ يَطُفْ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ وَقَدْ صَنَعَ ذَلِكَ ابْنُ عُمَرَ حِينَ قَالَ إِنْ صُدِدْتُ عَنِ الْبَيْتِ صَنَعْنَا كَمَا صَنَعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ الْتَفَتَ إِلَى أَصْحَابِهِ فَقَالَ مَا أَمْرُهُمَا إِلاَّ وَاحِدٌ أُشْهِدُكُمْ أَنِّي أَوْجَبْتُ الْحَجَّ مَعَ الْعُمْرَةِ ‏.‏ قَالَ مَالِكٌ وَقَدْ أَهَلَّ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ بِالْعُمْرَةِ ثُمَّ قَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهْلِلْ بِالْحَجِّ مَعَ الْعُمْرَةِ ثُمَّ لاَ يَحِلُّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{744}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik, from Muhammad ibn Abd ar-Rahman, from Sulayman ibn Yasar, that when the Messenger of Allah, may Allah bless him and grant him peace, set out for hajj in the year of the farewell hajj, some of his companions went into ihram to do hajj on its own, some of them combined hajj and umra, and some went into ihram to do umra on its own. Those who had gone into ihram to do hajj, or hajj and umra together, did not come out of ihram, whils tthose who had gone into ihram to doumra (on its own) came out of ihram}}
\hadithdefcmd{malik}{745}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الثَّقَفِيِّ، أَنَّهُ سَأَلَ أَنَسَ بْنَ مَالِكٍ - وَهُمَا غَادِيَانِ مِنْ مِنًى إِلَى عَرَفَةَ - كَيْفَ كُنْتُمْ تَصْنَعُونَ فِي هَذَا الْيَوْمِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ يُهِلُّ الْمُهِلُّ مِنَّا فَلاَ يُنْكَرُ عَلَيْهِ وَيُكَبِّرُ الْمُكَبِّرُ فَلاَ يُنْكَرُ عَلَيْهِ ‏.‏\hadithno{745}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard some of the people of knowledge say, "If someone goes into ihram to do umra and then wants to go into ihram to do hajj as well, he can do so, as long as he has not done tawaf of the House and s'ay between Safa and Marwa. This is what Abdullah ibn 'Umar did when he said, 'If I am blocked from the House we shall do what we did when we were with the Messenger of Allah, may Allah bless him and grant him peace.' He then turned to his companions and said, 'It is the same either way. I call you to witness that I have decided in favour of hajj and umra together. ' " Malik said, "The companions of the Messenger of Allah, may Allah bless him and grant him peace, went into ihram to do umra in the year of the farewell hajj, and the Messenger of Allah, may Allah bless him and grant him peace, said to them, 'Anyone that has a sacrificial animal with him should go into ihram to do hajj and umra together, and he should not come out of ihram until he has finished both.' " Yahya related to me from Malik that Muhammad ibn Abi Bakr ath- Thaqafi once asked Anas ibn Malik, while the two of them were going from Mina to Arafa, "What did you use to do on this day when you were with the Messenger of Allah, may Allah bless him and grant him peace?" He said, "Those of us who were saying the talbiya would continue doing so, and no-one disapproved of it, and those of us who were saying 'Allahu akbar' would continue doing so, and no-one disapproved of that either}}
\hadithdefcmd{malik}{746}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، كَانَ يُلَبِّي فِي الْحَجِّ حَتَّى إِذَا زَاغَتِ الشَّمْسُ مِنْ يَوْمِ عَرَفَةَ قَطَعَ التَّلْبِيَةَ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَذَلِكَ الأَمْرُ الَّذِي لَمْ يَزَلْ عَلَيْهِ أَهْلُ الْعِلْمِ بِبَلَدِنَا ‏.‏\hadithno{746}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik, from Jafar ibn Muhammad, from his father, that AIi ibn Abi Talib used to say the talbiya while on hajj until after noon on the day of Arafa, when he would stop doing so. Yahya said that Malik said, "This is what the people of knowledge in our city are still doing}}
\hadithdefcmd{malik}{747}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ تَتْرُكُ التَّلْبِيَةَ إِذَا رَجَعَتْ إِلَى الْمَوْقِفِ ‏.‏\hadithno{747}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Abd ar-Rahman ibn al-Qasim, from his father, that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, would stop saying the talbiya when she arrived at the place of standing (i.e. Arafa)}}
\hadithdefcmd{malik}{748}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقْطَعُ التَّلْبِيَةَ فِي الْحَجِّ إِذَا انْتَهَى إِلَى الْحَرَمِ حَتَّى يَطُوفَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ يُلَبِّي حَتَّى يَغْدُوَ مِنْ مِنًى إِلَى عَرَفَةَ فَإِذَا غَدَا تَرَكَ التَّلْبِيَةَ وَكَانَ يَتْرُكُ التَّلْبِيَةَ فِي الْعُمْرَةِ إِذَا دَخَلَ الْحَرَمَ ‏.‏\hadithno{748}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Nafi, that when 'Abdullah ibn Umar was doing hajj he would keep saying the talbiya until he reached the Haram and did tawaf of the House and say between Safa and Marwa. He would then say the talbiya until he left Mina to go to Arafa, at which point he would stop doing so. If he was doing umra he would stop saying the talbiya on entering the Haram}}
\hadithdefcmd{malik}{749}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ كَانَ يَقُولُ كَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ لاَ يُلَبِّي وَهُوَ يَطُوفُ بِالْبَيْتِ ‏.‏\hadithno{749}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Ibn Shihab used to say, "Abdullah ibn Umar would never say the talbiya while he was doing tawaf of the House}}
\hadithdefcmd{malik}{750}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا كَانَتْ تَنْزِلُ مِنْ عَرَفَةَ بِنَمِرَةَ ثُمَّ تَحَوَّلَتْ إِلَى الأَرَاكِ ‏.‏ قَالَتْ وَكَانَتْ عَائِشَةُ تُهِلُّ مَا كَانَتْ فِي مَنْزِلِهَا وَمَنْ كَانَ مَعَهَا فَإِذَا رَكِبَتْ فَتَوَجَّهَتْ إِلَى الْمَوْقِفِ تَرَكَتِ الإِهْلاَلَ ‏.‏ قَالَتْ وَكَانَتْ عَائِشَةُ تَعْتَمِرُ بَعْدَ الْحَجِّ مِنْ مَكَّةَ فِي ذِي الْحِجَّةِ ثُمَّ تَرَكَتْ ذَلِكَ فَكَانَتْ تَخْرُجُ قَبْلَ هِلاَلِ الْمُحَرَّمِ حَتَّى تَأْتِيَ الْجُحْفَةَ فَتُقِيمَ بِهَا حَتَّى تَرَى الْهِلاَلَ فَإِذَا رَأَتِ الْهِلاَلَ أَهَلَّتْ بِعُمْرَةٍ ‏.‏\hadithno{750}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik, from AIqama ibn Abi AIqama, from his mother, that A'isha, umm al-muminin, used to camp on the plain of Arafa at a place called Namira, and then later she changed to another place called al-Arak. She said, ''A'isha, and those who were with her, would say the talbiya while she was at the place where they were camping, and then, when she had mounted and set out towards the place of standing, she would stop doing so." She continued, ''A'isha used to do umra when she was in Makka after the hajj was over, in the month of Dhu'l-Hijja.Then she stopped doing that, and instead would set out before the new moon of Muharram for al-J uhfa, where she would stay until she saw the new moon, and then, when she had seen the new moon, she would go into ihram to do umra}}
\hadithdefcmd{malik}{751}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، غَدَا يَوْمَ عَرَفَةَ مِنْ مِنًى فَسَمِعَ التَّكْبِيرَ عَالِيًا فَبَعَثَ الْحَرَسَ يَصِيحُونَ فِي النَّاسِ أَيُّهَا النَّاسُ إِنَّهَا التَّلْبِيَةُ ‏.‏\hadithno{751}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik, from Yahya ibn Said, that Umar ibn Abd alAziz was once going from Mina (to Arafa) on the day of Arafa and heard the takbir being said loudly, so he sent the guard to shout out to the people, "O people, you should be saying the talbiya}}
\hadithdefcmd{malik}{752}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ يَا أَهْلَ مَكَّةَ مَا شَأْنُ النَّاسِ يَأْتُونَ شُعْثًا وَأَنْتُمْ مُدَّهِنُونَ أَهِلُّوا إِذَا رَأَيْتُمُ الْهِلاَلَ ‏.‏\hadithno{752}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik, from Abd ar-Rahman ibn al-Qasim, from his father, that Umar ibn al-Khattab said, "People of Makka, why is it that people arrive dishevelled while you still have oil on your hair? Go into ihram when you see the new moon}}
\hadithdefcmd{malik}{753}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، أَقَامَ بِمَكَّةَ تِسْعَ سِنِينَ يُهِلُّ بِالْحَجِّ لِهِلاَلِ ذِي الْحِجَّةِ وَعُرْوَةُ بْنُ الزُّبَيْرِ مَعَهُ يَفْعَلُ ذَلِكَ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَإِنَّمَا يُهِلُّ أَهْلُ مَكَّةَ وَغَيْرُهُمْ بِالْحَجِّ إِذَا كَانُوا بِهَا وَمَنْ كَانَ مُقِيمًا بِمَكَّةَ مِنْ غَيْرِ أَهْلِهَا مِنْ جَوْفِ مَكَّةَ لاَ يَخْرُجُ مِنَ الْحَرَمِ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَمَنْ أَهَلَّ مِنْ مَكَّةَ بِالْحَجِّ فَلْيُؤَخِّرِ الطَّوَافَ بِالْبَيْتِ وَالسَّعْىَ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى يَرْجِعَ مِنْ مِنًى وَكَذَلِكَ صَنَعَ عَبْدُ اللَّهِ بْنُ عُمَرَ ‏.‏ وَسُئِلَ مَالِكٌ عَمَّنْ أَهَلَّ بِالْحَجِّ مِنْ أَهْلِ الْمَدِينَةِ أَوْ غَيْرِهِمْ مِنْ مَكَّةَ لِهِلاَلِ ذِي الْحِجَّةِ كَيْفَ يَصْنَعُ بِالطَّوَافِ قَالَ أَمَّا الطَّوَافُ الْوَاجِبُ فَلْيُؤَخِّرْهُ وَهُوَ الَّذِي يَصِلُ بَيْنَهُ وَبَيْنَ السَّعْىِ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَلْيَطُفْ مَا بَدَا لَهُ وَلْيُصَلِّ رَكْعَتَيْنِ كُلَّمَا طَافَ سُبْعًا وَقَدْ فَعَلَ ذَلِكَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِينَ أَهَلُّوا بِالْحَجِّ فَأَخَّرُوا الطَّوَافَ بِالْبَيْتِ وَالسَّعْىَ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى رَجَعُوا مِنْ مِنًى وَفَعَلَ ذَلِكَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَكَانَ يُهِلُّ لِهِلاَلِ ذِي الْحِجَّةِ بِالْحَجِّ مِنْ مَكَّةَ وَيُؤَخِّرُ الطَّوَافَ بِالْبَيْتِ وَالسَّعْىَ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى يَرْجِعَ مِنْ مِنًى ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ مِنْ أَهْلِ مَكَّةَ هَلْ يُهِلُّ مِنْ جَوْفِ مَكَّةَ بِعُمْرَةٍ قَالَ بَلْ يَخْرُجُ إِلَى الْحِلِّ فَيُحْرِمُ مِنْهُ ‏.‏\hadithno{753}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Hisham ibn Urwa, that Abdullah ibn az-Zubayr stayed in Makka for nine years. He would go into ihram for hajj at the beginning of Dhu'l-Hijja, and Urwa ibn az- Zubayr, who was with him, would do likewise. Yahya said that Malik said, "The people of Makka and whoever else is living there besides them should go into ihram for hajj if they are in Makka, and anyone that is living in the centre of Makka and is not one of the people of Makka should not leave the Haram." Yahya said that Malik said, "Someone who goes into ihram for hajj in Makka should delay tawaf of the House and the sa'y between Safa and Marwa until he has come back from Mina, which is what Abdullah ibn Umar used to do." Malik was asked what the people of Madina, or anybody else, should do about tawaf if they went into ihram in Makka at the beginning of Dhu'l-Hijja, and he said, "They should delay the obligatory tawaf, which is the one they combine with the say between Safa and Marwa, but they can do whatever other tawaf they want to, and they should pray two rakas every time they complete seven tawafs, which is what the companions of the Messenger of Allah, may Allah bless him and grant him peace, did when they had gone into ihram to do hajj. They delayed the tawaf of the House and the sa'y between Safa and Marwa until they had come back from Mina. Abdullah ibn Umar also did this, going into ihram for hajj in Makka at the beginning of Dhu'l-Hijja, and then delaying tawaf of theHouse and the say between Safa and Marwa until he had come back from Mina." Malik was asked whether one of the people of Makka could go into ihram to do umra in the centre of Makka, and he said, "No. He should go outside the Haram and go into ihram there}}
\hadithdefcmd{malik}{754}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ أَنَّ زِيَادَ بْنَ أَبِي سُفْيَانَ كَتَبَ إِلَى عَائِشَةَ زَوْجِ النِّبِيِّ صلى الله عليه وسلم أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ قَالَ مَنْ أَهْدَى هَدْيًا حَرُمَ عَلَيْهِ مَا يَحْرُمُ عَلَى الْحَاجِّ حَتَّى يُنْحَرَ الْهَدْىُ وَقَدْ بَعَثْتُ بِهَدْىٍ فَاكْتُبِي إِلَىَّ بِأَمْرِكِ أَوْ مُرِي صَاحِبَ الْهَدْىِ ‏.‏ قَالَتْ عَمْرَةُ قَالَتْ عَائِشَةُ لَيْسَ كَمَا قَالَ ابْنُ عَبَّاسٍ أَنَا فَتَلْتُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ ثُمَّ قَلَّدَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ ثُمَّ بَعَثَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ أَبِي فَلَمْ يَحْرُمْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم شَىْءٌ أَحَلَّهُ اللَّهُ لَهُ حَتَّى نُحِرَ الْهَدْىُ ‏.‏\hadithno{754}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik, from 'Abdullah ibn Abi Bakr ibn Muhammad, that Amra bint 'Abd ar-Rahman told him that Ziyad ibn Abi Sufyan once wrote to A'isha, the wife of the Prophet, may Allah bless him and grant him peace, saying, "'Abdullah ibn Abbas said that whatever was haram for some one doing hajj was also haram for some one who sent a sacrificial animal until the animal was sacrificed. I have sent one, so write and tell me what you say about this, or tell the man in charge of the animal what to do. Amra said that A'isha said, "It is notas Ibn Abbas has said. I once plaited the garlands for the sacrificial animal of the Messenger of Allah, may Allah bless him and grant him peace, with my own two hands. Then after that the Messenger of Allah, may Allah bless him and grant him peace, himself put the garlands on the animal and then sent it with my father. And there was nothing that Allah had made halal forthe Messenger of Allah, may Allah bless him and grant him peace, that was haram for him until such time as the animal had been sacrificed}}
\hadithdefcmd{malik}{755}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سَأَلْتُ عَمْرَةَ بِنْتَ عَبْدِ الرَّحْمَنِ عَنِ الَّذِي، يَبْعَثُ بِهَدْيِهِ وَيُقِيمُ هَلْ يَحْرُمُ عَلَيْهِ شَىْءٌ فَأَخْبَرَتْنِي أَنَّهَا سَمِعَتْ عَائِشَةَ تَقُولُ لاَ يَحْرُمُ إِلاَّ مَنْ أَهَلَّ وَلَبَّى ‏.‏\hadithno{755}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "I asked Amra bint Abd ar-Rahman if there was anything that was haram for someone who sent a sacrificial animal (to Makka) but did not go there himself, and she told me that she had heard A'isha say, 'It is only some one who goes into ihram for hajj and begins saying the talbiya for whom things are haram}}
\hadithdefcmd{malik}{756}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ رَبِيعَةَ بْنِ عَبْدِ اللَّهِ بْنِ الْهُدَيْرِ، أَنَّهُ رَأَى رَجُلاً مُتَجَرِّدًا بِالْعِرَاقِ فَسَأَلَ النَّاسَ عَنْهُ فَقَالُوا إِنَّهُ أَمَرَ بِهَدْيِهِ أَنْ يُقَلَّدَ فَلِذَلِكَ تَجَرَّدَ ‏.‏ قَالَ رَبِيعَةُ فَلَقِيتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ فَذَكَرْتُ لَهُ ذَلِكَ فَقَالَ بِدْعَةٌ وَرَبِّ الْكَعْبَةِ ‏.‏ وَسُئِلَ مَالِكٌ عَمَّنْ خَرَجَ بِهَدْىٍ لِنَفْسِهِ فَأَشْعَرَهُ وَقَلَّدَهُ بِذِي الْحُلَيْفَةِ وَلَمْ يُحْرِمْ هُوَ حَتَّى جَاءَ الْجُحْفَةَ قَالَ لاَ أُحِبُّ ذَلِكَ وَلَمْ يُصِبْ مَنْ فَعَلَهُ وَلاَ يَنْبَغِي لَهُ أَنْ يُقَلِّدَ الْهَدْىَ وَلاَ يُشْعِرَهُ إِلاَّ عِنْدَ الإِهْلاَلِ إِلاَّ رَجُلٌ لاَ يُرِيدُ الْحَجَّ فَيَبْعَثُ بِهِ وَيُقِيمُ فِي أَهْلِهِ ‏.‏ وَسُئِلَ مَالِكٌ هَلْ يَخْرُجُ بِالْهَدْىِ غَيْرُ مُحْرِمٍ فَقَالَ نَعَمْ لاَ بَأْسَ بِذَلِكَ ‏.‏ وَسُئِلَ أَيْضًا عَمَّا اخْتَلَفَ فِيهِ النَّاسُ مِنَ الإِحْرَامِ لِتَقْلِيدِ الْهَدْىِ مِمَّنْ لاَ يُرِيدُ الْحَجَّ وَلاَ الْعُمْرَةَ فَقَالَ الأَمْرُ عِنْدَنَا الَّذِي نَأْخُذُ بِهِ فِي ذَلِكَ قَوْلُ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ بِهَدْيِهِ ثُمَّ أَقَامَ فَلَمْ يَحْرُمْ عَلَيْهِ شَىْءٌ مِمَّا أَحَلَّهُ اللَّهُ لَهُ حَتَّى نُحِرَ هَدْيُهُ ‏.‏\hadithno{756}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Yahya ibn Said, from Muhammad ibn Ibrahim ibn al-Harith at-Taymi, that Rabia ibn Abdullah ibn al-Hudayr once saw a man in a state of ihram in Iraq. So he asked people about him and they said, "He has given directions for his sacrificial animal to be garlanded, and it is for that reason that he has put on ihram ." Rabia said, "I then met Abdullah ibn az- Zubayr and so I mentioned this to him and he said, 'By the Lord of the Kaba, an innovation.' " Malik was asked about some one who set out with his own sacrificial animal and marked it and garlanded it at Dhu'l-Hulayfa, but did not go into ihram until he had reached al- Juhfa,and hesaid, "I do not like that, and whoever does so has not acted properly. He should only garland his sacrificial animal, or mark it, when he goes into ihram, unless it is someone who does not intend to do hajj, in which case he sends it off and stays with his family." Malik was asked if somone who was not in ihram could set out with a sacrificial animal, and he said, "Yes. There is no harm in that." He was also asked to comment on the different views people had about what became haram for some one who garlanded a sacrificial animal but did not intend to do either hajj or umra, and he said, "What we go by as far as this is concerned is what A'isha, umm al-muminin said, 'The Messenger of Allah, may Allah bless him and grant him peace, sent his sacrificial animal off and did not go there himself, and there was nothing that Allah had made halal for him that was haram for him until the animal had been sacrificed}}
\hadithdefcmd{malik}{757}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ الْمَرْأَةُ الْحَائِضُ الَّتِي تُهِلُّ بِالْحَجِّ أَوِ الْعُمْرَةِ إِنَّهَا تُهِلُّ بِحَجِّهَا أَوْ عُمْرَتِهَا إِذَا أَرَادَتْ وَلَكِنْ لاَ تَطُوفُ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَهِيَ تَشْهَدُ الْمَنَاسِكَ كُلَّهَا مَعَ النَّاسِ غَيْرَ أَنَّهَا لاَ تَطُوفُ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَلاَ تَقْرَبُ الْمَسْجِدَ حَتَّى تَطْهُرَ ‏.‏\hadithno{757}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Nafi, that Abdullah ibn Umar used to say, "A menstruating woman who wants to go into ihram to do either hajj or umra can do so if she so wishes, but she cannot do tawaf of the House, nor the say between Safa and Marwa. She can participate in all the rituals along with everybody else, except that she cannot do tawaf of the House, nor the say between Safa and Marwa, nor can she come near the mosque until she is pure}}
\hadithdefcmd{malik}{758}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَمَرَ ثَلاَثًا عَامَ الْحُدَيْبِيَةِ وَعَامَ الْقَضِيَّةِ وَعَامَ الْجِعِرَّانَةِ ‏.‏\hadithno{758}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, did umra three times:in the year of Hudaybiya, in the year of al-Qadiyya, and in the year of al-Jiirrana}}
\hadithdefcmd{malik}{759}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَعْتَمِرْ إِلاَّ ثَلاَثًا إِحْدَاهُنَّ فِي شَوَّالٍ وَاثْنَتَيْنِ فِي ذِي الْقَعْدَةِ ‏.‏\hadithno{759}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa, from his father, that the Messenger of Allah, may Allah bless him and grant him peace, only did three umras, one of them in Shawwal, and two in Dhu'l-Qada}}
\hadithdefcmd{malik}{760}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ الأَسْلَمِيِّ، أَنَّ رَجُلاً، سَأَلَ سَعِيدَ بْنَ الْمُسَيَّبِ فَقَالَ أَعْتَمِرُ قَبْلَ أَنْ أَحُجَّ، فَقَالَ سَعِيدٌ نَعَمْ قَدِ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ أَنْ يَحُجَّ ‏.‏\hadithno{760}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik, from Abd ar-Rahman ibn Harmala al-Aslami, that somebody asked Said ibn al-Musayyab, "Can I do umra before I do hajj?", and Said said, "Yes, the Messenger of Allah, may Allah bless him and grant him peace, did umra before doing hajj}}
\hadithdefcmd{malik}{761}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ أَبِي سَلَمَةَ، اسْتَأْذَنَ عُمَرَ بْنَ الْخَطَّابِ أَنْ يَعْتَمِرَ، فِي شَوَّالٍ فَأَذِنَ لَهُ فَاعْتَمَرَ ثُمَّ قَفَلَ إِلَى أَهْلِهِ وَلَمْ يَحُجَّ ‏.‏\hadithno{761}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Ibn Shihab, from Said ibn al-Musayyab, that Umar ibn Abi Salama once asked Umar ibn alKhattab for permission to do umra in Shawwal. He gave him permission, so he did umra and then went back to his family, and he did not do hajj}}
\hadithdefcmd{malik}{762}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقْطَعُ التَّلْبِيَةَ فِي الْعُمْرَةِ إِذَا دَخَلَ الْحَرَمَ ‏.‏ قَالَ مَالِكٌ فِيمَنْ أَحْرَمَ مِنَ التَّنْعِيمِ إِنَّهُ يَقْطَعُ التَّلْبِيَةَ حِينَ يَرَى الْبَيْتَ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَنِ الرَّجُلِ يَعْتَمِرُ مِنْ بَعْضِ الْمَوَاقِيتِ وَهُوَ مِنْ أَهْلِ الْمَدِينَةِ أَوْ غَيْرِهِمْ مَتَى يَقْطَعُ التَّلْبِيَةَ قَالَ أَمَّا الْمُهِلُّ مِنَ الْمَوَاقِيتِ فَإِنَّهُ يَقْطَعُ التَّلْبِيَةَ إِذَا انْتَهَى إِلَى الْحَرَمِ ‏.‏ قَالَ وَبَلَغَنِي أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ كَانَ يَصْنَعُ ذَلِكَ ‏.‏\hadithno{762}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik, from Hisham ibn 'Urwa, that his father would stop saying the talbiya when he entered the Haram, if he was doing 'umra. Malik said that someone who went into ihram at at-Tanim should stop saying the talbiya when he saw the House. Yahya said that Malik was asked where a man from the people of Madina, or elsewhere, who had begun doing umra at one of the mawaqit, should stop saying the talbiya, and he said, "Someone who goes into ihram at one of the mawaqit should stop saying the talbiya when he arrives at the Haram." Malik added, "I have heard that Abdullah ibn Umar used to do that}}
\hadithdefcmd{malik}{763}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ حَدَّثَهُ أَنَّهُ، سَمِعَ سَعْدَ بْنَ أَبِي وَقَّاصٍ، وَالضَّحَّاكَ بْنَ قَيْسٍ، عَامَ حَجَّ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ - وَهُمَا يَذْكُرَانِ التَّمَتُّعَ بِالْعُمْرَةِ إِلَى الْحَجِّ - فَقَالَ الضَّحَّاكُ بْنُ قَيْسٍ لاَ يَفْعَلُ ذَلِكَ إِلاَّ مَنْ جَهِلَ أَمْرَ اللَّهِ عَزَّ وَجَلَّ ‏.‏ فَقَالَ سَعْدٌ بِئْسَ مَا قُلْتَ يَا ابْنَ أَخِي ‏.‏ فَقَالَ الضَّحَّاكُ فَإِنَّ عُمَرَ بْنَ الْخَطَّابِ قَدْ نَهَى عَنْ ذَلِكَ ‏.‏ فَقَالَ سَعْدٌ قَدْ صَنَعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَنَعْنَاهَا مَعَهُ ‏.‏\hadithno{763}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik, from Ibn Shihab, that Muhammad ibn Abdullah ibn al-Harith ibn Nawfal ibn Abd al-Muttalib told him that he had heard Sad ibn Abi Waqqas and ad-Dahhak ibn Qays discussing tamattu in between umra and hajj. Ad-Dahhak ibn Qays said, "Only someone who is ignorant of what Allah, the Exalted and Glorified, says would do that." Whereupon Sad said, "How wrong is what you have just said, son of my brother!" Ad-Dahhak said, ''Umar ibn al-Khattab forbade that," and Sad said, "The Messenger of Allah, may Allah bless him and grant him peace, did it, and we did it with him}}
\hadithdefcmd{malik}{764}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ صَدَقَةَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ وَاللَّهِ لأَنْ أَعْتَمِرَ قَبْلَ الْحَجِّ وَأُهْدِيَ أَحَبُّ إِلَىَّ مِنْ أَنْ أَعْتَمِرَ بَعْدَ الْحَجِّ فِي ذِي الْحِجَّةِ ‏.‏\hadithno{764}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Sadaqa ibn Yasar, that Abdullah ibn Umar said, "By Allah, I would rather do umra before hajj and sacrifice an animal than do umra after hajj in the month of Dhu'l-Hijja}}
\hadithdefcmd{malik}{765}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ مَنِ اعْتَمَرَ فِي أَشْهُرِ الْحَجِّ فِي شَوَّالٍ أَوْ ذِي الْقَعْدَةِ أَوْ فِي ذِي الْحِجَّةِ قَبْلَ الْحَجِّ ثُمَّ أَقَامَ بِمَكَّةَ حَتَّى يُدْرِكَهُ الْحَجُّ فَهُوَ مُتَمَتِّعٌ إِنْ حَجَّ وَعَلَيْهِ مَا اسْتَيْسَرَ مِنَ الْهَدْىِ فَإِنْ لَمْ يَجِدْ فَصِيَامُ ثَلاَثَةِ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةٍ إِذَا رَجَعَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ إِذَا أَقَامَ حَتَّى الْحَجِّ ثُمَّ حَجَّ مِنْ عَامِهِ ‏.‏ قَالَ مَالِكٌ فِي رَجُلٍ مِنْ أَهْلِ مَكَّةَ انْقَطَعَ إِلَى غَيْرِهَا وَسَكَنَ سِوَاهَا ثُمَّ قَدِمَ مُعْتَمِرًا فِي أَشْهُرِ الْحَجِّ ثُمَّ أَقَامَ بِمَكَّةَ حَتَّى أَنْشَأَ الْحَجَّ مِنْهَا إِنَّهُ مُتَمَتِّعٌ يَجِبُ عَلَيْهِ الْهَدْىُ أَوِ الصِّيَامُ إِنْ لَمْ يَجِدْ هَدْيًا وَأَنَّهُ لاَ يَكُونُ مِثْلَ أَهْلِ مَكَّةَ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ مِنْ غَيْرِ أَهْلِ مَكَّةَ دَخَلَ مَكَّةَ بِعُمْرَةٍ فِي أَشْهُرِ الْحَجِّ وَهُوَ يُرِيدُ الإِقَامَةَ بِمَكَّةَ حَتَّى يُنْشِئَ الْحَجَّ أَمُتَمَتِّعٌ هُوَ فَقَالَ نَعَمْ هُوَ مُتَمَتِّعٌ وَلَيْسَ هُوَ مِثْلَ أَهْلِ مَكَّةَ وَإِنْ أَرَادَ الإِقَامَةَ وَذَلِكَ أَنَّهُ دَخَلَ مَكَّةَ وَلَيْسَ هُوَ مِنْ أَهْلِهَا وَإِنَّمَا الْهَدْىُ أَوِ الصِّيَامُ عَلَى مَنْ لَمْ يَكُنْ مِنْ أَهْلِ مَكَّةَ وَأَنَّ هَذَا الرَّجُلَ يُرِيدُ الإِقَامَةَ وَلاَ يَدْرِي مَا يَبْدُو لَهُ بَعْدَ ذَلِكَ وَلَيْسَ هُوَ مِنْ أَهْلِ مَكَّةَ ‏.‏\hadithno{765}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Abdullah ibn Dinar, that Abdullah ibn Umar used to say, "Anyone that does umra in the months of hajj, that is, in Shawwal, Dhu'l-Qada, or in Dhu'l-Hijja before the hajj, and then stays in Makka until the time for hajj, is doing tamattu if he then does hajj. He must sacrifice whatever animal it is easy for him to obtain, and if he cannot find one then he must fast three days during hajj and seven days when he returns." Malik said, "This is only the case if he stays until the hajj and does hajj in that same year." Malik said that if someone who was from Makka but had stopped living there and gone to live elsewhere, came back to do umra in the months of the hajj and then stayed in Makka to begin hajj there, he was doing tamattu, and had to offer up a sacrificial animal, or fast if he could not find one. He was not the same as the people of Makka. Malik was asked whether someone who was not from Makka and entered Makka to do umra in the months of hajj with the intention of staying on to begin his hajj there was doing tamattu or not, and he said, "Yes, he is doing tamattu, and he is not the same as the people of Makka, even if he has the intention of staying there. This is because he has entered Makka, and is not one of its people, and making a sacrifice or fasting is incumbent on anyone who is not from Makka, and, although he intends to stay, he does not know what possibilities might arise later. He is not one of the people of Makka}}
\hadithdefcmd{malik}{766}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ مَنِ اعْتَمَرَ فِي شَوَّالٍ أَوْ ذِي الْقَعْدَةِ أَوْ فِي ذِي الْحِجَّةِ ثُمَّ أَقَامَ بِمَكَّةَ حَتَّى يُدْرِكَهُ الْحَجُّ فَهُوَ مُتَمَتِّعٌ إِنْ حَجَّ وَمَا اسْتَيْسَرَ مِنَ الْهَدْىِ فَمَنْ لَمْ يَجِدْ فَصِيَامُ ثَلاَثَةِ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةٍ إِذَا رَجَعَ ‏.‏\hadithno{766}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said used to hear Said ibn al-Musayyab say, "Anyone that does umra in Shawwal, Dhu'l-Qada or Dhu l-Hijja, and then stays in Makka until it is time for the hajj, is doing tamattu if he then does hajj. He must sacrifice whatever animal it is easy for him to obtain, and if he cannot find one then he must fast three days during hajj and seven days when he returns}}
\hadithdefcmd{malik}{767}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَةُ إِلَى الْعُمْرَةِ كَفَّارَةٌ لِمَا بَيْنَهُمَا وَالْحَجُّ الْمَبْرُورُ لَيْسَ لَهُ جَزَاءٌ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{767}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said, "Someone who does umra in Shawwal, Dhu'l-Qada or Dhu'l-Hijja and then goes back to his people, and then returns and does hajj in that same year does not have to sacrifice an animal. Sacrificing an animal is only incumbent on some one who does umra in the months of hajj, and then stays in Makka and then does hajj. A person not from Makka who moves to Makka and establishes his home there and does umra in the months of the hajj and then begins his hajj there is not doing tamattu. He does not have to sacrifice an animal nor does he have to fast. He is in the same position as the people of Makka if he is one of those who are living there." Malik was asked whether a man from Makka who had gone to live in another town or had been on a journey and then returned to Makka with the intention of staying there, regardless of whether he had a family there or not, and entered it to do umra in the months of the hajj, and then began his hajj there, beginning his umra at the miqat of the Prophet, may Allah bless him and grant him peace, or at a place nearer than that, was doing tamattu or not? Malik answered, "He does not have to sacrifice an animal or fast as someone who is doing tamattu has to do. This is because Allah, the Blessed and Exalted, says in His Book, 'That is for someone whose family are not present at Masjid al-Haram. ' Yahya related to me from Malik, from Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman, from Abu Salih as-Samman, from Abu Hurayra, that the Messenger of Allah, may Allah bless him and grant him peace ,said, "Umra is an expiation for what is between it and the next umra, and the only reward for an accepted hajj is the Garden}}
\hadithdefcmd{malik}{768}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ أَنَّهُ سَمِعَ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، يَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي قَدْ كُنْتُ تَجَهَّزْتُ لِلْحَجِّ فَاعْتَرَضَ لِي ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اعْتَمِرِي فِي رَمَضَانَ فَإِنَّ عُمْرَةً فِيهِ كَحِجَّةٍ ‏"‏ ‏.‏\hadithno{768}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman, heard Abu Bakribn Abd ar-Rahman say, "A woman came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'I had arranged to do hajj, but I was prevented,' and the Messenger of Allah, may Allah bless him and grant him peace, said, 'Do umra in Ramadan, for doing umra in it is like doing hajj}}
\hadithdefcmd{malik}{769}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ افْصِلُوا بَيْنَ حَجِّكُمْ وَعُمْرَتِكُمْ فَإِنَّ ذَلِكَ أَتَمُّ لِحَجِّ أَحَدِكُمْ وَأَتَمُّ لِعُمْرَتِهِ أَنْ يَعْتَمِرَ فِي غَيْرِ أَشْهُرِ الْحَجِّ ‏.‏\hadithno{769}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Nafi, from Abdullah ibn Umar, that Umar ibn al-Khattab said, "Keep your hajj separate from your umra. That way your hajj will be more complete. And your umra will be more complete if you do it outside of the months of the hajj}}
\hadithdefcmd{malik}{770}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُثْمَانَ بْنَ عَفَّانَ، كَانَ إِذَا اعْتَمَرَ رُبَّمَا لَمْ يَحْطُطْ عَنْ رَاحِلَتِهِ حَتَّى يَرْجِعَ ‏.‏ قَالَ مَالِكٌ الْعُمْرَةُ سُنَّةٌ وَلاَ نَعْلَمُ أَحَدًا مِنَ الْمُسْلِمِينَ أَرْخَصَ فِي تَرْكِهَا ‏.‏ قَالَ مَالِكٌ وَلاَ أَرَى لأَحَدٍ أَنْ يَعْتَمِرَ فِي السَّنَةِ مِرَارًا ‏.‏ قَالَ مَالِكٌ فِي الْمُعْتَمِرِ يَقَعُ بِأَهْلِهِ إِنَّ عَلَيْهِ فِي ذَلِكَ الْهَدْىَ وَعُمْرَةً أُخْرَى يَبْتَدِئُ بِهَا بَعْدَ إِتْمَامِهِ الَّتِي أَفْسَدَ وَيُحْرِمُ مِنْ حَيْثُ أَحْرَمَ بِعُمْرَتِهِ الَّتِي أَفْسَدَ إِلاَّ أَنْ يَكُونَ أَحْرَمَ مِنْ مَكَانٍ أَبْعَدَ مِنْ مِيقَاتِهِ فَلَيْسَ عَلَيْهِ أَنْ يُحْرِمَ إِلاَّ مِنْ مِيقَاتِهِ ‏.‏ قَالَ مَالِكٌ وَمَنْ دَخَلَ مَكَّةَ بِعُمْرَةٍ فَطَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ وَهُوَ جُنُبٌ أَوْ عَلَى غَيْرِ وُضُوءٍ ثُمَّ وَقَعَ بِأَهْلِهِ ثُمَّ ذَكَرَ - قَالَ - يَغْتَسِلُ أَوْ يَتَوَضَّأُ ثُمَّ يَعُودُ فَيَطُوفُ بِالْبَيْتِ وَيَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ وَيَعْتَمِرُ عُمْرَةً أُخْرَى وَيُهْدِي وَعَلَى الْمَرْأَةِ إِذَا أَصَابَهَا زَوْجُهَا وَهِيَ مُحْرِمَةٌ مِثْلُ ذَلِكَ ‏.‏ قَالَ مَالِكٌ فَأَمَّا الْعُمْرَةُ مِنَ التَّنْعِيمِ فَإِنَّهُ مَنْ شَاءَ أَنْ يَخْرُجَ مِنَ الْحَرَمِ ثُمَّ يُحْرِمَ فَإِنَّ ذَلِكَ مُجْزِئٌ عَنْهُ إِنْ شَاءَ اللَّهُ وَلَكِنِ الْفَضْلُ أَنْ يُهِلَّ مِنَ الْمِيقَاتِ الَّذِي وَقَّتَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ مَا هُوَ أَبْعَدُ مِنَ التَّنْعِيمِ ‏.‏\hadithno{770}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Uthman ibn Affan would sometimes never get down from the animal he was riding on when he was doing umra, until he had returned . Malik said, ''Umra is a sunna, and we do not know of any muslim who has ever said that it is permissible not to do it." Malik said, "I do not think that anyone can do more than one umra in any one year." Malik said that someone doing umra who had sexual intercourse with his wife had to sacrifice an animal and do a second umra, which he had to begin when he had finished the one that he had spoiled. He should go into ihram at the same place where he went into ihram for the umra which he had spoiled, except if he had entered into ihram at a place further away than his miqat. This was because he only had to go into ihram from his miqat. Malik said, "Someone who entered Makka to do umra, and does tawaf of the House and say between Safa and Marwa while he is junub, or not in wudu, and afterwards has intercourse with his wife, and then remembers, should do ghusl, or wudu, and then go back and do tawaf around the House and say between Safa and Marwa and do another umra and sacrifice an animal. A woman should do the same if her husband has intercourse with her while she is in ihram. " Malik said, "As for beginning umra at at-Tanim, (it is not the only alternative). It is permissible if Allah wills for some one to leave the Haram and go into ihram if he wishes, but the best way is for him to go into ihram at the miqat which the Messenger of Allah, may Allah bless him and grant him peace, used (i.e. at-Tanim), or one which is further away}}
\hadithdefcmd{malik}{771}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَبَا رَافِعٍ وَرَجُلاً مِنَ الأَنْصَارِ فَزَوَّجَاهُ مَيْمُونَةَ بِنْتَ الْحَارِثِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ قَبْلَ أَنْ يَخْرُجَ ‏.‏\hadithno{771}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik, from Rabia ibn Abi Abd ar-Rahman, from Sulayman ibn Yasar, that the Messenger of Allah, may Allah bless him and grant him peace, sent Abu Rafi and a man of the Ansar to arrange his marriage to Maymuna bint al-Harith, and the Messenger of Allah, may Allah bless him and grant him peace, was in Madina before he had left for umra}}
\hadithdefcmd{malik}{772}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، أَخِي بَنِي عَبْدِ الدَّارِ أَنَّ عُمَرَ بْنَ عُبَيْدِ اللَّهِ، أَرْسَلَ إِلَى أَبَانَ بْنِ عُثْمَانَ - وَأَبَانُ يَوْمَئِذٍ أَمِيرُ الْحَاجِّ وَهُمَا مُحْرِمَانِ - إِنِّي قَدْ أَرَدْتُ أَنْ أُنْكِحَ طَلْحَةَ بْنَ عُمَرَ بِنْتَ شَيْبَةَ بْنِ جُبَيْرٍ وَأَرَدْتُ أَنْ تَحْضُرَ ‏.‏ فَأَنْكَرَ ذَلِكَ عَلَيْهِ أَبَانُ وَقَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْكِحِ الْمُحْرِمُ وَلاَ يُنْكِحْ وَلاَ يَخْطُبْ ‏"‏ ‏.‏\hadithno{772}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik, from Nafi, from Nubayh ibn Wahb, who was from the tribe of Bani Abd ad-Dar, that Umar ibn Ubaydullah sent a message to Aban ibn Uthman (who was amir of the hajj at the time), while both of them were in ihram, saying, "I want to marry Bint Shayba ibn Jubayr to Talha ibn Umar and I want you to be present." Aban told him that he should not do that and said, "I heard Uthman ibn Affan say that the Messenger of Allah, may Allah bless him and grant him peace, said, 'A man in ihram should not marry, or give in marriage, or get betrothed}}
\hadithdefcmd{malik}{773}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، أَنَّ أَبَا غَطَفَانَ بْنَ طَرِيفٍ الْمُرِّيَّ، أَخْبَرَهُ أَنَّ أَبَاهُ طَرِيفًا تَزَوَّجَ امْرَأَةً وَهُوَ مُحْرِمٌ فَرَدَّ عُمَرُ بْنُ الْخَطَّابِ نِكَاحَهُ ‏.‏\hadithno{773}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik, from Da'ud ibn al-Husayn, that Abu Ghatafan ibn Tarif al-Murri told him that his father Tarif had married a woman while he was in ihram, and Umar ibn al-Khattab had rescinded the marriage}}
\hadithdefcmd{malik}{774}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ لاَ يَنْكِحِ الْمُحْرِمُ وَلاَ\hadithno{774}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Nafi, that Abdullah ibn Umar used to say, "Someone in ihram may neither get married, nor arrange a marriage for himself or others}}
\hadithdefcmd{malik}{775}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، سُئِلُوا عَنْ نِكَاحِ الْمُحْرِمِ، فَقَالُوا لاَ يَنْكِحِ الْمُحْرِمُ وَلاَ يُنْكِحْ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ الْمُحْرِمِ إِنَّهُ يُرَاجِعُ امْرَأَتَهُ إِنْ شَاءَ إِذَا كَانَتْ فِي عِدَّةٍ مِنْهُ ‏.‏\hadithno{775}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab, Salim ibn Abdullah and Sulayman ibn Yasar were asked about whether someone in ihram could get married, and they said, "Some one in ihram may neither get married nor give some one in marriage." Malik said that a man who was in ihram could return to his wife if he wanted to, if she was still in her idda after she had been divorced from him}}
\hadithdefcmd{malik}{776}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ فَوْقَ رَأْسِهِ وَهُوَ يَوْمَئِذٍ بِلَحْيَىْ جَمَلٍ مَكَانٌ بِطَرِيقِ مَكَّةَ ‏.‏\hadithno{776}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik, from Yahya ibn Sa'id, from Sulayman ibn Yasar, that the Messenger of Allah, may Allah bless him and grant him peace, was once cupped on the top of his head while he was in ihram, at Lahyay Jamal, which is a place on the road to Makka}}
\hadithdefcmd{malik}{777}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ لاَ يَحْتَجِمُ الْمُحْرِمُ إِلاَّ مِمَّا لاَ بُدَّ لَهُ مِنْهُ ‏.‏ قَالَ مَالِكٌ لاَ يَحْتَجِمُ الْمُحْرِمُ إِلاَّ مِنْ ضَرُورَةٍ ‏.‏\hadithno{777}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Nafi, that Abdullah ibn Umar used to say, "Someone in ihram should not be cupped, except when there is no other alternative." Malik said, "Someone who is in ihram should not be cupped except when it is necessary}}
\hadithdefcmd{malik}{778}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ التَّيْمِيِّ عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ الأَنْصَارِيِّ عَنْ أَبِي قَتَادَةَ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانُوا بِبَعْضِ طَرِيقِ مَكَّةَ تَخَلَّفَ مَعَ أَصْحَابٍ لَهُ مُحْرِمِينَ وَهُوَ غَيْرُ مُحْرِمٍ فَرَأَى حِمَارًا وَحْشِيًّا فَاسْتَوَى عَلَى فَرَسِهِ فَسَأَلَ أَصْحَابَهُ أَنْ يُنَاوِلُوهُ سَوْطَهُ فَأَبَوْا عَلَيْهِ فَسَأَلَهُمْ رُمْحَهُ فَأَبَوْا فَأَخَذَهُ ثُمَّ شَدَّ عَلَى الْحِمَارِ فَقَتَلَهُ فَأَكَلَ مِنْهُ بَعْضُ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبَى بَعْضُهُمْ فَلَمَّا أَدْرَكُوا رَسُولَ اللَّهِ صلى الله عليه وسلم سَأَلُوهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّمَا هِيَ طُعْمَةٌ أَطْعَمَكُمُوهَا اللَّهُ ‏"‏ ‏.‏\hadithno{778}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik, from Abu'n-Nadr, the mawla of 'Umar ibn 'Ubaydullah at-Taymi, from Nafi, the mawla of Abu Qatada al- Ansari, that Abu Qatada was once with the Messenger of Allah, may Allah bless him and grant him peace. When they got to one of the roads to Makka he fell behind with some companions of his who were muhrim, while he was not. Then he saw a wild ass, so he got on his mount and asked his companions to give him his whip but they refused. Then he asked them for his spear and they refused to give it to him. So he took hold of it and attacked the ass and killed it. Some of the companions of the Messenger of Allah, may Allah bless him and grant him peace, ate from it, and others refused. When they had caught up with the Messenger of Allah, may Allah bless him and grant him peace, they asked him about it and he said, "It is food that Allah has fed you with}}
\hadithdefcmd{malik}{779}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ الزُّبَيْرَ بْنَ الْعَوَّامِ، كَانَ يَتَزَوَّدُ صَفِيفَ الظِّبَاءِ وَهُوَ مُحْرِمٌ ‏.‏ قَالَ مَالِكٌ وَالصَّفِيفُ الْقَدِيدُ ‏.‏\hadithno{779}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Hisham ibn Urwa, from his father, that az-Zubayr ibn al-Awwam used to take dried gazelle meat (safif adh-dhiba) as provisions while he was in ihram. Malik said, "Safif are dried strips of meat}}
\hadithdefcmd{malik}{780}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ عَنْ أَبِي قَتَادَةَ، فِي الْحِمَارِ الْوَحْشِيِّ مِثْلَ حَدِيثِ أَبِي النَّضْرِ إِلاَّ أَنَّ فِي، حَدِيثِ زَيْدِ بْنِ أَسْلَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هَلْ مَعَكُمْ مِنْ لَحْمِهِ شَىْءٌ ‏"‏ ‏.‏\hadithno{780}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik, from Zayd ibn Aslam, that Ata ibn Yasar had told him, from Abu Qatada, the same hadith about the wild ass as that of Abu'n-Nadr, except that in the hadith of Zayd ibn Aslam the Messenger of Allah, may Allah bless him and grant him peace, said, "Do you still have any of its meat?}}
\hadithdefcmd{malik}{781}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، أَنَّهُ قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيُّ، عَنْ عِيسَى بْنِ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، عَنْ عُمَيْرِ بْنِ سَلَمَةَ الضَّمْرِيِّ، عَنِ الْبَهْزِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يُرِيدُ مَكَّةَ وَهُوَ مُحْرِمٌ حَتَّى إِذَا كَانَ بِالرَّوْحَاءِ إِذَا حِمَارٌ وَحْشِيٌّ عَقِيرٌ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ دَعُوهُ فَإِنَّهُ يُوشِكُ أَنْ يَأْتِيَ صَاحِبُهُ ‏"‏ ‏.‏ فَجَاءَ الْبَهْزِيُّ وَهُوَ صَاحِبُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ شَأْنَكُمْ بِهَذَا الْحِمَارِ ‏.‏ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ فَقَسَمَهُ بَيْنَ الرِّفَاقِ ثُمَّ مَضَى حَتَّى إِذَا كَانَ بِالأَثَايَةِ - بَيْنَ الرُّوَيْثَةِ وَالْعَرْجِ - إِذَا ظَبْىٌ حَاقِفٌ فِي ظِلٍّ فِيهِ سَهْمٌ فَزَعَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ رَجُلاً أَنْ يَقِفَ عِنْدَهُ لاَ يَرِيبُهُ أَحَدٌ مِنَ النَّاسِ حَتَّى يُجَاوِزَهُ ‏.‏\hadithno{781}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said al-Ansari said that Muhammad ibn Ibrahim ibn al-Harith at-Taymi told him from Isa ibn Talha ibn Ubaydullah, fromUmayr ibn Salama ad-Damri, from al-Bahzi, that the Messenger of Allah, may Allah bless him and grant him peace, set out once for Makka while in ihram. When they had reached ar-Rawha, they unexpectedly came upon a wounded wild ass. Someone mentioned it to the Messenger of Allah, may Allah bless him and grant him peace, and hesaid, "Leave it. The man to whom it belongs is about to come." Then al-Bahzi, who was the man, came to the Prophet, may Allah bless him and grant him peace, and said, "Messenger of Allah, do whatever you want with this ass,' and the Messenger of Allah, may Allah bless him and grant him peace, told Abu Bakr to divide it up among the company. Then they went on until they came to the well of al-Uthaba, which was between ar-Ruwaytha and al-Arj (between Makka and Madina), where they unexpectedly came upon a gazelle with an arrow in it, Iying on its side in some shade. He claimed that the Messenger of Allah, may Allah bless him and grant him peace, told someone to stand by it to make sure no one disturbed it until everyone had passed by}}
\hadithdefcmd{malik}{782}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ أَقْبَلَ مِنَ الْبَحْرَيْنِ حَتَّى إِذَا كَانَ بِالرَّبَذَةِ وَجَدَ رَكْبًا مِنْ أَهْلِ الْعِرَاقِ مُحْرِمِينَ فَسَأَلُوهُ عَنْ لَحْمِ صَيْدٍ وَجَدُوهُ عِنْدَ أَهْلِ الرَّبَذَةِ فَأَمَرَهُمْ بِأَكْلِهِ قَالَ ثُمَّ إِنِّي شَكَكْتُ فِيمَا أَمَرْتُهُمْ بِهِ فَلَمَّا قَدِمْتُ الْمَدِينَةَ ذَكَرْتُ ذَلِكَ لِعُمَرَ بْنِ الْخَطَّابِ فَقَالَ عُمَرُ مَاذَا أَمَرْتَهُمْ بِهِ فَقَالَ أَمَرْتُهُمْ بِأَكْلِهِ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ لَوْ أَمَرْتَهُمْ بِغَيْرِ ذَلِكَ لَفَعَلْتُ بِكَ يَتَوَاعَدُهُ ‏.‏\hadithno{782}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Yahya ibn Said, that he heard Said ibn al-Musayyab relating from Abu Hurayra that he was once coming back from Bahrayn, and, when he reached ar-Rabadha, he found a caravan of people from Iraq in ihram, who asked him whether they could eat the meat of some game which they had found with the people of ar- Rabadha, and he told them they could eat it. He said, "Afterwards I had doubts about what I had told them to do, so when I got back to Madina I mentioned the matter to Umar ibn al-Khattab and he said, 'What did you tell them to do?' I said, ' I told them to eat it.' Umar ibn al-Khattab said, threatening me, 'If you had told them to do anything else I would have done something to you}}
\hadithdefcmd{malik}{783}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ عَبْدَ اللَّهِ بْنَ عُمَرَ أَنَّهُ مَرَّ بِهِ قَوْمٌ مُحْرِمُونَ بِالرَّبَذَةِ فَاسْتَفْتَوْهُ فِي لَحْمِ صَيْدٍ وَجَدُوا نَاسًا أَحِلَّةً يَأْكُلُونَهُ فَأَفْتَاهُمْ بِأَكْلِهِ قَالَ ثُمَّ قَدِمْتُ الْمَدِينَةَ عَلَى عُمَرَ بْنِ الْخَطَّابِ فَسَأَلْتُهُ عَنْ ذَلِكَ فَقَالَ بِمَ أَفْتَيْتَهُمْ قَالَ فَقُلْتُ أَفْتَيْتُهُمْ بِأَكْلِهِ ‏.‏ قَالَ فَقَالَ عُمَرُ لَوْ أَفْتَيْتَهُمْ بِغَيْرِ ذَلِكَ لأَوْجَعْتُكَ ‏.‏\hadithno{783}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Ibn Shihab, that Salim ibn Abdullah heard Abu Hurayra relating to Abdullah ibn Umar how a group of three people in ihram had passed him at ar-Rabadha and had asked him for a fatwa about eating game which people who were not in ihram were eating, and he told them that they could eat it. He said, "Then I went to Umar ibn al-Khattab in Madina and asked him about it, and he said, 'What did you say to them?' and I said, 'I told them that they could eat it.' Umar said, 'If you had told them anything else I would have done you an injury}}
\hadithdefcmd{malik}{784}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ كَعْبَ الأَحْبَارِ، أَقْبَلَ مِنَ الشَّامِ فِي رَكْبٍ حَتَّى إِذَا كَانُوا بِبَعْضِ الطَّرِيقِ وَجَدُوا لَحْمَ صَيْدٍ فَأَفْتَاهُمْ كَعْبٌ بِأَكْلِهِ قَالَ فَلَمَّا قَدِمُوا عَلَى عُمَرَ بْنِ الْخَطَّابِ بِالْمَدِينَةِ ذَكَرُوا ذَلِكَ لَهُ فَقَالَ مَنْ أَفْتَاكُمْ بِهَذَا قَالُوا كَعْبٌ ‏.‏ قَالَ فَإِنِّي قَدْ أَمَّرْتُهُ عَلَيْكُمْ حَتَّى تَرْجِعُوا ثُمَّ لَمَّا كَانُوا بِبَعْضِ طَرِيقِ مَكَّةَ مَرَّتْ بِهِمْ رِجْلٌ مِنْ جَرَادٍ فَأَفْتَاهُمْ كَعْبٌ أَنْ يَأْخُذُوهُ فَيَأْكُلُوهُ فَلَمَّا قَدِمُوا عَلَى عُمَرَ بْنِ الْخَطَّابِ ذَكَرُوا لَهُ ذَلِكَ فَقَالَ مَا حَمَلَكَ عَلَى أَنْ تُفْتِيَهُمْ بِهَذَا قَالَ هُوَ مِنْ صَيْدِ الْبَحْرِ ‏.‏ قَالَ وَمَا يُدْرِيكَ قَالَ يَا أَمِيرَ الْمُؤْمِنِينَ - وَالَّذِي نَفْسِي بِيَدِهِ - إِنْ هِيَ إِلاَّ نَثْرَةُ حُوتٍ يَنْثُرُهُ فِي كُلِّ عَامٍ مَرَّتَيْنِ ‏.‏\hadithno{784}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik, from Zayd ibn Aslam, from Ata ibn Yasar, that Kab al-Ahbar was once coming back from Syria with a group of riders, and at a certain point along the road they found some game- meat and Kab said they could eat it. When they got back to Madina they went to Umar ibn al-Khattab and told him about that, and he said, "Who told you you could do that?", and they said, ''Kab.'' He said, "He was indeed the one I made amir over you until you should return." Later, when they were on the road to Makka, a swarm of locusts passed them by and Kab told them to catch them and eat them. When they got back to Umar ibn al-Khattab they told him about this, and he said (to Kab), "What made you tell them they could do that?" Kab said, "It is game of the sea." He said, "How do you know?", and Kab said, "Amir al- muminin, by the One in whose hand my self is, it is only the sneeze of a fish which it sneezes twice every year." Malik was asked whether a muhrim could buy game that he had found on the way. He replied, "Game that is only hunted to be offered to people performing Hajj I disapprove of and forbid, but there is no harm in game that a man has which he does not intend for those in ihram, but which a muhrim finds and buys." Malik said, about someone who had some game with him that he had hunted or bought at the time when he had entered into ihram, that he did not have to get rid of it, and that there was no harm in him giving it to his family. Malik said that it was halal for some one in ihram to fish in the sea or in rivers and lakes, etc}}
\hadithdefcmd{malik}{785}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ اللَّيْثِيِّ، أَنَّهُ أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِمَارًا وَحْشِيًّا وَهُوَ بِالأَبْوَاءِ أَوْ بِوَدَّانَ فَرَدَّهُ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَا فِي وَجْهِي قَالَ ‏ "‏ إِنَّا لَمْ نَرُدَّهُ عَلَيْكَ إِلاَّ أَنَّا حُرُمٌ ‏"‏ ‏.‏\hadithno{785}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik, from Ibn Shihab, from Ubaydullah ibn Abdullah ibn Utba ibn Masud, from Abdullah ibn Abbas, that as-Sab ibn Jaththama al-Laythi once gave a wild ass to the Messenger of Allah, may Allah bless him and grant him peace, while he was at al- Abwa, or Waddan, and the Messenger of Allah, may Allah bless him and grant him peace, gave it back to him. However, when the Messenger of Allah, may Allah bless him and grant him peace, saw the expression on the man's face he said, "We only gave it back to you because we are in ihram}}
\hadithdefcmd{malik}{786}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، قَالَ رَأَيْتُ عُثْمَانَ بْنَ عَفَّانَ بِالْعَرْجِ وَهُوَ مُحْرِمٌ فِي يَوْمٍ صَائِفٍ قَدْ غَطَّى وَجْهَهُ بِقَطِيفَةِ أُرْجُوَانٍ ثُمَّ أُتِيَ بِلَحْمِ صَيْدٍ فَقَالَ لأَصْحَابِهِ كُلُوا ‏.‏ فَقَالُوا أَوَلاَ تَأْكُلُ أَنْتَ فَقَالَ إِنِّي لَسْتُ كَهَيْئَتِكُمْ إِنَّمَا صِيدَ مِنْ أَجْلِي ‏.‏\hadithno{786}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Abdullah ibn Abi Bakr, that Abd ar-Rahman ibn Amir ibn Rabia said, "I once saw Uthman ibn Affan in ihram on a hot summer's day at al-Arj,and he had covered his face with a red woollen cloth. Some game-meat was brought to him and he told his companions to eat. They said, 'Will you not eat then?', and he said, 'I am not in the same position as you. It was hunted for my sake}}
\hadithdefcmd{malik}{787}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ لَهُ يَا ابْنَ أُخْتِي إِنَّمَا هِيَ عَشْرُ لَيَالٍ فَإِنْ تَخَلَّجَ فِي نَفْسِكَ شَىْءٌ فَدَعْهُ تَعْنِي أَكْلَ لَحْمِ الصَّيْدِ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ الْمُحْرِمِ يُصَادُ مِنْ أَجْلِهِ صَيْدٌ فَيُصْنَعُ لَهُ ذَلِكَ الصَّيْدُ فَيَأْكُلُ مِنْهُ وَهُوَ يَعْلَمُ أَنَّهُ مِنْ أَجْلِهِ صِيدَ فَإِنَّ عَلَيْهِ جَزَاءَ ذَلِكَ الصَّيْدِ كُلِّهِ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الرَّجُلِ يُضْطَرُّ إِلَى أَكْلِ الْمَيْتَةِ وَهُوَ مُحْرِمٌ أَيَصِيدُ الصَّيْدَ فَيَأْكُلُهُ أَمْ يَأْكُلُ الْمَيْتَةَ فَقَالَ بَلْ يَأْكُلُ الْمَيْتَةَ وَذَلِكَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى لَمْ يُرَخِّصْ لِلْمُحْرِمِ فِي أَكْلِ الصَّيْدِ وَلاَ فِي أَخْذِهِ فِي حَالٍ مِنَ الأَحْوَالِ وَقَدْ أَرْخَصَ فِي الْمَيْتَةِ عَلَى حَالِ الضَّرُورَةِ ‏.‏ قَالَ مَالِكٌ وَأَمَّا مَا قَتَلَ الْمُحْرِمُ أَوْ ذَبَحَ مِنَ الصَّيْدِ فَلاَ يَحِلُّ أَكْلُهُ لِحَلاَلٍ وَلاَ لِمُحْرِمٍ لأَنَّهُ لَيْسَ بِذَكِيٍّ كَانَ خَطَأً أَوْ عَمْدًا فَأَكْلُهُ لاَ يَحِلُّ وَقَدْ سَمِعْتُ ذَلِكَ مِنْ غَيْرِ وَاحِدٍ وَالَّذِي يَقْتُلُ الصَّيْدَ ثُمَّ يَأْكُلُهُ إِنَّمَا عَلَيْهِ كَفَّارَةٌ وَاحِدَةٌ مِثْلُ مَنْ قَتَلَهُ وَلَمْ يَأْكُلْ مِنْهُ ‏.‏\hadithno{787}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from Hisham ibn Urwa, from his father, that A'isha, umm al-muminin, said to him, "Son of my sister, it is only for ten nights, so if you get an urge to do something, leave it," by which she meant eating game-meat. Malik said that if game was hunted forthe sake of a man who is in ihram and it was prepared for him and he ate some of it knowing that it had been hunted for his sake, then he had to pay a forfeit for all of the game that had been hunted on his behalf. Malik was asked about whether someone who was forced to eat carrion while he was in ihram should hunt game and then eat that rather than the carrion, and he said, "It is better for him to eat the carrion, because Allah, the Blessed and Exalted, has not given permission for someone in ihram to either eat game or take it in any situation, but He has made allowances for eating carrion when absolutely necessary." Malik said, "It is not halal for anyone, whether in ihram or not, to eat game which has been killed or sacrificed by some one in ihram, because, whether it was killed deliberately or by mistake, it was not done in a halal manner, and so eating it is not halal. I have heard this from more than one person. Somebody who kills game and then eats it only has to make a single kaffara, which is the same as for somebody who kills game but does not eat any of it}}
\hadithdefcmd{malik}{788}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لَيْسَ عَلَى الْمُحْرِمِ فِي قَتْلِهِنَّ جُنَاحٌ الْغُرَابُ وَالْحِدَأَةُ وَالْعَقْرَبُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{788}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said, "It is not halal to eat any game that has been hunted in the Haram, or has had a dog set after it in the Haram and then been killed outside the Haram. Anyone that does that has to pay a forfeit for what has been hunted. However, some one that sets his dog after game outside the Haram and then follows it until it is hunted down in the Haram does not have to pay any forfeit, unless he set the dog after the game near to the Haram. The game should not be eaten, however. If he set the dog loose near the Haram then he has to pay a forfeit for the game." Malik said, "Allah, the Blessed and Exalted, says, 'O you who trust, do not kill game while you are in ihram. Whoever of you kills game intentionally has to pay a forfeit commensurate with what he has killed in cattle which two men from among you shall judge, a sacrificial animal which reaches the Kaba, or else he makes a kaffara of either feeding poor people or the equivalent of that in fasting, so that he may taste the consequences of what he has done.' " (Sura 5 ayat 95). Malik said, "Someone who hunts game when he is not in ihram and then kills it while he is in ihram is in the same position as someone who buys game while he is in ihram and then kills it. Allah has forbidden killing it, and so a man who does so has to pay a forfeit for it. The position that we go by in this matter is that a forfeit is assessed for anyone who kills game while he is in ihram." Yahya said that Malik said, "The best that I have heard about someone who kills game and is assessed for it is that the game which he has killed is assessed and its value in food is estimated and with that food he feeds each poor man a mudd, or fasts a day in place of each mudd. The number of poor men is considered, and if it is ten then he fasts ten days, and if it is twenty he fasts twenty days, according to how many people there are to be fed, even if there are more than sixty." Malik said, "I have heard that a forfeit is assessed for someone who kills game in the Haram while he is not in ihram in the same way that it is assessed for some one who kills game in the Haram while he is in ihram ." Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "There are five kinds of animal which it is not wrong for some one in ihram to kill:crows, kites, scorpions, rats and mice, and wild dogs}}
\hadithdefcmd{malik}{789}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ مَنْ قَتَلَهُنَّ وَهُوَ مُحْرِمٌ فَلاَ جُنَاحَ عَلَيْهِ الْعَقْرَبُ وَالْفَأْرَةُ وَالْغُرَابُ وَالْحِدَأَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{789}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace,said,"There are five (kinds of) animal which it is not wrong for some one in ihram to kill:scorpions, rats and mice, crows, kites and wild dogs}}
\hadithdefcmd{malik}{790}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ فَوَاسِقُ يُقْتَلْنَ فِي الْحَرَمِ الْفَأْرَةُ وَالْعَقْرَبُ وَالْغُرَابُ وَالْحِدَأَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏\hadithno{790}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "There are five trespassers that can be killed in the Haram:rats and mice, scorpions, crows, kites and wild dogs}}
\hadithdefcmd{malik}{791}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَمَرَ بِقَتْلِ الْحَيَّاتِ فِي الْحَرَمِ ‏.‏ قَالَ مَالِكٌ فِي الْكَلْبِ الْعَقُورِ الَّذِي أُمِرَ بِقَتْلِهِ فِي الْحَرَمِ إِنَّ كُلَّ مَا عَقَرَ النَّاسَ وَعَدَا عَلَيْهِمْ وَأَخَافَهُمْ مِثْلُ الأَسَدِ وَالنَّمِرِ وَالْفَهْدِ وَالذِّئْبِ فَهُوَ الْكَلْبُ الْعَقُورُ وَأَمَّا مَا كَانَ مِنَ السِّبَاعِ لاَ يَعْدُو مِثْلُ الضَّبُعِ وَالثَّعْلَبِ وَالْهِرِّ وَمَا أَشْبَهَهُنَّ مِنَ السِّبَاعِ فَلاَ يَقْتُلُهُنَّ الْمُحْرِمُ فَإِنْ قَتَلَهُ فَدَاهُ وَأَمَّا مَا ضَرَّ مِنَ الطَّيْرِ فَإِنَّ الْمُحْرِمَ لاَ يَقْتُلُهُ إِلاَّ مَا سَمَّى النَّبِيُّ صلى الله عليه وسلم الْغُرَابُ وَالْحِدَأَةُ وَإِنْ قَتَلَ الْمُحْرِمُ شَيْئًا مِنَ الطَّيْرِ سِوَاهُمَا فَدَاهُ ‏.‏\hadithno{791}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Umar ibn al- Khattab told people to kill snakes in the Haram. Malik said, about the "wild dogs" which people were told to kill in the Haram, that any animals that wounded, attacked, or terrorised men, such as lions, leopards, Iynxes and wolves, were counted as"wild dogs." However, someone who was in ihram should not kill beasts of prey that did not attack (people), such as hyenas, foxes, cats and anything else like them, and if he did then he had to pay a forfeit for it. Similarly, someone in ihram should not kill any predatory birds except the kinds that the Prophet, may Allah bless him and grant him peace, specified, namely crows and kites. If someone in ihram killed any other kind of bird he had to pay a forfeit for it}}
\hadithdefcmd{malik}{792}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ رَبِيعَةَ بْنِ عَبْدِ اللَّهِ بْنِ الْهُدَيْرِ، أَنَّهُ رَأَى عُمَرَ بْنَ الْخَطَّابِ يُقَرِّدُ بَعِيرًا لَهُ فِي طِينٍ بِالسُّقْيَا وَهُوَ مُحْرِمٌ ‏.‏ قَالَ مَالِكٌ وَأَنَا أَكْرَهُهُ ‏.‏\hadithno{792}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Yahya ibn Said from Muhammad ibn Ibrahim ibn alHarith at-Taymi from Rabia ibn Abi Abdullah ibn alHudayr that he saw Umar ibn al-Khattab taking the ticks off a camel of his at as- Suqya while he was in ihram . Malik said that he disapproved of that}}
\hadithdefcmd{malik}{793}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، أَنَّهَا قَالَتْ سَمِعْتُ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تُسْأَلُ عَنِ الْمُحْرِمِ أَيَحُكُّ جَسَدَهُ فَقَالَتْ نَعَمْ فَلْيَحْكُكْهُ وَلْيَشْدُدْ وَلَوْ رُبِطَتْ يَدَاىَ وَلَمْ أَجِدْ إِلاَّ رِجْلَىَّ لَحَكَكْتُ ‏.‏\hadithno{793}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Alqama ibn Abi Alqama that his mother said, "I heard A'isha, the wife of the Prophet, may Allah bless him and grant him peace, being asked whether some one in ihram could scratch their body or not, and she said, 'Yes, he can scratch it and do so as hard as he pleases. I would scratch even if my hands were tied and I could only use my feet}}
\hadithdefcmd{malik}{794}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ مُوسَى، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، نَظَرَ فِي الْمِرْآةِ لِشَكْوٍ كَانَ بِعَيْنَيْهِ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{794}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Musa that Abdullah ibn Umar once looked in the mirror for something that was irritating him while he was in ihram}}
\hadithdefcmd{malik}{795}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَكْرَهُ أَنْ يَنْزِعَ الْمُحْرِمُ، حَلَمَةً أَوْ قُرَادًا عَنْ بَعِيرِهِ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{795}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar did not like people who were in ihram removing mites or ticks from their camels. Malik said, "This is what I like most out of what I have heard about the matter}}
\hadithdefcmd{malik}{796}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي مَرْيَمَ، ‏.‏ أَنَّهُ سَأَلَ سَعِيدَ بْنَ الْمُسَيَّبِ عَنْ ظُفْرٍ، لَهُ انْكَسَرَ وَهُوَ مُحْرِمٌ فَقَالَ سَعِيدٌ اقْطَعْهُ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الرَّجُلِ يَشْتَكِي أُذُنَهُ أَيَقْطُرُ فِي أُذُنِهِ مِنَ الْبَانِ الَّذِي لَمْ يُطَيَّبْ وَهُوَ مُحْرِمٌ فَقَالَ لاَ أَرَى بِذَلِكَ بَأْسًا وَلَوْ جَعَلَهُ فِي فِيهِ لَمْ أَرَ بِذَلِكَ بَأْسًا ‏.‏ قَالَ مَالِكٌ وَلاَ بَأْسَ أَنْ يَبُطَّ الْمُحْرِمُ خُرَاجَهُ وَيَفْقَأَ دُمَّلَهُ وَيَقْطَعَ عِرْقَهُ إِذَا احْتَاجَ إِلَى ذَلِكَ ‏.‏\hadithno{796}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Muhammad ibn Abdullah ibn Abi Maryam once asked Said ibn al-Musayyab about (what to do with) a nail of his that had broken while he was in ihram and Said said, "cut it off." Malik was asked whether some one in ihram who had an ear-complaint could use medicinal oil which was not perfumed for dropping into his ears, and he said, "I do not see any harm in that, and even if he were to put it into his mouth I still would not see any harm in it." Malik said that there was no harm in some one in ihram lancing an abscess that he had, or a boil, or cutting a vein, if he needed to do so}}
\hadithdefcmd{malik}{797}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كَانَ الْفَضْلُ بْنُ عَبَّاسٍ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَتْهُ امْرَأَةٌ مِنْ خَثْعَمَ تَسْتَفْتِيهِ فَجَعَلَ الْفَضْلُ يَنْظُرُ إِلَيْهَا وَتَنْظُرُ إِلَيْهِ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْرِفُ وَجْهَ الْفَضْلِ إِلَى الشِّقِّ الآخَرِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ فِي الْحَجِّ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا لاَ يَسْتَطِيعُ أَنْ يَثْبُتَ عَلَى الرَّاحِلَةِ أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{797}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Sulayman ibn Yasar that Abdullah ibn Abbas said, "Al-Fadl ibn Abbas was riding behind the Messenger of Allah, may Allah bless him and grant him peace, when a woman from the Khathama tribe came to him to ask him for a fatwa. Al-Fadl began to look at her, and she at him, and the Messenger of Allah, may Allah bless him and grant him peace, turned Fadl's face away to the other side. The woman said, 'Messenger of Allah, Allah's making the hajj obligatory finds my father a very old man, unable to stay firm on his riding-beast. Can I do hajj for him?', and he said, 'Yes.' This was during the farewell hajj}}
\hadithdefcmd{malik}{798}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَلَّ هُوَ وَأَصْحَابُهُ بِالْحُدَيْبِيَةِ فَنَحَرُوا الْهَدْىَ وَحَلَقُوا رُءُوسَهُمْ وَحَلُّوا مِنْ كُلِّ شَىْءٍ قَبْلَ أَنْ يَطُوفُوا بِالْبَيْتِ وَقَبْلَ أَنْ يَصِلَ إِلَيْهِ الْهَدْىُ ثُمَّ لَمْ يُعْلَمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أَحَدًا مِنْ أَصْحَابِهِ وَلاَ مِمَّنْ كَانَ مَعَهُ أَنْ يَقْضُوا شَيْئًا وَلاَ يَعُودُوا لِشَىْءٍ ‏.‏\hadithno{798}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me that Malik said, "Someone whose passage to the House is blocked by an enemy is freed from every restriction of ihram, and should sacrifice his animal and shave his head wherever he has been detained, and there is nothing for him to make up afterwards." Yahya related to me from Malik that he had heard that when the Messenger of Allah, may Allah bless him and grant him peace, and his companions came out of ihram at al-Hudaybiya they sacrificed their sacrificial animals and shaved their heads, and were freed from all the restrictions of ihram without having done tawaf of the House and without their sacrificial animals reaching the Kaba. There is nothing known about the Messenger of Allah, may Allah bless him and grant him peace, ever telling any of his companions, or anybody else that was with him, to make up for anything they had missed or to go back to doing anything they had not finished doing}}
\hadithdefcmd{malik}{799}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ حِينَ خَرَجَ إِلَى مَكَّةَ مُعْتِمَرًا فِي الْفِتْنَةِ إِنْ صُدِدْتُ عَنِ الْبَيْتِ صَنَعْنَا كَمَا صَنَعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَهَلَّ بِعُمْرَةٍ مِنْ أَجْلِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهَلَّ بِعُمْرَةٍ عَامَ الْحُدَيْبِيَةِ ثُمَّ إِنَّ عَبْدَ اللَّهِ نَظَرَ فِي أَمْرِهِ فَقَالَ مَا أَمْرُهُمَا إِلاَّ وَاحِدٌ ثُمَّ الْتَفَتَ إِلَى أَصْحَابِهِ فَقَالَ مَا أَمْرُهُمَا إِلاَّ وَاحِدٌ أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ الْحَجَّ مَعَ الْعُمْرَةِ ‏.‏ ثُمَّ نَفَذَ حَتَّى جَاءَ الْبَيْتَ فَطَافَ طَوَافًا وَاحِدًا وَرَأَى ذَلِكَ مُجْزِيًا عَنْهُ وَأَهْدَى ‏.‏\hadithno{799}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that when Abdullah ibn Umar set out for Makka during the troubles (between al-Hajjaj ibn Yusuf and Zubair ibn al-Awwam) he said, "If I am blocked from going to the House we shall do what we did when we were with the Messenger of Allah, may Allah bless him and grant him peace," and he went into ihram for umra, because that was what the Messenger of Allah, may Allah bless him and grant him peace, did in the year of al-Hudaybiya. But afterwards, he reconsidered his position and said, "It is the same either way." After that he turned to his companions and said, "It is the same either way. I call you to witness that I have decided in favour of hajj and umra together." He then got through to the House (without being stopped) and did one set of tawaf, which he considered to be enough for himself, and sacrificed an animal. Malik said, "This is what we go by if someone is hindered by an enemy, as the Prophet, may Allah bless him and grant him peace, and his companions were. If some one is hindered by anything other than an enemy, he is only freed from ihram by tawaf of the House}}
\hadithdefcmd{malik}{800}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ الْمُحْصَرُ بِمَرَضٍ لاَ يَحِلُّ حَتَّى يَطُوفَ بِالْبَيْتِ وَيَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ فَإِذَا اضْطُرَّ إِلَى لُبْسِ شَىْءٍ مِنَ الثِّيَابِ الَّتِي لاَ بُدَّ لَهُ مِنْهَا أَوِ الدَّوَاءِ صَنَعَ ذَلِكَ وَافْتَدَى ‏.‏\hadithno{800}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Umar said, "Someone who is held back from going to the House by illness can only come out of ihram after he has done tawaf of the House and say between Safa and Marwa. If it is absolutely necessary for him to wear any ordinary clothes, or undergo medical treatment, he should do that and pay compensation for it}}
\hadithdefcmd{malik}{801}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ بَلَغَهُ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ تَقُولُ الْمُحْرِمُ لاَ يُحِلُّهُ إِلاَّ الْبَيْتُ ‏.‏\hadithno{801}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he had heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, used to say, "Only the House frees a person in ihram from ihram}}
\hadithdefcmd{malik}{802}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ السَّخْتِيَانِيِّ، عَنْ رَجُلٍ، مِنْ أَهْلِ الْبَصْرَةِ كَانَ قَدِيمًا أَنَّهُ قَالَ خَرَجْتُ إِلَى مَكَّةَ حَتَّى إِذَا كُنْتُ بِبَعْضِ الطَّرِيقِ كُسِرَتْ فَخِذِي فَأَرْسَلْتُ إِلَى مَكَّةَ وَبِهَا عَبْدُ اللَّهِ بْنُ عَبَّاسٍ وَعَبْدُ اللَّهِ بْنُ عُمَرَ وَالنَّاسُ فَلَمْ يُرَخِّصْ لِي أَحَدٌ أَنْ أَحِلَّ فَأَقَمْتُ عَلَى ذَلِكَ الْمَاءِ سَبْعَةَ أَشْهُرٍ حَتَّى أَحْلَلْتُ بِعُمْرَةٍ ‏.‏\hadithno{802}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Abi Tamima as- Sakhtayani that a very old man from Basra once said to him, "I set out for Makka but on the way there I broke my thigh, so I sent a message on to Makka Abdullah ibn Abbas and Abdullah ibn Umar and the people were there, but no-one allowed me to leave ihram, and I stayed there for seven months until I left ihram by doing an umra}}
\hadithdefcmd{malik}{803}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ مَنْ حُبِسَ دُونَ الْبَيْتِ بِمَرَضٍ فَإِنَّهُ لاَ يَحِلُّ حَتَّى يَطُوفَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{803}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Umar said, "Some one who is detained by sickness before he has got to the House cannot leave ihram until he has done tawaf of the House and say between Safa and Marwa}}
\hadithdefcmd{malik}{804}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ مَعْبَدَ بْنَ حُزَابَةَ الْمَخْزُومِيَّ، صُرِعَ بِبَعْضِ طَرِيقِ مَكَّةَ وَهُوَ مُحْرِمٌ فَسَأَلَ مَنْ يَلِي عَلَى الْمَاءِ الَّذِي كَانَ عَلَيْهِ فَوَجَدَ عَبْدَ اللَّهِ بْنَ عُمَرَ وَعَبْدَ اللَّهِ بْنَ الزُّبَيْرِ وَمَرْوَانَ بْنَ الْحَكَمِ فَذَكَرَ لَهُمُ الَّذِي عَرَضَ لَهُ فَكُلُّهُمْ أَمَرَهُ أَنْ يَتَدَاوَى بِمَا لاَ بُدَّ لَهُ مِنْهُ وَيَفْتَدِيَ فَإِذَا صَحَّ اعْتَمَرَ فَحَلَّ مِنْ إِحْرَامِهِ ثُمَّ عَلَيْهِ حَجُّ قَابِلٍ وَيُهْدِي مَا اسْتَيْسَرَ مِنَ الْهَدْىِ ‏.‏ قَالَ مَالِكٌ وَعَلَى هَذَا الأَمْرُ عِنْدَنَا فِيمَنْ أُحْصِرَ بِغَيْرِ عَدُوٍّ وَقَدْ أَمَرَ عُمَرُ بْنُ الْخَطَّابِ أَبَا أَيُّوبَ الأَنْصَارِيَّ وَهَبَّارَ بْنَ الأَسْوَدِ حِينَ فَاتَهُمَا الْحَجُّ وَأَتَيَا يَوْمَ النَّحْرِ أَنْ يَحِلاَّ بِعُمْرَةٍ ثُمَّ يَرْجِعَا حَلاَلاً ثُمَّ يَحُجَّانِ عَامًا قَابِلاً وَيُهْدِيَانِ فَمَنْ لَمْ يَجِدْ فَصِيَامُ ثَلاَثَةِ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةٍ إِذَا رَجَعَ إِلَى أَهْلِهِ ‏.‏ قَالَ مَالِكٌ وَكُلُّ مَنْ حُبِسَ عَنِ الْحَجِّ بَعْدَ مَا يُحْرِمُ إِمَّا بِمَرَضٍ أَوْ بِغَيْرِهِ أَوْ بِخَطَإٍ مِنَ الْعَدَدِ أَوْ خَفِيَ عَلَيْهِ الْهِلاَلُ فَهُوَ مُحْصَرٌ عَلَيْهِ مَا عَلَى الْمُحْصَرِ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَمَّنْ أَهَلَّ مِنْ أَهْلِ مَكَّةَ بِالْحَجِّ ثُمَّ أَصَابَهُ كَسْرٌ أَوْ بَطْنٌ مُتَحَرِّقٌ أَوِ امْرَأَةٌ تَطْلُقُ ‏.‏ قَالَ مَنْ أَصَابَهُ هَذَا مِنْهُمْ فَهُوَ مُحْصَرٌ يَكُونُ عَلَيْهِ مِثْلُ مَا عَلَى أَهْلِ الآفَاقِ إِذَا هُمْ أُحْصِرُوا ‏.‏ قَالَ مَالِكٌ فِي رَجُلٍ قَدِمَ مُعْتَمِرًا فِي أَشْهُرِ الْحَجِّ حَتَّى إِذَا قَضَى عُمْرَتَهُ أَهَلَّ بِالْحَجِّ مِنْ مَكَّةَ ثُمَّ كُسِرَ أَوْ أَصَابَهُ أَمْرٌ لاَ يَقْدِرُ عَلَى أَنْ يَحْضُرَ مَعَ النَّاسِ الْمَوْقِفَ ‏.‏ قَالَ مَالِكٌ أَرَى أَنْ يُقِيمَ حَتَّى إِذَا بَرَأَ خَرَجَ إِلَى الْحِلِّ ثُمَّ يَرْجِعُ إِلَى مَكَّةَ فَيَطُوفُ بِالْبَيْتِ وَيَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ يَحِلُّ ثُمَّ عَلَيْهِ حَجُّ قَابِلٍ وَالْهَدْىُ ‏.‏ قَالَ مَالِكٌ فِيمَنْ أَهَلَّ بِالْحَجِّ مِنْ مَكَّةَ ثُمَّ طَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ مَرِضَ فَلَمْ يَسْتَطِعْ أَنْ يَحْضُرَ مَعَ النَّاسِ الْمَوْقِفَ ‏.‏ قَالَ مَالِكٌ إِذَا فَاتَهُ الْحَجُّ فَإِنِ اسْتَطَاعَ خَرَجَ إِلَى الْحِلِّ فَدَخَلَ بِعُمْرَةٍ فَطَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ لأَنَّ الطَّوَافَ الأَوَّلَ لَمْ يَكُنْ نَوَاهُ لِلْعُمْرَةِ فَلِذَلِكَ يَعْمَلُ بِهَذَا وَعَلَيْهِ حَجُّ قَابِلٍ وَالْهَدْىُ ‏.‏ فَإِنْ كَانَ مِنْ غَيْرِ أَهْلِ مَكَّةَ فَأَصَابَهُ مَرَضٌ حَالَ بَيْنَهُ وَبَيْنَ الْحَجِّ فَطَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ حَلَّ بِعُمْرَةٍ وَطَافَ بِالْبَيْتِ طَوَافًا آخَرَ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ لأَنَّ طَوَافَهُ الأَوَّلَ وَسَعْيَهُ إِنَّمَا كَانَ نَوَاهُ لِلْحَجِّ وَعَلَيْهِ حَجُّ قَابِلٍ وَالْهَدْىُ ‏.‏\hadithno{804}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Sulayman ibn Yasar that Said ibn Huzaba al-Makhzumi was thrown off his mount while he was in ihram on the road to Makka. He asked after the person in charge of the relay station where he was injured and he found Abdullah ibn Umar, Abdullah ibn az-Zubayr and Marwan ibn al-Hakam there. He told them what had happened to him and all of them said that he should take whatever medicine he had to take and pay compensation for it. Then, when he got better again, he should do umra and come out of his ihram, after which he had to do hajj another year and to offer whatever sacrificial animal he was able to in the future. Malik said, "This is what we do here (in Madina) if someone is detained by something other than an enemy. And when Abu Ayyub al- Ansari and Habbar ibn al-Aswad came to the day of the sacrifice and had missed the hajj, Umar ibn al-Khattab told them to come out of ihram by doing umra and then to go home free of ihram and do hajj some time in the future and to sacrifice an animal, or, if they could not find one, to fast three days during the hajj and seven days after they had returned to their families." Malik said, "Anyone who is detained from doing hajj after he has gone into ihram, whether by illness or otherwise, or by an error in calculating the month or because the new moon is concealed from him is in the same position as some one who is hindered from doing the hajj and must do the same as he does." Yahya said that Malik was asked about the situation of someone from Makka who went into ihram for hajj and then broke a bone or had severe stomach pain, or of a woman who was in labour, and he said, "Someone to whom this happens is in the same situation as one who is hindered from doing the hajj, and he must do the same as people from outlying regions do when they are hindered from doing the hajj." Malik said, about someone who arrived in the months of the hajj with the intention of doing umra, and completed his umra and went into ihram in Makka to do hajj, and then broke a bone or something else happened to him which stopped him from being present at Arafa with everybody else, "I think that he should stay where he is until he is better and then go outside the area of the Haram, and then return to Makka and do tawaf of the House and say between Safa and Marwa, and then leave ihram. He must then do hajj again another year and offer a sacrificial animal ." Malik said, about someone who left ihram in Makka, and then did tawaf of the House and say between Safa and Marwa, and then fell ill and was unable to be present with everybody at Arafa, "If the hajj passes someone by he should, if he can, go out of the area of the Haram and then come back in again to do umra and do tawaf of the House and say between Safa and Marwa, because he had not intended his initial tawaf to be for an umra, and so for this reason he does it again. He must do the next hajj and offer a sacrificial animal. If he is not one of the people of Makka, and something happens to him which stops him from doing the hajj, but he does tawaf of the House and say between Safa and Marwa, he should come out of ihram by doing an umra and then do tawaf of the House a second time, and say between Safa and Marwa, because his initial tawaf and say were intended for the hajj. He must do the next hajj and offer a sacrificial animal}}
\hadithdefcmd{malik}{805}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، أَخْبَرَ عَبْدَ اللَّهِ بْنَ عُمَرَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أَلَمْ تَرَىْ أَنَّ قَوْمَكِ حِينَ بَنَوُا الْكَعْبَةَ اقْتَصَرُوا عَنْ قَوَاعِدِ إِبْرَاهِيمَ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ تَرُدُّهَا عَلَى قَوَاعِدِ إِبْرَاهِيمَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْلاَ حِدْثَانُ قَوْمِكِ بِالْكُفْرِ لَفَعَلْتُ ‏"‏ ‏.‏ قَالَ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَئِنْ كَانَتْ عَائِشَةُ سَمِعَتْ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أُرَى رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ اسْتِلاَمَ الرُّكْنَيْنِ اللَّذَيْنِ يَلِيَانِ الْحِجْرَ إِلاَّ أَنَّ الْبَيْتَ لَمْ يُتَمَّمْ عَلَى قَوَاعِدِ إِبْرَاهِيمَ ‏.‏\hadithno{805}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Muhammad ibn Abi Bakras-Siddiq told Abdullah ibn Umar from A'isha, that the Prophet, may Allah bless him and grant him peace, said, "Don't you see that when your people built the Kaba they fell short of the foundations of Ibrahim?" A'isha said, "Messenger of Allah, won't you return it to the foundations of Ibrahim?" and the Messenger of Allah, may Allah bless him and grant him peace, said, "If it were not that your people have only recently left kufr, I would have done so." Salim ibn Abdullah said that Abdullah ibn Umar said, "If A'isha heard this from the Messenger of Allah, may Allah bless him and grant him peace, then I consider that the Messenger of Allah, may Allah bless him and grant him peace, only refrained from greeting the two corners which are adjacent to the Hijr because the House had not been completed on the foundations of Ibrahim." (i.e. the corners he did not touch were not the original corners of the Kaba)}}
\hadithdefcmd{malik}{806}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، قَالَتْ مَا أُبَالِي أَصَلَّيْتُ فِي الْحِجْرِ أَمْ فِي الْبَيْتِ ‏.‏\hadithno{806}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, umm al-muminin, said, "I do not mind whether I pray in the Hijr or in the House." (i.e. praying in the Hijr is the same as praying in the House)}}
\hadithdefcmd{malik}{807}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يَقُولُ سَمِعْتُ بَعْضَ، عُلَمَائِنَا يَقُولُ مَا حُجِرَ الْحِجْرُ فَطَافَ النَّاسُ مِنْ وَرَائِهِ إِلاَّ إِرَادَةَ أَنْ يَسْتَوْعِبَ النَّاسُ الطَّوَافَ بِالْبَيْتِ كُلِّهِ ‏.‏\hadithno{807}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he heard Ibn Shihab say that he had heard one of the people of knowledge say that the Hijr was only enclosed so that people would go beyond it as they were making tawaf, and their tawaf would therefore encompass the original House}}
\hadithdefcmd{malik}{808}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم رَمَلَ مِنَ الْحَجَرِ الأَسْوَدِ حَتَّى انْتَهَى إِلَيْهِ ثَلاَثَةَ أَطْوَافٍ ‏.‏\hadithno{808}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad from his father that Jabir ibn Abdullah said, "I saw the Messenger of Allah, may Allah bless him and grant him peace, hastening from the Black Stone until he reached it again, three times." Malik said, "This is what is still done by the people of knowledge in our city}}
\hadithdefcmd{malik}{809}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَرْمُلُ مِنَ الْحَجَرِ الأَسْوَدِ إِلَى الْحَجَرِ الأَسْوَدِ ثَلاَثَةَ أَطْوَافٍ وَيَمْشِي أَرْبَعَةَ أَطْوَافٍ ‏.‏\hadithno{809}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to hasten from the Black Stone round to the Black Stone three times and then would walk four circuits normally}}
\hadithdefcmd{malik}{810}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، كَانَ إِذَا طَافَ بِالْبَيْتِ يَسْعَى الأَشْوَاطَ الثَّلاَثَةَ يَقُولُ اللَّهُمَّ لاَ إِلَهَ إِلاَّ أَنْتَا وَأَنْتَ تُحْيِي بَعْدَ مَا أَمَتَّا يَخْفِضُ صَوْتَهُ بِذَلِكَ ‏.‏\hadithno{810}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that when his father did tawaf of the House he would hasten in the first three circuits and say in a low voice, "O Allah, there is no god but You, and You bring to life after You have made to die." Allahumma la ilaha illa anta, wa anta tuhyi badama amatta}}
\hadithdefcmd{malik}{811}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ رَأَى عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ أَحْرَمَ بِعُمْرَةٍ مِنَ التَّنْعِيمِ - قَالَ - ثُمَّ رَأَيْتُهُ يَسْعَى حَوْلَ الْبَيْتِ الأَشْوَاطَ الثَّلاَثَةَ ‏.‏\hadithno{811}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that he saw Abdullah ibn az-Zubayr go into ihram for umra at at-Tanim. He said, "Then I saw him hasten around the House for three circuits}}
\hadithdefcmd{malik}{812}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا أَحْرَمَ مِنْ مَكَّةَ لَمْ يَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى يَرْجِعَ مِنْ مِنًى وَكَانَ لاَ يَرْمُلُ إِذَا طَافَ حَوْلَ الْبَيْتِ إِذَا أَحْرَمَ مِنْ مَكَّةَ ‏.‏\hadithno{812}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar never used to do tawaf of the House or say between Safa and Marwa if he went into ihram in Makka until he had returned from Mina, nor would he hasten when doing tawaf of the House if he went into ihram in Makka}}
\hadithdefcmd{malik}{813}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَضَى طَوَافَهُ بِالْبَيْتِ وَرَكَعَ الرَّكْعَتَيْنِ وَأَرَادَ أَنْ يَخْرُجَ إِلَى الصَّفَا وَالْمَرْوَةِ اسْتَلَمَ الرُّكْنَ الأَسْوَدَ قَبْلَ أَنْ يَخْرُجَ ‏.‏\hadithno{813}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that when the Messenger of Allah, may Allah bless him and grant him peace, had finished his tawaf of the House, prayed two rakas, and wanted to go to Safa and Marwa, he would salute the corner of the Black Stone before he left}}
\hadithdefcmd{malik}{814}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ‏"‏ كَيْفَ صَنَعْتَ يَا أَبَا مُحَمَّدٍ فِي اسْتِلاَمِ الرُّكْنِ ‏"‏ ‏.‏ فَقَالَ عَبْدُ الرَّحْمَنِ اسْتَلَمْتُ وَتَرَكْتُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَصَبْتَ ‏"‏ ‏.‏\hadithno{814}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said that the Messenger of Allah, may Allah bless him and grant him peace, once said to Abd ar-Rahman ibn Awf, "What do you do, Abu Muhammad, when saluting the corner?" and Abd ar-Rahman said, "Sometimes I salute it, and sometimes I don't." The Messenger of Allah, may Allah bless him and grant him peace, said, "You are right}}
\hadithdefcmd{malik}{815}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، كَانَ إِذَا طَافَ بِالْبَيْتِ يَسْتَلِمُ الأَرْكَانَ كُلَّهَا وَكَانَ لاَ يَدَعُ الْيَمَانِيَ إِلاَّ أَنْ يُغْلَبَ عَلَيْهِ ‏.‏\hadithno{815}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to salute all the corners when he did tawaf of the House and did not omit the Yamani corner unless he was prevented from it}}
\hadithdefcmd{malik}{816}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ وَهُوَ يَطُوفُ بِالْبَيْتِ لِلرُّكْنِ الأَسْوَدِ إِنَّمَا أَنْتَ حَجَرٌ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبَّلَكَ مَا قَبَّلْتُكَ ثُمَّ قَبَّلَهُ ‏.‏\hadithno{816}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Umar ibn al-Khattab said to the corner of the Black Stone while he was doing tawaf of the House, "You are only a stone, and if I had not seen the Messenger of Allah, may Allah bless him and grant him peace, kiss you, I would not do so." Then he kissed it. Malik said, "I have heard some of the people of knowledge recommending someone doing tawaf of the House to put his hand to his mouth when he takes it from the Yamani corner}}
\hadithdefcmd{malik}{817}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ لاَ يَجْمَعُ بَيْنَ السُّبْعَيْنِ لاَ يُصَلِّي بَيْنَهُمَا وَلَكِنَّهُ كَانَ يُصَلِّي بَعْدَ كُلِّ سُبْعٍ رَكْعَتَيْنِ فَرُبَّمَا صَلَّى عِنْدَ الْمَقَامِ أَوْ عِنْدَ غَيْرِهِ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الطَّوَافِ إِنْ كَانَ أَخَفَّ عَلَى الرَّجُلِ أَنْ يَتَطَوَّعَ بِهِ فَيَقْرُنَ بَيْنَ الأُسْبُوعَيْنِ أَوْ أَكْثَرَ ثُمَّ يَرْكَعُ مَا عَلَيْهِ مِنْ رُكُوعِ تِلْكَ السُّبُوعِ قَالَ لاَ يَنْبَغِي ذَلِكَ وَإِنَّمَا السُّنَّةُ أَنْ يُتْبِعَ كُلَّ سُبْعٍ رَكْعَتَيْنِ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَدْخُلُ فِي الطَّوَافِ فَيَسْهُو حَتَّى يَطُوفَ ثَمَانِيَةَ أَوْ تِسْعَةَ أَطْوَافٍ قَالَ يَقْطَعُ إِذَا عَلِمَ أَنَّهُ قَدْ زَادَ ثُمَّ يُصَلِّي رَكْعَتَيْنِ وَلاَ يَعْتَدُّ بِالَّذِي كَانَ زَادَ وَلاَ يَنْبَغِي لَهُ أَنْ يَبْنِيَ عَلَى التِّسْعَةِ حَتَّى يُصَلِّيَ سُبْعَيْنِ جَمِيعًا لأَنَّ السُّنَّةَ فِي الطَّوَافِ أَنْ يُتْبِعَ كُلَّ سُبْعٍ رَكْعَتَيْنِ ‏.‏ قَالَ مَالِكٌ وَمَنْ شَكَّ فِي طَوَافِهِ بَعْدَ مَا يَرْكَعُ رَكْعَتَىِ الطَّوَافِ فَلْيَعُدْ فَلْيُتَمِّمْ طَوَافَهُ عَلَى الْيَقِينِ ثُمَّ لِيُعِدِ الرَّكْعَتَيْنِ لأَنَّهُ لاَ صَلاَةَ لِطَوَافٍ إِلاَّ بَعْدَ إِكْمَالِ السُّبْعِ ‏.‏ وَمَنْ أَصَابَهُ شَىْءٌ بِنَقْضِ وُضُوئِهِ وَهُوَ يَطُوفُ بِالْبَيْتِ أَوْ يَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ أَوْ بَيْنَ ذَلِكَ فَإِنَّهُ مَنْ أَصَابَهُ ذَلِكَ وَقَدْ طَافَ بَعْضَ الطَّوَافِ أَوْ كُلَّهُ وَلَمْ يَرْكَعْ رَكْعَتَىِ الطَّوَافِ فَإِنَّهُ يَتَوَضَّأُ وَيَسْتَأْنِفُ الطَّوَافَ وَالرَّكْعَتَيْنِ وَأَمَّا السَّعْىُ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَإِنَّهُ لاَ يَقْطَعُ ذَلِكَ عَلَيْهِ مَا أَصَابَهُ مِنِ انْتِقَاضِ وُضُوئِهِ وَلاَ يَدْخُلُ السَّعْىَ إِلاَّ وَهُوَ طَاهِرٌ بِوُضُوءٍ ‏.‏\hadithno{817}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father would never do two sets of seven tawafs together without praying between them. After every seven tawafs he would pray two rakas, sometimes at the maqam of Ibrahim, and sometimes elsewhere. Malik was asked whether a man doing voluntary tawaf could, to make it easier on himself, join two or more sets of seven circuits and then pray whatever he owed for those sets of seven, and he said, "He should not do that. The sunna is that he does two rakasafter every seven circuits." Malik said, about someone who began doing tawaf and then forgot how many he had done and did eightor nine circuits, "He should stop when he knows that he has done more than the right number and then pray two rakas,and he should not count the ones that he has done in excess. Neither should he build on the nine that he has done and then pray the rakas for the two sets of seven circuits together, because the sunna is that you pray two rakas after every seven circuits." Malik said that someone who was in doubt about his tawaf after he had prayed the two rakas of tawaf should go back and complete his tawaf until he was certain of how much he had done. He should then repeat the two rakas, because prayer when doing tawaf was only valid after completing seven circuits. "If some one breaks his wudu either while he is doing tawaf, or when he has finished tawaf but before he has prayed the two rakas of tawaf, he should do wudu and begin the tawaf and the two rakas afresh. Breaking wudu does not interrupt say between Safa and Marwa, but a person should not begin say unless he is pure by being in wudu}}
\hadithdefcmd{malik}{818}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَبْدٍ الْقَارِيَّ، أَخْبَرَهُ أَنَّهُ، طَافَ بِالْبَيْتِ مَعَ عُمَرَ بْنِ الْخَطَّابِ بَعْدَ صَلاَةِ الصُّبْحِ فَلَمَّا قَضَى عُمَرُ طَوَافَهُ نَظَرَ فَلَمْ يَرَ الشَّمْسَ طَلَعَتْ فَرَكِبَ حَتَّى أَنَاخَ بِذِي طُوًى فَصَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{818}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Humayd ibn Abd ar-Rahman ibn Awf that Abd ar-Rahman ibn Abd al-Qari mentioned to him that he once did tawaf of the House with Umar ibn al-Khattab after subh and when Umar had finished his tawaf he looked and saw that the sun had not yet risen, so he rode on until he made his camel kneel at Dhu Tuwa, and he prayed two rakas}}
\hadithdefcmd{malik}{819}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّهُ قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ يَطُوفُ بَعْدَ صَلاَةِ الْعَصْرِ ثُمَّ يَدْخُلُ حُجْرَتَهُ فَلاَ أَدْرِي مَا يَصْنَعُ ‏.‏\hadithno{819}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abu'z Zubayr al-Makki said, "I saw Abdullah ibn Abbas doing tawaf after asr. Then he went into his room and I do not know what he did}}
\hadithdefcmd{malik}{820}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّهُ قَالَ لَقَدْ رَأَيْتُ الْبَيْتَ يَخْلُو بَعْدَ صَلاَةِ الصُّبْحِ وَبَعْدَ صَلاَةِ الْعَصْرِ مَا يَطُوفُ بِهِ أَحَدٌ ‏.‏ قَالَ مَالِكٌ وَمَنْ طَافَ بِالْبَيْتِ بَعْضَ أُسْبُوعِهِ ثُمَّ أُقِيمَتْ صَلاَةُ الصُّبْحِ أَوْ صَلاَةُ الْعَصْرِ فَإِنَّهُ يُصَلِّي مَعَ الإِمَامِ ثُمَّ يَبْنِي عَلَى مَا طَافَ حَتَّى يُكْمِلَ سُبْعًا ثُمَّ لاَ يُصَلِّي حَتَّى تَطْلُعَ الشَّمْسُ أَوْ تَغْرُبَ ‏.‏ قَالَ وَإِنْ أَخَّرَهُمَا حَتَّى يُصَلِّيَ الْمَغْرِبَ فَلاَ بَأْسَ بِذَلِكَ ‏.‏ قَالَ مَالِكٌ وَلاَ بَأْسَ أَنْ يَطُوفَ الرَّجُلُ طَوَافًا وَاحِدًا بَعْدَ الصُّبْحِ وَبَعْدَ الْعَصْرِ لاَ يَزِيدُ عَلَى سُبْعٍ وَاحِدٍ وَيُؤَخِّرُ الرَّكْعَتَيْنِ حَتَّى تَطْلُعَ الشَّمْسُ كَمَا صَنَعَ عُمَرُ بْنُ الْخَطَّابِ وَيُؤَخِّرُهُمَا بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ فَإِذَا غَرَبَتِ الشَّمْسُ صَلاَّهُمَا إِنْ شَاءَ وَإِنْ شَاءَ أَخَّرَهُمَا حَتَّى يُصَلِّيَ الْمَغْرِبَ لاَ بَأْسَ بِذَلِكَ ‏.‏\hadithno{820}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Abu'z-Zubayr al-Makki said, "I saw the House deserted both after subh and asr, with no-one doing tawaf." Malik said, "If someone does some of his circuits and then the subh or asr prayer is begun, he should pray with the imam and then complete the rest of his circuits but should not pray at all until the sun has either risen or set " He added, "There is no harm in delaying the two rakas until after he has prayed maghrib." Malik said, "There is no harm in someone doing a single tawaf after subh or after asr, not to do more than one group of seven circuits, and then as long as he delays the two rakas until after the sun has risen, as Umar ibn al-Khattab did, or he delays them until after the sun has set if it is after asr. Then when the sun has set he can pray them if he wants, or, if he wants, he can delay them until after he has prayed maghrib. There is no harm in that}}
\hadithdefcmd{malik}{821}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لاَ يَصْدُرَنَّ أَحَدٌ مِنَ الْحَاجِّ حَتَّى يَطُوفَ بِالْبَيْتِ فَإِنَّ آخِرَ النُّسُكِ الطَّوَافُ بِالْبَيْتِ ‏.‏ قَالَ مَالِكٌ فِي قَوْلِ عُمَرَ بْنِ الْخَطَّابِ فَإِنَّ آخِرَ النُّسُكِ الطَّوَافُ بِالْبَيْتِ إِنَّ ذَلِكَ - فِيمَا نُرَى وَاللَّهُ أَعْلَمُ - لِقَوْلِ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏وَمَنْ يُعَظِّمْ شَعَائِرَ اللَّهِ فَإِنَّهَا مِنْ تَقْوَى الْقُلُوبِ‏\}‏ وَقَالَ ‏\{‏ثُمَّ مَحِلُّهَا إِلَى الْبَيْتِ الْعَتِيقِ‏\}‏ فَمَحِلُّ الشَّعَائِرِ كُلِّهَا وَانْقِضَاؤُهَا إِلَى الْبَيْتِ الْعَتِيقِ ‏.‏\hadithno{821}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that Umar ibn al-Khattab said, "No-one should leave the hajj until he has done tawaf of the House, and tawaf of the House is the final rite." Malik said, commenting about Umar ibn al-Khattab's saying 'tawaf of the House is the final rite,' "In our opinion, and Allah knows best, that is because Allah, the Blessed and Exalted, says, 'Whoever exalts the rituals of Allah - that is from the taqwa of the hearts' (Sura 22 ayat 32), and He says, 'Then their halal place (of sacrifice) is at the Ancient House,' and the place of all the rituals and where they end is therefore at the Ancient House}}
\hadithdefcmd{malik}{822}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، ‏.‏ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رَدَّ رَجُلاً مِنْ مَرِّ الظَّهْرَانِ لَمْ يَكُنْ وَدَّعَ الْبَيْتَ حَتَّى وَدَّعَ ‏.‏\hadithno{822}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Umar ibn al-Khattab refused to let one man who had not taken leave of the House pass adh-Dhahran, (a valley eighteen miles from Makka) until he had taken leave of it}}
\hadithdefcmd{malik}{823}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ مَنْ أَفَاضَ فَقَدْ قَضَى اللَّهُ حَجَّهُ فَإِنَّهُ إِنْ لَمْ يَكُنْ حَبَسَهُ شَىْءٌ فَهُوَ حَقِيقٌ أَنْ يَكُونَ آخِرُ عَهْدِهِ الطَّوَافَ بِالْبَيْتِ وَإِنْ حَبَسَهُ شَىْءٌ أَوْ عَرَضَ لَهُ فَقَدْ قَضَى اللَّهُ حَجَّهُ ‏.‏ قَالَ مَالِكٌ وَلَوْ أَنَّ رَجُلاً جَهِلَ أَنْ يَكُونَ آخِرُ عَهْدِهِ الطَّوَافَ بِالْبَيْتِ حَتَّى صَدَرَ لَمْ أَرَ عَلَيْهِ شَيْئًا إِلاَّ أَنْ يَكُونَ قَرِيبًا فَيَرْجِعَ فَيَطُوفَ بِالْبَيْتِ ثُمَّ يَنْصَرِفَ إِذَا كَانَ قَدْ أَفَاضَ ‏.‏\hadithno{823}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "Allah has completed the hajj of anyone who does the tawaf al-ifada. It is fitting that tawaf of the House be the last of his contract, as long as nothing prevents him, and if something prevents him, or an obstacle arises, then Allah has completed his hajj." Malik said, "I do not think that a man who does not know that the last of his contract is tawaf of the House until he has left owes anything, unless he is nearby and can return, do tawaf, and then leave having done the tawaf al-ifada}}
\hadithdefcmd{malik}{824}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ شَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي أَشْتَكِي فَقَالَ ‏"‏ طُوفِي مِنْ وَرَاءِ النَّاسِ وَأَنْتِ رَاكِبَةٌ ‏"‏ ‏.‏ قَالَتْ فَطُفْتُ رَاكِبَةً بَعِيرِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم حِينَئِذٍ يُصَلِّي إِلَى جَانِبِ الْبَيْتِ وَهُوَ يَقْرَأُ بِـ ‏\{‏الطُّورِ وَكِتَابٍ مَسْطُورٍ ‏\}‏‏.‏\hadithno{824}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abu'l-Aswad Muhammad ibn Abd ar-Rahman ibn Nawfal from Urwa ibn az-Zubayr from Zaynab bint Abi Salama that Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, said, "I once complained to the Messenger of Allah, may Allah bless him and grant him peace, that I was ill and he said, 'Do tawaf riding behind the people.' So I did tawaf riding my camel, while the Messenger of Allah, may Allah bless him and grant him peace, was praying by the side of the House, reciting Surat at-Tur}}
\hadithdefcmd{malik}{825}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّ أَبَا مَاعِزٍ الأَسْلَمِيَّ عَبْدَ اللَّهِ بْنَ سُفْيَانَ، أَخْبَرَهُ أَنَّهُ، كَانَ جَالِسًا مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ فَجَاءَتْهُ امْرَأَةٌ تَسْتَفْتِيهِ فَقَالَتْ إِنِّي أَقْبَلْتُ أُرِيدُ أَنْ أَطُوفَ بِالْبَيْتِ حَتَّى إِذَا كُنْتُ بِبَابِ الْمَسْجِدِ هَرَقْتُ الدِّمَاءَ فَرَجَعْتُ حَتَّى ذَهَبَ ذَلِكَ عَنِّي ثُمَّ أَقْبَلْتُ حَتَّى إِذَا كُنْتُ عِنْدَ بَابِ الْمَسْجِدِ هَرَقْتُ الدِّمَاءَ فَرَجَعْتُ حَتَّى ذَهَبَ ذَلِكَ عَنِّي ثُمَّ أَقْبَلْتُ حَتَّى إِذَا كُنْتُ عِنْدَ بَابِ الْمَسْجِدِ هَرَقْتُ الدِّمَاءَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ إِنَّمَا ذَلِكَ رَكْضَةٌ مِنَ الشَّيْطَانِ فَاغْتَسِلِي ثُمَّ اسْتَثْفِرِي بِثَوْبٍ ثُمَّ طُوفِي ‏.‏\hadithno{825}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zubayr al-Makki that Abu Maiz al-Aslami Abdullah ibn Sufyan told him that once, when he was sitting with Abdullah ibn Umar, a woman came to ask him for an opinion. She said, "I set out intending to do tawaf of the House, but then, when I got to the gate of the Mosque, I started bleeding, so I went back until it had left me. Then I set out again, and then, when I got to the gate of the mosque, I started bleeding, so I went back until it had left me. Then I set off again, and then, when I got to the gate of the mosque, I started bleeding." Abdullah ibn Umar said, "That is only an impulse from Shaytan. Do ghusl, then bind your private parts with a cloth and do tawaf}}
\hadithdefcmd{malik}{826}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعْدَ بْنَ أَبِي وَقَّاصٍ، كَانَ إِذَا دَخَلَ مَكَّةَ مُرَاهِقًا خَرَجَ إِلَى عَرَفَةَ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ يَطُوفُ بَعْدَ أَنْ يَرْجِعَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ وَاسِعٌ إِنْ شَاءَ اللَّهُ ‏.‏ وَسُئِلَ مَالِكٌ هَلْ يَقِفُ الرَّجُلُ فِي الطَّوَافِ بِالْبَيْتِ الْوَاجِبِ عَلَيْهِ يَتَحَدَّثُ مَعَ الرَّجُلِ فَقَالَ لاَ أُحِبُّ ذَلِكَ لَهُ ‏.‏ قَالَ مَالِكٌ لاَ يَطُوفُ أَحَدٌ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ إِلاَّ وَهُوَ طَاهِرٌ ‏.‏\hadithno{826}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that if Sad ibn Abi Waqqas entered Makka late, he would go to Arafa before doing tawaf of the House and say between Safa and Marwa, and then do tawaf when he got back. Malik said, "The leeway is broad, if Allah wills." Malik was asked whether somebody that was doing obligatory tawaf could stop and talk with another man, and he said, "I do not like him to do that." Malik said, "Only someone who is pure (by being in wudu) should do tawaf of the House or say between Safa and Marwa}}
\hadithdefcmd{malik}{827}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ حِينَ خَرَجَ مِنَ الْمَسْجِدِ وَهُوَ يُرِيدُ الصَّفَا وَهُوَ يَقُولُ ‏ "‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏ فَبَدَأَ بِالصَّفَا ‏.‏\hadithno{827}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad ibn AIi from his father that Jabir ibn Abdullah said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say as he left the mosque, intending to go to Safa, 'We begin with that with which Allah began,' and he began with Safa}}
\hadithdefcmd{malik}{828}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا وَقَفَ عَلَى الصَّفَا يُكَبِّرُ ثَلاَثًا وَيَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ يَصْنَعُ ذَلِكَ ثَلاَثَ مَرَّاتٍ وَيَدْعُو وَيَصْنَعُ عَلَى الْمَرْوَةِ مِثْلَ ذَلِكَ ‏.‏\hadithno{828}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammed ibn AIi from his father from Jabir ibn Abdullah that the Messenger of Allah, may Allah bless him and grant him peace, used to say, "Allah is greater" three times when he stopped on Safa, and "There is no god but Allah, alone, without any partner. To Him belong the Kingdom and praise, and He has power over everything" three times, and make dua. He would then do the same on Marwa}}
\hadithdefcmd{malik}{829}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، وَهُوَ عَلَى الصَّفَا يَدْعُو يَقُولُ اللَّهُمَّ إِنَّكَ قُلْتَ ادْعُونِي أَسْتَجِبْ لَكُمْ وَإِنَّكَ لاَ تُخْلِفُ الْمِيعَادَ وَإِنِّي أَسْأَلُكَ كَمَا هَدَيْتَنِي لِلإِسْلاَمِ أَنْ لاَ تَنْزِعَهُ مِنِّي حَتَّى تَتَوَفَّانِي وَأَنَا مُسْلِمٌ ‏.‏\hadithno{829}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that he heard Abdullah ibn Umar making dua on Safa saying, "O Allah, You have said, 'call on Me - I will answer you' and You do not break Your promise. So I am askingYou, in the same way that You have guided me to Islam, not to take it away from me, and that You make me die while I am muslim}}
\hadithdefcmd{malik}{830}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ قُلْتُ لِعَائِشَةَ أُمِّ الْمُؤْمِنِينَ وَأَنَا يَوْمَئِذٍ، حَدِيثُ السِّنِّ أَرَأَيْتِ قَوْلَ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏ فَمَا عَلَى الرَّجُلِ شَىْءٌ أَنْ لاَ يَطَّوَّفَ بِهِمَا ‏.‏ فَقَالَتْ عَائِشَةُ كَلاَّ لَوْ كَانَ كَمَا تَقُولُ لَكَانَتْ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا إِنَّمَا أُنْزِلَتْ هَذِهِ الآيَةُ فِي الأَنْصَارِ كَانُوا يُهِلُّونَ لِمَنَاةَ وَكَانَتْ مَنَاةُ حَذْوَ قُدَيْدٍ وَكَانُوا يَتَحَرَّجُونَ أَنْ يَطُوفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ فَلَمَّا جَاءَ الإِسْلاَمُ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَنْزَلَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا ‏\}‏\hadithno{830}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "Once when I was young I said to A'isha, umm al-muminin, 'Have you seen the saying of Allah, the Blessed and Exalted, "Safa and Marwa are among the waymarks of Allah, so whoever does hajj or umra to the House, there is no harm in his going between them," so it follows that there should be no harm for some one who does not go between them.' A'isha said, 'No. If it were as you say, there would be no harm in his not going between them. This ayat was only revealed about the Ansar. They used to make pilgrimage to Manat, and Manat was an idol near Qudayd, and they used to avoid going between Safa and Marwa, and when Islam came they asked the Messenger of Allah, may Allah bless him and grant him peace, about this and Allah, the Blessed and Exalted, revealed, "Safa and Marwa are among the waymarks of Allah, so whoever does hajj or umra to the House, there is no harm in his going between them}}
\hadithdefcmd{malik}{831}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ سَوْدَةَ بِنْتَ عَبْدِ اللَّهِ بْنِ عُمَرَ، كَانَتْ عِنْدَ عُرْوَةَ بْنِ الزُّبَيْرِ فَخَرَجَتْ تَطُوفُ بَيْنَ الصَّفَا وَالْمَرْوَةِ فِي حَجٍّ أَوْ عُمْرَةٍ مَاشِيَةً وَكَانَتِ امْرَأَةً ثَقِيلَةً فَجَاءَتْ حِينَ انْصَرَفَ النَّاسُ مِنَ الْعِشَاءِ فَلَمْ تَقْضِ طَوَافَهَا حَتَّى نُودِيَ بِالأُولَى مِنَ الصُّبْحِ فَقَضَتْ طَوَافَهَا فِيمَا بَيْنَهَا وَبَيْنَهُ ‏.‏ وَكَانَ عُرْوَةُ إِذَا رَآهُمْ يَطُوفُونَ عَلَى الدَّوَابِّ يَنْهَاهُمْ أَشَدَّ النَّهْىِ فَيَعْتَلُّونَ بِالْمَرَضِ حَيَاءً مِنْهُ فَيَقُولُ لَنَا فِيمَا بَيْنَنَا وَبَيْنَهُ لَقَدْ خَابَ هَؤُلاَءِ وَخَسِرُوا ‏.‏ قَالَ مَالِكٌ مَنْ نَسِيَ السَّعْىَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فِي عُمْرَةٍ فَلَمْ يَذْكُرْ حَتَّى يَسْتَبْعِدَ مِنْ مَكَّةَ أَنَّهُ يَرْجِعُ فَيَسْعَى وَإِنْ كَانَ قَدْ أَصَابَ النِّسَاءَ فَلْيَرْجِعْ فَلْيَسْعَ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى يُتِمَّ مَا بَقِيَ عَلَيْهِ مِنْ تِلْكَ الْعُمْرَةِ ثُمَّ عَلَيْهِ عُمْرَةٌ أُخْرَى وَالْهَدْىُ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الرَّجُلِ يَلْقَاهُ الرَّجُلُ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَيَقِفُ مَعَهُ يُحَدِّثُهُ فَقَالَ لاَ أُحِبُّ لَهُ ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَمَنْ نَسِيَ مِنْ طَوَافِهِ شَيْئًا أَوْ شَكَّ فِيهِ فَلَمْ يَذْكُرْ إِلاَّ وَهُوَ يَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ فَإِنَّهُ يَقْطَعُ سَعْيَهُ ثُمَّ يُتِمُّ طَوَافَهُ بِالْبَيْتِ عَلَى مَا يَسْتَيْقِنُ وَيَرْكَعُ رَكْعَتَىِ الطَّوَافِ ثُمَّ يَبْتَدِئُ سَعْيَهُ بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏\hadithno{831}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that Sawda bint Abdullah ibn Umar, who was in the household of Urwa ibn az- Zubayr, set off walking between Safa and Marwa when doing either hajj or an umra. She was a heavy woman and she began when everybody was leaving after the isha prayer, and she still had not completed her circuits when the first call was given for subh, but finished them between the two calls to prayer. If Urwa saw people doing circuits on riding beasts he would tell them in very strong terms not to do so, and they would pretend to be ill, out of awe of him. Hisham added, "He used to say to us about them 'These are unsuccessful and have lost.' " Malik said, "Someone who forgets say between Safa and Marwa in an umra, and does not remember until he is far from Makka, should return and do say. If, in the meantime, he has had intercourse with a woman, he should return and do say between Safa and Marwa so as to complete what remains of that umra, and then after that he has to do another umra and offer a sacrificial animal." Malik was asked about someone who met another man when doing say between Safa and Marwa and stopped to talk with him, and he said, "I do not like anyone to do that." Malik said, "If anyone forgets some of his tawaf or is uncertain about it and remembers only when he is doing say between Safa and Marwa, he should stop the say and complete his tawaf of the House apart from that about which he is certain. After that he prays the two rakas of the tawaf, and then begins his say between Safa and Marwa}}
\hadithdefcmd{malik}{832}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا نَزَلَ مِنَ الصَّفَا وَالْمَرْوَةِ مَشَى حَتَّى إِذَا انْصَبَّتْ قَدَمَاهُ فِي بَطْنِ الْوَادِي سَعَى حَتَّى يَخْرُجَ مِنْهُ ‏.‏\hadithno{832}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad from his father from Jabir ibn Abdullah that the Messenger of Allah, may Allah bless him and grant him peace, walked when he came down from Safa and Marwa and then, when he reached the middle of the valley, he broke into a light run until he had left it. Malik said, about a man who, out of ignorance, did the say between Safa and Marwa before he had done tawaf of the House, "He should go back and do tawaf of the House and then do say between Safa and Marwa. If he does not learn about this until he has left Makka and is far away, he should return to Makka and do tawaf of the House and say between Safa and Marwa. If in the meantime he has had intercourse with a woman he should return, and do tawaf of the House and say between Safa and Marwa so that he completes what he owes of that umra. Then, after that, he has to do another umra and offer a sacrificial animal}}
\hadithdefcmd{malik}{833}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عُمَيْرٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنْ أُمِّ الْفَضْلِ بِنْتِ الْحَارِثِ، أَنَّ نَاسًا، تَمَارَوْا عِنْدَهَا يَوْمَ عَرَفَةَ فِي صِيَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ بَعْضُهُمْ هُوَ صَائِمٌ وَقَالَ بَعْضُهُمْ لَيْسَ بِصَائِمٍ فَأَرْسَلْتُ إِلَيْهِ بِقَدَحِ لَبَنٍ وَهُوَ وَاقِفٌ عَلَى بَعِيرِهِ فَشَرِبَ ‏.‏\hadithno{833}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n Nadr, the mawla of Umar ibn Ubaydullah, from Umayr, the mawla of Abdullah ibn Abbas, from Umm al-Fadl bint al-Harith, that she was present when some people were arguing on the day of Arafa about whether the Messenger of Allah, may Allah bless him and grant him peace, was fasting or not. Some of them said he was fasting, and some of them said he was not. So she sent a bowl of milk to him while his camel was standing still and he drank}}
\hadithdefcmd{malik}{834}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، كَانَتْ تَصُومُ يَوْمَ عَرَفَةَ ‏.‏ قَالَ الْقَاسِمُ وَلَقَدْ رَأَيْتُهَا عَشِيَّةَ عَرَفَةَ يَدْفَعُ الإِمَامُ ثُمَّ تَقِفُ حَتَّى يَبْيَضَّ مَا بَيْنَهَا وَبَيْنَ النَّاسِ مِنَ الأَرْضِ ثُمَّ تَدْعُو بِشَرَابٍ فَتُفْطِرُ ‏.‏\hadithno{834}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from al-Qasim ibn Muhammad that A'isha, umm al-muminin, used to fast on the day of Arafa . Al-Qasim said, "I saw her, when the imam began moving away (after sunset) on the afternoon of Arafa, stay where she was until the ground between her and the people became clear. Then she asked for something to drink and broke her fast}}
\hadithdefcmd{malik}{835}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْر��، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ صِيَامِ أَيَّامِ مِنًى ‏.‏\hadithno{835}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abu'n-Nadr, the mawla of Umar ibn Ubaydullah, from Sulayman ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, forbade fasting on the days of Mina}}
\hadithdefcmd{malik}{836}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ عَبْدَ اللَّهِ بْنَ حُذَافَةَ أَيَّامَ مِنًى يَطُوفُ يَقُولُ إِنَّمَا هِيَ أَيَّامُ أَكْلٍ وَشُرْبٍ وَذِكْرِ اللَّهِ ‏.‏\hadithno{836}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that the Messenger of Allah, may Allah bless him and grant him peace, sent Abdullah ibn Hudhayfa out on the days of Mina to circulate among the people to tell them those days were for eating and drinking and remembrance of Allah}}
\hadithdefcmd{malik}{837}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ صِيَامِ يَوْمَيْنِ يَوْمِ الْفِطْرِ وَيَوْمِ الأَضْحَى ‏.‏\hadithno{837}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Yahya ibn Habban from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, forbade fasting on two days - the day of the Id al-Fitr and the day of the Id al-Adha}}
\hadithdefcmd{malik}{838}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِي، عَنْ أَبِي مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ أُخْتِ عَقِيلِ بْنِ أَبِي طَالِبٍ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، دَخَلَ عَلَى أَبِيهِ عَمْرِو بْنِ الْعَاصِ فَوَجَدَهُ يَأْكُلُ قَالَ فَدَعَانِي قَالَ فَقُلْتُ لَهُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ هَذِهِ الأَيَّامُ الَّتِي نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامِهِنَّ وَأَمَرَنَا بِفِطْرِهِنَّ ‏.‏\hadithno{838}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Abdullah ibn al- Hadi from Abu Murra, the mawla of Umm Hani, the sister of Aqil ibn Abi Talib, that Abdullah ibn Amr ibn al-As told him that he had visited his father Amr ibn al-As and found him eating. His father had invited him to eat, and when he replied that he was fasting, his father said, "These are the days on which the Messenger of Allah, may Allah bless him and grant him peace, forbade us to fast, and told us to break the fast on them." Malik said, "These days are the days of tashriq}}
\hadithdefcmd{malik}{839}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهْدَى جَمَلاً كَانَ لأَبِي جَهْلِ بْنِ هِشَامٍ فِي حَجٍّ أَوْ عُمْرَةٍ ‏.‏\hadithno{839}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm that the Messenger of Allah, may Allah bless him and grant him peace, sacrificed a camel, which had belonged to Abu Jahl ibn Hisham, in either a hajj or an umra}}
\hadithdefcmd{malik}{840}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهَا بَدَنَةٌ ‏.‏ فَقَالَ ‏"‏ ارْكَبْهَا وَيْلَكَ ‏"‏ ‏.‏ فِي الثَّانِيَةِ أَوِ الثَّالِثَةِ ‏.‏\hadithno{840}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, saw a man driving forward a camel which he was going to sacrifice, and he told him to ride it. The man said, "Messenger of Allah, it is an animal that I am going to sacrifice," and he replied, "Ride it, woe on you," either the second or the third time}}
\hadithdefcmd{malik}{841}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ كَانَ يَرَى عَبْدَ اللَّهِ بْنَ عُمَرَ يُهْدِي فِي الْحَجِّ بَدَنَتَيْنِ بَدَنَتَيْنِ وَفِي الْعُمْرَةِ بَدَنَةً بَدَنَةً ‏.‏ قَالَ وَرَأَيْتُهُ فِي الْعُمْرَةِ يَنْحَرُ بَدَنَةً وَهِيَ قَائِمَةٌ فِي دَارِ خَالِدِ بْنِ أَسِيدٍ وَكَانَ فِيهَا مَنْزِلُهُ ‏.‏ قَالَ وَلَقَدْ رَأَيْتُهُ طَعَنَ فِي لَبَّةِ بَدَنَتِهِ حَتَّى خَرَجَتِ الْحَرْبَةُ مِنْ تَحْتِ كَتِفِهَا ‏.‏\hadithno{841}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that he used to see Abdullah ibn Umar sacrificing animals two at a time during hajj and one at a time during umra. He said, "I saw him sacrifice an animal during an umra outside the house of Khalid ibn Usayd, where he was staying. I saw him stick his spear in the throat of the animal he was going to sacrifice until the spear came out under its shoulder}}
\hadithdefcmd{malik}{842}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَهْدَى جَمَلاً فِي حَجٍّ أَوْ عُمْرَةٍ ‏.‏\hadithno{842}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Umar ibn Abd al-Aziz once sacrificed a camel during a hajj or an umra}}
\hadithdefcmd{malik}{843}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي جَعْفَرٍ الْقَارِئِ، ‏.‏ أَنَّ عَبْدَ اللَّهِ بْنَ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ الْمَخْزُومِيَّ، أَهْدَى بَدَنَتَيْنِ إِحْدَاهُمَا بُخْتِيَّةٌ ‏.‏\hadithno{843}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Jafar al-Qari that Abdullah ibn Ayyash ibn Abi Rabia al-Makhzumi sacrificed two camels, one of them a Bactrian}}
\hadithdefcmd{malik}{844}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِذَا نُتِجَتِ النَّاقَةُ فَلْيُحْمَلْ وَلَدُهَا حَتَّى يُنْحَرَ مَعَهَا فَإِنْ لَمْ يُوجَدْ لَهُ مَحْمَلٌ حُمِلَ عَلَى أُمِّهِ حَتَّى يُنْحَرَ مَعَهَا ‏.‏\hadithno{844}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "If a she-camel that is being driven as a sacrificial animal gives birth, the offspring should be carried along as well and they are sacrificed together with her, and if there is no place where they can be carried, they should be carried on the mother until they are all sacrificed}}
\hadithdefcmd{malik}{845}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، قَالَ إِذَا اضْطُرِرْتَ إِلَى بَدَنَتِكَ فَارْكَبْهَا رُكُوبًا غَيْرَ فَادِحٍ وَإِذَا اضْطُرِرْتَ إِلَى لَبَنِهَا فَاشْرَبْ بَعْدَ مَا يَرْوَى فَصِيلُهَا فَإِذَا نَحَرْتَهَا فَانْحَرْ فَصِيلَهَا مَعَهَا ‏.‏\hadithno{845}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{ahya related to me from Malik from Hisham ibn Urwa that his father said, "If necessary, ride on your sacrificial animal, without burdening it, and if necessary, drink its milk after its young one has drunk its fill, and when you sacrifice it, sacrifice the young one with it}}
\hadithdefcmd{malik}{846}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ إِذَا أَهْدَى هَدْيًا مِنَ الْمَدِينَةِ قَلَّدَهُ وَأَشْعَرَهُ بِذِي الْحُلَيْفَةِ يُقَلِّدُهُ قَبْلَ أَنْ يُشْعِرَهُ وَذَلِكَ فِي مَكَانٍ وَاحِدٍ وَهُوَ مُوَجَّهٌ لِلْقِبْلَةِ يُقَلِّدُهُ بِنَعْلَيْنِ وَيُشْعِرُهُ مِنَ الشِّقِّ الأَيْسَرِ ثُمَّ يُسَاقُ مَعَهُ حَتَّى يُوقَفَ بِهِ مَعَ النَّاسِ بِعَرَفَةَ ثُمَّ يَدْفَعُ بِهِ مَعَهُمْ إِذَا دَفَعُوا فَإِذَا قَدِمَ مِنًى غَدَاةَ النَّحْرِ نَحَرَهُ قَبْلَ أَنْ يَحْلِقَ أَوْ يُقَصِّرَ وَكَانَ هُوَ يَنْحَرُ هَدْيَهُ بِيَدِهِ يَصُفُّهُنَّ قِيَامًا وَيُوَجِّهُهُنَّ إِلَى الْقِبْلَةِ ثُمَّ يَأْكُلُ وَيُطْعِمُ ‏.‏\hadithno{846}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that when he brought an animal to be sacrificed from Madina he would garland it and brand it at Dhu'l-Hulayfa, doing the garlanding before the branding, but doing both in the same place, while facing the qibla. He would garland the animal with two sandals and brand it on its left side. It would then be driven with him until he observed the standing together with everybody at Arafa. Then he would drive it on with him when everybody else moved on, and then when he arrived at Mina on the morning of the sacrifice, he would sacrifice the animal, before he shaved his head. He would sacrifice the animals with his own hands ,lining them up standing and facing the qibla. He would then eat some of the meat, and give some of it away}}
\hadithdefcmd{malik}{847}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا طَعَنَ فِي سَنَامِ هَدْيِهِ وَهُوَ يُشْعِرُهُ قَالَ بِسْمِ اللَّهِ وَاللَّهُ أَكْبَرُ ‏.‏\hadithno{847}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, when nicking the hump of his sacrificial animal to brand it, "In the name of Allah, and Allah is greater}}
\hadithdefcmd{malik}{848}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ الْهَدْىُ مَا قُلِّدَ وَأُشْعِرَ وَوُقِفَ بِهِ بِعَرَفَةَ ‏.‏\hadithno{848}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "A sacrificial animal is what has been garlanded, branded, and stood with on Arafa}}
\hadithdefcmd{malik}{849}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُجَلِّلُ بُدْنَهُ الْقُبَاطِيَّ وَالأَنْمَاطَ وَالْحُلَلَ ثُمَّ يَبْعَثُ بِهَا إِلَى الْكَعْبَةِ فَيَكْسُوهَا إِيَّاهَا ‏.‏\hadithno{849}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to drape his sacrificial animals in fine Egyptian linen, saddlecloths and sets of clothing, which he would afterwards send to the Kaba and have the Kaba draped with them}}
\hadithdefcmd{malik}{850}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ دِينَارٍ مَا كَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَصْنَعُ بِجِلاَلِ بُدْنِهِ حِينَ كُسِيَتِ الْكَعْبَةُ هَذِهِ الْكِسْوَةَ قَالَ كَانَ يَتَصَدَّقُ بِهَا ‏.‏\hadithno{850}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he asked Abdullah ibn Dinar what Abdullah ibn Umar used to do with the drapings of his animals when the Kaba began to be draped with the kiswa, and he said, "He gave them away as sadaqa}}
\hadithdefcmd{malik}{851}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ فِي الضَّحَايَا وَالْبُدْنِ الثَّنِيُّ فَمَا فَوْقَهُ ‏.‏\hadithno{851}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, about sacrificial animals, "Six-year-old camels, three- year-old cows and sheep, or older than these}}
\hadithdefcmd{malik}{852}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَشُقُّ جِلاَلَ بُدْنِهِ وَلاَ يُجَلِّلُهَا حَتَّى يَغْدُوَ مِنْ مِنًى إِلَى عَرَفَةَ ‏.‏\hadithno{852}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar never used to tear the drapes of his sacrificial animals, and he would not drape them until he went from Mina to Arafa}}
\hadithdefcmd{malik}{853}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ لِبَنِيهِ يَا بَنِيَّ لاَ يُهْدِيَنَّ أَحَدُكُمْ مِنَ الْبُدْنِ شَيْئًا يَسْتَحْيِي أَنْ يُهْدِيَهُ لِكَرِيمِهِ فَإِنَّ اللَّهَ أَكْرَمُ الْكُرَمَاءِ وَأَحَقُّ مَنِ اخْتِيرَ لَهُ ‏.‏\hadithno{853}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to say to his sons, "My sons, let none of you sacrifice any animal which he would be ashamed to sacrifice for a noble woman, for surely Allah is the noblest of noble ones, and the most deserving of those for whom things are chosen}}
\hadithdefcmd{malik}{854}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ صَاحِبَ، هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ بِمَا عَطِبَ مِنَ الْهَدْىِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ بَدَنَةٍ عَطِبَتْ مِنَ الْهَدْىِ فَانْحَرْهَا ثُمَّ أَلْقِ قِلاَدَتَهَا فِي دَمِهَا ثُمَّ خَلِّ بَيْنَهَا وَبَيْنَ النَّاسِ يَأْكُلُونَهَا ‏"‏ ‏.‏\hadithno{854}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the man who was in charge of the sacrificial animal of the Messenger of Allah, may Allah bless him and grant him peace, said, "Messenger of Allah, what should I do with a sacrificial animal that gets injured?" The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Slaughter any sacrificial animal that is injured. Then throw the garlands in its blood, and then give the people a free hand in eating it}}
\hadithdefcmd{malik}{855}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ مَنْ سَاقَ بَدَنَةً تَطَوُّعًا فَعَطِبَتْ فَنَحَرَهَا ثُمَّ خَلَّى بَيْنَهَا وَبَيْنَ النَّاسِ يَأْكُلُونَهَا فَلَيْسَ عَلَيْهِ شَىْءٌ وَإِنْ أَكَلَ مِنْهَا أَوْ أَمَرَ مَنْ يَأْكُلُ مِنْهَا غَرِمَهَا ‏.‏\hadithno{855}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said ibn al- Musayyab said, "If someone dedicates an animal voluntarily and then it is injured and he kills it and gives everyone a free hand in eating it, he owes nothing. If, however, he eats some of it himself, or tells certain other people to eat it, then he owes compensation}}
\hadithdefcmd{malik}{856}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، مِثْلَ ذَلِكَ ‏.‏\hadithno{856}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili from Abdullah ibn Abbas the same as that}}
\hadithdefcmd{malik}{857}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ مَنْ أَهْدَى بَدَنَةً جَزَاءً أَوْ نَذْرًا أَوْ هَدْىَ تَمَتُّعٍ فَأُصِيبَتْ فِي الطَّرِيقِ فَعَلَيْهِ الْبَدَلُ ‏.‏\hadithno{857}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "If someone dedicates an animal as compensation, or for a vow, or as the sacrifice for tamattu, and misfortune befalls it on the road, he must provide a substitute}}
\hadithdefcmd{malik}{858}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ مَنْ أَهْدَى بَدَنَةً ثُمَّ ضَلَّتْ أَوْ مَاتَتْ فَإِنَّهَا إِنْ كَانَتْ نَذْرًا أَبْدَلَهَا وَإِنْ كَانَتْ تَطَوُّعًا فَإِنْ شَاءَ أَبْدَلَهَا وَإِنْ شَاءَ تَرَكَهَا ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ أَنَّهُ سَمِعَ أَهْلَ الْعِلْمِ يَقُولُونَ لاَ يَأْكُلُ صَاحِبُ الْهَدْىِ مِنَ الْجَزَاءِ وَالنُّسُكِ ‏.‏\hadithno{858}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "If someone dedicates an animal and then it goes astray or dies, he should provide a substitute, if it was for a vow. If, however, it was voluntary, then he can either provide a substitute for it or not, as he wishes}}
\hadithdefcmd{malik}{859}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَعَلِيَّ بْنَ أَبِي طَالِبٍ، وَأَبَا، هُرَيْرَةَ سُئِلُوا عَنْ رَجُلٍ، أَصَابَ أَهْلَهُ وَهُوَ مُحْرِمٌ بِالْحَجِّ فَقَالُوا يَنْفُذَانِ يَمْضِيَانِ لِوَجْهِهِمَا حَتَّى يَقْضِيَا حَجَّهُمَا ثُمَّ عَلَيْهِمَا حَجُّ قَابِلٍ وَالْهَدْىُ ‏.‏ قَالَ وَقَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ وَإِذَا أَهَلاَّ بِالْحَجِّ مِنْ عَامٍ قَابِلٍ تَفَرَّقَا حَتَّى يَقْضِيَا حَجَّهُمَا ‏.‏\hadithno{859}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard the people of knowledge say, "Someone who dedicates a sacrificial animal for compensation or as part of the hajj should not eat from it." Yahya related to me from Malik that he had heard that Umar ibn al-Khattab and AIi ibn Abi Talib and Abu Hurayra were asked about a man who had intercourse with his wife while he was in ihram on hajj. They said, "The two of them should carry on and complete their hajj. Then they must do hajj again in another year, and sacrifice an animal." Malik added that AIi ibn Abi Talib said, "When they then go into ihram for hajj in a future year they should keep apart until they have completed their hajj}}
\hadithdefcmd{malik}{860}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ مَا تَرَوْنَ فِي رَجُلٍ وَقَعَ بِامْرَأَتِهِ وَهُوَ مُحْرِمٌ فَلَمْ يَقُلْ لَهُ الْقَوْمُ شَيْئًا فَقَالَ سَعِيدٌ إِنَّ رَجُلاً وَقَعَ بِامْرَأَتِهِ وَهُوَ مُحْرِمٌ فَبَعَثَ إِلَى الْمَدِينَةِ يَسْأَلُ عَنْ ذَلِكَ فَقَالَ بَعْضُ النَّاسِ يُفَرَّقُ بَيْنَهُمَا إِلَى عَامٍ قَابِلٍ ‏.‏ فَقَالَ سَعِيدُ بْنُ الْمُسَيَّبِ لِيَنْفُذَا لِوَجْهِهِمَا فَلْيُتِمَّا حَجَّهُمَا الَّذِي أَفْسَدَاهُ فَإِذَا فَرَغَا رَجَعَا فَإِنْ أَدْرَكَهُمَا حَجٌّ قَابِلٌ فَعَلَيْهِمَا الْحَجُّ وَالْهَدْىُ وَيُهِلاَّنِ مِنْ حَيْثُ أَهَلاَّ بِحَجِّهِمَا الَّذِي أَفْسَدَاهُ ‏.‏ وَيَتَفَرَّقَانِ حَتَّى يَقْضِيَا حَجَّهُمَا ‏.‏ قَالَ مَالِكٌ يُهْدِيَانِ جَمِيعًا بَدَنَةً بَدَنَةً ‏.‏ قَالَ مَالِكٌ فِي رَجُلٍ وَقَعَ بِامْرَأَتِهِ فِي الْحَجِّ مَا بَيْنَهُ وَبَيْنَ أَنْ يَدْفَعَ مِنْ عَرَفَةَ وَيَرْمِيَ الْجَمْرَةَ إِنَّهُ يَجِبُ عَلَيْهِ الْهَدْىُ وَحَجُّ قَابِلٍ قَالَ فَإِنْ كَانَتْ إِصَابَتُهُ أَهْلَهُ بَعْدَ رَمْىِ الْجَمْرَةِ فَإِنَّمَا عَلَيْهِ أَنْ يَعْتَمِرَ وَيُهْدِيَ وَلَيْسَ عَلَيْهِ حَجُّ قَابِلٍ ‏.‏ قَالَ مَالِكٌ وَالَّذِي يُفْسِدُ الْحَجَّ أَوِ الْعُمْرَةَ حَتَّى يَجِبَ عَلَيْهِ فِي ذَلِكَ الْهَدْىُ فِي الْحَجِّ أَوِ الْعُمْرَةِ الْتِقَاءُ الْخِتَانَيْنِ وَإِنْ لَمْ يَكُنْ مَاءٌ دَافِقٌ ‏.‏ قَالَ وَيُوجِبُ ذَلِكَ أَيْضًا الْمَاءُ الدَّافِقُ إِذَا كَانَ مِنْ مُبَاشَرَةٍ فَأَمَّا رَجُلٌ ذَكَرَ شَيْئًا حَتَّى خَرَجَ مِنْهُ مَاءٌ دَافِقٌ فَلاَ أَرَى عَلَيْهِ شَيْئًا وَلَوْ أَنَّ رَجُلاً قَبَّلَ امْرَأَتَهُ وَلَمْ يَكُنْ مِنْ ذَلِكَ مَاءٌ دَافِقٌ لَمْ يَكُنْ عَلَيْهِ فِي الْقُبْلَةِ إِلاَّ الْهَدْىُ وَلَيْسَ عَلَى الْمَرْأَةِ الَّتِي يُصِيبُهَا زَوْجُهَا وَهِيَ مُحْرِمَةٌ مِرَارًا فِي الْحَجِّ أَوِ الْعُمْرَةِ وَهِيَ لَهُ فِي ذَلِكَ مُطَاوِعَةٌ إِلاَّ الْهَدْىُ وَحَجُّ قَابِلٍ إِنْ أَصَابَهَا فِي الْحَجِّ وَإِنْ كَانَ أَصَابَهَا فِي الْعُمْرَةِ فَإِنَّمَا عَلَيْهَا قَضَاءُ الْعُمْرَةِ الَّتِي أَفْسَدَتْ وَالْهَدْىُ ‏.‏\hadithno{860}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he heard Said ibn al-Musayyab asking a group of people, "What do you think about someone who has intercourse with his wife while he is in ihram?" and none of them answered him. Said said, "There is a man who has had intercourse with his wife while in ihram who has sent a message to Madina asking about it." Some of them said, "They should be kept apart until a future year," and Said ibn al-Musayyab said, "They should carry on and complete the hajj which they have spoiled, and then return home when they have finished. If another hajj comes upon them, they must do hajj and sacrifice an animal. They should go into ihram at the same place where they went into ihram for the hajj that they spoiled, and they should keep apart until they have finished their hajj." Malik said, "They should both sacrifice an animal." Malik said, about a man who had intercourse with his wife during hajj after he had come down from Arafa but before he had stoned the Jamra, "He must sacrifice an animal and do hajj again in another year. If, however, he had intercourse with his wife after he stoned the Jamra, he only has to do an umra and sacrifice an animal and he does not have to do another hajj." Malik said, "What spoils a hajj or an umra and makes sacrificing an animal and repeating the hajj necessary is the meeting of the two circumcised parts, even if there is no emission. It is also made necessary by an emission if it is the result of bodily contact. I do not think that a man who remembers something and has an emission owes anything, and if a man were to kiss his wife and no emission were to occur from that, he would only have to sacrifice an animal. A woman in ihram who has intercourse with her husband several times during hajj or umra out of obedience to him only has to do another hajj and sacrifice an animal. That is if her husband has intercourse with her while she is doing hajj. If he has intercourse with her while she is doing umra, she must repeat the umra she has spoiled and sacrifice an animal}}
\hadithdefcmd{malik}{861}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ يَسَارٍ، أَنَّ أَبَا أَيُّوبَ الأَنْصَارِيَّ، خَرَجَ حَاجًّا حَتَّى إِذَا كَانَ بِالنَّازِيَةِ مِنْ طَرِيقِ مَكَّةَ أَضَلَّ رَوَاحِلَهُ وَإِنَّهُ قَدِمَ عَلَى عُمَرَ بْنِ الْخَطَّابِ يَوْمَ النَّحْرِ فَذَكَرَ ذَلِكَ لَهُ فَقَالَ عُمَرُ اصْنَعْ كَمَا يَصْنَعُ الْمُعْتَمِرُ ثُمَّ قَدْ حَلَلْتَ فَإِذَا أَدْرَكَكَ الْحَجُّ قَابِلاً فَاحْجُجْ وَأَهْدِ مَا اسْتَيْسَرَ مِنَ الْهَدْىِ ‏.‏\hadithno{861}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that Sulayman ibn Yasar told him that Abu Ayyub al-Ansari once set off to do hajj and then, when he reached an-Naziya, on the road to Makka, his riding beasts strayed. He reached Umar ibn al-Khattab on the day of sacrifice and told him what had happened and Umar said, "Do what someone doing umra would do, and then you can leave ihram, and then when the hajj next comes upon you, do it and sacrifice whatever animal is easy for you}}
\hadithdefcmd{malik}{862}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ هَبَّارَ بْنَ الأَسْوَدِ، جَاءَ يَوْمَ النَّحْرِ وَعُمَرُ بْنُ الْخَطَّابِ يَنْحَرُ هَدْيَهُ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ أَخْطَأْنَا الْعِدَّةَ كُنَّا نُرَى أَنَّ هَذَا الْيَوْمَ يَوْمُ عَرَفَةَ ‏.‏ فَقَالَ عُمَرُ اذْهَبْ إِلَى مَكَّةَ فَطُفْ أَنْتَ وَمَنْ مَعَكَ وَانْحَرُوا هَدْيًا إِنْ كَانَ مَعَكُمْ ثُمَّ احْلِقُوا أَوْ قَصِّرُوا وَارْجِعُوا فَإِذَا كَانَ عَامٌ قَابِلٌ فَحُجُّوا وَأَهْدُوا فَمَنْ لَمْ يَجِدْ فَصِيَامُ ثَلاَثَةِ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةٍ إِذَا رَجَعَ ‏.‏ قَالَ مَالِكٌ وَمَنْ قَرَنَ الْحَجَّ وَالْعُمْرَةَ ثُمَّ فَاتَهُ الْحَجُّ فَعَلَيْهِ أَنْ يَحُجَّ قَابِلاً وَيَقْرِنُ بَيْنَ الْحَجِّ وَالْعُمْرَةِ وَيُهْدِي هَدْيَيْنِ هَدْيًا لِقِرَانِهِ الْحَجَّ مَعَ الْعُمْرَةِ وَهَدْيًا لِمَا فَاتَهُ مِنَ الْحَجِّ ‏.‏\hadithno{862}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Nafi from Sulayman ibn Yasar that Habbar ibn al-Aswad arrived on the day of sacrifice while Umar ibn al-Khattab was sacrificing his animal and said, "Amir al-muminin, we made a mistake in our reckoning and we thought that today was the day of Arafa." Umar said, "Go to Makka, you and whoever else is with you, and do tawaf and sacrifice your animal if you have one with you. Then shave or cut your hair and return home. Then, in another year, do hajj and sacrifice an animal, and if you cannot find one, fast three days on hajj and seven when you return home." Malik said, "Someone who intends to do hajj and umra together and then misses the hajj must do hajj again in another year, doing hajj with umra, and offer two sacrificial animals, one for doing the hajj with umra, and one for the hajj that he has missed}}
\hadithdefcmd{malik}{863}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ سُئِلَ عَنْ رَجُلٍ، وَقَعَ بِأَهْلِهِ وَهُوَ بِمِنًى قَبْلَ أَنْ يُفِيضَ فَأَمَرَهُ أَنْ يَنْحَرَ بَدَنَةً ‏.‏\hadithno{863}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr al-Makki from Ata ibn Abi Rabah that Abdullah ibn Abbas was asked about a man who had had intercourse with his wife while at Mina before he had done the tawaf al-ifada, and he told him to sacrifice an animal}}
\hadithdefcmd{malik}{864}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ عِكْرِمَةَ، مَوْلَى ابْنِ عَبَّاسٍ قَالَ لاَ أَظُنُّهُ إِلاَّ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ الَّذِي يُصِيبُ أَهْلَهُ قَبْلَ أَنْ يُفِيضَ يَعْتَمِرُ وَيُهْدِي ‏.‏\hadithno{864}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili that lkrama, the mawla of Ibn Abbas, said, (and Thawr believed it to be from Abdullah ibn Abbas), "Someone who has intercourse with his wife before he has done the tawaf al-ifada should do an umra and sacrifice an animal}}
\hadithdefcmd{malik}{865}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ رَبِيعَةَ بْنَ أَبِي عَبْدِ الرَّحْمَنِ، يَقُولُ فِي ذَلِكَ مِثْلَ قَوْلِ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ نَسِيَ الإِفَاضَةَ حَتَّى خَرَجَ مِنْ مَكَّةَ وَرَجَعَ إِلَى بِلاَدِهِ فَقَالَ أَرَى إِنْ لَمْ يَكُنْ أَصَابَ النِّسَاءَ فَلْيَرْجِعْ فَلْيُفِضْ وَإِنْ كَانَ أَصَابَ النِّسَاءَ فَلْيَرْجِعْ فَلْيُفِضْ ثُمَّ لِيَعْتَمِرْ وَلْيُهْدِ وَلاَ يَنْبَغِي لَهُ أَنْ يَشْتَرِيَ هَدْيَهُ مِنْ مَكَّةَ وَيَنْحَرَهُ بِهَا وَلَكِنْ إِنْ لَمْ يَكُنْ سَاقَهُ مَعَهُ مِنْ حَيْثُ اعْتَمَرَ فَلْيَشْتَرِهِ بِمَكَّةَ ثُمَّ لِيُخْرِجْهُ إِلَى الْحِلِّ فَلْيَسُقْهُ مِنْهُ إِلَى مَكَّةَ ثُمَّ يَنْحَرُهُ بِهَا ‏.‏\hadithno{865}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had heard Rabia ibn Abi Abd ar-Rahman saying the same about that as what Ikrama related from Ibn Abbas. Malik said, "That is what I like most out of what I have heard about the matter." Malik was asked about a man who forgot the tawaf al-ifada until he had left Makka and returned to his community and he said, "I think that he should go back and do the tawaf al-ifada, as long as he has not had sexual relations with women. If, however, he has had sexual relations with women, then he should not only return and do the tawaf al-ifada, but he should also do an umra and sacrifice an animal. He should not buy theanimal in Makka and sacrifice it there, but if he has not brought one with him from wherever it was he set out to do umra, he should buy one in Makka and then take it outside the limits of the Haram and drive it from there to Makka and sacrifice it there}}
\hadithdefcmd{malik}{866}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، كَانَ يَقُولُ ‏\{‏مَا اسْتَيْسَرَ مِنَ الْهَدْىِ‏\}‏ شَاةٌ ‏.‏\hadithno{866}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad from his father that Ali ibn Abi Talib used to say, "The least difficult thing acceptable as a sacrificial animal is a sheep}}
\hadithdefcmd{malik}{867}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يَقُولُ ‏\{‏مَا اسْتَيْسَرَ مِنَ الْهَدْىِ‏\}‏ شَاةٌ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ لأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَقْتُلُوا الصَّيْدَ وَأَنْتُمْ حُرُمٌ وَمَنْ قَتَلَهُ مِنْكُمْ مُتَعَمِّدًا فَجَزَاءٌ مِثْلُ مَا قَتَلَ مِنَ النَّعَمِ يَحْكُمُ بِهِ ذَوَا عَدْلٍ مِنْكُمْ هَدْيًا بَالِغَ الْكَعْبَةِ أَوْ كَفَّارَةٌ طَعَامُ مَسَاكِينَ أَوْ عَدْلُ ذَلِكَ صِيَامًا‏\}‏ فَمِمَّا يُحْكَمُ بِهِ فِي الْهَدْىِ شَاةٌ وَقَدْ سَمَّاهَا اللَّهُ هَدْيًا وَذَلِكَ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا وَكَيْفَ يَشُكُّ أَحَدٌ فِي ذَلِكَ وَكُلُّ شَىْءٍ لاَ يَبْلُغُ أَنْ يُحْكَمَ فِيهِ بِبَعِيرٍ أَوْ بَقَرَةٍ فَالْحُكْمُ فِيهِ شَاةٌ وَمَا لاَ يَبْلُغُ أَنْ يُحْكَمَ فِيهِ بِشَاةٍ فَهُوَ كَفَّارَةٌ مِنْ صِيَامٍ أَوْ إِطْعَامِ مَسَاكِينَ ‏.‏\hadithno{867}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Abbas used to say, "The least difficult thing acceptable as a sacrificial animal is a sheep." Malik said, "That is what I like most out of what I have heard about the matter, because Allah, the Blessed and Exalted, says in His Book, 'O you who trust, do not kill game while you are in ihram. Whoever of you kills it intentionally, there shall be repayment the like of what he has slain, from livestock, as shall be judged by two men of justice among you, a sacrificial animal which will reach the Kaba, or food for poor people, or the equivalent of that in fasting,' (Sura 5 ayat 95) and a sheep is one of the animals which is judged to be acceptable as a sacrifice. Allah has called it a sacrificial animal, and there is no dispute among us about the matter. How, indeed, could anyone be in doubt about the matter? A sheep is the kaffara for anything which does not reach the extent of something for which a camel or a cow would be the kaffara, and the kaffara for something which does not reach the extent of something for which a sheep would be the kaffara is fasting, or feeding poor people}}
\hadithdefcmd{malik}{868}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ ‏\{‏مَا اسْتَيْسَرَ مِنَ الْهَدْى‏\}‏ بَدَنَةٌ أَوْ بَقَرَةٌ ‏.‏\hadithno{868}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Urnar used to say, "The least thing that is acceptable as a sacrificial animal is a camel or a cow}}
\hadithdefcmd{malik}{869}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّ مَوْلاَةً، لِعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ يُقَالُ لَهَا رُقَيَّةُ أَخْبَرَتْهُ أَنَّهَا، خَرَجَتْ مَعَ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ إِلَى مَكَّةَ - قَالَتْ - فَدَخَلَتْ عَمْرَةُ مَكَّةَ يَوْمَ التَّرْوِيَةِ وَأَنَا مَعَهَا فَطَافَتْ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ دَخَلَتْ صُفَّةَ الْمَسْجِدِ فَقَالَتْ أَمَعَكِ مِقَصَّانِ فَقُلْتُ لاَ ‏.‏ فَقَالَتْ فَالْتَمِسِيهِ لِي ‏.‏ فَالْتَمَسْتُهُ حَتَّى جِئْتُ بِهِ فَأَخَذَتْ مِنْ قُرُونِ رَأْسِهَا فَلَمَّا كَانَ يَوْمُ النَّحْرِ ذَبَحَتْ شَاةً ‏.‏\hadithno{869}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik fromAbdullah ibn Abi Bakr that a mawla of Amir bint Abd ar-Rahman called Ruqayya told him that she once set out with Amra bint Abd ar-Rahman to go to Makka. She said, ''Amra entered Makka on the eighth of Dhu'l-Hijja, and I was with her. She did tawaf of the House, and say between Safa and Marwa, and then entered the back of the mosque. She asked me, 'Do you have a pair of scissors with you?' and I said, 'No.' She said, 'Then try and find some for me.' I went and looked for some and brought them back and she cut some hair from the tresses of her head.Then, on the day of sacrifice, she slaughtered a sheep}}
\hadithdefcmd{malik}{870}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ صَدَقَةَ بْنِ يَسَارٍ الْمَكِّيِّ، أَنَّ رَجُلاً، مِنْ أَهْلِ الْيَمَنِ جَاءَ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ وَقَدْ ضَفَرَ رَأْسَهُ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنِّي قَدِمْتُ بِعُمْرَةٍ مُفْرَدَةٍ ‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ لَوْ كُنْتُ مَعَكَ أَوْ سَأَلْتَنِي لأَمَرْتُكَ أَنْ تَقْرِنَ ‏.‏ فَقَالَ الْيَمَانِيُّ قَدْ كَانَ ذَلِكَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ خُذْ مَا تَطَايَرَ مِنْ رَأْسِكَ وَأَهْدِ ‏.‏ فَقَالَتِ امْرَأَةٌ مِنْ أَهْلِ الْعِرَاقِ مَا هَدْيُهُ يَا أَبَا عَبْدِ الرَّحْمَنِ فَقَالَ هَدْيُهُ ‏.‏ فَقَالَتْ لَهُ مَا هَدْيُهُ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَوْ لَمْ أَجِدْ إِلاَّ أَنْ أَذْبَحَ شَاةً لَكَانَ أَحَبَّ إِلَىَّ مِنْ أَنْ أَصُومَ ‏.‏\hadithno{870}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Sadaqa ibn Yasar al-Makki that a man from the people of Yemen, who had his hair braided, came to Abdullah ibn Umar and said, "Abu Abd arRahman, I have come to do just umra. ''Abdullah ibn Umar said to him, "If I had been with you or you had asked me I would have told you to do hajj and umra together." The Yemeni answered, "I am doing what I am doing," and Abdullah ibn Umar said to him, "Cut off the locks that are hanging from your head and offer a sacrificial animal." A woman from Iraq said, "What should his sacrificial animal be, Abu Abd ar-Rahman?" and he said, "His sacrificial animal?" and she said to him, "What should his sacrificial animal be?" Abdullah ibn Umar said, "If I could only find a sheep to sacrifice, I would prefer to do that than to fast}}
\hadithdefcmd{malik}{871}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ الْمَرْأَةُ الْمُحْرِمَةُ إِذَا حَلَّتْ لَمْ تَمْتَشِطْ حَتَّى تَأْخُذَ مِنْ قُرُونِ رَأْسِهَا وَإِنْ كَانَ لَهَا هَدْىٌ لَمْ تَأْخُذْ مِنْ شَعْرِهَا شَيْئًا حَتَّى تَنْحَرَ هَدْيَهَا ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ أَنَّهُ سَمِعَ بَعْضَ أَهْلِ الْعِلْمِ يَقُولُ لاَ يَشْتَرِكُ الرَّجُلُ وَامْرَأَتُهُ فِي بَدَنَةٍ وَاحِدَةٍ لِيُهْدِ كُلُّ وَاحِدٍ بَدَنَةً بَدَنَةً ‏.‏ وَسُئِلَ مَالِكٌ عَمَّنْ بُعِثَ مَعَهُ بِهَدْىٍ يَنْحَرُهُ فِي حَجٍّ وَهُوَ مُهِلٌّ بِعُمْرَةٍ هَلْ يَنْحَرُهُ إِذَا حَلَّ أَمْ يُؤَخِّرُهُ حَتَّى يَنْحَرَهُ فِي الْحَجِّ وَيُحِلُّ هُوَ مِنْ عُمْرَتِهِ فَقَالَ بَلْ يُؤَخِّرُهُ حَتَّى يَنْحَرَهُ فِي الْحَجِّ وَيُحِلُّ هُوَ مِنْ عُمْرَتِهِ ‏.‏ قَالَ مَالِكٌ وَالَّذِي يُحْكَمُ عَلَيْهِ بِالْهَدْىِ فِي قَتْلِ الصَّيْدِ أَوْ يَجِبُ عَلَيْهِ هَدْىٌ فِي غَيْرِ ذَلِكَ فَإِنَّ هَدْيَهُ لاَ يَكُونُ إِلاَّ بِمَكَّةَ كَمَا قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏هَدْيًا بَالِغَ الْكَعْبَة‏\}‏ وَأَمَّا مَا عُدِلَ بِهِ الْهَدْىُ مِنَ الصِّيَامِ أَوِ الصَّدَقَةِ فَإِنَّ ذَلِكَ يَكُونُ بِغَيْرِ مَكَّةَ حَيْثُ أَحَبَّ صَاحِبُهُ أَنْ يَفْعَلَهُ فَعَلَهُ ‏.‏\hadithno{871}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "A woman in ihram should not comb her hair when she leaves ihram until she has cut some of the tresses of her hair, and if she has an animal for sacrifice with her she should not cut off any of her hair until the animal has been killed}}
\hadithdefcmd{malik}{872}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ يَعْقُوبَ بْنِ خَالِدٍ الْمَخْزُومِيِّ، عَنْ أَبِي أَسْمَاءَ، مَوْلَى عَبْدِ اللَّهِ بْنِ جَعْفَرٍ أَنَّهُ أَخْبَرَهُ أَنَّهُ، كَانَ مَعَ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ فَخَرَجَ مَعَهُ مِنَ الْمَدِينَةِ فَمَرُّوا عَلَى حُسَيْنِ بْنِ عَلِيٍّ وَهُوَ مَرِيضٌ بِالسُّقْيَا فَأَقَامَ عَلَيْهِ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ حَتَّى إِذَا خَافَ الْفَوَاتَ خَرَجَ وَبَعَثَ إِلَى عَلِيِّ بْنِ أَبِي طَالِبٍ وَأَسْمَاءَ بِنْتِ عُمَيْسٍ وَهُمَا بِالْمَدِينَةِ فَقَدِمَا عَلَيْهِ ثُمَّ إِنَّ حُسَيْنًا أَشَارَ إِلَى رَأْسِهِ فَأَمَرَ عَلِيٌّ بِرَأْسِهِ فَحُلِّقَ ثُمَّ نَسَكَ عَنْهُ بِالسُّقْيَا فَنَحَرَ عَنْهُ بَعِيرًا ‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ وَكَانَ حُسَيْنٌ خَرَجَ مَعَ عُثْمَانَ بْنِ عَفَّانَ فِي سَفَرِهِ ذَلِكَ إِلَى مَكَّةَ ‏.‏\hadithno{872}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik that he had heard one of the people of knowledge say, "A man and wife should not share in one sacrificial animal. Each should sacrifice an animal separately." Malik was asked about whether someone who had been entrusted with an animal for him to sacrifice on hajj, who went into ihram for umra, should sacrifice it when he came out of ihram or postpone it so that he sacrificed it at the time of the hajj while in the meantime he came out of ihram from his umra. He said, "He should postpone it so that he may sacrifice it at the time of the hajj, and meanwhile come out of ihram from his umra." Malik said, "If it is judged that some- one must offer an animal for having killed game, or for any other reason, this animal can only be sacrificed at Makka, since Allah, the Blessed and Exalted, says, 'a sacrificial animal which will reach the Kaba.' The fasting or sadaqa that is considered equivalent to offering a sacrifice can be done outside Makka, and the person who is doing it can do it wherever he likes." Yahya related to me from Malik from Yahya ibn Said from Yaqub ibn Khalid al-Makhzumi that Abu Asma, the mawla of Abdullah ibn Jafar, told him that he was with Abdullah ibn Jafar when they set out once from Madina. At as-Suqya they passed by Husayn ibn Ali, who was ill at the time. Abdullah ibn Jafar stayed with him and then, when he feared that he was late (for the hajj) he left, and sent for Ali ibn Abi Talib and Asma bint Umays in Madina, and they came to Husayn. Then Husayn pointed to his head, and AIi told someone to shave his head. Then he sacrificed an animal for him at as-Suqya, killing a camel for him. Yahya ibn Said added, "Husayn had set out with Uthman ibn Affan on that particular journey to Makka}}
\hadithdefcmd{malik}{873}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَرَفَةُ كُلُّهَا مَوْقِفٌ وَارْتَفِعُوا عَنْ بَطْنِ عُرَنَةَ وَالْمُزْدَلِفَةُ كُلُّهَا مَوْقِفٌ وَارْتَفِعُوا عَنْ بَطْنِ مُحَسِّرٍ ‏"‏ ‏.‏\hadithno{873}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "The whole of Arafa is a mawqif, except the middle of Urana, and the whole of Muzdalifa is a standing-place, except for the middle of Muhassir}}
\hadithdefcmd{malik}{874}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّهُ كَانَ يَقُولُ اعْلَمُوا أَنَّ عَرَفَةَ كُلَّهَا مَوْقِفٌ إِلاَّ بَطْنَ عُرَنَةَ وَأَنَّ الْمُزْدَلِفَةَ كُلَّهَا مَوْقِفٌ إِلاَّ بَطْنَ مُحَسِّرٍ ‏.‏ قَالَ مَالِكٌ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏فَلاَ رَفَثَ وَلاَ فُسُوقَ وَلاَ جِدَالَ فِي الْحَجِّ ‏\}‏ قَالَ فَالرَّفَثُ إِصَابَةُ النِّسَاءِ وَاللَّهُ أَعْلَمُ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏أُحِلَّ لَكُمْ لَيْلَةَ الصِّيَامِ الرَّفَثُ إِلَى نِسَائِكُمْ ‏\}‏ قَالَ وَالْفُسُوقُ الذَّبْحُ لِلأَنْصَابِ وَاللَّهُ أَعْلَمُ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏أَوْ فِسْقًا أُهِلَّ لِغَيْرِ اللَّهِ بِهِ‏\}‏ ‏.‏ قَالَ وَالْجِدَالُ فِي الْحَجِّ أَنَّ قُرَيْشًا كَانَتْ تَقِفُ عِنْدَ الْمَشْعَرِ الْحَرَامِ بِالْمُزْدَلِفَةِ بِقُزَحَ وَكَانَتِ الْعَرَبُ وَغَيْرُهُمْ يَقِفُونَ بِعَرَفَةَ فَكَانُوا يَتَجَادَلُونَ يَقُولُ هَؤُلاَءِ نَحْنُ أَصْوَبُ وَيَقُولُ هَؤُلاَءِ نَحْنُ أَصْوَبُ فَقَالَ اللَّهُ تَعَالَى وَ ‏\{‏لِكُلِّ أُمَّةٍ جَعَلْنَا مَنْسَكًا هُمْ نَاسِكُوهُ فَلاَ يُنَازِعُنَّكَ فِي الأَمْرِ وَادْعُ إِلَى رَبِّكَ إِنَّكَ لَعَلَى هُدًى مُسْتَقِيمٍ‏\}‏ فَهَذَا الْجِدَالُ فِيمَا نُرَى وَاللَّهُ أَعْلَمُ وَقَدْ سَمِعْتُ ذَلِكَ مِنْ أَهْلِ الْعِلْمِ ‏.‏\hadithno{874}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that Abdullah ibn az-Zubayr used to say, "Know that the whole of Arafa is a standing-place except for the middle of Urana, and that the wholeof Muzdalifa is a standing-place except for the middle of Muhassir." Malik said, "Allah, the Blessed and Exalted says, 'There is to be no rafath, no fusuq and no jidal during the hajj.' " (Sura 2 ayat 197). He added, "Rafath is sexual relations with women, and Allah knows best. Allah, the Blessed and Exalted says, 'Rafath with your women is permitted to you on the night of the fast.' (Sura 2 ayat 197). Fusuq are sacrifices made to idols, and Allah knows best. Allah, the Blessed and Exalted, says, 'Or a fisq offered up to other than Allah.' (Sura 2 ayat 197) Jidal (arguing) during the hajj refers to when the Quraysh used to stand near the mashar al-haram at Quzah in Muzdalifa, while the Arabs and others would stand at Arafa, and they would argue about who was the more correct. Allah, the Blessed and Exalted, says, 'And we appointed a method of sacrifice for every nation, which they followed, so let them not dispute with you about the matter, and call to your Lord. Surely you are on a straight guidance.' (Sura 22 ayat 67) This is what jidal refers to in our opinion, and Allah knows best. This I have heard from the people of knowledge}}
\hadithdefcmd{malik}{875}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ مَنْ لَمْ يَقِفْ بِعَرَفَةَ مِنْ لَيْلَةِ الْمُزْدَلِفَةِ قَبْلَ أَنْ يَطْلُعَ الْفَجْرُ فَقَدْ فَاتَهُ الْحَجُّ وَمَنْ وَقَفَ بِعَرَفَةَ مِنْ لَيْلَةِ الْمُزْدَلِفَةِ مِنْ قَبْلِ أَنْ يَطْلُعَ الْفَجْرُ فَقَدْ أَدْرَكَ الْحَجَّ ‏.‏\hadithno{875}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik was asked about whether a man could stand at Arafa, or at Muzdalifa, or stone the Jamras, or do say between Safa and Marwa if he was not in wudu, and he said, "Every practice in the hajj that a menstruating woman can take part in can be taken part in by a man who is not in wudu and there is nothing due from him for that. However, it is better for him to be in wudu for all those things, and he should not make a general practice of it." Malik was asked whether a man who was riding should get down to do the standing at Arafa or if he could stand while mounted, and he said, "He can stand while mounted, unless he or his riding beast have an illness, in which case Allah is the one who most often accepts an excuse." Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "Someone who does not stand at Arafa on the night of Muzdalifa before the dawn breaks has missed the hajj, and someone who stands at Arafa on the night of Muzdalifa before the dawn breaks has caught the hajj}}
\hadithdefcmd{malik}{876}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ مَنْ أَدْرَكَهُ الْفَجْرُ مِنْ لَيْلَةِ الْمُزْدَلِفَةِ وَلَمْ يَقِفْ بِعَرَفَةَ فَقَدْ فَاتَهُ الْحَجُّ وَمَنْ وَقَفَ بِعَرَفَةَ مِنْ لَيْلَةِ الْمُزْدَلِفَةِ قَبْلَ أَنْ يَطْلُعَ الْفَجْرُ فَقَدْ أَدْرَكَ الْحَجَّ ‏.‏ قَالَ مَالِكٌ فِي الْعَبْدِ يُعْتَقُ فِي الْمَوْقِفِ بِعَرَفَةَ فَإِنَّ ذَلِكَ لاَ يَجْزِي عَنْهُ مِنْ حَجَّةِ الإِسْلاَمِ إِلاَّ أَنْ يَكُونَ لَمْ يُحْرِمْ فَيُحْرِمُ بَعْدَ أَنْ يُعْتَقَ ثُمَّ يَقِفُ بِعَرَفَةَ مِنْ تِلْكَ اللَّيْلَةِ قَبْلَ أَنْ يَطْلُعَ الْفَجْرُ فَإِنْ فَعَلَ ذَلِكَ أَجْزَأَ عَنْهُ وَإِنْ لَمْ يُحْرِمْ حَتَّى طَلَعَ الْفَجْرُ كَانَ بِمَنْزِلَةِ مَنْ فَاتَهُ الْحَجُّ إِذَا لَمْ يُدْرِكِ الْوُقُوفَ بِعَرَفَةَ قَبْلَ طُلُوعِ الْفَجْرِ مِنْ لَيْلَةِ الْمُزْدَلِفَةِ وَيَكُونُ عَلَى الْعَبْدِ حَجَّةُ الإِسْلاَمِ يَقْضِيهَا ‏.‏\hadithno{876}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "Someone who does not stand at Arafa on the night of Muzdalifa before the dawn breaks has missed the hajj, and some one who stands at Arafa on the night of Muzdalifa before the dawn breaks has caught the hajj. Malik said, about a slave freed during the wuquf at Arafa, "His standing does not fulfil for him the hajj of Islam, except if he was not in ihram and then he went into ihram after he was freed and he stood at Arafa that same night before the dawn broke in which case that is enough for him. If, however, he did not go into ihram until after the dawn had broken, he is in the same position as someone who misses the hajj by not catching the standing at Arafa before the breaking of the dawn on the night of Muzdalifa, and he will have to do the hajj of Islam later}}
\hadithdefcmd{malik}{877}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ سَالِمٍ، وَعُبَيْدِ اللَّهِ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّ أَبَاهُمَا عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُقَدِّمُ أَهْلَهُ وَصِبْيَانَهُ مِنَ الْمُزْدَلِفَةِ إِلَى مِنًى حَتَّى يُصَلُّوا الصُّبْحَ بِمِنًى وَيَرْمُوا قَبْلَ أَنْ يَأْتِيَ النَّاسُ ‏.‏\hadithno{877}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafj from Salim and Ubaydullah, two sons of Abdullah ibn Umar, that their father Abdullah ibn Umar used to send his family and children from Muzdalifa to Mina ahead of him so that they could pray subh at Mina and throw the stones before everyone (else) arrived}}
\hadithdefcmd{malik}{878}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّ مَوْلاَةً، لأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ أَخْبَرَتْهُ قَالَتْ، جِئْنَا مَعَ أَسْمَاءَ ابْنَةِ أَبِي بَكْرٍ مِنًى بِغَلَسٍ - قَالَتْ - فَقُلْتُ لَهَا لَقَدْ جِئْنَا مِنًى بِغَلَسٍ ‏.‏ فَقَالَتْ قَدْ كُنَّا نَصْنَعُ ذَلِكَ مَعَ مَنْ هُوَ خَيْرٌ مِنْكِ ‏.‏\hadithno{878}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Ata ibn Abi Rabah that a mawla of Asma bint Abi Bakr told him, "We arrived at Mina with Asma bint Abi Bakr at the end of the night, and I said to her, 'We have arrived at Mina at the end of the night,' and she said, 'We used to do that with one who was better than you}}
\hadithdefcmd{malik}{879}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ، كَانَ يُقَدِّمُ نِسَاءَهُ وَصِبْيَانَهُ مِنَ الْمُزْدَلِفَةِ إِلَى مِنًى ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ أَنَّهُ سَمِعَ بَعْضَ أَهْلِ الْعِلْمِ يَكْرَهُ رَمْىَ الْجَمْرَةِ حَتَّى يَطْلُعَ الْفَجْرُ مِنْ يَوْمِ النَّحْرِ وَمَنْ رَمَى فَقَدْ حَلَّ لَهُ النَّحْرُ ‏.‏\hadithno{879}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Talha ibn Ubaydullah used to send his family and children from Muzdalifa to Mina ahead of him}}
\hadithdefcmd{malik}{880}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، أَخْبَرَتْهُ أَنَّهَا، كَانَتْ تَرَى أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ بِالْمُزْدَلِفَةِ تَأْمُرُ الَّذِي يُصَلِّي لَهَا وَلأَصْحَابِهَا الصُّبْحَ يُصَلِّي لَهُمُ الصُّبْحَ حِينَ يَطْلُعُ الْفَجْرُ ثُمَّ تَرْكَبُ فَتَسِيرُ إِلَى مِنًى وَلاَ تَقِفُ ‏.‏\hadithno{880}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to.me from Malik that he had heard one of the people of knowledge disapproving of stoning the jamra until after dawn on the day of sacrifice, as it was halal for whoever had thrown the stones to sacrifice. Yahya related to me from Malik from Hisham ibn Urwa that Fatima bint al-Mundhir told him that she used to see Asma bint Abi Bakrat Muzdalifa telling whoever led the subh prayer for her and her companions to pray it as soon as the dawn broke, after which she would mount and go to Mina without stopping at all}}
\hadithdefcmd{malik}{881}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ سُئِلَ أُسَامَةُ بْنُ زَيْدٍ - وَأَنَا جَالِسٌ، مَعَهُ - كَيْفَ كَانَ يَسِيرُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ حِينَ دَفَعَ قَالَ كَانَ يَسِيرُ الْعَنَقَ فَإِذَا وَجَدَ فَجْوَةً نَصَّ ‏.‏ قَالَ مَالِكٌ قَالَ هِشَامٌ وَالنَّصُّ فَوْقَ الْعَنَقِ ‏.‏\hadithno{881}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "I was sitting with Usama ibn Zayd when some one asked him, 'How did the Messenger of Allah, may Allah bless him and grant him peace, travel when he went from Arafa to Muzdalifa during the farewell hajj?' and he replied, 'He went at a medium pace, but when he found a gap (in the crowds) he speeded up}}
\hadithdefcmd{malik}{882}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُحَرِّكُ رَاحِلَتَهُ فِي بَطْنِ مُحَسِّرٍ قَدْرَ رَمْيَةٍ بِحَجَرٍ ‏.‏\hadithno{882}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to spur on his mount in the middle of Muhassir over the distance of a stone's throw}}
\hadithdefcmd{malik}{883}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ بِمِنًى ‏"‏ هَذَا الْمَنْحَرُ وَكُلُّ مِنًى مَنْحَرٌ ‏"‏ ‏.‏ وَقَالَ فِي الْعُمْرَةِ ‏"‏ هَذَا الْمَنْحَرُ - يَعْنِي الْمَرْوَةَ - وَكُلُّ فِجَاجِ مَكَّةَ وَطُرُقِهَا مَنْحَرٌ ‏"‏ ‏.‏\hadithno{883}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said once at Mina, "This place (where I have just sacrificed), and the whole of Mina, is a place of sacrifice," and he said once during umra, "This place of sacrifice" meaning Marwa, "and all the pathways of Makka and its roads are a place of sacrifice}}
\hadithdefcmd{malik}{884}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَتْنِي عَمْرَةُ بِنْتُ عَبْدِ الرَّحْمَنِ، أَنَّهَا سَمِعَتْ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، تَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِخَمْسِ لَيَالٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ وَلاَ نُرَى إِلاَّ أَنَّهُ الْحَجُّ فَلَمَّا دَنَوْنَا مِنْ مَكَّةَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ إِذَا طَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ أَنْ يَحِلَّ ‏.‏ قَالَتْ عَائِشَةُ فَدُخِلَ عَلَيْنَا يَوْمَ النَّحْرِ بِلَحْمِ بَقَرٍ فَقُلْتُ مَا هَذَا فَقَالُوا نَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَزْوَاجِهِ ‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ فَذَكَرْتُ هَذَا الْحَدِيثَ لِلْقَاسِمِ بْنِ مُحَمَّدٍ فَقَالَ أَتَتْكَ وَاللَّهِ بِالْحَدِيثِ عَلَى وَجْهِهِ ‏.‏\hadithno{884}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that Amra bint Abd ar-Rahman told him that she had heard A'isha, umm al-muminin, saying, "We set out with the Messenger of Allah, may Allah bless him and grant him peace, when there were five nights left in Dhu'l-Qada and we assumed that we must be setting out for hajj. When we got near to Makka, the Messenger of Allah, may Allah bless him and grant him peace, told everyone that did not have a sacrificial animal with them to leave ihram after they had done tawaf of the House and say between Safa and Marwa." A'isha added, "We were sent some beef on the day of sacrifice. I asked what it was and they said that the Messenger of Allah, may Allah bless him and grant him peace, had sacrificed for his wives." Yahya ibn Said said, "I mentioned this hadith to Qasim ibn Muhammad and he said, 'She has given you the complete hadith, by Allah}}
\hadithdefcmd{malik}{885}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ حَفْصَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَا شَأْنُ النَّاسِ حَلُّوا وَلَمْ تَحْلِلْ أَنْتَ مِنْ عُمْرَتِكَ فَقَالَ ‏ "‏ إِنِّي لَبَّدْتُ رَأْسِي وَقَلَّدْتُ هَدْيِي فَلاَ أَحِلُّ حَتَّى أَنْحَرَ ‏"‏ ‏.‏\hadithno{885}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that Hafsa, umm al-muminin, once said to the Messenger of Allah, may Allah bless him and grant him peace, "Why is it that everyone has left ihram and you still have not left ihram from your umra?" and he replied, "I have matted my hair and garlanded my sacrificial animal and will not leave ihram until I have sacrificed the animal}}
\hadithdefcmd{malik}{886}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَحَرَ بَعْضَ هَدْيِهِ وَنَحَرَ غَيْرُهُ بَعْضَهُ ‏.‏\hadithno{886}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad from his father from Ali ibn Abi Talib that the Messenger of Allah, may Allah bless him and grant him peace, killed some of his sacrificial animals himself, and someone else killed the rest}}
\hadithdefcmd{malik}{887}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ مَنْ نَذَرَ بَدَنَةً فَإِنَّهُ يُقَلِّدُهَا نَعْلَيْنِ وَيُشْعِرُهَا ثُمَّ يَنْحَرُهَا عِنْدَ الْبَيْتِ أَوْ بِمِنًى يَوْمَ النَّحْرِ لَيْسَ لَهَا مَحِلٌّ دُونَ ذَلِكَ وَمَنْ نَذَرَ جَزُورًا مِنَ الإِبِلِ أَوِ الْبَقَرِ فَلْيَنْحَرْهَا حَيْثُ شَاءَ ‏.‏\hadithno{887}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "Someone who vows to sacrifice a camel or a cow to Allah should garland it with two sandals about its neck, and brand it by causing blood to flow from its side. He should then sacrifice it either at the House or at Mina on the day of sacrifice. There are no other correct places apart from those. However, someone who vows to slaughter a camel or a cow simply as a sacrifice can sacrifice it wherever he wishes}}
\hadithdefcmd{malik}{888}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، كَانَ يَنْحَرُ بُدْنَهُ قِيَامًا ‏.‏ قَالَ مَالِكٌ لاَ يَجُوزُ لأَحَدٍ أَنْ يَحْلِقَ رَأْسَهُ حَتَّى يَنْحَرَ هَدْيَهُ وَلاَ يَنْبَغِي لأَحَدٍ أَنْ يَنْحَرَ قَبْلَ الْفَجْرِ يَوْمَ النَّحْرِ وَإِنَّمَا الْعَمَلُ كُلُّهُ يَوْمَ النَّحْرِ الذَّبْحُ وَلُبْسُ الثِّيَابِ وَإِلْقَاءُ التَّفَثِ وَالْحِلاَقُ لاَ يَكُونُ شَىْءٌ مِنْ ذَلِكَ يُفْعَلُ قَبْلَ يَوْمِ النَّحْرِ ‏.‏\hadithno{888}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to kill his sacrificial animals while they were standing. Malik said, "No-one is permitted to shave his head until he has killed his sacrificial animal, and no-one must sacrifice before dawn on the day of sacrifice. The things that should be done on the day of sacrifice are slaughtering, donning clothes, grooming the body generally (at-tafath) and shaving the head, and none of this may be done before the day of sacrifice}}
\hadithdefcmd{malik}{889}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ ارْحَمِ الْمُحَلِّقِينَ ‏"‏ ‏.‏ قَالُوا وَالْمُقَصِّرِينَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏\hadithno{889}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "O Allah, have mercy on those who shave their hair." They said, "And those who shorten (their hair), Messenger of Allah." He said, "O Allah, have mercy on those who shave." They said, "And those who shorten, Messenger of Allah." He said, "And those who shorten}}
\hadithdefcmd{malik}{890}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَدْخُلُ مَكَّةَ لَيْلاً وَهُوَ مُعْتَمِرٌ فَيَطُوفُ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ وَيُؤَخِّرُ الْحِلاَقَ حَتَّى يُصْبِحَ ‏.‏ قَالَ وَلَكِنَّهُ لاَ يَعُودُ إِلَى الْبَيْتِ فَيَطُوفُ بِهِ حَتَّى يَحْلِقَ رَأْسَهُ ‏.‏ قَالَ وَرُبَّمَا دَخَلَ الْمَسْجِدَ فَأَوْتَرَ فِيهِ وَلاَ يَقْرَبُ الْبَيْتَ ‏.‏ قَالَ مَالِكٌ التَّفَثُ حِلاَقُ الشَّعَرِ وَلُبْسُ الثِّيَابِ وَمَا يَتْبَعُ ذَلِكَ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَنْ رَجُلٍ نَسِيَ الْحِلاَقَ بِمِنًى فِي الْحَجِّ هَلْ لَهُ رُخْصَةٌ فِي أَنْ يَحْلِقَ بِمَكَّةَ قَالَ ذَلِكَ وَاسِعٌ وَالْحِلاَقُ بِمِنًى أَحَبُّ إِلَىَّ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا أَنَّ أَحَدًا لاَ يَحْلِقُ رَأْسَهُ وَلاَ يَأْخُذُ مِنْ شَعَرِهِ حَتَّى يَنْحَرَ هَدْيًا إِنْ كَانَ مَعَهُ وَلاَ يَحِلُّ مِنْ شَىْءٍ حَرُمَ عَلَيْهِ حَتَّى يَحِلَّ بِمِنًى يَوْمَ النَّحْرِ وَذَلِكَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ ‏\{‏وَلاَ تَحْلِقُوا رُءُوسَكُمْ حَتَّى يَبْلُغَ الْهَدْىُ مَحِلَّهُ ‏\}‏\hadithno{890}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim that his father used to go into Makka by night when he was doing umra and do tawaf of the House and say between Safa and Marwa and delay the shaving until the morning, but he would not go back to the House and do tawaf again until he had shaved his head. Abd ar-Rahman added, "Sometimes he would enter the mosque and do the witr prayer there without actually going near the House." Malik said, "At-tafath is shaving the head, putting on normal clothes and things of that nature." Yahya said that Malik was asked whether a man who forgot to shave (his head) at Mina during the hajj could shave in Makka, and he said, "That is permissible, but I prefer the shaving to be done at Mina." Malik said, "What we are all agreed upon here (in Madina) is that no-one should shave his head or cut his hair until he has killed his sacrificial animal, if he has one, and things that are haram for him do not become halal for him until he leaves ihram at Mina on the day of sacrifice. This is because Allah, the Blessed and Exalted, says, 'Do not shave yourheads until the sacrificial animal has reached its destination}}
\hadithdefcmd{malik}{891}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا أَفْطَرَ مِنْ رَمَضَانَ وَهُوَ يُرِيدُ الْحَجَّ لَمْ يَأْخُذْ مِنْ رَأْسِهِ وَلاَ مِنْ لِحْيَتِهِ شَيْئًا حَتَّى يَحُجَّ ‏.‏ قَالَ مَالِكٌ لَيْسَ ذَلِكَ عَلَى النَّاسِ ‏.‏\hadithno{891}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that if Abdullah ibn Umar had finished the fast of Ramadan and intended to do hajj, he would not cut his hair or beard at all until he had done hajj. Malik said, "It is not necessary for people to do the same}}
\hadithdefcmd{malik}{892}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا حَلَقَ فِي حَجٍّ أَوْ عُمْرَةٍ أَخَذَ مِنْ لِحْيَتِهِ وَشَارِبِهِ ‏.‏\hadithno{892}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to trim his beard and moustache when he shaved at the end of a hajj or umra}}
\hadithdefcmd{malik}{893}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ رَجُلاً، أَتَى الْقَاسِمَ بْنَ مُحَمَّدٍ فَقَالَ إِنِّي أَفَضْتُ وَأَفَضْتُ مَعِي بِأَهْلِي ثُمَّ عَدَلْتُ إِلَى شِعْبٍ فَذَهَبْتُ لأَدْنُوَ مِنْ أَهْلِي فَقَالَتْ إِنِّي لَمْ أُقَصِّرْ مِنْ شَعَرِي بَعْدُ فَأَخَذْتُ مِنْ شَعَرِهَا بِأَسْنَانِي ثُمَّ وَقَعْتُ بِهَا فَضَحِكَ الْقَاسِمُ وَقَالَ مُرْهَا فَلْتَأْخُذْ مِنْ شَعَرِهَا بِالْجَلَمَيْنِ ‏.‏ قَالَ مَالِكٌ أَسْتَحِبُّ فِي مِثْلِ هَذَا أَنْ يُهْرِقَ دَمًا وَذَلِكَ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ قَالَ مَنْ نَسِيَ مِنْ نُسُكِهِ شَيْئًا فَلْيُهْرِقْ دَمًا ‏.‏\hadithno{893}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that a man came to Qasim ibn Muhammad and said, "I did the tawaf al- ifada along with my wife, and then I went off onto a mountain path and approached my wife to make love to her, and she said, 'I have not cut my hair yet.' So I bit some of her hair off with my teeth and then had intercourse with her." Qasim laughed and said, "Tell her to cut her hair with some scissors." Malik said, "To my liking an animal should be sacrificed in an instance such as this, because Abdullah ibn Abbas said, 'Whoever forgets any of his rites on hajj should sacrifice an animal}}
\hadithdefcmd{malik}{894}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ لَقِيَ رَجُلاً مِنْ أَهْلِهِ يُقَالُ لَهُ الْمُجَبَّرُ قَدْ أَفَاضَ وَلَمْ يَحْلِقْ وَلَمْ يُقَصِّرْ جَهِلَ ذَلِكَ فَأَمَرَهُ عَبْدُ اللَّهِ أَنْ يَرْجِعَ فَيَحْلِقَ أَوْ يُقَصِّرَ ثُمَّ يَرْجِعَ إِلَى الْبَيْتِ فَيُفِيضَ ‏.‏\hadithno{894}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar once met a relative of his called al-Mujabbar who had done the tawaf al-ifada but, out of ignorance, had not shaved his head or cut his hair. Abdullah told him to go back and shave his head or cut his hair, and then go back and do the tawaf al-ifada}}
\hadithdefcmd{malik}{895}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، كَانَ إِذَا أَرَادَ أَنْ يُحْرِمَ دَعَا بِالْجَلَمَيْنِ فَقَصَّ شَارِبَهُ وَأَخَذَ مِنْ لِحْيَتِهِ قَبْلَ أَنْ يَرْكَبَ وَقَبْلَ أَنْ يُهِلَّ مُحْرِمًا ‏.‏\hadithno{895}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that when Salim ibn Abdullah intended to go into ihram he would call for some scissors and trim his moustache and beard before setting off and before going into ihram}}
\hadithdefcmd{malik}{896}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَنْ ضَفَرَ رَأْسَهُ فَلْيَحْلِقْ وَلاَ تَشَبَّهُوا بِالتَّلْبِيدِ ‏.‏\hadithno{896}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from 'Abdullah ibn 'Umar that Umar ibn al-Khattab said, "Someone who puts plaits in his hair should shave his head, and do not plait your hair in such a way that it seems you have matted it}}
\hadithdefcmd{malik}{897}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَنْ عَقَصَ رَأْسَهُ أَوْ ضَفَرَ أَوْ لَبَّدَ فَقَدْ وَجَبَ عَلَيْهِ الْحِلاَقُ ‏.‏\hadithno{897}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Said ibn al-Musayyab that Umar ibn al-Khattab said, "Anyone who has braided his hair, or plaited it or matted it must shave his head}}
\hadithdefcmd{malik}{898}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْكَعْبَةَ هُوَ وَأُسَامَةُ بْنُ زَيْدٍ وَبِلاَلُ بْنُ رَبَاحٍ وَعُثْمَانُ بْنُ طَلْحَةَ الْحَجَبِيُّ فَأَغْلَقَهَا عَلَيْهِ وَمَكَثَ فِيهَا ‏.‏ قَالَ عَبْدُ اللَّهِ فَسَأَلْتُ بِلاَلاً حِينَ خَرَجَ مَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ جَعَلَ عَمُودًا عَنْ يَمِينِهِ وَعَمُودَيْنِ عَنْ يَسَارِهِ وَثَلاَثَةَ أَعْمِدَةٍ وَرَاءَهُ - وَكَانَ الْبَيْتُ يَوْمَئِذٍ عَلَى سِتَّةِ أَعْمِدَةٍ - ثُمَّ صَلَّى ‏.‏\hadithno{898}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, entered the Kaba with Usama ibn Zayd, Bilal ibn Rabah and Uthman ibn Talha al-Hajabi and locked it behind him and stayed there for some time. Abdullah said that he asked Bilal when he came out what the Messenger of Allah had done there and he said, "He positioned himself with one support to his left, two supports to his right, and three behind him (the house had six supports at that time) and then he prayed}}
\hadithdefcmd{malik}{899}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ كَتَبَ عَبْدُ الْمَلِكِ بْنُ مَرْوَانَ إِلَى الْحَجَّاجِ بْنِ يُوسُفَ أَنْ لاَ تُخَالِفَ عَبْدَ اللَّهِ بْنَ عُمَرَ فِي شَىْءٍ مِنْ أَمْرِ الْحَجِّ ‏.‏ قَالَ فَلَمَّا كَانَ يَوْمُ عَرَفَةَ جَاءَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ حِينَ زَالَتِ الشَّمْسُ وَأَنَا مَعَهُ فَصَاحَ بِهِ عِنْدَ سُرَادِقِهِ أَيْنَ هَذَا فَخَرَجَ عَلَيْهِ الْحَجَّاجُ وَعَلَيْهِ مِلْحَفَةٌ مُعَصْفَرَةٌ فَقَالَ مَا لَكَ يَا أَبَا عَبْدِ الرَّحْمَنِ فَقَالَ الرَّوَاحَ إِنْ كُنْتَ تُرِيدُ السُّنَّةَ ‏.‏ فَقَالَ أَهَذِهِ السَّاعَةَ قَالَ نَعَمْ ‏.‏ قَالَ فَأَنْظِرْنِي حَتَّى أُفِيضَ عَلَىَّ مَاءً ثُمَّ أَخْرُجَ ‏.‏ فَنَزَلَ عَبْدُ اللَّهِ حَتَّى خَرَجَ الْحَجَّاجُ فَسَارَ بَيْنِي وَبَيْنَ أَبِي فَقُلْتُ لَهُ إِنْ كُنْتَ تُرِيدُ أَنْ تُصِيبَ السُّنَّةَ الْيَوْمَ فَاقْصُرِ الْخُطْبَةَ وَعَجِّلِ الصَّلاَةَ - قَالَ - فَجَعَلَ يَنْظُرُ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ كَيْمَا يَسْمَعَ ذَلِكَ مِنْهُ فَلَمَّا رَأَى ذَلِكَ عَبْدُ اللَّهِ قَالَ صَدَقَ سَالِمٌ ‏.‏\hadithno{899}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Salim ibn Abdullah said, ''Abd al-Malik ibn Marwan wrote to al-Hajjaj ibn Yusuf telling him not to disagree with Abdullah ibn Umar about anything to do with the hajj. Then, when the day of Arafa came Abdullah ibn Umar went to him just after noon, and I went with him. He called out to him outside his tent, 'Where is this man?' and a-lHajjaj came out to him, wearing a blanket dyed with safflower, and said to him, 'What's up with you, Abu Abd ar-Rahman?' He said, 'Hurry up, if you want to follow the sunna.' Al-Hajjaj said, 'At this hour?' and he said, 'Yes.' Al-Hajjaj said, 'Wait until I have poured some water over myself, and then I will come out.' So Abdullah dismounted and waited until al- Hajjaj came out. He passed between me and my father and I said to him, 'If you want to accord with the sunna today, then make the khutba short, do not delay the prayer and do the prayer quickly.' Then he began looking at Abdullah ibn Umar to see if he would say the same thing, and when Abdullah saw that, he said, 'What Salim is saying is true.' " 20.64 Doing the Prayer at Mina on the Eighth Day of Dhu-l-Hijja, and the Jumua at Mina and Arafa}}
\hadithdefcmd{malik}{900}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُصَلِّي الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ وَالصُّبْحَ بِمِنًى ثُمَّ يَغْدُو إِذَا طَلَعَتِ الشَّمْسُ إِلَى عَرَفَةَ ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا أَنَّ الإِمَامَ لاَ يَجْهَرُ بِالْقُرْآنِ فِي الظُّهْرِ يَوْمَ عَرَفَةَ وَأَنَّهُ يَخْطُبُ النَّاسَ يَوْمَ عَرَفَةَ وَأَنَّ الصَّلاَةَ يَوْمَ عَرَفَةَ إِنَّمَا هِيَ ظُهْرٌ وَإِنْ وَافَقَتِ الْجُمُعَةَ فَإِنَّمَا هِيَ ظُهْرٌ وَلَكِنَّهَا قُصِرَتْ مِنْ أَجْلِ السَّفَرِ ‏.‏ قَالَ مَالِكٌ فِي إِمَامِ الْحَاجِّ إِذَا وَافَقَ يَوْمُ الْجُمُعَةِ يَوْمَ عَرَفَةَ أَوْ يَوْمَ النَّحْرِ أَوْ بَعْضَ أَيَّامِ التَّشْرِيقِ إِنَّهُ لاَ يُجَمِّعُ فِي شَىْءٍ مِنْ تِلْكَ الأَيَّامِ ‏.‏\hadithno{900}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to pray dhuhr, asr, maghrib, isha and subh at Mina. Then in the morning, after the sun had risen, he would go to Arafa . Malik said, "What we are all agreed upon here (in Madina) is that the imam does not recite the Qur'an out loud in dhuhr on the day of Arafa, and that he gives a khutba to the people on that day, and that the prayer on the day of Arafa is really a dhuhr prayer, and even if it coincides with a jumua it is still a dhuhr prayer, but one which has been shortened because of travelling." Malik said that the imam of the pilgrims should not pray the jumua prayer if the day of Arafa, the day of sacrifice or one of the three days after the day of sacrifice, was a Friday}}
\hadithdefcmd{malik}{901}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ جَمِيعًا ‏.‏\hadithno{901}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, prayed maghrib and isha together at Muzdalifa}}
\hadithdefcmd{malik}{902}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ سَمِعَهُ يَقُولُ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَةَ حَتَّى إِذَا كَانَ بِالشِّعْبِ نَزَلَ فَبَالَ فَتَوَضَّأَ فَلَمْ يُسْبِغِ الْوُضُوءَ فَقُلْتُ لَهُ الصَّلاَةَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَرَكِبَ فَلَمَّا جَاءَ الْمُزْدَلِفَةَ نَزَلَ فَتَوَضَّأَ فَأَسْبَغَ الْوُضُوءَ ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّى الْمَغْرِبَ ثُمَّ أَنَاخَ كُلُّ إِنْسَانٍ بَعِيرَهُ فِي مَنْزِلِهِ ثُمَّ أُقِيمَتِ الْعِشَاءُ فَصَلاَّهَا وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا ‏.‏\hadithno{902}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Musa ibn Uqba that Kurayb, the mawla of Ibn 'Abbas, heard Usama ibn Zayd say, "The Messenger ofAllah, may Allah bless him and grant him peace, left Arafa and then, when he reached ash-Shib, he dismounted and urinated and then did wudu, though not thoroughly. I said to him, 'It is time for the prayer, Messenger of Allah,' and he said 'The prayer is ahead of you,' and then mounted. When we arrived at Muzdalifa he dismounted and did wudu thoroughly. Then the iqama was said for the prayer and he prayed maghrib. After that everyone settled his camel in its resting-place, and then the iqama for isha was said and he prayed it, without having prayed anything between the two}}
\hadithdefcmd{malik}{903}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ الأَنْصَارِيِّ، أَنَّ عَبْدَ اللَّهِ بْنَ يَزِيدَ الْخَطْمِيَّ، أَخْبَرَهُ أَنَّ أَبَا أَيُّوبَ الأَنْصَارِيَّ أَخْبَرَهُ أَنَّهُ، صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ جَمِيعًا ‏.‏\hadithno{903}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Adi ibn Thabit al-Ansari that Abdullah ibn Yazid al-Khatmi told him that Abu Ayyub al-Ansari told him that he prayed maghrib and isha together at Muzdalifa during the farewell hajj, with the Messenger of Allah, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{904}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُصَلِّي الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ جَمِيعًا ‏.‏\hadithno{904}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to pray maghrib and isha together at Muzdalifa}}
\hadithdefcmd{malik}{905}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الصَّلاَةَ الرُّبَاعِيَّةَ بِمِنًى رَكْعَتَيْنِ وَأَنَّ أَبَا بَكْرٍ صَلاَّهَا بِمِنًى رَكْعَتَيْنِ وَأَنَّ عُمَرَ بْنَ الْخَطَّابِ صَلاَّهَا بِمِنًى رَكْعَتَيْنِ وَأَنَّ عُثْمَانَ صَلاَّهَا بِمِنًى رَكْعَتَيْنِ شَطْرَ إِمَارَتِهِ ثُمَّ أَتَمَّهَا بَعْدُ ‏.‏\hadithno{905}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik said that the people of Makka who are doing hajj should shorten the prayer to two rakas when at Mina until they go back to Ma ka. Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, prayed four raka prayers with only two rakas when at Mina, and that Abu Bakr prayed them at Mina with only two rakas, and that Umar ibn al-Khattab prayed them at Mina with only two rakas, and that Uthman prayed them at Mina with only two rakas for half of his khalifate, and then later completed them}}
\hadithdefcmd{malik}{906}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، ‏.‏ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، لَمَّا قَدِمَ مَكَّةَ صَلَّى بِهِمْ رَكْعَتَيْنِ ثُمَّ انْصَرَفَ فَقَالَ يَا أَهْلَ مَكَّةَ أَتِمُّوا صَلاَتَكُمْ فَإِنَّا قَوْمٌ سَفْرٌ ‏.‏ ثُمَّ صَلَّى عُمَرُ بْنُ الْخَطَّابِ رَكْعَتَيْنِ بِمِنًى وَلَمْ يَبْلُغْنَا أَنَّهُ قَالَ لَهُمْ شَيْئًا ‏.‏\hadithno{906}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab that Umar ibn al-Khattab prayed two rakas with everybody when he arrived in Makka. Then, when he had finished, he said, "People of Makka, complete your prayer, because we are a group of travellers." Later, Umar ibn al-Khattab prayed two rakas with them at Mina, but we have not heard that he said anything to them on that occasion}}
\hadithdefcmd{malik}{907}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، صَلَّى لِلنَّاسِ بِمَكَّةَ رَكْعَتَيْنِ فَلَمَّا انْصَرَفَ قَالَ يَا أَهْلَ مَكَّةَ أَتِمُّوا صَلاَتَكُمْ فَإِنَّا قَوْمٌ سَفْرٌ ‏.‏ ثُمَّ صَلَّى عُمَرُ رَكْعَتَيْنِ بِمِنًى وَلَمْ يَبْلُغْنَا أَنَّهُ قَالَ لَهُمْ شَيْئًا ‏.‏ سُئِلَ مَالِكٌ عَنْ أَهْلِ مَكَّةَ كَيْفَ صَلاَتُهُمْ بِعَرَفَةَ أَرَكْعَتَانِ أَمْ أَرْبَعٌ وَكَيْفَ بِأَمِيرِ الْحَاجِّ إِنْ كَانَ مِنْ أَهْلِ مَكَّةَ أَيُصَلِّي الظُّهْرَ وَالْعَصْرَ بِعَرَفَةَ أَرْبَعَ رَكَعَاتٍ أَوْ رَكْعَتَيْنِ وَكَيْفَ صَلاَةُ أَهْلِ مَكَّةَ فِي إِقَامَتِهِمْ فَقَالَ مَالِكٌ يُصَلِّي أَهْلُ مَكَّةَ بِعَرَفَةَ وَمِنًى مَا أَقَامُوا بِهِمَا رَكْعَتَيْنِ رَكْعَتَيْنِ يَقْصُرُونَ الصَّلاَةَ حَتَّى يَرْجِعُوا إِلَى مَكَّةَ ‏.‏ قَالَ وَأَمِيرُ الْحَاجِّ أَيْضًا إِذَا كَانَ مِنْ أَهْلِ مَكَّةَ قَصَرَ الصَّلاَةَ بِعَرَفَةَ وَأَيَّامَ مِنًى وَإِنْ كَانَ أَحَدٌ سَاكِنًا بِمِنًى مُقِيمًا بِهَا فَإِنَّ ذَلِكَ يُتِمُّ الصَّلاَةَ بِمِنًى وَإِنْ كَانَ أَحَدٌ سَاكِنًا بِعَرَفَةَ مُقِيمًا بِهَا فَإِنَّ ذَلِكَ يُتِمُّ الصَّلاَةَ بِهَا أَيْضًا ‏.‏\hadithno{907}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from his father that Umar ibn al-Khattab prayed two rakas with the people of Makka, and then, when he had finished, he said, "People of Makka, complete your prayer, becausewe are a group of travellers." Later, Umar prayed two rakas with them at Mina, but we have not heard that he said anything to them on that occasion. Malik was asked whether the people of Makka should pray two rakas at Arafa or four, and whether the amir of the hajj, if he was a Makkan, should pray dhuhr and asr with four rakas or two, and also how the people of Makka who were living (at Mina) should pray, and he said, "The people of Makka should pray only two rakas at Arafa and Mina for as long as they stay there, and should shorten the prayer until they return to Makka. The amir of the hajj, if he is a Makkan, should also shorten the prayer at Arafa and during the days of Mina. Anyone who is living at Mina as a resident should do the full prayer at Mina, and similarly anyone who lives at Arafa and is a resident there should do the full prayer at Arafa}}
\hadithdefcmd{malik}{908}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَرَجَ الْغَدَ مِنْ يَوْمِ النَّحْرِ حِينَ ارْتَفَعَ النَّهَارُ شَيْئًا فَكَبَّرَ فَكَبَّرَ النَّاسُ بِتَكْبِيرِهِ ثُمَّ خَرَجَ الثَّانِيَةَ مِنْ يَوْمِهِ ذَلِكَ بَعْدَ ارْتِفَاعِ النَّهَارِ فَكَبَّرَ فَكَبَّرَ النَّاسُ بِتَكْبِيرِهِ ثُمَّ خَرَجَ الثَّالِثَةَ حِينَ زَاغَتِ الشَّمْسُ فَكَبَّرَ فَكَبَّرَ النَّاسُ بِتَكْبِيرِهِ حَتَّى يَتَّصِلَ التَّكْبِيرُ وَيَبْلُغَ الْبَيْتَ فَيُعْلَمَ أَنَّ عُمَرَ قَدْ خَرَجَ يَرْمِي ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّ التَّكْبِيرَ فِي أَيَّامِ التَّشْرِيقِ دُبُرَ الصَّلَوَاتِ وَأَوَّلُ ذَلِكَ تَكْبِيرُ الإِمَامِ وَالنَّاسُ مَعَهُ دُبُرَ صَلاَةِ الظُّهْرِ مِنْ يَوْمِ النَّحْرِ وَآخِرُ ذَلِكَ تَكْبِيرُ الإِمَامِ وَالنَّاسُ مَعَهُ دُبُرَ صَلاَةِ الصُّبْحِ مِنْ آخِرِ أَيَّامِ التَّشْرِيقِ ثُمَّ يَقْطَعُ التَّكْبِيرَ ‏.‏ قَالَ مَالِكٌ وَالتَّكْبِيرُ فِي أَيَّامِ التَّشْرِيقِ عَلَى الرِّجَالِ وَالنِّسَاءِ مَنْ كَانَ فِي جَمَاعَةٍ أَوْ وَحْدَهُ بِمِنًى أَوْ بِالآفَاقِ كُلِّهَا وَاجِبٌ وَإِنَّمَا يَأْتَمُّ النَّاسُ فِي ذَلِكَ بِإِمَامِ الْحَاجِّ وَبِالنَّاسِ بِمِنًى لأَنَّهُمْ إِذَا رَجَعُوا وَانْقَضَى الإِحْرَامُ ائْتَمُّوا بِهِمْ حَتَّى يَكُونُوا مِثْلَهُمْ فِي الْحِلِّ فَأَمَّا مَنْ لَمْ يَكُنْ حَاجًّا فَإِنَّهُ لاَ يَأْتَمُّ بِهِمْ إِلاَّ فِي تَكْبِيرِ أَيَّامِ التَّشْرِيقِ ‏.‏ قَالَ مَالِكٌ الأَيَّامُ الْمَعْدُودَاتُ أَيَّامُ التَّشْرِيقِ ‏.‏\hadithno{908}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me that Malik said, "Someone who comes to Makka at or before the new moon of Dhu'l-Hij ja and goes into ihram for the hajj should do the full prayer until he leaves Makka for Mina, and then he should shorten the prayer. This is because he has decided to stay there for more than four nights." Yahya related to me from Malik from Yahya ibn Said that he had heard that on the day after the day of sacrifice Umar ibn al-Khattab went out a little after the sun had risen and said the takbir, and everyone repeated it after him. Then he went out a second time the same day when the sun was well up and said the takbir, and everyone repeated it after him. Then he went out a third time after mid-day and said the takbir, and everyone repeated it after him until it resounded from group to group until it reached the House and people knew that Umar had left to throw the stones. Malik said, "What we do here (in Madina) is to say the takbir during the days of tashriq after each prayer. The first time is when the imam and everyone with him says the takbir after the dhuhr prayer on the day of sacrifice, and the last is when the imam and everyone with him says the takbir after subh on the last of the days of tashriq, after which he stops saying the takbir." Malik said, "The takbirs during the days of tashriq should be done by both men and women, whether they are in a group or by themselves, at Mina or elsewhere, and all of the takbirs should be done. In this everyone follows the imam of the hajj and the people at Mina, because when everyone returns (to Makka) and comes out of ihram they keep the same people as imams while out of ihram (as they did when they were in ihram). Some one who is not doing hajj does not follow them except for the takbirs during the days of tashriq." Malik said, "The 'limited number of days' are the days of tashriq}}
\hadithdefcmd{malik}{909}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَاخَ بِالْبَطْحَاءِ الَّتِي بِذِي الْحُلَيْفَةِ فَصَلَّى بِهَا ‏.‏ قَالَ نَافِعٌ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{909}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, made his camel kneel down at al-Batha, which is at Dhu'l-Hulayfa, and prayed there. Nafi said, "Abdullah ibn Umar used to do that." Malik said, "No-one should go past al-Muarras when he is returning from hajj without praying there. If he passes it at a time when prayer is not permissible he should stay there until prayer is permissible and then pray whatever he feels is appropriate. (This is) because I have heard that the Messenger of Allah, may Allah bless him and grant him peace, stopped there to rest, and that Abdullah ibn Umar stopped his camel there also}}
\hadithdefcmd{malik}{910}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُصَلِّي الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ بِالْمُحَصَّبِ ثُمَّ يَدْخُلُ مَكَّةَ مِنَ اللَّيْلِ فَيَطُوفُ بِالْبَيْتِ ‏.‏\hadithno{910}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to pray dhuhr, asr, maghrib and isha at al-Muhassab, and then enter Makka at night and do tawaf of the House}}
\hadithdefcmd{malik}{911}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ قَالَ زَعَمُوا أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَبْعَثُ رِجَالاً يُدْخِلُونَ النَّاسَ مِنْ وَرَاءِ الْعَقَبَةِ ‏.‏\hadithno{911}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Nafi said, "They say that Umar ibn al-Khattab used to send men out to bring people in from beyond al-Aqaba}}
\hadithdefcmd{malik}{912}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لاَ يَبِيتَنَّ أَحَدٌ مِنَ الْحَاجِّ لَيَالِيَ مِنًى مِنْ وَرَاءِ الْعَقَبَةِ ‏.‏\hadithno{912}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that Umar ibn al-Khattab said, "No-one doing hajj should spend the nights of Mina beyond al-Aqaba}}
\hadithdefcmd{malik}{913}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ فِي الْبَيْتُوتَةِ بِمَكَّةَ لَيَالِيَ مِنًى لاَ يَبِيتَنَّ أَحَدٌ إِلاَّ بِمِنًى ‏.‏\hadithno{913}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, talking about spending the nights of Mina at Makka, "No- one must spend the night anywhere except Mina}}
\hadithdefcmd{malik}{914}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَقِفُ عِنْدَ الْجَمْرَتَيْنِ الأُولَيَيْنِ وُقُوفًا طَوِيلاً حَتَّى يَمَلَّ الْقَائِمُ ‏.‏\hadithno{914}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab used to stop at the first two jamras for such a long time that someone standing up would get tired}}
\hadithdefcmd{malik}{915}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقِفُ عِنْدَ الْجَمْرَتَيْنِ الأُولَيَيْنِ وُقُوفًا طَوِيلاً يُكَبِّرُ اللَّهَ وَيُسَبِّحُهُ وَيَحْمَدُهُ وَيَدْعُو اللَّهَ وَلاَ يَقِفُ عِنْدَ جَمْرَةِ الْعَقَبَةِ ‏.‏\hadithno{915}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to stop for a long time at the first two jamras saying, "Allah is greater", "Glory be to Allah", "Praise be to Allah", and making duas to Allah, but he did not stop at the jamrat al-Aqaba}}
\hadithdefcmd{malik}{916}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُكَبِّرُ عِنْدَ رَمْىِ الْجَمْرَةِ كُلَّمَا رَمَى بِحَصَاةٍ ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ أَنَّهُ سَمِعَ بَعْضَ أَهْلِ الْعِلْمِ يَقُولُ الْحَصَى الَّتِي يُرْمَى بِهَا الْجِمَارُ مِثْلُ حَصَى الْخَذْفِ ‏.‏ قَالَ مَالِكٌ وَأَكْبَرُ مِنْ ذَلِكَ قَلِيلاً أَعْجَبُ إِلَىَّ ‏.‏\hadithno{916}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say "Allah is greater" whenever he threw a pebble while stoning the jamra}}
\hadithdefcmd{malik}{917}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ مَنْ غَرَبَتْ لَهُ الشَّمْسُ مِنْ أَوْسَطِ أَيَّامِ التَّشْرِيقِ وَهُوَ بِمِنًى فَلاَ يَنْفِرَنَّ حَتَّى يَرْمِيَ الْجِمَارَ مِنَ الْغَدِ ‏.‏\hadithno{917}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard some of the people of knowledge saying, "The pebbles used for stoning the jamras should be like the stones used as slingshot." Malik said, "I like it better if they are a little larger than that." Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "Someone who is at Mina when the sun sets in the middle of the days of tashriq must not leave until he has stoned the jamras on the following day}}
\hadithdefcmd{malik}{918}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّ النَّاسَ، كَانُوا إِذَا رَمَوُا الْجِمَارَ مَشَوْا ذَاهِبِينَ وَرَاجِعِينَ وَأَوَّلُ مَنْ رَكِبَ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ ‏.‏\hadithno{918}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn Qasim from his father that when people went to stone the jamras they would walk both going there and coming back. The first one to ride was Muawiya ibn Abi Sufyan}}
\hadithdefcmd{malik}{919}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ مِنْ أَيْنَ كَانَ الْقَاسِمُ يَرْمِي جَمْرَةَ الْعَقَبَةِ فَقَالَ مِنْ حَيْثُ تَيَسَّرَ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ هَلْ يُرْمَى عَنِ الصَّبِيِّ وَالْمَرِيضِ فَقَالَ نَعَمْ وَيَتَحَرَّى الْمَرِيضُ حِينَ يُرْمَى عَنْهُ فَيُكَبِّرُ وَهُوَ فِي مَنْزِلِهِ وَيُهَرِيقُ دَمًا فَإِنْ صَحَّ الْمَرِيضُ فِي أَيَّامِ التَّشْرِيقِ رَمَى الَّذِي رُمِيَ عَنْهُ وَأَهْدَى وُجُوبًا ‏.‏ قَالَ مَالِكٌ لاَ أَرَى عَلَى الَّذِي يَرْمِي الْجِمَارَ أَوْ يَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ وَهُوَ غَيْرُ مُتَوَضِّئٍ إِعَادَةً وَلَكِنْ لاَ يَتَعَمَّدُ ذَلِكَ ‏.‏\hadithno{919}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he asked Abd ar-Rahman ibn Qasim, "From where did Qasim stonethe jamrat al-Aqaba?"and he replied, "From wherever it was possible." Yahya said that Malik was asked whether some one else could throw the stones for a child or a sick man and he said, "Yes, and a sick man should inquire as to when the stones will be thrown for him and then say the takbir while he is in the place where he is staying, bleeding. If a sick man regains his health during the days of tashriq, he should stone whatever stoning has been done for him and he must offer a sacrificial animal." Malik said, "I do not consider that someone who stones the jamras or does say between Safa and Marwa without being in wudu has to repeat anything, but he should not make a general practice of it}}
\hadithdefcmd{malik}{920}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ لاَ تُرْمَى الْجِمَارُ فِي الأَيَّامِ الثَّلاَثَةِ حَتَّى تَزُولَ الشَّمْسُ ‏.‏\hadithno{920}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "The jamras should not be stoned during the three days until after the sun has passed the meridian}}
\hadithdefcmd{malik}{921}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ أَبِيهِ، أَنَّ أَبَا الْبَدَّاحِ بْنَ عَاصِمِ بْنِ عَدِيٍّ، أَخْبَرَهُ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْخَصَ لِرِعَاءِ الإِبِلِ فِي الْبَيْتُوتَةِ خَارِجِينَ عَنْ مِنًى يَرْمُونَ يَوْمَ النَّحْرِ ثُمَّ يَرْمُونَ الْغَدَ وَمِنْ بَعْدِ الْغَدِ لِيَوْمَيْنِ ثُمَّ يَرْمُونَ يَوْمَ النَّفْرِ ‏.‏\hadithno{921}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Hazm from his father that Abu'l-Baddah ibn Asim ibn Adi told him from his father that the Messenger of Allah, may Allah bless him and grant him peace, allowed the camel-herders to spend the night outside of Mina, and they threw the stones (once) on the day of sacrifice, and (once) for the following day and the day after that, and (once) on the day when they left Mina}}
\hadithdefcmd{malik}{922}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّهُ سَمِعَهُ يَذْكُرُ، أَنَّهُ أُرْخِصَ لِلرِّعَاءِ أَنْ يَرْمُوا، بِاللَّيْلِ يَقُولُ فِي الزَّمَانِ الأَوَّلِ ‏.‏ قَالَ مَالِكٌ تَفْسِيرُ الْحَدِيثِ الَّذِي أَرْخَصَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم لِرِعَاءِ الإِبِلِ فِي تَأْخِيرِ رَمْىِ الْجِمَارِ فِيمَا نُرَى - وَاللَّهُ أَعْلَمُ - أَنَّهُمْ يَرْمُونَ يَوْمَ النَّحْرِ فَإِذَا مَضَى الْيَوْمُ الَّذِي يَلِي يَوْمَ النَّحْرِ رَمَوْا مِنَ الْغَدِ وَذَلِكَ يَوْمُ النَّفْرِ الأَوَّلِ فَيَرْمُونَ لِلْيَوْمِ الَّذِي مَضَى ثُمَّ يَرْمُونَ لِيَوْمِهِمْ ذَلِكَ لأَنَّهُ لاَ يَقْضِي أَحَدٌ شَيْئًا حَتَّى يَجِبَ عَلَيْهِ فَإِذَا وَجَبَ عَلَيْهِ وَمَضَى كَانَ الْقَضَاءُ بَعْدَ ذَلِكَ فَإِنْ بَدَا لَهُمُ النَّفْرُ فَقَدْ فَرَغُوا وَإِنْ أَقَامُوا إِلَى الْغَدِ رَمَوْا مَعَ النَّاسِ يَوْمَ النَّفْرِ الآخِرِ وَنَفَرُوا ‏.‏\hadithno{922}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said heard Ata ibn Abi Rabah mentioning that the camel-herders were allowed to throw the stones at night, and saying that this was in the early period (of Islam). Malik said, "The explanation of the hadith where the Messenger of Allah, may Allah bless him and grant him peace, allowed the camel-herders to delay the stoning of the jamras is, in our view, and Allah knows best, that they threw stones on the day of sacrifice, and then threw again two days later, which was the first possible day for leaving, and this throwing was for the day which had passed. They then threw again for the day itself, because it is only possible for someone to make up for something which is obligatory for him, and when something obligatory passes someone by (without him doing it) he must necessarily make it up afterwards (and not beforehand). So (in the case of the camel-herders), if it seemed appropriate for them to leave that day, they would have done all that they were supposed to do, and if they were to stay until the following day, they would throw stones with everybody else on the second and last day for leaving, and then leave}}
\hadithdefcmd{malik}{923}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، أَنَّ ابْنَةَ أَخٍ، لِصَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ نُفِسَتْ بِالْمُزْدَلِفَةِ فَتَخَلَّفَتْ هِيَ وَصَفِيَّةُ حَتَّى أَتَتَا مِنًى بَعْدَ أَنْ غَرَبَتِ الشَّمْسُ مِنْ يَوْمِ النَّحْرِ فَأَمَرَهُمَا عَبْدُ اللَّهِ بْنُ عُمَرَ أَنْ تَرْمِيَا الْجَمْرَةَ حِينَ أَتَتَا وَلَمْ يَرَ عَلَيْهِمَا شَيْئًا ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَمَّنْ نَسِيَ جَمْرَةً مِنَ الْجِمَارِ فِي بَعْضِ أَيَّامِ مِنًى حَتَّى يُمْسِيَ قَالَ لِيَرْمِ أَىَّ سَاعَةٍ ذَكَرَ مِنْ لَيْلٍ أَوْ نَهَارٍ كَمَا يُصَلِّي الصَّلاَةَ إِذَا نَسِيَهَا ثُمَّ ذَكَرَهَا لَيْلاً أَوْ نَهَارًا فَإِنْ كَانَ ذَلِكَ بَعْدَ مَا صَدَرَ وَهُوَ بِمَكَّةَ أَوْ بَعْدَ مَا يَخْرُجُ مِنْهَا فَعَلَيْهِ الْهَدْىُ ‏.‏\hadithno{923}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Abu Bakr ibn Nafi from his father that the daughter of one of Safiyya bint Abi Ubayd's brothers was bleeding after she had given birth to a child at Muzdalifa. She and Safiyya were delayed and did not arrive at Mina until after the sun had set on the day of sacrifice. Abdullah ibn Umar told them both to stone the jamra at the time they arrived and he did not think that they owed anything. Yahya said that Malik was asked about some one who forgot to stone one of the jamras on one of the days of Mina until it was evening and he said, "He should throw the stones at whatever time of day or night he remembers, just as he would pray the prayer if he forgot it and then remembered it at any time of day or night. If he remembers (that he has not done the stoning) after he has returned to Makka, or after he has left, he must sacrifice an animal}}
\hadithdefcmd{malik}{924}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَطَبَ النَّاسَ بِعَرَفَةَ وَعَلَّمَهُمْ أَمْرَ الْحَجِّ وَقَالَ لَهُمْ فِيمَا قَالَ إِذَا جِئْتُمْ مِنًى فَمَنْ رَمَى الْجَمْرَةَ فَقَدْ حَلَّ لَهُ مَا حَرُمَ عَلَى الْحَاجِّ إِلاَّ النِّسَاءَ وَالطِّيبَ لاَ يَمَسَّ أَحَدٌ نِسَاءً وَلاَ طِيبًا حَتَّى يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{924}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi and Abdullah ibn Dinar from Abdullah ibn Umar that Umar ibn al-Khattab gave a khutba to the people at Arafa and taught them the conduct of the hajj, and one of the things he said to them in his speech was, "When you get to Mina and have stoned the jamra then whatever is haram for someone doing the hajj becomes halal, except women and scent. No-one should touch women or scent until he has done tawaf of the House}}
\hadithdefcmd{malik}{925}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَنْ رَمَى الْجَمْرَةَ ثُمَّ حَلَقَ أَوْ قَصَّرَ وَنَحَرَ هَدْيًا - إِنْ كَانَ مَعَهُ - فَقَدْ حَلَّ لَهُ مَا حَرُمَ عَلَيْهِ إِلاَّ النِّسَاءَ وَالطِّيبَ حَتَّى يَطُوفَ بِالْبَيْتِ ‏.‏\hadithno{925}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi and Abdullah ibn Dinar from Abdullah ibn Umar that Umar ibn al-Khattab said, "When someone has stoned the jamra and shaved his head or cut off some of his hair and sacrificed an animal, whatever was haram for him becomes halal, except women and scent, (which remain haram for him) until he has done tawaf of the House}}
\hadithdefcmd{malik}{926}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حَجَّةِ الْوَدَاعِ فَأَهْلَلْنَا بِعُمْرَةٍ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مَعَهُ هَدْىٌ فَلْيُهْلِلْ بِالْحَجِّ مَعَ الْعُمْرَةِ ثُمَّ لاَ يَحِلُّ حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏ قَالَتْ فَقَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ فَلَمْ أَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَشَكَوْتُ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْقُضِي رَأْسَكِ وَامْتَشِطِي وَأَهِلِّي بِالْحَجِّ وَدَعِي الْعُمْرَةَ ‏"‏ ‏.‏ قَالَتْ فَفَعَلْتُ فَلَمَّا قَضَيْنَا الْحَجَّ أَرْسَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ إِلَى التَّنْعِيمِ فَاعْتَمَرْتُ فَقَالَ ‏"‏ هَذَا مَكَانُ عُمْرَتِكِ ‏"‏ ‏.‏ فَطَافَ الَّذِينَ أَهَلُّوا بِالْعُمْرَةِ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ ثُمَّ حَلُّوا مِنْهَا ثُمَّ طَافُوا طَوَافًا آخَرَ بَعْدَ أَنْ رَجَعُوا مِنْ مِنًى لِحَجِّهِمْ وَأَمَّا الَّذِينَ كَانُوا أَهَلُّوا بِالْحَجِّ أَوْ جَمَعُوا الْحَجَّ وَالْعُمْرَةَ فَإِنَّمَا طَافُوا طَوَافًا وَاحِدًا ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، بِمِثْلِ ذَلِكَ ‏\hadithno{926}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Abd ar-Rahman ibn al-Qasim, from his father that A'isha, umm al-muminin, said, "We set out with the Messenger of Allah, may Allah bless him and grant him peace, in the year of the farewell hajj and we went into ihram for umra. Afterwards, the Messenger of Allah, may Allah bless him and grant him peace, said, 'Whoever has a sacrificial animal with him should go into ihram for hajj and umra together, and he should not leave ihram without leaving ihram for both of them at the same time.' " She continued "I was menstruating when I got to Makka, so I did not do tawaf of the House or say between Safa and Marwa. I complained to the Messenger of Allah, may Allah bless him and grant him peace, and he said, 'Undo your hair and comb it and leave the umra and go back into ihram for the hajj.' " She said, "I did so, and when we had completed the hajj, the Messenger of Allah, may Allah bless him and grant him peace, sent me with Abd ar-Rahman ibn Abi Bakr as-Siddiq to at-Tanim and I performed an umra and he said, 'This is in place of your umra.' " "Those who had entered ihram for the umra did tawaf of the House and say between Safa and Marwa, then left ihram. Then they did another tawaf after returning from Mina for their hajj, whereas those who entered ihram for the hajj or combined the hajj and the umra, only did one tawaf." Yahya related the same as that to me from Malik from Ibn Shihab from Urwa ibn az-Zubayr from A'isha}}
\hadithdefcmd{malik}{928}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ قَدِمْتُ مَكَّةَ وَأَنَا حَائِضٌ، فَلَمْ أَطُفْ بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ فَشَكَوْتُ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ افْعَلِي مَا يَفْعَلُ الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ وَلاَ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى تَطْهُرِي ‏"‏ ‏.‏\hadithno{928}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father that A'isha said, "I came to Makka at the time of my period so I did not do tawaf of the House or go between Safa and Marwa. I complained to the Messenger of Allah, may Allah bless him and grant him peace, and he said, 'Do what the people doing hajj do except do not do tawaf of the House and go between Safa and Marwa until you are pure.' " Malik said, concerning a woman who entered ihram for umra at the time of hajj, and she arrived in Makka during her period and so could not do tawaf of the House, "When she fears that the time (for hajj) is getting close, she gets into ihram for the hajj and sacrifices an animal. She is like someone who combines the hajj and the umra. One tawaf is enough for her. If a women starts her period after she has already done tawaf of the House and prayed, she does say between Safa and Marwa and stops at Arafa and Muzdalifa and stones the jamras but she does not do the tawaf al-ifada until she is pure and has finished her menses}}
\hadithdefcmd{malik}{929}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ صَفِيَّةَ بِنْتَ حُيَىٍّ، حَاضَتْ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَحَابِسَتُنَا هِيَ ‏"‏ ‏.‏ فَقِيلَ إِنَّهَا قَدْ أَفَاضَتْ ‏.‏ فَقَالَ ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{929}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father from A'isha umm al-muminin that Safiyya bint Huyy began menstruating and so she mentioned it to the Messenger of Allah, may Allah bless him and grant him peace, and he asked, "Will she delay us?" and he was told, "She has already done the tawaf al-ifada," and he said, "Then she will not delay us}}
\hadithdefcmd{malik}{930}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ إِنَّ صَفِيَّةَ بِنْتَ حُيَىٍّ قَدْ حَاضَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَعَلَّهَا تَحْبِسُنَا أَلَمْ تَكُنْ طَافَتْ مَعَكُنَّ بِالْبَيْتِ ‏"‏ ‏.‏ قُلْنَ بَلَى ‏.‏ قَالَ ‏"‏ فَاخْرُجْنَ ‏"‏ ‏.‏\hadithno{930}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Hazm from his father from Amra bint Abd ar-Rahman that A'isha umm al- muminin said to the Messenger of Allah, may Allah bless him and grant him peace, "Messenger of Allah, Safiyya bint Huyy has begun her period," and the Messenger of Allah, may Allah bless him and grant him peace, said, "Perhaps she will delay us. Has she done tawaf of the House with you?" They said, "Of course." He said, "So you are free to leave}}
\hadithdefcmd{malik}{931}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الرِّجَالِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، ‏.‏ أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، كَانَتْ إِذَا حَجَّتْ وَمَعَهَا نِسَاءٌ تَخَافُ أَنْ يَحِضْنَ قَدَّمَتْهُنَّ يَوْمَ النَّحْرِ فَأَفَضْنَ فَإِنْ حِضْنَ بَعْدَ ذَلِكَ لَمْ تَنْتَظِرْهُنَّ فَتَنْفِرُ بِهِنَّ - وَهُنَّ حُيَّضٌ - إِذَا كُنَّ قَدْ أَفَضْنَ ‏.‏\hadithno{931}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from AbuRijal Muhammad ibn Abd ar- Rahman from Amra bint Abd ar-Rahman that when A'isha umm al-muminin was doing hajj with women who were expecting their periods, she would hurry them to do the tawaf al-ifada on the Day of Sacrifice. If they started to menstruate after the tawaf al-ifada she did not stop for them but left with them while they were menstruating}}
\hadithdefcmd{malik}{932}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ صَفِيَّةَ بِنْتَ حُيَىٍّ فَقِيلَ لَهُ قَدْ حَاضَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَعَلَّهَا حَابِسَتُنَا ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ طَافَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏ قَالَ مَالِكٌ قَالَ هِشَامٌ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ ‏.‏ وَنَحْنُ نَذْكُرُ ذَلِكَ فَلِمَ يُقَدِّمُ النَّاسُ نِسَاءَهُمْ إِنْ كَانَ ذَلِكَ لاَ يَنْفَعُهُنَّ وَلَوْ كَانَ الَّذِي يَقُولُونَ لأَصْبَحَ بِمِنًى أَكْثَرُ مِنْ سِتَّةِ آلاَفِ امْرَأَةٍ حَائِضٍ كُلُّهُنَّ قَدْ أَفَاضَتْ ‏.‏\hadithno{932}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from A'isha umm al-muminin that the Messenger of Allah, may Allah bless him and grant him peace, mentioned Safiyya bint Huyy and he was told that she had started her period. The Messenger of Allah, may Allah bless him and grant him peace, said, "Perhaps she will delay us." They said, "Messenger of Allah, she has done tawaf," and the Messenger of Allah, may Allah bless him and grant him peace, said, "Then she will not delay us." Malik said that Hisham said that Urwa said that A'isha said, "We have publicized that, so why do people make their women stay on to their inconvenience? If it were as they say, more than six thousand menstruating women would still be in Mina in the morning, all of them having already done the tawaf al- ifada}}
\hadithdefcmd{malik}{933}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ أُمَّ سُلَيْمٍ بِنْتَ مِلْحَانَ اسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَحَاضَتْ - أَوْ وَلَدَتْ - بَعْدَ مَا أَفَاضَتْ يَوْمَ النَّحْرِ فَأَذِنَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَرَجَتْ ‏.‏\hadithno{933}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from his father that Abu Salama ibn Abd ar-Rahman told him that Umm Sulaym bint Milhan asked the Messenger of Allah, may Allah bless him and grant him peace, for advice one time when she had begun menstruating, or had given birth to a child after she had done tawaf al-ifada on the Day of Sacrifice. The Messenger of Allah, may Allah bless him and grant him peace, gave her permission to leave. Malik said, "A woman menstruating at Mina stays until she has done tawaf of the House. There is no escape from that for her. If she has already done the tawaf al-ifada and she starts to menstruate afterwards, she may leave for her country, since permission for the menstruating women to leave has been transmitted to us from the Messenger of Allah, may Allah bless him and grant him peace." He added, "If a woman starts her period at Mina before she does the tawaf al-ifada, and the period lasts longer than usual, she has to stay longer than the time that bleeding would usually detain women}}
\hadithdefcmd{malik}{934}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَضَى فِي الضَّبُعِ بِكَبْشٍ وَفِي الْغَزَالِ بِعَنْزٍ وَفِي الأَرْنَبِ بِعَنَاقٍ وَفِي الْيَرْبُوعِ بِجَفْرَةٍ ‏.‏\hadithno{934}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr that Umar ibn al-Khattab gave the judgement of a ram for a hyena, a female goat for a gazelle, a she-goat less than one year old for a rabbit, and a four month old kid for a jerboa}}
\hadithdefcmd{malik}{935}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ قُرَيْرٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، أَنَّ رَجُلاً، جَاءَ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ إِنِّي أَجْرَيْتُ أَنَا وَصَاحِبٌ، لِي فَرَسَيْنِ نَسْتَبِقُ إِلَى ثُغْرَةِ ثَنِيَّةٍ فَأَصَبْنَا ظَبْيًا وَنَحْنُ مُحْرِمَانِ فَمَاذَا تَرَى فَقَالَ عُمَرُ لِرَجُلٍ إِلَى جَنْبِهِ تَعَالَ حَتَّى أَحْكُمَ أَنَا وَأَنْتَ ‏.‏ قَالَ فَحَكَمَا عَلَيْهِ بِعَنْزٍ فَوَلَّى الرَّجُلُ وَهُوَ يَقُولُ هَذَا أَمِيرُ الْمُؤْمِنِينَ لاَ يَسْتَطِيعُ أَنْ يَحْكُمَ فِي ظَبْىٍ حَتَّى دَعَا رَجُلاً يَحْكُمُ مَعَهُ ‏.‏ فَسَمِعَ عُمَرُ قَوْلَ الرَّجُلِ فَدَعَاهُ فَسَأَلَهُ هَلْ تَقْرَأُ سُورَةَ الْمَائِدَةِ قَالَ لاَ ‏.‏ قَالَ فَهَلْ تَعْرِفُ هَذَا الرَّجُلَ الَّذِي حَكَمَ مَعِي فَقَالَ لاَ ‏.‏ فَقَالَ لَوْ أَخْبَرْتَنِي أَنَّكَ تَقْرَأُ سُورَةَ الْمَائِدَةِ لأَوْجَعْتُكَ ضَرْبًا ثُمَّ قَالَ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏يَحْكُمُ بِهِ ذَوَا عَدْلٍ مِنْكُمْ هَدْيًا بَالِغَ الْكَعْبَةِ‏\}‏ وَهَذَا عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ ‏.‏\hadithno{935}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd al-Malik ibn Qurayr from Muhammad ibn Sirin that a man came to Umar ibn al-Khattab and said, "I was racing a friend on horseback towards a narrow mountain trail and we killed a gazelle accidently and we were in ihram. What is your opinion?" Umar said to a man by his side, "Come, so that you and I may make an assessment." They decided on a female goat for him, and the man turned away saying, "This amir al-muminin cannot even make an assessment in the case of a gazelle until he calls a man to decide with him." Umar overheard the man's words and called him and asked him, "Do you recite surat al-Ma'ida?" and he said, "No." He said, "Then do you recognize this man who has taken the decision with me?" and he said, "No." He said, "If you had told me that you did recite surat al-Ma'ida, I would have dealt you a blow." Then he said, "Allah the Blessed, the Exalted says in His Book, 'as shall be judged by two men of justice among you, a sacrificial animal to reach the Kaba' (Sura 5 ayat 95), and this is Abd ar-Rahman ibn Awf}}
\hadithdefcmd{malik}{936}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، كَانَ يَقُولُ فِي الْبَقَرَةِ مِنَ الْوَحْشِ بَقَرَةٌ وَفِي الشَّاةِ مِنَ الظِّبَاءِ شَاةٌ ‏.‏\hadithno{936}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to say, "For the female of wild animals a cow is given and for the female of gazelles a sheep}}
\hadithdefcmd{malik}{937}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ فِي حَمَامِ مَكَّةَ إِذَا قُتِلَ شَاةٌ ‏.‏ وَقَالَ مَالِكٌ فِي الرَّجُلِ مِنْ أَهْلِ مَكَّةَ يُحْرِمُ بِالْحَجِّ أَوِ الْعُمْرَةِ وَفِي بَيْتِهِ فِرَاخٌ مِنْ حَمَامِ مَكَّةَ فَيُغْلَقُ عَلَيْهَا فَتَمُوتُ فَقَالَ أَرَى بِأَنْ يَفْدِيَ ذَلِكَ عَنْ كُلِّ فَرْخٍ بِشَاةٍ ‏.‏ قَالَ مَالِكٌ لَمْ أَزَلْ أَسْمَعُ أَنَّ فِي النَّعَامَةِ إِذَا قَتَلَهَا الْمُحْرِمُ بَدَنَةً ‏.‏ قَالَ مَالِكٌ أَرَى أَنَّ فِي بَيْضَةِ النَّعَامَةِ عُشْرَ ثَمَنِ الْبَدَنَةِ كَمَا يَكُونُ فِي جَنِينِ الْحُرَّةِ غُرَّةٌ عَبْدٌ أَوْ وَلِيدَةٌ وَقِيمَةُ الْغُرَّةِ خَمْسُونَ دِينَارًا وَذَلِكَ عُشْرُ دِيَةِ أُمِّهِ وَكُلُّ شَىْءٍ مِنَ النُّسُورِ أَوِ الْعِقْبَانِ أَوِ الْبُزَاةِ أَوِ الرَّخَمِ فَإِنَّهُ صَيْدٌ يُودَى كَمَا يُودَى الصَّيْدُ إِذَا قَتَلَهُ الْمُحْرِمُ وَكُلُّ شَىْءٍ فُدِيَ فَفِي صِغَارِهِ مِثْلُ مَا يَكُونُ فِي كِبَارِهِ وَإِنَّمَا مَثَلُ ذَلِكَ مَثَلُ دِيَةِ الْحُرِّ الصَّغِيرِ وَالْكَبِيرِ فَهُمَا بِمَنْزِلَةٍ وَاحِدَةٍ سَوَاءٌ ‏.‏\hadithno{937}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab used to say, "For the pigeon of Makka, when it is killed, a sheep is due." Malik said, that if a man of the people of Makka were to enter ihram for hajj or umra and there was a flock of Makkan pigeons in his house and they were shut in and died, "I think that he should pay for that with a sheep for each bird}}
\hadithdefcmd{malik}{938}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَجُلاً، جَاءَ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ إِنِّي أَصَبْتُ جَرَادَاتٍ بِسَوْطِي وَأَنَا مُحْرِمٌ ‏.‏ فَقَالَ لَهُ عُمَرُ أَطْعِمْ قَبْضَةً مِنْ طَعَامٍ ‏.‏\hadithno{938}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik said, I still hear that when a person in ihram kills an ostrich, a camel is due." Malik said, "I think that for an ostrich egg, one tenth of the price of a camel is due in the same way that there is a newly-born male or female slave for the unborn child of a free woman. The value of the newly-born slave is fifty dinars, and that is one-tenth of what the blood-money for the mother would be. "Birds from the eagle family, eagles or falcons or vultures count as game for which a price is paid just as a price is paid for any game which a person in ihram kills. For everything for which a penalty is paid, the assessment is the same, whether the animal is old or young. The analogy of that is that the blood-money for the young and the old freeman, are considered to be the same." Yahya related to me from Malik from Zayd ibn Aslam that a man came to Umar ibn al-Khattab and said, "Amir al-muminin, I killed some locusts with my whip when I was in ihram," and Umar said to him, "Give a handful of food}}
\hadithdefcmd{malik}{939}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَجُلاً، جَاءَ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَسَأَلَهُ عَنْ جَرَادَاتٍ، قَتَلَهَا وَهُوَ مُحْرِمٌ فَقَالَ عُمَرُ لِكَعْبٍ تَعَالَ حَتَّى نَحْكُمَ ‏.‏ فَقَالَ كَعْبٌ دِرْهَمٌ ‏.‏ فَقَالَ عُمَرُ لِكَعْبٍ إِنَّكَ لَتَجِدُ الدَّرَاهِمَ لَتَمْرَةٌ خَيْرٌ مِنْ جَرَادَةٍ ‏.‏\hadithno{939}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that a man came to Umar ibn al-Khattab and asked him about some locusts he had killed while he was in ihram. Umar said to Kab, "Come, let's decide." Kab said, "A dirham," and Umar said to Kab, "You can find dirhams. A date is better than a locust}}
\hadithdefcmd{malik}{940}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الْكَرِيمِ بْنِ مَالِكٍ الْجَزَرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُحْرِمًا فَآذَاهُ الْقَمْلُ فِي رَأْسِهِ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَحْلِقَ رَأْسَهُ وَقَالَ ‏ "‏ صُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ مُدَّيْنِ مُدَّيْنِ لِكُلِّ إِنْسَانٍ أَوِ انْسُكْ بِشَاةٍ أَىَّ ذَلِكَ فَعَلْتَ أَجْزَأَ عَنْكَ ‏"‏ ‏.‏\hadithno{940}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd al-Karim ibn Malik al- Jazari from Abd ar-Rahman ibn Abi Layla from Kab ibn Ujra that one time he was with the Messenger of Allah, may Allah bless him and grant him peace, in ihram, and he was suffering from lice on his head. The Messenger of Allah, may Allah bless him and grant him peace, told him to shave his head, saying, "Fast three days, or feed six poor people, two mudds for each person, or sacrifice a sheep. If you do any of those it will be enough for you}}
\hadithdefcmd{malik}{941}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ، عَنْ مُجَاهِدٍ أَبِي الْحَجَّاجِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ لَعَلَّكَ آذَاكَ هَوَامُّكَ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْلِقْ رَأْسَكَ وَصُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ أَوِ انْسُكْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{941}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Humayd bin Qays from Mujahid Abu'l Hajjaj from Ibn Abi Layla from Kab ibn Ujra that the Messenger of Allah, may Allah bless him and grant him peace, said to him, "Perhaps your pests are troubling you?" He replied that indeed they were, and the Messenger of Allah, may Allah bless him and grant him peace, said, "Shave your head and fast three days or feed six poor men or sacrifice a sheep}}
\hadithdefcmd{malik}{942}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَطَاءِ بْنِ عَبْدِ اللَّهِ الْخُرَاسَانِيِّ، أَنَّهُ قَالَ حَدَّثَنِي شَيْخٌ، بِسُوقِ الْبُرَمِ بِالْكُوفَةِ عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّهُ قَالَ جَاءَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَنْفُخُ تَحْتَ قِدْرٍ لأَصْحَابِي وَقَدِ امْتَلأَ رَأْسِي وَلِحْيَتِي قَمْلاً فَأَخَذَ بِجَبْهَتِي ثُمَّ قَالَ ‏ "‏ احْلِقْ هَذَا الشَّعَرَ وَصُمْ ثَلاَثَةَ أَيَّامٍ أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ ‏"‏ ‏.‏ وَقَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِمَ أَنَّهُ لَيْسَ عِنْدِي مَا أَنْسُكُ بِهِ ‏.‏\hadithno{942}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that Ata ibn Abdullah al-Khurasani said that an old man from Suq al-Buram in Kufa had related to him that Kab ibn Ujra said, "The Messenger of Allah, may Allah bless him and grant him peace, came to me while I was blowing under a cooking pot belonging to my companions and my head and beard were full of lice. He took my forehead and said, 'Shave your hair and fast three days or feed six poor people.' The Messenger of Allah, may Allah bless him and grant him peace, was aware that I did not have anything with me to sacrifice.'" Malik said, concerning paying compensation (fidya) for the relief of physical discomfort, "The custom concerning it is that no one pays compensation until he has done something which makes it obligatory to pay compensation just as making amends (kaffara) is only done when it has become obligatory for the one who owes it. The person can pay the compensation wherever he wishes, regardless of whether he has to sacrifice an animal or fast or give sadaqa in Makka or in any other town." Malik said, "It is not correct for a person in ihram to pluck out any of his hair or to shave it or cut it until he has left ihram, unless he is suffering from an ailment of the head, in which case he owes the compensation Allah the Exalted has ordered. It is not correct for a person in ihram to cut his nails, or to kill his lice, or to remove them from his head or from his skin or his garment to the ground. If a person in ihram removes lice from his skin or his garment, he must give away the quantity of food that he can scoop up with both hands. " Malik said,"Anyone who, while in ihram, plucks out hairs from his nose or armpit or rubs his body with a depilatory agent or shaves the hair from around a head wound out of necessity or shaves his neck for the place of the cupping glasses, regardless of whether it is in forgetfulness or in ignorance, owes compensation in all these instances, and he must not shave the place of the cupping glasses. Someone, who, out of ignorance, shaves his head before he stones the jamra. must also pay compensation}}
\hadithdefcmd{malik}{943}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ السَّخْتِيَانِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ مَنْ نَسِيَ مِنْ نُسُكِهِ شَيْئًا أَوْ تَرَكَهُ فَلْيُهْرِقْ دَمًا ‏.‏ قَالَ أَيُّوبُ لاَ أَدْرِي قَالَ تَرَكَ أَوْ نَسِيَ ‏.‏ قَالَ مَالِكٌ مَا كَانَ مِنْ ذَلِكَ هَدْيًا فَلاَ يَكُونُ إِلاَّ بِمَكَّةَ وَمَا كَانَ مِنْ ذَلِكَ نُسُكًا فَهُوَ يَكُونُ حَيْثُ أَحَبَّ صَاحِبُ النُّسُكِ ‏.‏\hadithno{943}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Abi Tamima as- Sakhtayani from Said ibn Jubayr that Abdullah ibn Abbas said, "If someone forgets anything of the rituals or omits them intentionally, he must slaughter an animal." Ayyub added "I do not know if he said 'Omits' or 'forgets'." Malik said, "If it is a hady that has to be slaughtered it may only be done in Makka, but if it is a sacrifice, it may be slaughtered wherever the one who owes the sacrifice prefers}}
\hadithdefcmd{malik}{944}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ قَالَ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلنَّاسِ بِمِنًى وَالنَّاسُ يَسْأَلُونَهُ فَجَاءَهُ رَجُلٌ فَقَالَ لَهُ يَا رَسُولَ اللَّهِ لَمْ أَشْعُرْ فَحَلَقْتُ قَبْلَ أَنْ أَنْحَرَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْحَرْ وَلاَ حَرَجَ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ لَمْ أَشْعُرْ فَنَحَرْتُ قَبْلَ أَنْ أَرْمِيَ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ فَمَا سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ شَىْءٍ قُدِّمَ وَلاَ أُخِّرَ إِلاَّ قَالَ ‏"‏ افْعَلْ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{944}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said, concerning someone who wishes to wear clothes that a person in ihram must not wear, or cut his hair, or touch perfume without necessity, because he finds it easy to pay the compensation, "No-one must do such things. They are only allowed in cases of necessity, and compensation is owed by whoever does them." Malik was asked whether the culprit could choose for himself the method of compensation he makes, and he was asked what kind of animal was to be sacrificed, and how much food was to be given, and how many days were to be fasted, and whether the person could delay any of these, or if they had to be done immediately. He answered, 'Whenever there are alternatives in the Book of Allah for the kaffara, the culprit can choose to do whichever of the alternatives he prefers. As for the sacrifice - a sheep, and as for the fasting - three days. As for the food - feeding six poor men, for every poor man two mudds, by the first mudd, the mudd of the Prophet, may Allah bless him and grant him peace." Malik said, "I have heard one of the people of knowledge saying, 'When a person in ihram throws something and hits game unintentionally and kills it, he must pay compensation. In the same way, someone outside the Haram who throws anything into the Haram and hits game he did not intend to, killing it, has to pay compensation, because the intentional and the mistaken are in the same position in this matter.' " Malik said, concerning people who kill game together while they are muhrim or in the Haram, "I think that each one of them owes a full share. If a sacrificial animal is decided for them, each one of them owes one, and if fasting is decided for them, the full fasting is owed by each one of them. The analogy of that is a group of people who kill a man by mistake and the kaffara for that is that each person among them must free a slave or fast two consecutive months." Malik said, "Anyone who stones or hunts game after stoning the jamra and shaving his head but before he has performed the tawaf al-ifada, owes compensation for that game, because Allah the Blessed, the Exalted said, 'And when you leave ihram, then hunt,' and restrictions still remain for someone who has not done the tawaf al-ifada about touching perfume and women." Malik said, "The person in ihram does not owe anything for plants he cuts down in the Haram and it has not reached us that anyone has given a decision of anything for it, but O how wrong is what he has done! " Malik said, concerning some one who was ignorant of, or who forgot the fast of three days in the hajj, or who was ill during them and so did not fast them until he had returned to his community, "He must offer a sacrificial animal (hady) if he can find one and if not he must fast the three days among his people and the remaining seven after that." Yahya related to me from Malik from Ibn Shihab from clsa ibn Talha that Abdullah ibn Amr ibn al-As said, "The Messenger of Allah, may Allah bless him and grant him peace, stopped for the people at Mina, and they questioned him and a man came and said to him, 'Messenger of Allah, I was unclear about what to do and I shaved before sacrificing,' and the Messenger of Allah, may Allah bless him and grant him peace, said, 'Sacrifice, and don't worry.' Then another came to him and said 'Messenger of Allah, I was unclear about what to do and I sacrificed before throwing the stones.' He advised, 'Throw, and don't worry.' " Amr continued, saying that the Messenger of Allah, may Allah bless him and grant him peace, was not asked about anything done before or after without his saying, "Do it, and don't worry}}
\hadithdefcmd{malik}{945}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَفَلَ مِنْ غَزْوٍ أَوْ حَجٍّ أَوْ عُمْرَةٍ يُكَبِّرُ عَلَى كُلِّ شَرَفٍ مِنَ الأَرْضِ ثَلاَثَ تَكْبِيرَاتٍ ثُمَّ يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ آيِبُونَ تَائِبُونَ عَابِدُونَ سَاجِدُونَ لِرَبِّنَا حَامِدُونَ صَدَقَ اللَّهُ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏\hadithno{945}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that when the Messenger of Allah, may Allah bless him and grant him peace, returned from a military expedition or a hajj or an umra, he used to say three takbirs on every elevated part of the land, and then he used to say, "There is no god but Allah, alone, without partner. To Him belongs the Kingdom and to Him belongs the praise and He has power over everything. Returning, making tawba, serving, prostrating, praising our Lord. Allah has promised truly and given His slave victory and defeated the tribes alone}}
\hadithdefcmd{malik}{946}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِامْرَأَةٍ وَهِيَ فِي مِحَفَّتِهَا فَقِيلَ لَهَا هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخَذَتْ بِضَبْعَىْ صَبِيٍّ كَانَ مَعَهَا فَقَالَتْ أَلِهَذَا حَجٌّ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏\hadithno{946}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibrahim ibn Uqba from Kurayb the mawla of Abdullah ibn Abbas from Ibn Abbas that the Messenger of Allah, may Allah bless him and grant him peace, passed a woman in a litter and it was said to her, "This is the Messenger of Allah, may Allah bless him and grant him peace," and she took the forearms of a young boy who was with her and said, "Does this one have a hajj, Messenger of Allah?" and he said, "Yes, and you have a reward}}
\hadithdefcmd{malik}{947}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي عَبْلَةَ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ بْنِ كَرِيزٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا رُئِيَ الشَّيْطَانُ يَوْمًا هُوَ فِيهِ أَصْغَرُ وَلاَ أَدْحَرُ وَلاَ أَحْقَرُ وَلاَ أَغْيَظُ مِنْهُ فِي يَوْمِ عَرَفَةَ وَمَا ذَاكَ إِلاَّ لِمَا رَأَى مِنْ تَنَزُّلِ الرَّحْمَةِ وَتَجَاوُزِ اللَّهِ عَنِ الذُّنُوبِ الْعِظَامِ إِلاَّ مَا أُرِيَ يَوْمَ بَدْرٍ ‏"‏ ‏.‏ قِيلَ وَمَا رَأَى يَوْمَ بَدْرٍ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَمَا إِنَّهُ قَدْ رَأَى جِبْرِيلَ يَزَعُ الْمَلاَئِكَةَ ‏"‏ ‏.‏\hadithno{947}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Ibrahim ibn Abi Abla from Talha ibn Ubaydullah ibn Kariyz that the Messenger of Allah, may Allah bless him and grant him peace, said, "Shaytan is not considered more abased or more cast out or more contemptible or more angry on any day than on the Day of Arafa. That is only because he sees the descent of the Mercy and Allah's disregard for great wrong actions. That is except from what he was shown on the Day of Badr." Someone said, "What was he shown on the Day of Badr, Messenger of Allah?" He said, "Didn't he see Jibril arranging the ranks of the angels?}}
\hadithdefcmd{malik}{948}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زِيَادِ بْنِ أَبِي زِيَادٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ بْنِ كَرِيزٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْضَلُ الدُّعَاءِ دُعَاءُ يَوْمِ عَرَفَةَ وَأَفْضَلُ مَا قُلْتُ أَنَا وَالنَّبِيُّونَ مِنْ قَبْلِي لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ‏"‏ ‏.‏\hadithno{948}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zihad ibn Abi Ziyad the mawla of Abdullah ibn Ayyash ibn Abi Rabia from Talha ibn Ubaydullah ibn Kariyz that the Messenger of Allah, may Allah bless him and grant him peace, said, "The most excellent dua is the dua on the Day of Arafa, and the best of what I and the prophets before me have said, is 'There is no god but Allah, alone, without partner}}
\hadithdefcmd{malik}{949}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ مَكَّةَ عَامَ الْفَتْحِ وَعَلَى رَأْسِهِ الْمِغْفَرُ فَلَمَّا نَزَعَهُ جَاءَهُ رَجُلٌ فَقَالَ لَهُ يَا رَسُولَ اللَّهِ ابْنُ خَطَلٍ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْتُلُوهُ ‏"‏ ‏.‏\hadithno{949}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Anas ibn Malik that the Messenger of Allah, may Allah bless him and grant him peace, entered Makka, in the Year of Victory, wearing a helmet, and when he took it off a man came to him and said, "Messenger of Allah, Ibn Khatal is clinging to the covers of the Kaba,'' and the Messenger of Allah, may Allah bless him and grant him peace, said, "Kill him." Malik commented, "The Messenger of Allah, may Allah bless him and grant him peace, was not in ihram at the time, and Allah knows best}}
\hadithdefcmd{malik}{950}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَقْبَلَ مِنْ مَكَّةَ حَتَّى إِذَا كَانَ بِقُدَيْدٍ جَاءَهُ خَبَرٌ مِنَ الْمَدِينَةِ فَرَجَعَ فَدَخَلَ مَكَّةَ بِغَيْرِ إِحْرَامٍ ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، بِمِثْلِ ذَلِكَ ‏\hadithno{950}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar was coming from Makka and when he was at Qudayd, news came to him from Madina and he returned and entered Makka without ihram. Yahya related the same as that to me from Malik from Ibn Shihab}}
\hadithdefcmd{malik}{952}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ الدِّيلِيِّ، عَنْ مُحَمَّدِ بْنِ عِمْرَانَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّهُ قَالَ عَدَلَ إِلَىَّ عَبْدُ اللَّهِ بْنُ عُمَرَ وَأَنَا نَازِلٌ، تَحْتَ سَرْحَةٍ بِطَرِيقِ مَكَّةَ فَقَالَ مَا أَنْزَلَكَ تَحْتَ هَذِهِ السَّرْحَةِ فَقُلْتُ أَرَدْتُ ظِلَّهَا ‏.‏ فَقَالَ هَلْ غَيْرُ ذَلِكَ فَقُلْتُ لاَ مَا أَنْزَلَنِي إِلاَّ ذَلِكَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كُنْتَ بَيْنَ الأَخْشَبَيْنِ مِنْ مِنًى - وَنَفَخَ بِيَدِهِ نَحْوَ الْمَشْرِقِ - فَإِنَّ هُنَاكَ وَادِيًا يُقَالُ لَهُ السُّرَرُ بِهِ شَجَرَةٌ سُرَّ تَحْتَهَا سَبْعُونَ نَبِيًّا ‏"‏ ‏.‏\hadithno{952}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Amr ibn Halhala ad-Dili from Muhammad ibn lmran al-Ansari that his father said that Abdullah ibn Umar came upon him while he stopped for a rest under a tall tree on the road to Makka, and he said, "What has made you stop under this tall tree?" He replied that he sought it's shade. Abdullah ibn Umar said, "Anything besides that?" and he said, "No, that was the only. reason he stopped for a rest," and Abdullah ibn Umar said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'If you are between al-Akhshabayn (which are two mountains) near Mina,' indicating the east with his outspread hand, 'you will find a valley called as-Surar with a tree in it beneath which the umbilical cords of seventy prophets have been cut}}
\hadithdefcmd{malik}{953}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، مَرَّ بِامْرَأَةٍ مَجْذُومَةٍ وَهِيَ تَطُوفُ بِالْبَيْتِ فَقَالَ لَهَا يَا أَمَةَ اللَّهِ لاَ تُؤْذِي النَّاسَ لَوْ جَلَسْتِ فِي بَيْتِكِ ‏.‏ فَجَلَسَتْ فَمَرَّ بِهَا رَجُلٌ بَعْدَ ذَلِكَ فَقَالَ لَهَا إِنَّ الَّذِي كَانَ قَدْ نَهَاكِ قَدْ مَاتَ فَاخْرُجِي ‏.‏ فَقَالَتْ مَا كُنْتُ لأُطِيعَهُ حَيًّا وَأَعْصِيَهُ مَيِّتًا ‏.‏\hadithno{953}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Hazm from Ibn Abi Mulayka that Umar ibn al-Khattab passed a leprous woman doing tawaf of the House, and he said to her, "Slave of Allah, do not make people uneasy. Better that you stay in your house," so she did so. A man passed by her after that and said to her, "The one who forbade you has died, so come out," and she replied, "I am not going to obey him when he is alive and disobey him when he is dead}}
\hadithdefcmd{malik}{954}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يَقُولُ مَا بَيْنَ الرُّكْنِ وَالْبَابِ الْمُلْتَزَمُ ‏.‏\hadithno{954}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Abbas used to say that the area between the corner of the Black Stone and the door of the Kaba was called al-Multazam}}
\hadithdefcmd{malik}{955}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، أَنَّهُ سَمِعَهُ يَذْكُرُ، أَنَّ رَجُلاً، مَرَّ عَلَى أَبِي ذَرٍّ بِالرَّبَذَةِ وَأَنَّ أَبَا ذَرٍّ سَأَلَهُ أَيْنَ تُرِيدُ فَقَالَ أَرَدْتُ الْحَجَّ ‏.‏ فَقَالَ هَلْ نَزَعَكَ غَيْرُهُ فَقَالَ لاَ ‏.‏ قَالَ فَأْتَنِفِ الْعَمَلَ ‏.‏ قَالَ الرَّجُلُ فَخَرَجْتُ حَتَّى قَدِمْتُ مَكَّةَ فَمَكَثْتُ مَا شَاءَ اللَّهُ ثُمَّ إِذَا أَنَا بِالنَّاسِ مُنْقَصِفِينَ عَلَى رَجُلٍ فَضَاغَطْتُ عَلَيْهِ النَّاسَ فَإِذَا أَنَا بِالشَّيْخِ الَّذِي وَجَدْتُ بِالرَّبَذَةِ يَعْنِي أَبَا ذَرٍّ قَالَ فَلَمَّا رَآنِي عَرَفَنِي فَقَالَ هُوَ الَّذِي حَدَّثْتُكَ ‏.‏\hadithno{955}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said heard Muhammad ibn Yahya ibn Habban mentioning that a certain man passed Abu Dharr at ar-Rabadha (which was about 30 miles from Madina) and Abu Dharr asked him, "Where are you heading to?" and he replied, "I am intending to do hajj." Abu Dharr questioned, "Has anything else brought you out?" and he said, "No," so Abu Dharr said "Resume what you are doing wholeheartedly." The man related, "I went on till I came to Makka and I stayed as long as Allah willed. Suddenly, one time, I was with a crowd of people thronging about a man and I pushed through the people to him and it was the old man that I had come across at ar- Rabadha. When he saw me, he recognized me and said, 'Ah, you have done what I told you}}
\hadithdefcmd{malik}{956}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنْ الاِسْتِثْنَاءِ، فِي الْحَجِّ فَقَالَ أَوَيَصْنَعُ ذَلِكَ أَحَدٌ وَأَنْكَرَ ذَلِكَ ‏.‏ سُئِلَ مَالِكٌ هَلْ يَحْتَشُّ الرَّجُلُ لِدَابَّتِهِ مِنَ الْحَرَمِ فَقَالَ لاَ ‏.‏\hadithno{956}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he asked Ibn Shihab about making a condition in the hajj that one could leave ihram at any place where an obstacle befell one and he said, "Does anyone do that?' and disapproved of it. Malik was asked whether a man could cut plants from the Haram for his mount, and he said, "No}}
\hadithdefcmd{malik}{957}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا كَانَتْ تَقُولُ الصِّيَامُ لِمَنْ تَمَتَّعَ بِالْعُمْرَةِ إِلَى الْحَجِّ لِمَنْ لَمْ يَجِدْ هَدْيًا مَا بَيْنَ أَنْ يُهِلَّ بِالْحَجِّ إِلَى يَوْمِ عَرَفَةَ فَإِنْ لَمْ يَصُمْ صَامَ أَيَّامَ مِنًى ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ فِي ذَلِكَ مِثْلَ قَوْلِ عَائِشَةَ رضى الله تعالى عنها ‏\hadithno{957}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik said, concerning a woman who had never been on hajj, "If she doesn't have a mahram, or if she has, but he cannot come with her, she does not abandon Allah's making of the hajj obligatory for her. Let her go in a group of women." Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that A'isha umm al-muminin used to say, "Someone performing hajj at-tamattu who does not have a sacrificial animal fasts (three days) from the time he enters ihram for the hajj till the Day of Arafa, and if he does not fast then, he fasts the days of Mina." Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Umar used to say the same concerning that, as the words of A'isha, may Allah the Exalted be pleased with her}}
