% Auto-generated chapter 20 for abudawud
% Hadiths in this chapter: 161

\hadithdefcmd{abudawud}{2928}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ كُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ فَالأَمِيرُ الَّذِي عَلَى النَّاسِ رَاعٍ عَلَيْهِمْ وَهُوَ مَسْئُولٌ عَنْهُمْ وَالرَّجُلُ رَاعٍ عَلَى أَهْلِ بَيْتِهِ وَهُوَ مَسْئُولٌ عَنْهُمْ وَالْمَرْأَةُ رَاعِيَةٌ عَلَى بَيْتِ بَعْلِهَا وَوَلَدِهِ وَهِيَ مَسْئُولَةٌ عَنْهُمْ وَالَعَبْدُ رَاعٍ عَلَى مَالِ سَيِّدِهِ وَهُوَ مَسْئُولٌ عَنْهُ فَكُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏ ‏.‏\hadithno{2928}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7138) Sahih Muslim (1829)}\hadithtrans{Narrated 'Abdullah bin 'Umar:The Messenger of Allah (ﷺ) as saying: Each of you is a shepherd and each of you is responsible for his flock. The amir (ruler) who is over the people is a shepherd and is responsible for his flock; a man is a shepherd in charge of the inhabitants of his household and he is responsible for his flock; a woman is a shepherdess in charge of her husband's house and children and she is responsible for them; and a man's slave is a shepherd in charge of his master's property and he is responsible for it. So each of you is a shepherd and each of you is responsible for his flock}}
\hadithdefcmd{abudawud}{2929}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يُونُسُ، وَمَنْصُورٌ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ الرَّحْمَنِ بْنَ سَمُرَةَ لاَ تَسْأَلِ الإِمَارَةَ فَإِنَّكَ إِذَا أُعْطِيتَهَا عَنْ مَسْأَلَةٍ وُكِلْتَ فِيهَا إِلَى نَفْسِكَ وَإِنْ أُعْطِيتَهَا عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا ‏"‏ ‏.‏\hadithno{2929}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7147) Sahih Muslim (1652)}\hadithtrans{Narrated 'Abd al-Rahman b. Samurah:The Messenger of Allah (ﷺ) said to me: 'Abdul al-Rahman b. Samurah, do not ask for the position of commander, for if you are given it after asking you will be left to discharge it yourself, but if you are given it without asking you will be helped to discharge it}}
\hadithdefcmd{abudawud}{2930}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، حَدَّثَنَا خَالِدٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ أَخِيهِ، عَنْ بِشْرِ بْنِ قُرَّةَ الْكَلْبِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ انْطَلَقْتُ مَعَ رَجُلَيْنِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَتَشَهَّدَ أَحَدُهُمَا ثُمَّ قَالَ جِئْنَا لِتَسْتَعِينَ بِنَا عَلَى عَمَلِكَ ‏.‏ وَقَالَ الآخَرُ مِثْلَ قَوْلِ صَاحِبِهِ ‏.‏ فَقَالَ ‏ "‏ إِنَّ أَخْوَنَكُمْ عِنْدَنَا مَنْ طَلَبَهُ ‏"‏ ‏.‏ فَاعْتَذَرَ أَبُو مُوسَى إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَالَ لَمْ أَعْلَمْ لِمَا جَاءَا لَهُ ‏.‏ فَلَمْ يَسْتَعِنْ بِهِمَا عَلَى شَىْءٍ حَتَّى مَاتَ ‏.‏\hadithno{2930}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Musa:I went along with two men to see the Prophet (ﷺ). One of them recited tashahhud and said: We have come to you so that you may employ us for your work. The other also said the same thing. He (the Prophet) replied: The most faithless of you in our eyes is the one who asked for it (responsible post). Abu Musa then apologized to the Prophet (ﷺ) and said: I did not know why they came to you. He did not employ them for anything until he died}}
\hadithdefcmd{abudawud}{2931}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْمُخَرِّمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَخْلَفَ ابْنَ أُمِّ مَكْتُومٍ عَلَى الْمَدِينَةِ مَرَّتَيْنِ ‏.‏\hadithno{2931}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated Anas:The Prophet (ﷺ) appointed Ubn Umm Makthum as a governor of Medina (in his absence) twice}}
\hadithdefcmd{abudawud}{2932}{حَدَّثَنَا مُوسَى بْنُ عَامِرٍ الْمُرِّيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَرَادَ اللَّهُ بِالأَمِيرِ خَيْرًا جَعَلَ لَهُ وَزِيرَ صِدْقٍ إِنْ نَسِيَ ذَكَّرَهُ وَإِنْ ذَكَرَ أَعَانَهُ وَإِذَا أَرَادَ اللَّهُ بِهِ غَيْرَ ذَلِكَ جَعَلَ لَهُ وَزِيرَ سُوءٍ إِنْ نَسِيَ لَمْ يُذَكِّرْهُ وَإِنْ ذَكَرَ لَمْ يُعِنْهُ ‏"‏ ‏.‏\hadithno{2932}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: When Allah has a good purpose for a ruler, He appoints for him a sincere minister who reminds him if he forgets and helps him if he remembers; but when Allah has a different purpose from that for him. He appoints for him an evil minister who does not remind him if he forgets and does not help him if he remembers}}
\hadithdefcmd{abudawud}{2933}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنْ أَبِي سَلَمَةَ، سُلَيْمَانَ بْنِ سُلَيْمٍ عَنْ يَحْيَى بْنِ جَابِرٍ، عَنْ صَالِحِ بْنِ يَحْيَى بْنِ الْمِقْدَامِ، عَنْ جَدِّهِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَرَبَ عَلَى مَنْكِبِهِ ثُمَّ قَالَ لَهُ ‏ "‏ أَفْلَحْتَ يَا قُدَيْمُ إِنْ مُتَّ وَلَمْ تَكُنْ أَمِيرًا وَلاَ كَاتِبًا وَلاَ عَرِيفًا ‏"‏ ‏.‏\hadithno{2933}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Miqdam ibn Ma'dikarib: The Messenger of Allah (ﷺ) struck him on his shoulders and then said: You will attain success, Qudaym, if you die without having been a ruler, a secretary, or a chief}}
\hadithdefcmd{abudawud}{2934}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا غَالِبٌ الْقَطَّانُ، عَنْ رَجُلٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُمْ كَانُوا عَلَى مَنْهَلٍ مِنَ الْمَنَاهِلِ فَلَمَّا بَلَغَهُمُ الإِسْلاَمُ جَعَلَ صَاحِبُ الْمَاءِ لِقَوْمِهِ مِائَةً مِنَ الإِبِلِ عَلَى أَنْ يُسْلِمُوا فَأَسْلَمُوا وَقَسَمَ الإِبِلَ بَيْنَهُمْ وَبَدَا لَهُ أَنْ يَرْتَجِعَهَا مِنْهُمْ فَأَرْسَلَ ابْنَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ ائْتِ النَّبِيَّ صلى الله عليه وسلم فَقُلْ لَهُ إِنَّ أَبِي يُقْرِئُكَ السَّلاَمَ وَإِنَّهُ جَعَلَ لِقَوْمِهِ مِائَةً مِنَ الإِبِلِ عَلَى أَنْ يُسْلِمُوا فَأَسْلَمُوا وَقَسَمَ الإِبِلَ بَيْنَهُمْ وَبَدَا لَهُ أَنْ يَرْتَجِعَهَا مِنْهُمْ أَفَهُوَ أَحَقُّ بِهَا أَمْ هُمْ فَإِنْ قَالَ لَكَ نَعَمْ أَوْ لاَ فَقُلْ لَهُ إِنَّ أَبِي شَيْخٌ كَبِيرٌ وَهُوَ عَرِيفُ الْمَاءِ وَإِنَّهُ يَسْأَلُكَ أَنْ تَجْعَلَ لِيَ الْعِرَافَةَ بَعْدَهُ ‏.‏ فَأَتَاهُ فَقَالَ إِنَّ أَبِي يُقْرِئُكَ السَّلاَمَ ‏.‏ فَقَالَ ‏"‏ وَعَلَيْكَ وَعَلَى أَبِيكَ السَّلاَمُ ‏"‏ ‏.‏ فَقَالَ إِنَّ أَبِي جَعَلَ لِقَوْمِهِ مِائَةً مِنَ الإِبِلِ عَلَى أَنْ يُسْلِمُوا فَأَسْلَمُوا وَحَسُنَ إِسْلاَمُهُمْ ثُمَّ بَدَا لَهُ أَنْ يَرْتَجِعَهَا مِنْهُمْ أَفَهُوَ أَحَقُّ بِهَا أَمْ هُمْ فَقَالَ ‏"‏ إِنْ بَدَا لَهُ أَنْ يُسْلِمَهَا لَهُمْ فَلْيُسْلِمْهَا وَإِنْ بَدَا لَهُ أَنْ يَرْتَجِعَهَا فَهُوَ أَحَقُّ بِهَا مِنْهُمْ فَإِنْ هُمْ أَسْلَمُوا فَلَهُمْ إِسْلاَمُهُمْ وَإِنْ لَمْ يُسْلِمُوا قُوتِلُوا عَلَى الإِسْلاَمِ ‏"‏ ‏.‏ فَقَالَ إِنَّ أَبِي شَيْخٌ كَبِيرٌ وَهُوَ عَرِيفُ الْمَاءِ وَإِنَّهُ يَسْأَلُكَ أَنْ تَجْعَلَ لِيَ الْعِرَافَةَ بَعْدَهُ ‏.‏ فَقَالَ ‏"‏ إِنَّ الْعِرَافَةَ حَقٌّ وَلاَ بُدَّ لِلنَّاسِ مِنَ الْعُرَفَاءِ وَلَكِنَّ الْعُرَفَاءَ فِي النَّارِ ‏"‏ ‏.‏\hadithno{2934}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ghalib al-Qattan: Ghalib quoted a man who stated on the authority of his father that his grandfather reported: They lived at one of the springs. When Islam reached them, the master of the spring offered his people one hundred camels if they embraced Islam. So they embraced Islam, and he distributed the camels among them. But it occurred to him that he should take the camels back from them. He sent his son to the Prophet (ﷺ) and said to him: Go to the Prophet (ﷺ) and tell him: My father extends his greetings to you. He asked his people to give them one hundred camels if they embraced Islam, and they embraced Islam. He divided the camels among them. But it occurred to him then that he should withdraw his camels from them. Is he more entitled to them or we? If he says: Yes or no, then tell him: My father is an old man, and he is the chief of the people living at the water. He has requested you to make me chief after him. He came to him and said: My father has extended his greetings to you. He replied: On you and you father be peace. He said: My father asked his people to give them one hundred camels if they embraced Islam. So they embraced Islam, and their belief in Islam is good. Then it occurred to him that he should take his camels back from them. Is he more entitled to them or are they? He said: If he likes to give them the camels, he may give them; and if he likes to take them back, he is more entitled to them than his people. If they embraced Islam, then for them is their Islam. If they do not embrace Islam, they will be fought against in the cause of Islam. He said: My father is an old man; he is the chief of the people living at the spring. He has asked you to appoint me chief after him. He replied: The office of a chief is necessary, for people must have chiefs, but the chiefs will go to Hell}}
\hadithdefcmd{abudawud}{2935}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، عَنْ يَزِيدَ بْنِ كَعْبٍ، عَنْ عَمْرِو بْنِ مَالِكٍ، عَنْ أَبِي الْجَوْزَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ السِّجِلُّ كَاتِبٌ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2935}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) has a secretary named Sijill}}
\hadithdefcmd{abudawud}{2936}{حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ الأَسْبَاطِيُّ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْعَامِلُ عَلَى الصَّدَقَةِ بِالْحَقِّ كَالْغَازِي فِي سَبِيلِ اللَّهِ حَتَّى يَرْجِعَ إِلَى بَيْتِهِ ‏"‏ ‏.‏\hadithno{2936}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Rafi' ibn Khadij: I heard the Messenger of Allah (ﷺ) say: The official who collects sadaqah (zakat) in a just manner is like him who fights in Allah's path till he returns home}}
\hadithdefcmd{abudawud}{2937}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شِمَاسَةَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ صَاحِبُ مَكْسٍ ‏"‏ ‏.‏\hadithno{2937}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Uqbah ibn Amir: I heard the Messenger of Allah (ﷺ) as saying: One who wrongfully takes an extra tax (sahib maks) will not enter Paradise}}
\hadithdefcmd{abudawud}{2938}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْقَطَّانُ، عَنِ ابْنِ مَغْرَاءَ، عَنِ ابْنِ إِسْحَاقَ، قَالَ الَّذِي يَعْشُرُ النَّاسَ يَعْنِي صَاحِبَ الْمَكْسِ ‏.‏\hadithno{2938}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn Ishaq:Sahib maks means one who (receives) tithes (from) people}}
\hadithdefcmd{abudawud}{2939}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، وَسَلَمَةُ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ عُمَرُ إِنِّي إِنْ لاَ أَسْتَخْلِفْ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَسْتَخْلِفْ وَإِنْ أَسْتَخْلِفْ فَإِنَّ أَبَا بَكْرٍ قَدِ اسْتَخْلَفَ ‏.‏ قَالَ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ ذَكَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ فَعَلِمْتُ أَنَّهُ لاَ يَعْدِلُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم أَحَدًا وَأَنَّهُ غَيْرُ مُسْتَخْلِفٍ ‏.‏\hadithno{2939}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1823)}\hadithtrans{Narrated Ibn 'Umar:'Umar said: I shall not appoint a successor, for the Messenger of Allah (ﷺ) did not appoint a successor. If I appoint a successor (I can do so), for Abu Bakr had appointed a successor. He Ibn 'Umar) said: I swear by Allah, he did not mention (anyone) but the Messenger of Allah (ﷺ) and Abu Bakr. So I learnt he would not equate anyone with the Messenger of Allah (ﷺ), for he did not appoint any successor}}
\hadithdefcmd{abudawud}{2940}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نُبَايِعُ النَّبِيَّ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ وَيُلَقِّنُنَا فِيمَا اسْتَطَعْتَ ‏.‏\hadithno{2940}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2702) Sahih Muslim (1867)}\hadithtrans{Narrated Ibn 'Umar:We used to take the oath of allegiance to the Prophet (ﷺ) to hear and obey, and he would tell: In What I am able}}
\hadithdefcmd{abudawud}{2941}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، رضى الله عنها أَخْبَرَتْهُ عَنْ بَيْعَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم النِّسَاءَ قَالَتْ مَا مَسَّ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَ امْرَأَةٍ قَطُّ إِلاَّ أَنْ يَأْخُذَ عَلَيْهَا فَإِذَا أَخَذَ عَلَيْهَا فَأَعْطَتْهُ قَالَ ‏ "‏ اذْهَبِي فَقَدْ بَايَعْتُكِ ‏"‏ ‏.‏\hadithno{2941}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7214) Sahih Muslim (1866)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) never touched the hand of woman, but he received the oath of allegiance from her. When he received the oath of allegiance from her, she gave it to him, and he said: Go, I have received your oath of allegiance}}
\hadithdefcmd{abudawud}{2942}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنِي أَبُو عَقِيلٍ، زُهْرَةُ بْنُ مَعْبَدٍ عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ هِشَامٍ، قَالَ وَكَانَ قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم وَذَهَبَتْ بِهِ أُمُّهُ زَيْنَبُ بِنْتُ حُمَيْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ بَايِعْهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ صَغِيرٌ ‏"‏ ‏.‏ فَمَسَحَ رَأْسَهُ ‏.‏\hadithno{2942}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7210)}\hadithtrans{Narrated 'Abd Alla b. Hisham, :who was a Companion, reported that his mother Zainab daughter of Humain went to the Messenger of Allah (ﷺ) and said: Messenger of Allah, receive the oath of allegiance from him. The Messenger of Allah (ﷺ) said: He is Minor. He then wiped his head}}
\hadithdefcmd{abudawud}{2943}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ أَبُو طَالِبٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عَبْدِ الْوَارِثِ بْنِ سَعِيدٍ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اسْتَعْمَلْنَاهُ عَلَى عَمَلٍ فَرَزَقْنَاهُ رِزْقًا فَمَا أَخَذَ بَعْدَ ذَلِكَ فَهُوَ غُلُولٌ ‏"‏ ‏.‏\hadithno{2943}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraidah:The Prophet (ﷺ) as saying: When we appoint someone to an administrative post and provide him with an allowance, anything he takes beyond that is unfaithful dealing}}
\hadithdefcmd{abudawud}{2944}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا لَيْثٌ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنِ ابْنِ السَّاعِدِيِّ، قَالَ اسْتَعْمَلَنِي عُمَرُ عَلَى الصَّدَقَةِ فَلَمَّا فَرَغْتُ أَمَرَ لِي بِعُمَالَةٍ فَقُلْتُ إِنَّمَا عَمِلْتُ لِلَّهِ ‏.‏ قَالَ خُذْ مَا أُعْطِيتَ فَإِنِّي قَدْ عَمِلْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَمَّلَنِي ‏.‏\hadithno{2944}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1045)}\hadithtrans{Narrated Ibn al-Sa'idi:'Umar reported me to collect the sadaqah (i.e. zakat). When I became free, he ordered to give me payment for it. I said: I have worked for the sake of Allah. He said: Take what you have been given, for I held an administrative post in the time of the Messenger of Allah (ﷺ), and he gave me payment for it}}
\hadithdefcmd{abudawud}{2945}{حَدَّثَنَا مُوسَى بْنُ مَرْوَانَ الرَّقِّيُّ، حَدَّثَنَا الْمُعَافَى، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الْحَارِثِ بْنِ يَزِيدَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ كَانَ لَنَا عَامِلاً فَلْيَكْتَسِبْ زَوْجَةً فَإِنْ لَمْ يَكُنْ لَهُ خَادِمٌ فَلْيَكْتَسِبْ خَادِمًا فَإِنْ لَمْ يَكُنْ لَهُ مَسْكَنٌ فَلْيَكْتَسِبْ مَسْكَنًا ‏"‏ ‏.‏ قَالَ قَالَ أَبُو بَكْرٍ أُخْبِرْتُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اتَّخَذَ غَيْرَ ذَلِكَ فَهُوَ غَالٌّ أَوْ سَارِقٌ ‏"‏ ‏.‏\hadithno{2945}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Mustawrid ibn Shaddad: Al-Mustawrid heard the Prophet (ﷺ) say: He who acts as an employee for us must get a wife; if he has not a servant, he must get one, and if he has not a dwelling, he must get one. He said that Abu Bakr reported: I was told that the Prophet (ﷺ) said: He who takes anything else he is unfaithful or thief}}
\hadithdefcmd{abudawud}{2946}{حَدَّثَنَا ابْنُ السَّرْحِ، وَابْنُ أَبِي خَلَفٍ، - لَفْظُهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً مِنَ الأَزْدِ يُقَالُ لَهُ ابْنُ اللُّتْبِيَّةِ - قَالَ ابْنُ السَّرْحِ ابْنُ الأُتْبِيَّةِ - عَلَى الصَّدَقَةِ فَجَاءَ فَقَالَ هَذَا لَكُمْ وَهَذَا أُهْدِيَ لِي ‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ ‏"‏ مَا بَالُ الْعَامِلِ نَبْعَثُهُ فَيَجِيءُ فَيَقُولُ هَذَا لَكُمْ وَهَذَا أُهْدِيَ لِي ‏.‏ أَلاَّ جَلَسَ فِي بَيْتِ أُمِّهِ أَوْ أَبِيهِ فَيَنْظُرَ أَيُهْدَى لَهُ أَمْ لاَ لاَ يَأْتِي أَحَدٌ مِنْكُمْ بِشَىْءٍ مِنْ ذَلِكَ إِلاَّ جَاءَ بِهِ يَوْمَ الْقِيَامَةِ إِنْ كَانَ بَعِيرًا فَلَهُ رُغَاءٌ أَوْ بَقَرَةً فَلَهَا خُوَارٌ أَوْ شَاةً تَيْعَرُ ‏"‏ ‏.‏ ثُمَّ رَفَعَ يَدَيْهِ حَتَّى رَأَيْنَا عُفْرَةَ إِبْطَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏\hadithno{2946}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7174) Sahih Muslim (1832)}\hadithtrans{Narrated Abu Humaid al-Sa'idi:The Prophet (ﷺ) appointed a man of Azd called Ibn al-Lutbiyayah (to collect sadaqah). The narrator Ibn al-Sarh said: (He appointed) Ibn al-Utbiyyah to collect the sadaqah. When he returned he said: This is for you and this was given to me as present. So the Prophet (ﷺ) stood on the pulpit, and after praising and extolling Allah he said: What is the matter with a collector of sadaqah. We send him (to collect sadaqah), and when he return he says: This is for you and this is a present which was given to me. Why did he not sit in his father's or mother's house and see whether it would be given to him or not ? Whoever takes any of it will inevitably bring it on the Day of Resurrection, be it a camel which rumbles, an ox which bellows, or sheep which-bleats. Then raising his arms so that we could see where the hair grow under his armpits, he said: O Allah, have I given full information ? O Allah, have I given full information ?}}
\hadithdefcmd{abudawud}{2947}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مُطَرِّفٍ، عَنْ أَبِي الْجَهْمِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم سَاعِيًا ثُمَّ قَالَ ‏"‏ انْطَلِقْ أَبَا مَسْعُودٍ وَلاَ أُلْفِيَنَّكَ يَوْمَ الْقِيَامَةِ تَجِيءُ عَلَى ظَهْرِكَ بَعِيرٌ مِنْ إِبِلِ الصَّدَقَةِ لَهُ رُغَاءٌ قَدْ غَلَلْتَهُ ‏"‏ ‏.‏ قَالَ إِذًا لاَ أَنْطَلِقُ ‏.‏ قَالَ ‏"‏ إِذًا لاَ أُكْرِهُكَ ‏"‏ ‏.‏\hadithno{2947}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuMas'ud al-Ansari: The Prophet (ﷺ) appointed me to collect sadaqah and then said: Go, AbuMas'ud, I should not find you on the Day of Judgment carrying a camel of sadaqah on your back, which rumbles, the one you have taken by unfaithful dealing in sadaqah. He said: If it is so, I will not go. He said: Then I do not force you}}
\hadithdefcmd{abudawud}{2948}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي ابْنُ أَبِي مَرْيَمَ، أَنَّ الْقَاسِمَ بْنَ مُخَيْمِرَةَ، أَخْبَرَهُ أَنَّ أَبَا مَرْيَمَ الأَزْدِيَّ أَخْبَرَهُ قَالَ دَخَلْتُ عَلَى مُعَاوِيَةَ فَقَالَ مَا أَنْعَمَنَا بِكَ أَبَا فُلاَنٍ ‏.‏ وَهِيَ كَلِمَةٌ تَقُولُهَا الْعَرَبُ فَقُلْتُ حَدِيثًا سَمِعْتُهُ أُخْبِرُكَ بِهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ وَلاَّهُ اللَّهُ عَزَّ وَجَلَّ شَيْئًا مِنْ أَمْرِ الْمُسْلِمِينَ فَاحْتَجَبَ دُونَ حَاجَتِهِمْ وَخَلَّتِهِمْ وَفَقْرِهِمُ احْتَجَبَ اللَّهُ عَنْهُ دُونَ حَاجَتِهِ وَخَلَّتِهِ وَفَقْرِهِ ‏"‏ ‏.‏ قَالَ فَجَعَلَ رَجُلاً عَلَى حَوَائِجِ النَّاسِ ‏.‏\hadithno{2948}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuMaryam al-Azdi: When I entered upon Mu'awiyah, he said: How good your visit is to us, O father of so-and-so. (This is an idiom used by the Arabs on such occasions). I said: I tell you a tradition which I heard (from the Prophet). I heard the Messenger of Allah (ﷺ) say: If Allah puts anyone in the position of authority over the affairs of the Muslims, and he secludes himself (from them), not fulfilling their needs, wants, and poverty, Allah will keep Himself away from him, not fulfilling his need, want and poverty. He said: He (Mu'awiyah) appointed a man to fulfil the needs of the people}}
\hadithdefcmd{abudawud}{2949}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا بِهِ أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أُوتِيكُمْ مِنْ شَىْءٍ وَمَا أَمْنَعُكُمُوهُ إِنْ أَنَا إِلاَّ خَازِنٌ أَضَعُ حَيْثُ أُمِرْتُ ‏"‏ ‏.‏\hadithno{2949}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: It is not on my own that I give you or withhold from you: I am just a treasure, putting it where I have been commanded}}
\hadithdefcmd{abudawud}{2950}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، قَالَ ذَكَرَ عُمَرُ بْنُ الْخَطَّابِ يَوْمًا الْفَىْءَ فَقَالَ مَا أَنَا بِأَحَقَّ، بِهَذَا الْفَىْءِ مِنْكُمْ وَمَا أَحَدٌ مِنَّا بِأَحَقَّ بِهِ مِنْ أَحَدٍ إِلاَّ أَنَّا عَلَى مَنَازِلِنَا مِنْ كِتَابِ اللَّهِ عَزَّ وَجَلَّ وَقَسْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَالرَّجُلُ وَقِدَمُهُ وَالرَّجُلُ وَبَلاَؤُهُ وَالرَّجُلُ وَعِيَالُهُ وَالرَّجُلُ وَحَاجَتُهُ ‏.‏\hadithno{2950}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: Malik ibn Aws ibn al-Hadthan said: One day Umar ibn al-Khattab mentioned the spoils of war and said: I am not more entitled to this spoil of war than you; and none of us is more entitled to it than another, except that we occupy our positions fixed by the Book of Allah, Who is Great and Glorious, and the division made by the Messenger of Allah (ﷺ), people being arranged according to their precedence in accepting Islam, the hardship they have endured their having children and their need}}
\hadithdefcmd{abudawud}{2951}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، دَخَلَ عَلَى مُعَاوِيَةَ فَقَالَ حَاجَتُكَ يَا أَبَا عَبْدِ الرَّحْمَنِ فَقَالَ عَطَاءُ الْمُحَرَّرِينَ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَوَّلَ مَا جَاءَهُ شَىْءٌ بَدَأَ بِالْمُحَرَّرِينَ ‏.‏\hadithno{2951}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: Zayd ibn Aslam said: Abdullah ibn Umar entered upon Mu'awiyah. He asked: (Tell me) your need, AbuAbdurRahman. He replied: Give (the spoils) to those who were set free, for I saw the first thing the Messenger of Allah (ﷺ) did when anything came to him was to give something to those who had been set free}}
\hadithdefcmd{abudawud}{2952}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْقَاسِمِ بْنِ عَبَّاسٍ، عَنْ عَبْدِ اللَّهِ بْنِ نِيَارٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عَنْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِظَبْيَةٍ فِيهَا خَرَزٌ فَقَسَمَهَا لِلْحُرَّةِ وَالأَمَةِ ‏.‏ قَالَتْ عَائِشَةُ كَانَ أَبِي رضى الله عنه يَقْسِمُ لِلْحُرِّ وَالْعَبْدِ ‏.‏\hadithno{2952}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) was brought a pouch containing bead and divided it among free women and slave women. Aisha said: My father used to divide things between free men and slave}}
\hadithdefcmd{abudawud}{2953}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا ابْنُ الْمُصَفَّى، قَالَ حَدَّثَنَا أَبُو الْمُغِيرَةِ، جَمِيعًا عَنْ صَفْوَانَ بْنِ عَمْرٍو، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَتَاهُ الْفَىْءُ قَسَمَهُ فِي يَوْمِهِ فَأَعْطَى الآهِلَ حَظَّيْنِ وَأَعْطَى الْعَزَبَ حَظًّا ‏.‏ زَادَ ابْنُ الْمُصَفَّى فَدُعِينَا وَكُنْتُ أُدْعَى قَبْلَ عَمَّارٍ فَدُعِيتُ فَأَعْطَانِي حَظَّيْنِ وَكَانَ لِي أَهْلٌ ثُمَّ دُعِيَ بَعْدِي عَمَّارُ بْنُ يَاسِرٍ فَأَعْطَى لَهُ حَظًّا وَاحِدًا ‏.‏\hadithno{2953}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Awf bin Malik:When the spoils (fai') came to the Messenger of Allah (ﷺ), he divided it that day ; he gave two portions to a married man and one to a bachelor. The narrator Ibn al-Musaffa added: We were summoned, and I would be summoned before 'Ammar. So I was summoned and he gave me two portions, for I had a family ; then 'Ammar b. Yasir was summoned after me and given one}}
\hadithdefcmd{abudawud}{2954}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ مَنْ تَرَكَ مَالاً فَلأَهْلِهِ وَمَنْ تَرَكَ دَيْنًا أَوْ ضَيَاعًا فَإِلَىَّ وَعَلَىَّ ‏"‏ ‏.‏\hadithno{2954}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: I am nearer to the believers than themselves, so if anyone leaves property, it goes to his heirs, and if anyone leaves debt and dependants, let the matter come to me and I shall be responsible}}
\hadithdefcmd{abudawud}{2955}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ وَمَنْ تَرَكَ كَلاًّ فَإِلَيْنَا ‏"‏ ‏.‏\hadithno{2955}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6763) Sahih Muslim (1619)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: If anyone leaves property, it goes to his heirs. And if anyone leaves dependents (without resources), they come to us}}
\hadithdefcmd{abudawud}{2956}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ أَنَا أَوْلَى بِكُلِّ مُؤْمِنٍ مِنْ نَفْسِهِ فَأَيُّمَا رَجُلٍ مَاتَ وَتَرَكَ دَيْنًا فَإِلَىَّ وَمَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{2956}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir b. 'Abd Allah :The Prophet (ﷺ) as saying: I am nearer to every believer than himself, and if anyone leaves, it goes to his heirs}}
\hadithdefcmd{abudawud}{2957}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عُرِضَهُ يَوْمَ أُحُدٍ وَهُوَ ابْنُ أَرْبَعَ عَشْرَةَ فَلَمْ يُجِزْهُ وَعُرِضَهُ يَوْمَ الْخَنْدَقِ وَهُوَ ابْنُ خَمْسَ عَشْرَةَ سَنَةً فَأَجَازَهُ ‏.‏\hadithno{2957}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4097)}\hadithtrans{Narrated Nafi':That Ibn 'Umar was presented before the Prophet (ﷺ) on the day of Uhud, when he was fourteen years old, but he did not allow him. He was again presented to him on the day of Khandaq (the battle of Trench) when he was fifteen years old, he allowed him}}
\hadithdefcmd{abudawud}{2958}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي الْحَوَارِيِّ، حَدَّثَنَا سُلَيْمُ بْنُ مُطَيْرٍ، - شَيْخٌ مِنْ أَهْلِ وَادِي الْقُرَى - قَالَ حَدَّثَنِي أَبِي مُطَيْرٌ أَنَّهُ خَرَجَ حَاجًّا حَتَّى إِذَا كَانَ بِالسُّوَيْدَاءِ إِذَا أَنَا بِرَجُلٍ قَدْ جَاءَ كَأَنَّهُ يَطْلُبُ دَوَاءً وَحُضُضًا فَقَالَ أَخْبَرَنِي مَنْ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَهُوَ يَعِظُ النَّاسَ وَيَأْمُرُهُمْ وَيَنْهَاهُمْ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ خُذُوا الْعَطَاءَ مَا كَانَ عَطَاءً فَإِذَا تَجَاحَفَتْ قُرَيْشٌ عَلَى الْمُلْكِ وَكَانَ عَنْ دِينِ أَحَدِكُمْ فَدَعُوهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ الْمُبَارَكِ عَنْ مُحَمَّدِ بْنِ يَسَارٍ عَنْ سُلَيْمِ بْنِ مُطَيْرٍ ‏.‏\hadithno{2958}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated A man: Sulaym ibn Mutayr reported on the authority of his father that Mutayr went away to perform hajj. When he reached as-Suwaida', a man suddenly came searching for medicine and ammonium anthorhizum extract, and he said: A man who heard the Messenger of Allah (ﷺ) addressing the people commanding and prohibiting them, told me that he said: O people, accept presents so long as they remain presents; but when the Quraysh quarrel about the rule, and the presents are given for the religion of one of you, then leave them alone. Abu Dawud said: This tradition has been transmitted by Ibn al-Mubarak from Muhammad b. Yasar from Sulaim b. Mutair}}
\hadithdefcmd{abudawud}{2959}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُلَيْمُ بْنُ مُطَيْرٍ، - مِنْ أَهْلِ وَادِي الْقُرَى - عَنْ أَبِيهِ، أَنَّهُ حَدَّثَهُ قَالَ سَمِعْتُ رَجُلاً، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ فَأَمَرَ النَّاسَ وَنَهَاهُمْ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ ثُمَّ قَالَ ‏"‏ إِذَا تَجَاحَفَتْ قُرَيْشٌ عَلَى الْمُلْكِ فِيمَا بَيْنَهَا وَعَادَ الْعَطَاءُ أَوْ كَانَ رُشًا فَدَعُوهُ ‏"‏ ‏.‏ فَقِيلَ مَنْ هَذَا قَالُوا هَذَا ذُو الزَّوَائِدِ صَاحِبُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2959}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Dhul-Zawa'id: Mutayr said: I heard a man say: I heard the Messenger of Allah (ﷺ) in the Farewell Pilgrimage. He was commanding and prohibiting them (the people). He said: O Allah, did I give full information? They said: Yes. He said: When the Quraysh quarrel about the rule among themselves, and the presents become bribery, them leave them. The people were asked: Who was he (who narrated this tradition)? They said: This was Dhul-Zawa'id, a Companion of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{2960}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ الأَنْصَارِيِّ، أَنَّ جَيْشًا، مِنَ الأَنْصَارِ كَانُوا بِأَرْضِ فَارِسَ مَعَ أَمِيرِهِمْ وَكَانَ عُمَرُ يُعْقِبُ الْجُيُوشَ فِي كُلِّ عَامٍ فَشُغِلَ عَنْهُمْ عُمَرُ فَلَمَّا مَرَّ الأَجَلُ قَفَلَ أَهْلُ ذَلِكَ الثَّغْرِ فَاشْتَدَّ عَلَيْهِمْ وَتَوَاعَدَهُمْ وَهُمْ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا عُمَرُ إِنَّكَ غَفَلْتَ عَنَّا وَتَرَكْتَ فِينَا الَّذِي أَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِعْقَابِ بَعْضِ الْغَزِيَّةِ بَعْضًا ‏.‏\hadithno{2960}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abd Allah b. Ka'b b. Malik al-Ansari:An expedition of the Ansar was operating in Persia with their leader. 'Umar used to send expeditions by turns every year, but he neglected them. When the expired, the people of expedition appointed on the frontier came back. He ('Umar) took serious action against them and threatened them, though they were the Companions of the Messenger of Allah (ﷺ). They said: 'Umar you neglected us, and abandoned the practice for which the Messenger of Allah (ﷺ) commanded to send the detachments by turns}}
\hadithdefcmd{abudawud}{2961}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَائِذٍ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنِي فِيمَا، حَدَّثَهُ ابْنٌ لِعَدِيِّ بْنِ عَدِيٍّ الْكِنْدِيِّ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، كَتَبَ إِنَّ مَنْ سَأَلَ عَنْ مَوَاضِعِ الْفَىْءِ، فَهُوَ مَا حَكَمَ فِيهِ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه فَرَآهُ الْمُؤْمِنُونَ عَدْلاً مُوَافِقًا لِقَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ جَعَلَ اللَّهُ الْحَقَّ عَلَى لِسَانِ عُمَرَ وَقَلْبِهِ ‏"‏ ‏.‏ فَرَضَ الأَعْطِيَةَ وَعَقَدَ لأَهْلِ الأَدْيَانِ ذِمَّةً بِمَا فُرِضَ عَلَيْهِمْ مِنَ الْجِزْيَةِ لَمْ يَضْرِبْ فِيهَا بِخُمُسٍ وَلاَ مَغْنَمٍ ‏.‏\hadithno{2961}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad}\hadithtrans{Narrated Umar ibn al-Khattab: A son of Adi ibn Adi al-Kindi said that Umar ibn AbdulAziz wrote (to his governors): If anyone asks about the places where spoils (fay') should be spent, that should be done in accordance with the decision made by Umar ibn al-Khattab (Allah be pleased with him). The believers considered him to be just, according to the saying of the Prophet (ﷺ): Allah has placed truth upon Umar's tongue and heart. He fixed stipends for Muslims, and provided protection for the people of other religions by levying jizyah (poll-tax) on them, deducting no fifth from it, nor taking it as booty}}
\hadithdefcmd{abudawud}{2962}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مَكْحُولٍ، عَنْ غُضَيْفِ بْنِ الْحَارِثِ، عَنْ أَبِي ذَرٍّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ وَضَعَ الْحَقَّ عَلَى لِسَانِ عُمَرَ يَقُولُ بِهِ ‏"‏ ‏.‏\hadithno{2962}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuDharr: I heard the Messenger of Allah (ﷺ) say: Allah, the Exalted, has placed truth on Umar's tongue and he speaks it}}
\hadithdefcmd{abudawud}{2963}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ الْمَعْنَى، قَالاَ حَدَّثَنَا بِشْرُ بْنُ عُمَرَ الزَّهْرَانِيُّ، حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، قَالَ أَرْسَلَ إِلَىَّ عُمَرُ حِينَ تَعَالَى النَّهَارُ فَجِئْتُهُ فَوَجَدْتُهُ جَالِسًا عَلَى سَرِيرٍ مُفْضِيًا إِلَى رِمَالِهِ فَقَالَ حِينَ دَخَلْتُ عَلَيْهِ يَا مَالُ إِنَّهُ قَدْ دَفَّ أَهْلُ أَبْيَاتٍ مِنْ قَوْمِكَ وَإِنِّي قَدْ أَمَرْتُ فِيهِمْ بِشَىْءٍ فَاقْسِمْ فِيهِمْ ‏.‏ قُلْتُ لَوْ أَمَرْتَ غَيْرِي بِذَلِكَ ‏.‏ فَقَالَ خُذْهُ ‏.‏ فَجَاءَهُ يَرْفَأُ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ هَلْ لَكَ فِي عُثْمَانَ بْنِ عَفَّانَ وَعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَالزُّبَيْرِ بْنِ الْعَوَّامِ وَسَعْدِ بْنِ أَبِي وَقَّاصٍ قَالَ نَعَمْ ‏.‏ فَأَذِنَ لَهُمْ فَدَخَلُوا ثُمَّ جَاءَهُ يَرْفَأُ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ هَلْ لَكَ فِي الْعَبَّاسِ وَعَلِيٍّ قَالَ نَعَمْ ‏.‏ فَأَذِنَ لَهُمْ فَدَخَلُوا فَقَالَ الْعَبَّاسُ يَا أَمِيرَ الْمُؤْمِنِينَ اقْضِ بَيْنِي وَبَيْنَ هَذَا - يَعْنِي عَلِيًّا - فَقَالَ بَعْضُهُمْ أَجَلْ يَا أَمِيرَ الْمُؤْمِنِينَ اقْضِ بَيْنَهُمَا وَارْحَمْهُمَا ‏.‏ قَالَ مَالِكُ بْنُ أَوْسٍ خُيِّلَ إِلَىَّ أَنَّهُمَا قَدَّمَا أُولَئِكَ النَّفَرَ لِذَلِكَ ‏.‏ فَقَالَ عُمَرُ رَحِمَهُ اللَّهُ اتَّئِدَا ‏.‏ ثُمَّ أَقْبَلَ عَلَى أُولَئِكَ الرَّهْطِ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ ثُمَّ أَقْبَلَ عَلَى عَلِيٍّ وَالْعَبَّاسِ رضى الله عنهما فَقَالَ أَنْشُدُكُمَا بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ هَلْ تَعْلَمَانِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ فَقَالاَ نَعَمْ ‏.‏ قَالَ فَإِنَّ اللَّهَ خَصَّ رَسُولَهُ صلى الله عليه وسلم بِخَاصَّةٍ لَمْ يَخُصَّ بِهَا أَحَدًا مِنَ النَّاسِ فَقَالَ اللَّهُ تَعَالَى ‏\{‏ وَمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْهُمْ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلاَ رِكَابٍ وَلَكِنَّ اللَّهَ يُسَلِّطُ رُسُلَهُ عَلَى مَنْ يَشَاءُ وَاللَّهُ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏\}‏ وَكَانَ اللَّهُ أَفَاءَ عَلَى رَسُولِهِ بَنِي النَّضِيرِ فَوَاللَّهِ مَا اسْتَأْثَرَ بِهَا عَلَيْكُمْ وَلاَ أَخَذَهَا دُونَكُمْ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْخُذُ مِنْهَا نَفَقَةَ سَنَةٍ أَوْ نَفَقَتَهُ وَنَفَقَةَ أَهْلِهِ سَنَةً وَيَجْعَلُ مَا بَقِيَ أُسْوَةَ الْمَالِ ‏.‏ ثُمَّ أَقْبَلَ عَلَى أُولَئِكَ الرَّهْطِ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ هَلْ تَعْلَمُونَ ذَلِكَ قَالُوا نَعَمْ ‏.‏ ثُمَّ أَقْبَلَ عَلَى الْعَبَّاسِ وَعَلِيٍّ رضى الله عنهما فَقَالَ أَنْشُدُكُمَا بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ هَلْ تَعْلَمَانِ ذَلِكَ قَالاَ نَعَمْ ‏.‏ فَلَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجِئْتَ أَنْتَ وَهَذَا إِلَى أَبِي بَكْرٍ تَطْلُبُ أَنْتَ مِيرَاثَكَ مِنِ ابْنِ أَخِيكَ وَيَطْلُبُ هَذَا مِيرَاثَ امْرَأَتِهِ مِنْ أَبِيهَا فَقَالَ أَبُو بَكْرٍ رَحِمَهُ اللَّهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ وَاللَّهُ يَعْلَمُ إِنَّهُ لَصَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ فَوَلِيَهَا أَبُو بَكْرٍ فَلَمَّا تُوُفِّيَ أَبُو بَكْرٍ قُلْتُ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَوَلِيُّ أَبِي بَكْرٍ فَوَلِيتُهَا مَا شَاءَ اللَّهُ أَنْ أَلِيَهَا فَجِئْتَ أَنْتَ وَهَذَا وَأَنْتُمَا جَمِيعٌ وَأَمْرُكُمَا وَاحِدٌ فَسَأَلْتُمَانِيهَا فَقُلْتُ إِنْ شِئْتُمَا أَنْ أَدْفَعَهَا إِلَيْكُمَا عَلَى أَنَّ عَلَيْكُمَا عَهْدَ اللَّهِ أَنْ تَلِيَاهَا بِالَّذِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَلِيهَا فَأَخَذْتُمَاهَا مِنِّي عَلَى ذَلِكَ ثُمَّ جِئْتُمَانِي لأَقْضِيَ بَيْنَكُمَا بِغَيْرِ ذَلِكَ وَاللَّهِ لاَ أَقْضِي بَيْنَكُمَا بِغَيْرِ ذَلِكَ حَتَّى تَقُومَ السَّاعَةُ فَإِنْ عَجَزْتُمَا عَنْهَا فَرُدَّاهَا إِلَىَّ ‏.‏ قَالَ أَبُو دَاوُدَ إِنَّمَا سَأَلاَهُ أَنْ يَكُونَ يُصَيِّرُهُ بَيْنَهُمَا نِصْفَيْنِ لاَ أَنَّهُمَا جَهِلاَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ فَإِنَّهُمَا كَانَا لاَ يَطْلُبَانِ إِلاَّ الصَّوَابَ ‏.‏ فَقَالَ عُمَرُ لاَ أُوقِعُ عَلَيْهِ اسْمَ الْقَسْمِ أَدَعُهُ عَلَى مَا هُوَ عَلَيْهِ ‏.‏\hadithno{2963}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7305) Sahih Muslim (1757)}\hadithtrans{Narrated Malik b. Aws b. Al-Hadathan: 'Umar sent for me when the day rose high. I found him sitting on a couch without cover. When I entered upon him, he said: Malik, some people of you tribe gradually came here, and I have ordered to give them something, so distribute it among them. I said: If you assigned this (work) to some other person, (it would be better). He said: Take it. Then Yarfa' came to him and said: Commander of the Faithful, will you permit 'Uthman b. 'Affan, 'Abd al-Rahman b. 'Awf, al-Zubair b. al-'Awwam, and Sa'd b, Abi Waqqas (to enter) ? He said: Yes. So he permitted them and they entered. Yarfa' again came to him and said: Commander of the Faithful, would you permit al-'Abbas and 'Ali ? He said: Yes. He then permitted them and they entered. Al-'Abbas said: Commander of Faithful, decide between me and this, referring to 'Ali. Some of them said: Yes, Commander of the Faithful, decide between them and give them comfort. Malik b. Aws said: It occurred to me that both of them brought the other people for this. 'Umar said: Show patience (do not make haste). He then turned towards those people and said: I adjure you by Allah by Whose order the heaven and earth stand. Do you know that Messenger of Allah (ﷺ) said: We are not inherited whatever we leave is sadaqah (alms). They said: Yes. He then turned towards 'Ali and al-'Abbas and said: I adjure you by Allah by Whose order the heaven and earth stand. Do you know that Messenger of Allah (ﷺ) said: We are not inherited whatever we leave is sadaqah (alms). They said: Yes. He then said: Allah has appointed for the Messenger of Allah (ﷺ) a special portion (in the booty) which he did not do for anyone. Allah, Most High, said: What Allah has bestowed on His Apostle (and taken away) from them - for this ye made no expedition with either cavalry or camelry. But Allah gives power to His apostles over any He pleases ; and Allah has power over all things". Allah bestowed (the property of) Banu al-Nadir on His Apostle. I swear by Allah, he did not reserve it for himself, nor did he take it over and above you. The Messenger of Allah (ﷺ) used to his share for his maintenance annually, or used to take his contribution and give his family their annual contribution (from this property), then take what remained and deal with it as he did with Allah's property. He then turned towards those people and said: I adjure you by Allah by Whose order the heaven and earth stand. Do you know that ? They said: Yes. He then turned towards 'Ali and al-'Abbas and said: I adjure you by Allah by Whose order the heaven and earth stand. Do you know that ? They said: Yes. When the Messenger of Allah (ﷺ) died, Abu Bakr said: I am the protector of the Messenger of Allah (ﷺ). Then you and this ('Ali) came to Abu Bakr, demanding a share from the inheritance of your cousin, and this ('Ali) demanding the share of his wife from (the property of her) father. Abu Bakr then said: The Messenger of Allah (ﷺ) said: We are not inherited. Whatever we leave is sadaqah. Allah knows that he (Abu Bakr) was true, faithful, rightly-guided, and the follower of Triuth. Abu Bakr then administered it (property of the Prophet). When Abu Bakr died, I said: I am the protector of the Messenger of Allah (ﷺ) and Abu Bakr. So I administered whatever Allah wished. Then you and this ('Ali) came. Both of you are at one, and your matter is the same. So they asked me for it (property), and I said: If you wish I give it to you on condition that you are bound by the covenant of Allah, meaning that you will administer it as the Messenger of Allah (ﷺ) used to administer. So you took it from me on that condition. Then again you have come to me so that I decide between you other than that. I swear by Allah, I shall not decide between you other than that till the Last Hour comes. If you helpless, return it to me. Abu Dawud said: They asked him for making it half between them, and not that they were ignorant of the fact the Prophet (ﷺ) said: We are not inherited. Whatever we leave is sadaqah (alms). They were also seeking the truth. 'Umar then said: I do not apply the name of division to it ; It leave it on its former condition}}
\hadithdefcmd{abudawud}{2964}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسٍ، بِهَذِهِ الْقِصَّةِ قَالَ وَهُمَا - يَعْنِي عَلِيًّا وَالْعَبَّاسَ رَضِيَ اللَّهُ عَنْهُمَا - يَخْتَصِمَانِ فِيمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْ أَمْوَالِ بَنِي النَّضِيرِ ‏.‏ قَالَ أَبُو دَاوُدَ أَرَادَ أَنْ لاَ يُوقِعَ عَلَيْهِ اسْمَ قَسْمٍ ‏.‏\hadithno{2964}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrating this tradition Malik b. Aws said:They i.e 'Ali and al-'Abbas (Allah be pleased with them), were quarrelling about what Allah bestowed on His Messenger of Allah (ﷺ), that is, the property of Banu al-Nadir. Abu Dawud said: He ('Umar) intended that the name of division should not apply to it}}
\hadithdefcmd{abudawud}{2965}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَأَحْمَدُ بْنُ عَبْدَةَ، - الْمَعْنَى - أَنَّ سُفْيَانَ بْنَ عُيَيْنَةَ، أَخْبَرَهُمْ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، عَنْ عُمَرَ، قَالَ كَانَتْ أَمْوَالُ بَنِي النَّضِيرِ مِمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِمَّا لَمْ يُوجِفِ الْمُسْلِمُونَ عَلَيْهِ بِخَيْلٍ وَلاَ رِكَابٍ كَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَالِصًا يُنْفِقُ عَلَى أَهْلِ بَيْتِهِ - قَالَ ابْنُ عَبْدَةَ يُنْفِقُ عَلَى أَهْلِهِ قُوتَ سَنَةٍ - فَمَا بَقِيَ جُعِلَ فِي الْكُرَاعِ وَعُدَّةً فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ قَالَ ابْنُ عَبْدَةَ فِي الْكُرَاعِ وَالسِّلاَحِ ‏.‏\hadithno{2965}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2904) Sahih Muslim (1757)}\hadithtrans{Narrated 'Umar: The properties of Banu al-Nadir were part of what Allah bestowed on His Apostle from what the Muslims has not ridden on horses or camels to get; so they belonged specially to the Messenger of Allah (ﷺ) who gave his family their annual contribution. Ibn 'Abdah said: His family (ahlihi) and not the members of his houses (ahl baitihi) ; then applied what remained for horses and weapons in Allah's path}}
\hadithdefcmd{abudawud}{2966}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَيُّوبُ، عَنِ الزُّهْرِيِّ، قَالَ قَالَ عُمَرُ ‏\{‏ وَمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْهُمْ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلاَ رِكَابٍ ‏\}‏ ‏.‏ قَالَ الزُّهْرِيُّ قَالَ عُمَرُ هَذِهِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَاصَّةً قُرَى عُرَيْنَةَ فَدَكَ وَكَذَا وَكَذَا ‏\{‏ مَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْ أَهْلِ الْقُرَى فَلِلَّهِ وَلِلرَّسُولِ وَلِذِي الْقُرْبَى وَالْيَتَامَى وَالْمَسَاكِينِ وَابْنِ السَّبِيلِ ‏\}‏ وَ لِلْفُقَرَاءِ الَّذِينَ أُخْرِجُوا مِنْ دِيَارِهِمْ وَأَمْوَالِهِمْ وَالَّذِينَ تَبَوَّءُوا الدَّارَ وَالإِيمَانَ مِنْ قَبْلِهِمْ ‏.‏ وَالَّذِينَ جَاءُوا مِنْ بَعْدِهِمْ فَاسْتَوْعَبَتْ هَذِهِ الآيَةُ النَّاسَ فَلَمْ يَبْقَ أَحَدٌ مِنَ الْمُسْلِمِينَ إِلاَّ لَهُ فِيهَا حَقٌّ ‏.‏ قَالَ أَيُّوبُ أَوْ قَالَ حَظٌّ إِلاَّ بَعْضَ مَنْ تَمْلِكُونَ مِنْ أَرِقَّائِكُمْ ‏.‏\hadithno{2966}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Zuhri:'Umar said explaining the verse: "What Allah has bestowed on His Apostle (and taken away) from them - for this ye made no expedition with either cavalry or camelry" this belonged specially to the Messenger of Allah (ﷺ): lands of 'Urainah, Fadak, and so-and-so. What Allah as bestowed on His Apostle (and taken away) from the people of the townships - belong to Allah - to the Apostle, and to kindred and orphans, the needy and the wayfarer, to the indigent emigrants, those who were expelled from their homes and their property, and to those who, before them, had homes (in Medina), and had adopted the faith, and to those who came after them. This verse completely covered all the people ; they remained no one from Muslims but he had his right in it, or share (according to Ayyub's version) except the slaves}}
\hadithdefcmd{abudawud}{2967}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، ح وَحَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، - وَهَذَا لَفْظُ حَدِيثِهِ - كُلُّهُمْ عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، قَالَ كَانَ فِيمَا احْتَجَّ بِهِ عُمَرُ رضى الله عنه أَنَّهُ قَالَ كَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ثَلاَثُ صَفَايَا بَنُو النَّضِيرِ وَخَيْبَرُ وَفَدَكُ فَأَمَّا بَنُو النَّضِيرِ فَكَانَتْ حُبْسًا لِنَوَائِبِهِ وَأَمَّا فَدَكُ فَكَانَتْ حُبْسًا لأَبْنَاءِ السَّبِيلِ وَأَمَّا خَيْبَرُ فَجَزَّأَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَةَ أَجْزَاءٍ جُزْءَيْنِ بَيْنَ الْمُسْلِمِينَ وَجُزْءًا نَفَقَةً لأَهْلِهِ فَمَا فَضَلَ عَنْ نَفَقَةِ أَهْلِهِ جَعَلَهُ بَيْنَ فُقَرَاءِ الْمُهَاجِرِينَ ‏.‏\hadithno{2967}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: Malik ibn Aws al-Hadthan said: One of the arguments put forward by Umar was that he said that the Messenger of Allah (ﷺ) received three things exclusively to himself: Banu an-Nadir, Khaybar and Fadak. The Banu an-Nadir property was kept wholly for his emergent needs, Fadak for travellers, and Khaybar was divided by the Messenger of Allah (ﷺ) into three sections: two for Muslims, and one as a contribution for his family. If anything remained after making the contribution of his family, he divided it among the poor Emigrants}}
\hadithdefcmd{abudawud}{2968}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُقَيْلِ بْنِ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا أَخْبَرَتْهُ أَنَّ فَاطِمَةَ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْسَلَتْ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ رضى الله عنه تَسْأَلُهُ مِيرَاثَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِمَّا أَفَاءَ اللَّهُ عَلَيْهِ بِالْمَدِينَةِ وَفَدَكَ وَمَا بَقِيَ مِنْ خُمُسِ خَيْبَرَ ‏.‏ فَقَالَ أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ مِنْ هَذَا الْمَالِ ‏"‏ ‏.‏ وَإِنِّي وَاللَّهِ لاَ أُغَيِّرُ شَيئًا مِنْ صَدَقَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ حَالِهَا الَّتِي كَانَتْ عَلَيْهِ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلأَعْمَلَنَّ فِيهَا بِمَا عَمِلَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَبَى أَبُو بَكْرٍ رضى الله عنه أَنْ يَدْفَعَ إِلَى فَاطِمَةَ عَلَيْهَا السَّلاَمُ مِنْهَا شَيْئًا ‏.‏\hadithno{2968}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4240، 4241) Sahih Muslim (1759)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):Fatimah daughter of Messenger of Allah (ﷺ) sent a messenger to Abu Bakr demanding from him in inheritance of the Messenger of Allah (ﷺ) from what Allah bestowed on him at Medina and Fadak, and what remained of the fifth of Khaibar. Abu Bakr said: The Messenger of Allah (ﷺ) has said: We are not inherited. Whatever we leave is sadaqah. The family of Muhammad will eat from this property. I swear by Allah I shall not change it from the former condition of its being sadaqah as it was in the time of the Messenger of Allah (ﷺ). I shall deal with it as the Messenger of Allah dealt with it. Abu Bakr, therefore, refused to give anything to Fatimah from it}}
\hadithdefcmd{abudawud}{2969}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ بِهَذَا الْحَدِيثِ قَالَ وَفَاطِمَةُ عَلَيْهَا السَّلاَمُ حِينَئِذٍ تَطْلُبُ صَدَقَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي بِالْمَدِينَةِ وَفَدَكَ وَمَا بَقِيَ مِنْ خُمُسِ خَيْبَرَ ‏.‏ قَالَتْ عَائِشَةُ رضى الله عنها فَقَالَ أَبُو بَكْرٍ رضى الله عنه إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ وَإِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ فِي هَذَا الْمَالِ ‏"‏ ‏.‏ يَعْنِي مَالَ اللَّهِ لَيْسَ لَهُمْ أَنْ يَزِيدُوا عَلَى الْمَأْكَلِ ‏.‏\hadithno{2969}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3711، 3712)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Fatimah was demanding (the property of) sadaqah of the Messenger of Allah (ﷺ) at Medina and Fadak, and what remained from the fifth of Khaybar. Aisha quoted AbuBakr as saying: The Messenger of Allah (ﷺ) said: We are not inherited; whatever we leave is sadaqah. The family of Muhammad will eat from this property, that is, from the property of Allah. They will not take more then their sustenance}}
\hadithdefcmd{abudawud}{2970}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ، رضى الله عنها أَخْبَرَتْهُ بِهَذَا الْحَدِيثِ، قَالَ فِيهِ فَأَبَى أَبُو بَكْرٍ رضى الله عنه عَلَيْهَا ذَلِكَ وَقَالَ لَسْتُ تَارِكًا شَيْئًا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْمَلُ بِهِ إِلاَّ عَمِلْتُ بِهِ إِنِّي أَخْشَى إِنْ تَرَكْتُ شَيْئًا مِنْ أَمْرِهِ أَنْ أَزِيغَ فَأَمَّا صَدَقَتُهُ بِالْمَدِينَةِ فَدَفَعَهَا عُمَرُ إِلَى عَلِيٍّ وَعَبَّاسٍ رضى الله عنهم فَغَلَبَهُ عَلِيٌّ عَلَيْهَا وَأَمَّا خَيْبَرُ وَفَدَكُ فَأَمْسَكَهُمَا عُمَرُ وَقَالَ هُمَا صَدَقَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَتَا لِحُقُوقِهِ الَّتِي تَعْرُوهُ وَنَوَائِبِهِ وَأَمْرُهُمَا إِلَى مَنْ وَلِيَ الأَمْرَ ‏.‏ قَالَ فَهُمَا عَلَى ذَلِكَ إِلَى الْيَوْمِ ‏.‏\hadithno{2970}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3092) Sahih Muslim (1759)}\hadithtrans{Narrating the above tradition, 'Aishah added:Abu Bakr refused that to her. Her said: I am not going to leave anything the Messenger of Allah (ﷺ) used to do but I shall carry it out. I fear if I depart a little from his practice, I shall diverge (from the right path). As regards his sadaqah (property) at Medina, 'Umar had given it to 'Ali ad 'Abbas (Allah be pleased with them), and 'Ali dominated it. As for Khaibar and Fadak, 'Umar retained them. He said: They were the sadaqah (property) of the Messenger of Allah (ﷺ), exclusively reserved for his purposes that happened, and for his emergent needs. Their management was assigned to the one who was in authority. He said: They are in that condition to the present day}}
\hadithdefcmd{abudawud}{2971}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا ابْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، فِي قَوْلِهِ ‏\{‏ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلاَ رِكَابٍ ‏\}‏ قَالَ صَالَحَ النَّبِيُّ صلى الله عليه وسلم أَهْلَ فَدَكَ وَقُرًى قَدْ سَمَّاهَا لاَ أَحْفَظُهَا وَهُوَ مُحَاصِرٌ قَوْمًا آخَرِينَ فَأَرْسَلُوا إِلَيْهِ بِالصُّلْحِ قَالَ ‏\{‏ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلاَ رِكَابٍ ‏\}‏ يَقُولُ بِغَيْرِ قِتَالٍ قَالَ الزُّهْرِيُّ وَكَانَتْ بَنُو النَّضِيرِ لِلنَّبِيِّ صلى الله عليه وسلم خَالِصًا لَمْ يَفْتَحُوهَا عَنْوَةً افْتَتَحُوهَا عَلَى صُلْحٍ فَقَسَمَهَا النَّبِيُّ صلى الله عليه وسلم بَيْنَ الْمُهَاجِرِينَ لَمْ يُعْطِ الأَنْصَارَ مِنْهَا شَيْئًا إِلاَّ رَجُلَيْنِ كَانَتْ بِهِمَا حَاجَةٌ ‏.‏\hadithno{2971}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Al-Zuhri, explaining the verse "For this you made no expedition with either cavalry or camelry" said:The Prophet (ﷺ) concluded the treaty of peace with the people of Fadak and townships which he named which I could not remember ; he blockaded some other people who sent a message to him for capitulation. He said: "For this you made no expedition with either cavalry or camelry" means without fighting. Al-Zuhri said: The Banu al-Nadir property was exclusively kept for the Prophet (ﷺ) ; they did not conquer it by fighting, but conquered it by capitulation. To Prophet (ﷺ) divided it among the Emigrants. He did not give anything to the Helpers except two men were needy}}
\hadithdefcmd{abudawud}{2972}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، قَالَ جَمَعَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ بَنِي مَرْوَانَ حِينَ اسْتُخْلِفَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَتْ لَهُ فَدَكُ فَكَانَ يُنْفِقُ مِنْهَا وَيَعُودُ مِنْهَا عَلَى صَغِيرِ بَنِي هَاشِمٍ وَيُزَوِّجُ مِنْهَا أَيِّمَهُمْ وَإِنَّ فَاطِمَةَ سَأَلَتْهُ أَنْ يَجْعَلَهَا لَهَا فَأَبَى فَكَانَتْ كَذَلِكَ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى مَضَى لِسَبِيلِهِ فَلَمَّا أَنْ وَلِيَ أَبُو بَكْرٍ رضى الله عنه عَمِلَ فِيهَا بِمَا عَمِلَ النَّبِيُّ صلى الله عليه وسلم فِي حَيَاتِهِ حَتَّى مَضَى لِسَبِيلِهِ فَلَمَّا أَنْ وَلِيَ عُمَرُ عَمِلَ فِيهَا بِمِثْلِ مَا عَمِلاَ حَتَّى مَضَى لِسَبِيلِهِ ثُمَّ أَقْطَعَهَا مَرْوَانُ ثُمَّ صَارَتْ لِعُمَرَ بْنِ عَبْدِ الْعَزِيزِ قَالَ - يَعْنِي عُمَرَ بْنَ عَبْدِ الْعَزِيزِ - فَرَأَيْتُ أَمْرًا مَنَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاطِمَةَ عَلَيْهَا السَّلاَمُ لَيْسَ لِي بِحَقٍّ وَأَنَا أُشْهِدُكُمْ أَنِّي قَدْ رَدَدْتُهَا عَلَى مَا كَانَتْ يَعْنِي عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ وَلِيَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ الْخِلاَفَةَ وَغَلَّتُهُ أَرْبَعُونَ أَلْفَ دِينَارٍ وَتُوُفِّيَ وَغَلَّتُهُ أَرْبَعُمِائَةِ دِينَارٍ وَلَوْ بَقِيَ لَكَانَ أَقَلَّ ‏.‏\hadithno{2972}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn AbdulAziz: Al-Mughirah (ibn Shu'bah) said: Umar ibn AbdulAziz gathered the family of Marwan when he was made caliph, and he said: Fadak belonged to the Messenger of Allah (ﷺ), and he made contributions from it, showing repeated kindness to the poor of the Banu Hashim from it, and supplying from it the cost of marriage for those who were unmarried. Fatimah asked him to give it to her, but he refused. That is how matters stood during the lifetime of the Messenger of Allah (ﷺ) till he passed on (i.e. died). When AbuBakr was made ruler he administered it as the Prophet (ﷺ) had done in his lifetime till he passed on. Then when Umar ibn al-Khattab was made ruler he administered it as they had done till he passed on. Then it was given to Marwan as a fief, and it afterwards came to Umar ibn AbdulAziz. Umar ibn AbdulAziz said: I consider I have no right to something which the Messenger of Allah (ﷺ) refused to Fatimah, and I call you to witness that I have restored it to its former condition; meaning in the time of the Messenger of Allah (ﷺ). Abu Dawud said: When 'Umar b. 'Abd al-'Aziz was made caliph its revenue was forty thousand dinars, and when he died its revenue was four hundred dinars. Had he remained alive, it would have been less than it}}
\hadithdefcmd{abudawud}{2973}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنِ الْوَلِيدِ بْنِ جُمَيْعٍ، عَنْ أَبِي الطُّفَيْلِ، قَالَ جَاءَتْ فَاطِمَةُ رضى الله عنها إِلَى أَبِي بَكْرٍ رضى الله عنه تَطْلُبُ مِيرَاثَهَا مِنَ النَّبِيِّ صلى الله عليه وسلم قَالَ فَقَالَ أَبُو بَكْرٍ عَلَيْهِ السَّلاَمُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ إِذَا أَطْعَمَ نَبِيًّا طُعْمَةً فَهِيَ لِلَّذِي يَقُومُ مِنْ بَعْدِهِ ‏"‏ ‏.‏\hadithno{2973}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuBakr: AbutTufayl said: Fatimah came to AbuBakr asking him for the inheritance of the Prophet (ﷺ). AbuBakr said: I heard the Messenger of Allah (ﷺ) say: If Allah, Most High, gives a Prophet some means of sustenance, that goes to his successor}}
\hadithdefcmd{abudawud}{2974}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقْتَسِمُ وَرَثَتِي دِينَارًا مَا تَرَكْتُ بَعْدَ نَفَقَةِ نِسَائِي وَمُؤْنَةِ عَامِلِي فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏"‏ مُؤْنَةِ عَامِلِي ‏"‏ ‏.‏ يَعْنِي أَكَرَةَ الأَرْضِ ‏.‏\hadithno{2974}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3096) Sahih Muslim (1760)}\hadithtrans{Narrated Abu Hurairah: The Prophet (ﷺ) as saying: Do not distribute dinars among my heirs: Whatever I left after contribution to my wives and provisions for my governor is sadaqah (alms). Abu Dawud said: 'Amil means the workers or laborers on the land (i.e. peasants)}}
\hadithdefcmd{abudawud}{2975}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، قَالَ سَمِعْتُ حَدِيثًا، مِنْ رَجُلٍ فَأَعْجَبَنِي فَقُلْتُ اكْتُبْهُ لِي فَأَتَى بِهِ مَكْتُوبًا مُذَبَّرًا دَخَلَ الْعَبَّاسُ وَعَلِيٌّ عَلَى عُمَرَ وَعِنْدَهُ طَلْحَةُ وَالزُّبَيْرُ وَعَبْدُ الرَّحْمَنِ وَسَعْدٌ وَهُمَا يَخْتَصِمَانِ فَقَالَ عُمَرُ لِطَلْحَةَ وَالزُّبَيْرِ وَعَبْدِ الرَّحْمَنِ وَسَعْدٍ أَلَمْ تَعْلَمُوا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ مَالِ النَّبِيِّ صلى الله عليه وسلم صَدَقَةٌ إِلاَّ مَا أَطْعَمَهُ أَهْلَهُ وَكَسَاهُمْ إِنَّا لاَ نُورَثُ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنْفِقُ مِنْ مَالِهِ عَلَى أَهْلِهِ وَيَتَصَدَّقُ بِفَضْلِهِ ثُمَّ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَوَلِيَهَا أَبُو بَكْرٍ سَنَتَيْنِ فَكَانَ يَصْنَعُ الَّذِي كَانَ يَصْنَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ ثُمَّ ذَكَرَ شَيْئًا مِنْ حَدِيثِ مَالِكِ بْنِ أَوْسٍ ‏.‏\hadithno{2975}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: AbulBakhtari said: I heard from a man a tradition which I liked. I said to him: Write it down for me. So he brought it clearly written to me. (It says): Al-Abbas and Ali entered upon Umar when Talhah, az-Zubayr, AbdurRahman and Sa'd were with him. They (Abbas and Ali) were disputing. Umar said to Talhah, az-Zubayr, AbdurRahman and Sa'd: Do you not know that the Messenger of Allah (ﷺ) said: All the property of the Prophet (ﷺ) is sadaqah (alms), except what he provided for his family for their sustenance and their clothing. We are not to be inherited. They said: Yes, indeed. He said: The Messenger of Allah (ﷺ) used to spend from his property on his family, and give the residue as sadaqah (alms). The Messenger of Allah (ﷺ) then died, and AbuBakr ruled for two years. He would deal with it in the same manner as the Messenger of Allah (ﷺ) did. He then mentioned a little from the tradition of Malik ibn Aws}}
\hadithdefcmd{abudawud}{2976}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرَدْنَ أَنْ يَبْعَثْنَ عُثْمَانَ بْنَ عَفَّانَ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ فَيَسْأَلْنَهُ ثُمُنَهُنَّ مِنَ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ لَهُنَّ عَائِشَةُ أَلَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2976}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4034) Sahih Muslim (1758)}\hadithtrans{Narrated 'Aishah:When the Messenger of Allah (ﷺ) died, the wives of the Prophet (ﷺ) intended to send 'Uthman b. 'Affan to Abu Bakr to ask him their cost of living from (the inheritance of) the Prophet (ﷺ). Thereupon 'Aishah said: Did not the Messenger of Allah (ﷺ) say: We are not inherited. Whatever we leave is sadaqah}}
\hadithdefcmd{abudawud}{2977}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِهِ نَحْوَهُ قُلْتُ أَلاَ تَتَّقِينَ اللَّهَ أَلَمْ تَسْمَعْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا فَهُوَ صَدَقَةٌ وَإِنَّمَا هَذَا الْمَالُ لآلِ مُحَمَّدٍ لِنَائِبَتِهِمْ وَلِضَيْفِهِمْ فَإِذَا مِتُّ فَهُوَ إِلَى مَنْ وَلِيَ الأَمْرَ مِنْ بَعْدِي ‏"‏ ‏.‏\hadithno{2977}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{A similar tradition has been narrated by Ibn Shihab through a different chain of narrators. This version says:I said: Do you not fear Allah ? Did you not hear the Messenger of Allah (ﷺ) say: We are not inherited. Whatever we leave is sadaqah (alms). This property belongs to the family of Muhammad for their emergent needs and their guest. When I die, it will go to him who becomes ruler after me}}
\hadithdefcmd{abudawud}{2978}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَخْبَرَنِي جُبَيْرُ بْنُ مُطْعِمٍ، أَنَّهُ جَاءَ هُوَ وَعُثْمَانُ بْنُ عَفَّانَ يُكَلِّمَانِ رَسُولَ اللَّهِ صلى الله عليه وسلم فِيمَا قَسَمَ مِنَ الْخُمُسِ بَيْنَ بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ فَقُلْتُ يَا رَسُولَ اللَّهِ قَسَمْتَ لإِخْوَانِنَا بَنِي الْمُطَّلِبِ وَلَمْ تُعْطِنَا شَيْئًا وَقَرَابَتُنَا وَقَرَابَتُهُمْ مِنْكَ وَاحِدَةٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا بَنُو هَاشِمٍ وَبَنُو الْمُطَّلِبِ شَىْءٌ وَاحِدٌ ‏"‏ ‏.‏ قَالَ جُبَيْرٌ وَلَمْ يَقْسِمْ لِبَنِي عَبْدِ شَمْسٍ وَلاَ لِبَنِي نَوْفَلٍ مِنْ ذَلِكَ الْخُمُسِ كَمَا قَسَمَ لِبَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ ‏.‏ قَالَ وَكَانَ أَبُو بَكْرٍ يَقْسِمُ الْخُمُسَ نَحْوَ قَسْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم غَيْرَ أَنَّهُ لَمْ يَكُنْ يُعْطِي قُرْبَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يُعْطِيهِمْ ‏.‏ قَالَ وَكَانَ عُمَرُ بْنُ الْخَطَّابِ يُعْطِيهِمْ مِنْهُ وَعُثْمَانُ بَعْدَهُ ‏.‏\hadithno{2978}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4229)}\hadithtrans{Narrated Jubair b. Mut'im:That he and 'Uthman b. 'Affan went to the Messenger of Allah (ﷺ) talking to him about the fifth which he divided among the Banu Hisham and Abu 'Abd al-Muttalib. I said: Messenger of Allah, you have divided (the fifth) among our brethren Banu 'Abd al-Muttalib, but you have not given us anything, though our relationship to you is the same as theirs. The Prophet (ﷺ) said: The Banu Hisham and the Banu 'Abd al-Muttalib are one. Jubair said: He did not divide the fifth among the Banu 'Abd Shams and the Banu Nawfal as he divided among the Banu Hashim and the Banu 'Abd al-Muttalib. He said: Abu Bakr used to divide the fifth like the division of Messenger of Allah (ﷺ) except that he did not give the relatives of the Messenger of Allah (ﷺ), as he gave them. 'Umar b. al-Khattab and 'Uthman after him used to give them (a portion) from it}}
\hadithdefcmd{abudawud}{2979}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنِي يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، حَدَّثَنَا جُبَيْرُ بْنُ مُطْعِمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَقْسِمْ لِبَنِي عَبْدِ شَمْسٍ وَلاَ لِبَنِي نَوْفَلٍ مِنَ الْخُمُسِ شَيْئًا كَمَا قَسَمَ لِبَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ ‏.‏ قَالَ وَكَانَ أَبُو بَكْرٍ يَقْسِمُ الْخُمُسَ نَحْوَ قَسْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم غَيْرَ أَنَّهُ لَمْ يَكُنْ يُعْطِي قُرْبَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَمَا كَانَ يُعْطِيهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ عُمَرُ يُعْطِيهِمْ وَمَنْ كَانَ بَعْدَهُ مِنْهُمْ ‏.‏\hadithno{2979}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jubair b. Mu'tim:The Messenger of Allah (ﷺ) did not divide the fifth among the Banu 'Abd Shams and Banu Nawfal as he divided among the Banu Hashim and Banu 'Abd al-Muttalib. He said: Abu Bakr used to divide (the fifth) like the division of the Messenger of Allah (ﷺ), except that he did not give the relatives of the Messenger of Allah as the Messenger of Allah (ﷺ) himself gave them. 'Umar used to give them (from the fifth) and those who followed him}}
\hadithdefcmd{abudawud}{2980}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَخْبَرَنِي جُبَيْرُ بْنُ مُطْعِمٍ، قَالَ لَمَّا كَانَ يَوْمُ خَيْبَرَ وَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَهْمَ ذِي الْقُرْبَى فِي بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ وَتَرَكَ بَنِي نَوْفَلٍ وَبَنِي عَبْدِ شَمْسٍ فَانْطَلَقْتُ أَنَا وَعُثْمَانُ بْنُ عَفَّانَ حَتَّى أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَقُلْنَا يَا رَسُولَ اللَّهِ هَؤُلاَءِ بَنُو هَاشِمٍ لاَ نُنْكِرُ فَضْلَهُمْ لِلْمَوْضِعِ الَّذِي وَضَعَكَ اللَّهُ بِهِ مِنْهُمْ فَمَا بَالُ إِخْوَانِنَا بَنِي الْمُطَّلِبِ أَعْطَيْتَهُمْ وَتَرَكْتَنَا وَقَرَابَتُنَا وَاحِدَةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا وَبَنُو الْمُطَّلِبِ لاَ نَفْتَرِقُ فِي جَاهِلِيَّةٍ وَلاَ إِسْلاَمٍ وَإِنَّمَا نَحْنُ وَهُمْ شَىْءٌ وَاحِدٌ ‏"‏ ‏.‏ وَشَبَّكَ بَيْنَ أَصَابِعِهِ ‏.‏\hadithno{2980}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jubair b. Mu'tim:On the day of Khaibar the Messenger of Allah (ﷺ) divided the portion to his relatives among the Banu Hashim and Banu 'Abd al-Muttalib, and omitted Banu Nawfal and Banu 'Abd Shams. So I and 'Utham b. 'Affan went to the Prophet (ﷺ) and we said: Messenger of Allah, these are Banu Hashim whose superiority we do not deny because if the position in which Allah has placed you in relation to them ; but tell us about Banu 'Abd al-Muttalib to whom you have given something while omitting us though our relationship is the same as theirs. The Messenger of Allah (ﷺ) said: There is no distinction between us and Banu 'Abd al-Muttalib in pre-Islamic days and in Islam. We and they are one, and he (ﷺ) intertwined his fingers}}
\hadithdefcmd{abudawud}{2981}{حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْعِجْلِيُّ، حَدَّثَنَا وَكِيعٌ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنِ السُّدِّيِّ، فِي ذِي الْقُرْبَى قَالَ هُمْ بَنُو عَبْدِ الْمُطَّلِبِ ‏.‏\hadithno{2981}\hadithgrade{Al-Albani: Daif Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Explaining the relatives of the Prophet (ﷺ) al-Saddi said:They are Banu 'Abd al-Muttalib}}
\hadithdefcmd{abudawud}{2982}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي يَزِيدُ بْنُ هُرْمُزَ، أَنَّ نَجْدَةَ الْحَرُورِيَّ، حِينَ حَجَّ فِي فِتْنَةِ ابْنِ الزُّبَيْرِ أَرْسَلَ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنْ سَهْمِ ذِي الْقُرْبَى وَيَقُولُ لِمَنْ تَرَاهُ قَالَ ابْنُ عَبَّاسٍ لِقُرْبَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَسَمَهُ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ كَانَ عُمَرُ عَرَضَ عَلَيْنَا مِنْ ذَلِكَ عَرْضًا رَأَيْنَاهُ دُونَ حَقِّنَا فَرَدَدْنَاهُ عَلَيْهِ وَأَبَيْنَا أَنْ نَقْبَلَهُ ‏.‏\hadithno{2982}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: Yazid ibn Hurmuz said that when Najdah al-Haruri performed hajj during the rule of Ibn az-Zubayr, he sent someone to Ibn Abbas to ask him about the portion of the relatives (in the fifth). He asked: For whom do you think? Ibn Abbas replied: For the relatives of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) divided it among them. Umar presented it to us but we found it less than our right. We, therefore returned it to him and refused to accept it}}
\hadithdefcmd{abudawud}{2983}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا أَبُو جَعْفَرٍ الرَّازِيُّ، عَنْ مُطَرِّفٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ وَلاَّنِي رَسُولُ اللَّهِ صلى الله عليه وسلم خُمُسَ الْخُمُسِ فَوَضَعْتُهُ مَوَاضِعَهُ حَيَاةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَحَيَاةَ أَبِي بَكْرٍ وَحَيَاةَ عُمَرَ فَأُتِيَ بِمَالٍ فَدَعَانِي فَقَالَ خُذْهُ ‏.‏ فَقُلْتُ لاَ أُرِيدُهُ ‏.‏ قَالَ خُذْهُ فَأَنْتُمْ أَحَقُّ بِهِ ‏.‏ قُلْتُ قَدِ اسْتَغْنَيْنَا عَنْهُ فَجَعَلَهُ فِي بَيْتِ الْمَالِ ‏.‏\hadithno{2983}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abd al-Rahman b. Abi Laila:I heard 'Ali say: The Messenger of Allah (ﷺ) assigned me the fifth (of the booty). I spent it on its beneficiaries during the lifetime of the Messenger of Allah (ﷺ) and Abu Bakr and of 'Umar. Some property was brought to him ('Umar) and he called me and said: Take it. I said: I dod not want it. He said: Take it ; you have right to it. I said: We do not need it. So he deposited in the government treasury}}
\hadithdefcmd{abudawud}{2984}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هَاشِمُ بْنُ الْبَرِيدِ، حَدَّثَنَا حُسَيْنُ بْنُ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ سَمِعْتُ عَلِيًّا، عَلَيْهِ السَّلاَمُ يَقُولُ اجْتَمَعْتُ أَنَا وَالْعَبَّاسُ، وَفَاطِمَةُ، وَزَيْدُ بْنُ حَارِثَةَ، عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنْ رَأَيْتَ أَنْ تُوَلِّيَنِي حَقَّنَا مِنْ هَذَا الْخُمُسِ فِي كِتَابِ اللَّهِ فَأَقْسِمَهُ حَيَاتَكَ كَىْ لاَ يُنَازِعَنِي أَحَدٌ بَعْدَكَ فَافْعَلْ ‏.‏ قَالَ فَفَعَلَ ذَلِكَ - قَالَ - فَقَسَمْتُهُ حَيَاةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ وَلاَّنِيهِ أَبُو بَكْرٍ رضى الله عنه حَتَّى إِذَا كَانَتْ آخِرُ سَنَةٍ مِنْ سِنِي عُمَرَ رضى الله عنه فَإِنَّهُ أَتَاهُ مَالٌ كَثِيرٌ فَعَزَلَ حَقَّنَا ثُمَّ أَرْسَلَ إِلَىَّ فَقُلْتُ بِنَا عَنْهُ الْعَامَ غِنًى وَبِالْمُسْلِمِينَ إِلَيْهِ حَاجَةٌ فَارْدُدْهُ عَلَيْهِمْ فَرَدَّهُ عَلَيْهِمْ ثُمَّ لَمْ يَدْعُنِي إِلَيْهِ أَحَدٌ بَعْدَ عُمَرَ فَلَقِيتُ الْعَبَّاسَ بَعْدَ مَا خَرَجْتُ مِنْ عِنْدِ عُمَرَ فَقَالَ يَا عَلِيُّ حَرَمْتَنَا الْغَدَاةَ شَيْئًا لاَ يُرَدُّ عَلَيْنَا أَبَدًا وَكَانَ رَجُلاً دَاهِيًا ‏.‏\hadithno{2984}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: I, al-Abbas, Fatimah and Zayd ibn Harithah gathered with the Prophet (ﷺ) and I said: Messenger of Allah, if you think to assign us our right (portion) in this fifth ( of the booty) as mentioned in the Book of Allah, and this I may divide during your lifetime so that no one may dispute me after you, then do it. He said: He did that. He said: I divided it during the lifetime of the Messenger of Allah (ﷺ). AbuBakr then assigned it to me. During the last days of the caliphate of Umar a good deal of property came to him and took out our portion. I said to him: We are well to do this year; but the Muslims are needy, so return it to them. He, therefore, returned it to them. No one called me after Umar. I met al-Abbas when I came out from Umar. He said: Ali, today you have deprived us of a thing that will never be returned to us. He was indeed a man of wisdom}}
\hadithdefcmd{abudawud}{2985}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ الْحَارِثِ بْنِ نَوْفَلٍ الْهَاشِمِيُّ، أَنَّ عَبْدَ الْمُطَّلِبِ بْنَ رَبِيعَةَ بْنِ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ، أَخْبَرَهُ أَنَّ أَبَاهُ رَبِيعَةَ بْنَ الْحَارِثِ وَعَبَّاسَ بْنَ عَبْدِ الْمُطَّلِبِ قَالاَ لِعَبْدِ الْمُطَّلِبِ بْنِ رَبِيعَةَ وَلِلْفَضْلِ بْنِ عَبَّاسٍ ائْتِيَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُولاَ لَهُ يَا رَسُولَ اللَّهِ قَدْ بَلَغْنَا مِنَ السِّنِّ مَا تَرَى وَأَحْبَبْنَا أَنْ نَتَزَوَّجَ وَأَنْتَ يَا رَسُولَ اللَّهِ أَبَرُّ النَّاسِ وَأَوْصَلُهُمْ وَلَيْسَ عِنْدَ أَبَوَيْنَا مَا يُصْدِقَانِ عَنَّا فَاسْتَعْمِلْنَا يَا رَسُولَ اللَّهِ عَلَى الصَّدَقَاتِ فَلْنُؤَدِّ إِلَيْكَ مَا يُؤَدِّي الْعُمَّالُ وَلْنُصِبْ مَا كَانَ فِيهَا مِنْ مِرْفَقٍ ‏.‏ قَالَ فَأَتَى إِلَيْنَا عَلِيُّ بْنُ أَبِي طَالِبٍ وَنَحْنُ عَلَى تِلْكَ الْحَالِ فَقَالَ لَنَا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ وَاللَّهِ لاَ نَسْتَعْمِلُ مِنْكُمْ أَحَدًا عَلَى الصَّدَقَةِ ‏"‏ ‏.‏ فَقَالَ لَهُ رَبِيعَةُ هَذَا مِنْ أَمْرِكَ قَدْ نِلْتَ صِهْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ نَحْسُدْكَ عَلَيْهِ ‏.‏ فَأَلْقَى عَلِيٌّ رِدَاءَهُ ثُمَّ اضْطَجَعَ عَلَيْهِ فَقَالَ أَنَا أَبُو حَسَنٍ الْقَرْمُ وَاللَّهِ لاَ أَرِيمُ حَتَّى يَرْجِعَ إِلَيْكُمَا ابْنَاكُمَا بِجَوَابِ مَا بَعَثْتُمَا بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ عَبْدُ الْمُطَّلِبِ فَانْطَلَقْتُ أَنَا وَالْفَضْلُ إِلَى بَابِ حُجْرَةِ النَّبِيِّ صلى الله عليه وسلم حَتَّى نُوَافِقَ صَلاَةَ الظُّهْرِ قَدْ قَامَتْ فَصَلَّيْنَا مَعَ النَّاسِ ثُمَّ أَسْرَعْتُ أَنَا وَالْفَضْلُ إِلَى بَابِ حُجْرَةِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَوْمَئِذٍ عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ فَقُمْنَا بِالْبَابِ حَتَّى أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخَذَ بِأُذُنِي وَأُذُنِ الْفَضْلِ ثُمَّ قَالَ أَخْرِجَا مَا تُصَرِّرَانِ ثُمَّ دَخَلَ فَأَذِنَ لِي وَلِلْفَضْلِ فَدَخَلْنَا فَتَوَاكَلْنَا الْكَلاَمَ قَلِيلاً ثُمَّ كَلَّمْتُهُ أَوْ كَلَّمَهُ الْفَضْلُ - قَدْ شَكَّ فِي ذَلِكَ عَبْدُ اللَّهِ - قَالَ كَلَّمَهُ بِالأَمْرِ الَّذِي أَمَرَنَا بِهِ أَبَوَانَا فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَاعَةً وَرَفَعَ بَصَرَهُ قِبَلَ سَقْفِ الْبَيْتِ حَتَّى طَالَ عَلَيْنَا أَنَّهُ لاَ يَرْجِعُ إِلَيْنَا شَيْئًا حَتَّى رَأَيْنَا زَيْنَبَ تَلْمَعُ مِنْ وَرَاءِ الْحِجَابِ بِيَدِهَا تُرِيدُ أَنْ لاَ تَعْجَلاَ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي أَمْرِنَا ثُمَّ خَفَّضَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَأْسَهُ فَقَالَ لَنَا ‏"‏ إِنَّ هَذِهِ الصَّدَقَةَ إِنَّمَا هِيَ أَوْسَاخُ النَّاسِ وَإِنَّهَا لاَ تَحِلُّ لِمُحَمَّدٍ وَلاَ لآلِ مُحَمَّدٍ ادْعُوا لِي نَوْفَلَ بْنَ الْحَارِثِ ‏"‏ ‏.‏ فَدُعِيَ لَهُ نَوْفَلُ بْنُ الْحَارِثِ فَقَالَ ‏"‏ يَا نَوْفَلُ أَنْكِحْ عَبْدَ الْمُطَّلِبِ ‏"‏ ‏.‏ فَأَنْكَحَنِي نَوْفَلٌ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ادْعُوا لِي مَحْمِيَةَ بْنَ جَزْءٍ ‏"‏ ‏.‏ وَهُوَ رَجُلٌ مِنْ بَنِي زُبَيْدٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَهُ عَلَى الأَخْمَاسِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَحْمِيَةَ ‏"‏ أَنْكِحِ الْفَضْلَ ‏"‏ ‏.‏ فَأَنْكَحَهُ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُمْ فَأَصْدِقْ عَنْهُمَا مِنَ الْخُمُسِ كَذَا وَكَذَا ‏"‏ ‏.‏ لَمْ يُسَمِّهِ لِي عَبْدُ اللَّهِ بْنُ الْحَارِثِ ‏.‏\hadithno{2985}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1072)}\hadithtrans{Narrated AbdulMuttalib ibn Rabi'ah ibn al-Harith: AbdulMuttalib ibn Rabi'ah ibn al-Harith said that his father, Rabi'ah ibn al-Harith, and Abbas ibn al-Muttalib said to AbdulMuttalib ibn Rabi'ah and al-Fadl ibn Abbas: Go to the Messenger of Allah (ﷺ) and tell him: Messenger of Allah, we are now of age as you see, and we wish to marry. Messenger of Allah, you are the kindest of the people and the most skilled in matchmaking. Our fathers have nothing with which to pay our dower. So appoint us collector of sadaqah (zakat), Messenger of Allah, and we shall give you what the other collectors give you, and we shall have the benefit accruing from it. Ali came to us while we were in this condition. He said: The Messenger of Allah (ﷺ) said: No, I swear by Allah, he will not appoint any of you collector of sadaqah (zakat). Rabi'ah said to him: This is your condition; you have gained your relationship with the Messenger of Allah (ﷺ) by marriage, but we did not grudge you that. Ali then put his cloak on the earth and lay on it. He then said: I am the father of Hasan, the chief. I swear by Allah, I shall not leave this place until your sons come with a reply (to the question) for which you have sent them to the Prophet (ﷺ). AbdulMuttalib said: So I and al-Fadl went towards the door of the apartment of the Prophet (ﷺ). We found that the noon prayer in congregation had already started. So we prayed along with the people. I and al-Fadl then hastened towards the door of the apartment of the Prophet (ﷺ). He was (staying) with Zaynab, daughter of Jahsh, that day. We stood until the Messenger of Allah (ﷺ) came. He caught my ear and the ear of al-Fadl. He then said: Reveal what you conceal in your hearts. He then entered and permitted me and al-Fadl (to enter). So we entered and for a little while we asked each other to talk. I then talked to him, or al-Fadl talked to him (the narrator, Abdullah was not sure). He said: He spoke to him concerning the matter about which our fathers ordered us to ask him. The Messenger of Allah (ﷺ) remained silent for a moment and raised his eyes towards the ceiling of the room. He took so long that we thought he would not give any reply to us. Meanwhile we saw that Zaynab was signalling to us with her hand from behind the veil, asking us not to be in a hurry, and that the Messenger of Allah (ﷺ) was (thinking) about our matter. The Messenger of Allah (ﷺ) then lowered his head and said to us: This sadaqah (zakat) is a dirt of the people. It is legal neither for Muhammad nor for the family of Muhammad. Call Nawfal ibn al-Harith to me. So Nawfal ibn al-Harith was called to him. He said: Nawfal, marry AbdulMuttalib (to your daughter). So Nawfal married me (to his daughter). The Prophet (ﷺ) then said: Call Mahmiyyah ibn Jaz'i to me. He was a man of Banu Zubayd, whom the Messenger of Allah (ﷺ) had appointed collector of the fifths. The Messenger of Allah (ﷺ) said to Mahmiyyah: Marry al-Fadl (to your daughter). So he married him to her. The Messenger of Allah (ﷺ) said: Stand up and pay the dower from the fifth so-and-so on their behalf. Abdullah ibn al-Harith did not name it (i.e. the amount of the dower)}}
\hadithdefcmd{abudawud}{2986}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ بْنُ خَالِدٍ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ حُسَيْنَ بْنَ عَلِيٍّ، أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ قَالَ كَانَتْ لِي شَارِفٌ مِنْ نَصِيبِي مِنَ الْمَغْنَمِ يَوْمَ بَدْرٍ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَعْطَانِي شَارِفًا مِنَ الْخُمُسِ يَوْمَئِذٍ فَلَمَّا أَرَدْتُ أَنْ أَبْنِيَ بِفَاطِمَةَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاعَدْتُ رَجُلاً صَوَّاغًا مِنْ بَنِي قَيْنُقَاعَ أَنْ يَرْتَحِلَ مَعِي فَنَأْتِيَ بِإِذْخِرٍ أَرَدْتُ أَنْ أَبِيعَهُ مِنَ الصَّوَّاغِينَ فَأَسْتَعِينَ بِهِ فِي وَلِيمَةِ عُرْسِي فَبَيْنَا أَنَا أَجْمَعُ لِشَارِفَىَّ مَتَاعًا مِنَ الأَقْتَابِ وَالْغَرَائِرِ وَالْحِبَالِ - وَشَارِفَاىَ مُنَاخَانِ إِلَى جَنْبِ حُجْرَةِ رَجُلٍ مِنَ الأَنْصَارِ - أَقْبَلْتُ حِينَ جَمَعْتُ مَا جَمَعْتُ فَإِذَا بِشَارِفَىَّ قَدِ اجْتُبَّتْ أَسْنِمَتُهُمَا وَبُقِرَتْ خَوَاصِرُهُمَا وَأُخِذَ مِنْ أَكْبَادِهِمَا فَلَمْ أَمْلِكْ عَيْنَىَّ حِينَ رَأَيْتُ ذَلِكَ الْمَنْظَرَ فَقُلْتُ مَنْ فَعَلَ هَذَا قَالُوا فَعَلَهُ حَمْزَةُ بْنُ عَبْدِ الْمُطَّلِبِ وَهُوَ فِي هَذَا الْبَيْتِ فِي شَرْبٍ مِنَ الأَنْصَارِ غَنَّتْهُ قَيْنَةٌ وَأَصْحَابَهُ فَقَالَتْ فِي غِنَائِهَا أَلاَ يَا حَمْزُ لِلشُّرُفِ النِّوَاءِ فَوَثَبَ إِلَى السَّيْفِ فَاجْتَبَّ أَسْنِمَتَهُمَا وَبَقَرَ خَوَاصِرَهُمَا وَأَخَذَ مِنْ أَكْبَادِهِمَا ‏.‏ قَالَ عَلِيٌّ فَانْطَلَقْتُ حَتَّى أَدْخُلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ زَيْدُ بْنُ حَارِثَةَ قَالَ فَعَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم الَّذِي لَقِيتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا لَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا رَأَيْتُ كَالْيَوْمِ عَدَا حَمْزَةُ عَلَى نَاقَتَىَّ فَاجْتَبَّ أَسْنِمَتَهُمَا وَبَقَرَ خَوَاصِرَهُمَا وَهَا هُوَ ذَا فِي بَيْتٍ مَعَهُ شَرْبٌ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِرِدَائِهِ فَارْتَدَاهُ ثُمَّ انْطَلَقَ يَمْشِي وَاتَّبَعْتُهُ أَنَا وَزَيْدُ بْنُ حَارِثَةَ حَتَّى جَاءَ الْبَيْتَ الَّذِي فِيهِ حَمْزَةُ فَاسْتَأْذَنَ فَأُذِنَ لَهُ فَإِذَا هُمْ شَرْبٌ فَطَفِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَلُومُ حَمْزَةَ فِيمَا فَعَلَ فَإِذَا حَمْزَةُ ثَمِلٌ مُحْمَرَّةٌ عَيْنَاهُ فَنَظَرَ حَمْزَةُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ صَعَّدَ النَّظَرَ فَنَظَرَ إِلَى رُكْبَتَيْهِ ثُمَّ صَعَّدَ النَّظَرَ فَنَظَرَ إِلَى سُرَّتِهِ ثُمَّ صَعَّدَ النَّظَرَ فَنَظَرَ إِلَى وَجْهِهِ ثُمَّ قَالَ حَمْزَةُ وَهَلْ أَنْتُمْ إِلاَّ عَبِيدٌ لأَبِي فَعَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّهُ ثَمِلٌ فَنَكَصَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عَقِبَيْهِ الْقَهْقَرَى فَخَرَجَ وَخَرَجْنَا مَعَهُ ‏.‏\hadithno{2986}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3091) Sahih Muslim (1979)}\hadithtrans{‘Ali bin Abi Talib said “I had an old she Camel that I got as my share from the booty on the day of Badr. The Apostle of Allaah(ﷺ) also gave me an old she camel from the fifth that day. When I intended to cohabit with Fathimah daughter of the Apostle of Allaah(ﷺ), I made arrangement with a man who was a goldsmith belonging to Banu Qainuqa’ to go with me so that we may bring grass. I intended to sell it to the goldsmith there by seeking help in my wedding feast. While I was collecting for my old Camels saddles, baskets and ropes both of she Camels were seated in a corner of the apartment of a man of the Ansar. When I collected what I collected (i.e., equipment) I turned (towards them). I suddenly found that the humps of she Camels were cut off and their hips were pierced and their lives were taken out. I could not control my eyes (to weep) when I saw that scene. I said “Who has done this?” They (the people) replied “Hamzah bin ‘Abd Al Muttalib”. He is among the drunkards of the Ansar in this house. A singing girl is singing for him and his Companions. While singing she said “Oh Hamza, rise to these plumpy old she Camels. So he jumped to the sword and cut off their humps, pierced their hips and took out their livers.” ‘Ali said “I went till I entered upon the Apostle of Allaah(ﷺ) while Zaid bin Harithah was with him.” The Apostle of Allaah(ﷺ) realized what I had met with. The Apostle of Allaah(ﷺ) aid “What is the matter with you?” I said Apostle of Allaah(ﷺ), I never saw the thing that happened with me today. Hamzah wronged my she Camels, he cut off their humps, pierced their hips. Lo! He is in a house with drunkards. The Apostle of Allaah(ﷺ) asked for his cloak. It was brought to him. He then went out, I and Zaid bin Harithah followed him until we reached the house where Hamzah was. He asked permission ( to entre). He was permitted. He found drunkards there. The Apostle of Allaah(ﷺ) began to rebuke him (Hamzah) for his action. Hamzah was intoxicated and his eyes were reddish. Hamzah looked at the Apostle of Allaah(ﷺ). He then raised his eyes and looked at his knees, he then raised his eyes and looked at his navel and he then raised his eyes and looked at his face. Hamzah then said “Are you but the salves of my father? Then the Apostle of Allaah(ﷺ) knew that he was intoxicated. So the Apostle of Allaah(ﷺ) moved backward. He then went out and we also went out with him.”}}
\hadithdefcmd{abudawud}{2987}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي عَيَّاشُ بْنُ عُقْبَةَ الْحَضْرَمِيُّ، عَنِ الْفَضْلِ بْنِ الْحَسَنِ الضَّمْرِيِّ، أَنَّ أُمَّ الْحَكَمِ، أَوْ ضُبَاعَةَ ابْنَتَىِ الزُّبَيْرِ بْنِ عَبْدِ الْمُطَّلِبِ حَدَّثَتْهُ عَنْ إِحْدَاهُمَا أَنَّهَا قَالَتْ أَصَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَبْيًا فَذَهَبْتُ أَنَا وَأُخْتِي وَفَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَشَكَوْنَا إِلَيْهِ مَا نَحْنُ فِيهِ وَسَأَلْنَاهُ أَنْ يَأْمُرَ لَنَا بِشَىْءٍ مِنَ السَّبْىِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَبَقَكُنَّ يَتَامَى بَدْرٍ لَكِنْ سَأَدُلُّكُنَّ عَلَى مَا هُوَ خَيْرٌ لَكُنَّ مِنْ ذَلِكَ تُكَبِّرْنَ اللَّهَ عَلَى أَثَرِ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ تَكْبِيرَةً وَثَلاَثًا وَثَلاَثِينَ تَسْبِيحَةً وَثَلاَثًا وَثَلاَثِينَ تَحْمِيدَةً وَلاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏ ‏.‏ قَالَ عَيَّاشٌ وَهُمَا ابْنَتَا عَمِّ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2987}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umm Al Hakam or Duba’ah daughters of Al Zibair bin ‘Abd Al Muttalib said “Some captives of war were brought to the Apostle of Allaah(ﷺ). I and my sister Fatimah, daughter of Apostle of Allaah(ﷺ) went (to the Prophet) and complained to him about our existing condition. We asked him to order (to give) us some captives. The Apostle of Allaah(ﷺ) said “the orphans of the people who were killed in the battle of Badr came before you (and they asked for the captives). But I tell you something better than that. You should utter “Allaah is Most Great” after each prayer thirty three times, “Glory be to Allaah” thirty three times, “Praise be to Allaah” thirty three times and “there is no god but Allaah alone, He has no associate, the Kingdom belongs to Him and praise is due to Him and He has power over all things.” The narrator ‘Ayyash said “They were daughters of Uncle of the Prophet (ﷺ).”}}
\hadithdefcmd{abudawud}{2988}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، - يَعْنِي الْجُرَيْرِيَّ - عَنْ أَبِي الْوَرْدِ، عَنِ ابْنِ أَعْبُدَ، قَالَ قَالَ لِي عَلِيٌّ رضى الله عنه أَلاَ أُحَدِّثُكَ عَنِّي وَعَنْ فَاطِمَةَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَتْ مِنْ أَحَبِّ أَهْلِهِ إِلَيْهِ قُلْتُ بَلَى ‏.‏ قَالَ إِنَّهَا جَرَّتْ بِالرَّحَى حَتَّى أَثَّرَ فِي يَدِهَا وَاسْتَقَتْ بِالْقِرْبَةِ حَتَّى أَثَّرَ فِي نَحْرِهَا وَكَنَسَتِ الْبَيْتَ حَتَّى اغْبَرَّتْ ثِيَابُهَا فَأَتَى النَّبِيَّ صلى الله عليه وسلم خَدَمٌ فَقُلْتُ لَوْ أَتَيْتِ أَبَاكِ فَسَأَلْتِيهِ خَادِمًا فَأَتَتْهُ فَوَجَدَتْ عِنْدَهُ حُدَّاثًا فَرَجَعَتْ فَأَتَاهَا مِنَ الْغَدِ فَقَالَ ‏"‏ مَا كَانَ حَاجَتُكِ ‏"‏ ‏.‏ فَسَكَتَتْ فَقُلْتُ أَنَا أُحَدِّثُكَ يَا رَسُولَ اللَّهِ جَرَّتْ بِالرَّحَى حَتَّى أَثَّرَتْ فِي يَدِهَا وَحَمَلَتْ بِالْقِرْبَةِ حَتَّى أَثَّرَتْ فِي نَحْرِهَا فَلَمَّا أَنْ جَاءَكَ الْخَدَمُ أَمَرْتُهَا أَنْ تَأْتِيَكَ فَتَسْتَخْدِمَكَ خَادِمًا يَقِيهَا حَرَّ مَا هِيَ فِيهِ ‏.‏ قَالَ ‏"‏ اتَّقِي اللَّهَ يَا فَاطِمَةُ وَأَدِّي فَرِيضَةَ رَبِّكِ وَاعْمَلِي عَمَلَ أَهْلِكِ فَإِذَا أَخَذْتِ مَضْجَعَكِ فَسَبِّحِي ثَلاَثًا وَثَلاَثِينَ وَاحْمَدِي ثَلاَثًا وَثَلاَثِينَ وَكَبِّرِي أَرْبَعًا وَثَلاَثِينَ فَتِلْكَ مِائَةٌ فَهِيَ خَيْرٌ لَكِ مِنْ خَادِمٍ ‏"‏ ‏.‏ قَالَتْ رَضِيتُ عَنِ اللَّهِ عَزَّ وَجَلَّ وَعَنْ رَسُولِهِ صلى الله عليه وسلم ‏.‏\hadithno{2988}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn A’bud said, ‘Ali said to me “May I not narrate you about me and Fathimah daughter of the Apostle of Allaah(ﷺ)? She was most favorite to him of his family.” I said “Yes”. He said “She pulled the grinding stone with her hand so much that it affected her hand, she carried water in a water bag so much so that it affected the upper portion of her chest, she swept the house so much so that her clothes became dirty. The Prophet (ﷺ) acquired some slaves”. So I said “Would that you go to your father and ask him for a slave. She then came to him and found some people with him talking to him. She therefore returned. Next day she came again. He asked (her), what was your need? But she kept silence. So I said, I inform you, Apostle of Allaah(ﷺ). She pulled grinding stone so much that it affected her hand, she carried water bag so much so that it affected the upper portion of her chest. When the slaves were brought to you I asked her to come to you and to ask you for a slave to save her from the exertion she is suffering.” He said “Fear Allaah, Fathimah and perform the duty of your Lord and do the work of your family.” When you go to bed say “Glory be to Allaah” thirty three times, “Praise be to Allaah” thirty three times, “Allaah is Most Great” thirty four times. This is hundred times. That will be better for you than a servant. She said “I am pleased with Allaah, Most High and with his Apostle (ﷺ).”}}
\hadithdefcmd{abudawud}{2989}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، بِهَذِهِ الْقِصَّةِ قَالَ وَلَمْ يُخْدِمْهَا ‏.‏\hadithno{2989}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by ‘Ali bin Hussain through a different chain of narrators. This version adds “He (the Prophet) did not provide her with a slave.”}}
\hadithdefcmd{abudawud}{2990}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا عَنْبَسَةُ بْنُ عَبْدِ الْوَاحِدِ الْقُرَشِيُّ، قَالَ أَبُو جَعْفَرٍ - يَعْنِي ابْنَ عِيسَى - كُنَّا نَقُولُ إِنَّهُ مِنَ الأَبْدَالِ قَبْلَ أَنْ نَسْمَعَ أَنَّ الأَبْدَالَ مِنَ الْمَوَالِي قَالَ حَدَّثَنِي الدَّخِيلُ بْنُ إِيَاسِ بْنِ نُوحِ بْنِ مُجَّاعَةَ عَنْ هِلاَلِ بْنِ سِرَاجِ بْنِ مُجَّاعَةَ عَنْ أَبِيهِ عَنْ جَدِّهِ مُجَّاعَةَ أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم يَطْلُبُ دِيَةَ أَخِيهِ قَتَلَتْهُ بَنُو سَدُوسٍ مِنْ بَنِي ذُهْلٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ كُنْتُ جَاعِلاً لِمُشْرِكٍ دِيَةً جَعَلْتُ لأَخِيكَ وَلَكِنْ سَأُعْطِيكَ مِنْهُ عُقْبَى ‏"‏ ‏.‏ فَكَتَبَ لَهُ النَّبِيُّ صلى الله عليه وسلم بِمِائَةٍ مِنَ الإِبِلِ مِنْ أَوَّلِ خُمُسٍ يَخْرُجُ مِنْ مُشْرِكِي بَنِي ذُهْلٍ فَأَخَذَ طَائِفَةً مِنْهَا وَأَسْلَمَتْ بَنُو ذُهْلٍ فَطَلَبَهَا بَعْدُ مُجَّاعَةُ إِلَى أَبِي بَكْرٍ وَأَتَاهُ بِكِتَابِ النَّبِيِّ صلى الله عليه وسلم فَكَتَبَ لَهُ أَبُو بَكْرٍ بِاثْنَىْ عَشَرَ أَلْفَ صَاعٍ مِنْ صَدَقَةِ الْيَمَامَةِ أَرْبَعَةِ آلاَفٍ بُرًّا وَأَرْبَعَةِ آلاَفٍ شَعِيرًا وَأَرْبَعَةِ آلاَفٍ تَمْرًا وَكَانَ فِي كِتَابِ النَّبِيِّ صلى الله عليه وسلم لِمُجَّاعَةَ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ هَذَا كِتَابٌ مِنْ مُحَمَّدٍ النَّبِيِّ لِمُجَّاعَةَ بْنِ مُرَارَةَ مِنْ بَنِي سُلْمَى إِنِّي أَعْطَيْتُهُ مِائَةً مِنَ الإِبِلِ مِنْ أَوَّلِ خُمُسٍ يَخْرُجُ مِنْ مُشْرِكِي بَنِي ذُهْلٍ عُقْبَةً مِنْ أَخِيهِ ‏"‏ ‏.‏\hadithno{2990}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mujja'ah ibn Mirarah al-Yamani: Mujja'ah went to the Prophet (ﷺ) asking him for the blood-money of his brother whom Banu Sadus from Banu Dhuhl had killed. The Prophet (ﷺ) said: Had I appointed blood-money for a polytheist, I should have appointed it for your brother. But I shall give you compensation for him. So the Prophet (ﷺ) wrote (a document) for him that he should be given a hundred camels which were to be acquired from the fifth taken from the polytheists of Banu Dhuhl. So he took a part of them, for Banu Dhuhl embraced Islam. He then asked AbuBakr for them later on, and brought to him the document of the Prophet (ﷺ). So AbuBakr wrote for him that he should be given one thousand two hundred sa's from the sadaqah of al-Yamamah; four thousand (sa's) of wheat, four thousand (sa's) of barley, and four thousand (sa's) of dates. The text of the document written by the Prophet (ﷺ) for Mujja'ah was as follows: "In the name of Allah, the Beneficent, the Merciful. This document is from Muhammad, the Prophet, to Mujja'ah ibn Mirarah of Banu Sulma. I have given him one hundred camels from the first fifth acquired from the polytheist of Banu Dhuhl as a compensation for his brother}}
\hadithdefcmd{abudawud}{2991}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ الشَّعْبِيِّ، قَالَ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم سَهْمٌ يُدْعَى الصَّفِيَّ إِنْ شَاءَ عَبْدًا وَإِنْ شَاءَ أَمَةً وَإِنْ شَاءَ فَرَسًا يَخْتَارُهُ قَبْلَ الْخُمُسِ ‏.‏\hadithno{2991}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{‘Amir Al Sha’bi said “The Prophet (ﷺ) had a special portion in the booty called safi. This would be a slave if he desired or a slave girl if he desired or a horse if he desired. He would choose it before taking out the fifth.”}}
\hadithdefcmd{abudawud}{2992}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، وَأَزْهَرُ، قَالاَ حَدَّثَنَا ابْنُ عَوْنٍ، قَالَ سَأَلْتُ مُحَمَّدًا عَنْ سَهْمِ النَّبِيِّ، صلى الله عليه وسلم وَالصَّفِيِّ قَالَ كَانَ يُضْرَبُ لَهُ بِسَهْمٍ مَعَ الْمُسْلِمِينَ وَإِنْ لَمْ يَشْهَدْ وَالصَّفِيُّ يُؤْخَذُ لَهُ رَأْسٌ مِنَ الْخُمُسِ قَبْلَ كُلِّ شَىْءٍ ‏.‏\hadithno{2992}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Awn said “I asked Muhammad about the portion of the prophet(ﷺ) and safi. He replied “A portion was taken for him along with the Muslims, even if he did not attend (the battle) and safi (special portion) was taken from the fifth before everything.”}}
\hadithdefcmd{abudawud}{2993}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ السُّلَمِيُّ، حَدَّثَنَا عُمَرُ، - يَعْنِي ابْنَ عَبْدِ الْوَاحِدِ - عَنْ سَعِيدٍ، - يَعْنِي ابْنَ بَشِيرٍ - عَنْ قَتَادَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا غَزَا كَانَ لَهُ سَهْمٌ صَافٍ يَأْخُذُهُ مِنْ حَيْثُ شَاءَهُ فَكَانَتْ صَفِيَّةُ مِنْ ذَلِكَ السَّهْمِ وَكَانَ إِذَا لَمْ يَغْزُ بِنَفْسِهِ ضُرِبَ لَهُ بِسَهْمِهِ وَلَمْ يُخَيَّرْ ‏.‏\hadithno{2993}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Qatadah said “When the Apostle of Allaah(ﷺ) participated in battle there was for him a special portion which he took from where he desired. Safiyyah was from that portion. But when he did not participate himself in his battle, a portion was taken out for him, but he had no choice.”}}
\hadithdefcmd{abudawud}{2994}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ، أَخْبَرَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ صَفِيَّةُ مِنَ الصَّفِيِّ ‏.‏\hadithno{2994}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{A’ishah said “Safiyyah was called after the word safi (a special portion of the Prophet).”}}
\hadithdefcmd{abudawud}{2995}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الزُّهْرِيِّ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَدِمْنَا خَيْبَرَ فَلَمَّا فَتَحَ اللَّهُ تَعَالَى الْحِصْنَ ذُكِرَ لَهُ جَمَالُ صَفِيَّةَ بِنْتِ حُيَىٍّ وَقَدْ قُتِلَ زَوْجُهَا وَكَانَتْ عَرُوسًا فَاصْطَفَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ فَخَرَجَ بِهَا حَتَّى بَلَغْنَا سُدَّ الصَّهْبَاءِ حَلَّتْ فَبَنَى بِهَا ‏.‏\hadithno{2995}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2235)}\hadithtrans{Anas bin Malik said “We came to Khaibar. We bestowed the conquest of fortress (on us), the beauty of Safiyyah daughter of Huyayy was mentioned to him (the Prophet). Her husband was killed (in the battle) and she was a bride. The Apostle of Allaah(ﷺ) chose her for himself. He came out with her till we reached Sadd Al Sahba’ where she was purified. So he cohabited with her}}
\hadithdefcmd{abudawud}{2996}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَارَتْ صَفِيَّةُ لِدِحْيَةَ الْكَلْبِيِّ ثُمَّ صَارَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2996}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik said “Safiyyah first fell to Dihyat Al Kalbi, the she fell to the Apostle of Allaah(ﷺ)}}
\hadithdefcmd{abudawud}{2997}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ وَقَعَ فِي سَهْمِ دِحْيَةَ جَارِيَةٌ جَمِيلَةٌ فَاشْتَرَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعَةِ أَرْؤُسٍ ثُمَّ دَفَعَهَا إِلَى أُمِّ سُلَيْمٍ تَصْنَعُهَا وَتُهَيِّئُهَا قَالَ حَمَّادٌ وَأَحْسِبُهُ قَالَ وَتَعْتَدُّ فِي بَيْتِهَا صَفِيَّةُ بِنْتُ حُيَىٍّ ‏.‏\hadithno{2997}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas said “A beautiful slave girl fell to Dihyah”. The Apostle of Allaah(ﷺ) purchased her for seven slaves. He then gave her to Umm Sulaim for decorating her and preparing her for marriage. The narrator Hammad said, I think he said “Safiyyah daughter of Huyayy should pass her waiting period in her (Umm Sulaims’) house.”}}
\hadithdefcmd{abudawud}{2998}{حَدَّثَنَا دَاوُدُ بْنُ مُعَاذٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، ح وَحَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، - الْمَعْنَى - قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ جُمِعَ السَّبْىُ - يَعْنِي بِخَيْبَرَ - فَجَاءَ دِحْيَةُ فَقَالَ يَا رَسُولَ اللَّهِ أَعْطِنِي جَارِيَةً مِنَ السَّبْىِ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَخُذْ جَارِيَةً ‏"‏ ‏.‏ فَأَخَذَ صَفِيَّةَ بِنْتَ حُيَىٍّ فَجَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ أَعْطَيْتَ دِحْيَةَ - قَالَ يَعْقُوبُ - صَفِيَّةَ بِنْتَ حُيَىٍّ سَيِّدَةَ قُرَيْظَةَ وَالنَّضِيرِ - ثُمَّ اتَّفَقَا - مَا تَصْلُحُ إِلاَّ لَكَ ‏.‏ قَالَ ‏"‏ ادْعُوهُ بِهَا ‏"‏ ‏.‏ فَلَمَّا نَظَرَ إِلَيْهَا النَّبِيُّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ خُذْ جَارِيَةً مِنَ السَّبْىِ غَيْرَهَا ‏"‏ ‏.‏ وَإِنَّ النَّبِيَّ صلى الله عليه وسلم أَعْتَقَهَا وَتَزَوَّجَهَا ‏.‏\hadithno{2998}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2893) Sahih Muslim (1365 After 1427)}\hadithtrans{Anas said “Captives were gathered at Khaibar. Dihyah came out and said “Apostle of Allaah(ﷺ) give me a slave girl from the captives.” He said “Go and take a slave girl. He took Safiyyah daughter of Huyayy. A man then came to the Prophet (ﷺ) and said “You gave Safiyyah daughter of Huyayy, chief lady of Quraizah and Al Nadir to Dihyah? This is according to the version of Ya’qub. Then the agreed version goes “she is worthy of you.” He said “call him along with her. When the Prophet (ﷺ) looked at her, he said to him “take another slave girl from the captives. The Prophet (ﷺ) then set her free and married her}}
\hadithdefcmd{abudawud}{2999}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا قُرَّةُ، قَالَ سَمِعْتُ يَزِيدَ بْنَ عَبْدِ اللَّهِ، قَالَ كُنَّا بِالْمِرْبَدِ فَجَاءَ رَجُلٌ أَشْعَثُ الرَّأْسِ بِيَدِهِ قِطْعَةُ أَدِيمٍ أَحْمَرَ فَقُلْنَا كَأَنَّكَ مِنْ أَهْلِ الْبَادِيَةِ ‏.‏ فَقَالَ أَجَلْ ‏.‏ قُلْنَا نَاوِلْنَا هَذِهِ الْقِطْعَةَ الأَدِيمَ الَّتِي فِي يَدِكَ فَنَاوَلَنَاهَا فَقَرَأْنَاهَا فَإِذَا فِيهَا ‏ "‏ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ إِلَى بَنِي زُهَيْرِ بْنِ أُقَيْشٍ إِنَّكُمْ إِنْ شَهِدْتُمْ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ وَأَقَمْتُمُ الصَّلاَةَ وَآتَيْتُمُ الزَّكَاةَ وَأَدَّيْتُمُ الْخُمُسَ مِنَ الْمَغْنَمِ وَسَهْمَ النَّبِيِّ صلى الله عليه وسلم وَسَهْمَ الصَّفِيِّ أَنْتُمْ آمِنُونَ بِأَمَانِ اللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏ فَقُلْنَا مَنْ كَتَبَ لَكَ هَذَا الْكِتَابَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2999}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Yazid ibn Abdullah: We were at Mirbad. A man with dishevelled hair and holding a piece of red skin in his hand came. We said: You appear to be a bedouin. He said: Yes. We said: Give us this piece of skin in your hand. He then gave it to us and we read it. It contained the text: "From Muhammad, Messenger of Allah (ﷺ), to Banu Zuhayr ibn Uqaysh. If you bear witness that there is no god but Allah, and that Muhammad is the Messenger of Allah, offer prayer, pay zakat, pay the fifth from the booty, and the portion of the Prophet (ﷺ) and his special portion (safi), you will be under by the protection of Allah and His Apostle." We then asked: Who wrote this document for you? He replied: The Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{3000}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، أَنَّ الْحَكَمَ بْنَ نَافِعٍ، حَدَّثَهُمْ قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، - وَكَانَ أَحَدَ الثَّلاَثَةِ الَّذِينَ تِيبَ عَلَيْهِمْ - وَكَانَ كَعْبُ بْنُ الأَشْرَفِ يَهْجُو النَّبِيَّ صلى الله عليه وسلم وَيُحَرِّضُ عَلَيْهِ كُفَّارَ قُرَيْشٍ وَكَانَ النَّبِيُّ صلى الله عليه وسلم حِينَ قَدِمَ الْمَدِينَةَ وَأَهْلُهَا أَخْلاَطٌ مِنْهُمُ الْمُسْلِمُونَ وَالْمُشْرِكُونَ يَعْبُدُونَ الأَوْثَانَ وَالْيَهُودُ وَكَانُوا يُؤْذُونَ النَّبِيَّ صلى الله عليه وسلم وَأَصْحَابَهُ فَأَمَرَ اللَّهُ عَزَّ وَجَلَّ نَبِيَّهُ بِالصَّبْرِ وَالْعَفْوِ فَفِيهِمْ أَنْزَلَ اللَّهُ ‏\{‏ وَلَتَسْمَعُنَّ مِنَ الَّذِينَ أُوتُوا الْكِتَابَ مِنْ قَبْلِكُمْ ‏\}‏ الآيَةَ فَلَمَّا أَبَى كَعْبُ بْنُ الأَشْرَفِ أَنْ يَنْزِعَ عَنْ أَذَى النَّبِيِّ صلى الله عليه وسلم أَمَرَ النَّبِيُّ صلى الله عليه وسلم سَعْدَ بْنَ مُعَاذٍ أَنْ يَبْعَثَ رَهْطًا يَقْتُلُونَهُ فَبَعَثَ مُحَمَّدَ بْنَ مَسْلَمَةَ وَذَكَرَ قِصَّةَ قَتْلِهِ فَلَمَّا قَتَلُوهُ فَزِعَتِ الْيَهُودُ وَالْمُشْرِكُونَ فَغَدَوْا عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا طُرِقَ صَاحِبُنَا فَقُتِلَ ‏.‏ فَذَكَرَ لَهُمُ النَّبِيُّ صلى الله عليه وسلم الَّذِي كَانَ يَقُولُ وَدَعَاهُمُ النَّبِيُّ صلى الله عليه وسلم إِلَى أَنْ يَكْتُبَ بَيْنَهُ وَبَيْنَهُمْ كِتَابًا يَنْتَهُونَ إِلَى مَا فِيهِ فَكَتَبَ النَّبِيُّ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَهُمْ وَبَيْنَ الْمُسْلِمِينَ عَامَّةً صَحِيفَةً ‏.‏\hadithno{3000}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ka’ab bin Malik who was one of those whose repentance was accepted said “Ka’ab bin Al Ashraf used to satire the Prophet (ﷺ) and incited the infidels of the Quraish against him. When the Prophet (ﷺ) came to Madeena, its people were intermixed, some of them were Muslims and others polytheists aho worshipped idols and some were Jews. They used to hurt the Prophet (ﷺ) and his Companions. Then Allaah Most High commanded His Prophet to show patience and forgiveness. So Allaah revealed about them “And ye shall certainly hear much that will grieve you from those who receive Book before you”. When Ka’ab bin Al Ashraf refused to desist from hurting the Prophet (ﷺ) the Prophet(ﷺ) ordered Sa’d bin Mu’adh to send a band to kill him. He sent Muhammad bin Maslamah and mentioned the story of his murder. When they killed him, the Jews and the polytheist were frightened. Next day they came to the Prophet (ﷺ) and said “Our Companions were attacked and night and killed.” The Prophet(ﷺ) informed them about that which he would say. The Prophet (ﷺ) then called them so that he could write a deed of agreement between him and them and they should fulfill its provisions and desist from hurting him. He then wrote a deed of agreement between him and them and the Muslims in general.”}}
\hadithdefcmd{abudawud}{3001}{حَدَّثَنَا مُصَرِّفُ بْنُ عَمْرٍو الأَيَامِيُّ، حَدَّثَنَا يُونُسُ، - يَعْنِي ابْنَ بُكَيْرٍ - قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي مُحَمَّدٍ، مَوْلَى زَيْدِ بْنِ ثَابِتٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا أَصَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُرَيْشًا يَوْمَ بَدْرٍ وَقَدِمَ الْمَدِينَةَ جَمَعَ الْيَهُودَ فِي سُوقِ بَنِي قَيْنُقَاعَ فَقَالَ ‏"‏ يَا مَعْشَرَ يَهُودَ أَسْلِمُوا قَبْلَ أَنْ يُصِيبَكُمْ مِثْلُ مَا أَصَابَ قُرَيْشًا ‏"‏ ‏.‏ قَالُوا يَا مُحَمَّدُ لاَ يَغُرَّنَّكَ مِنْ نَفْسِكَ أَنَّكَ قَتَلْتَ نَفَرًا مِنْ قُرَيْشٍ كَانُوا أَغْمَارًا لاَ يَعْرِفُونَ الْقِتَالَ إِنَّكَ لَوْ قَاتَلْتَنَا لَعَرَفْتَ أَنَّا نَحْنُ النَّاسُ وَأَنَّكَ لَمْ تَلْقَ مِثْلَنَا ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي ذَلِكَ ‏\{‏ قُلْ لِلَّذِينَ كَفَرُوا سَتُغْلَبُونَ ‏\}‏ قَرَأَ مُصَرِّفٌ إِلَى قَوْلِهِ ‏\{‏ فِئَةٌ تُقَاتِلُ فِي سَبِيلِ اللَّهِ ‏\}‏ بِبَدْرٍ ‏\{‏ وَأُخْرَى كَافِرَةٌ ‏\}‏ ‏.‏\hadithno{3001}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas said “When the Apostle of Allaah(ﷺ) had victory over Quraish in the batte of Badr and came to Madeenah he gathered the Jews in the market of Banu Qainuqa and said “O community of Jews embrace Islam before you suffer an injury as the Quraish suffered.” They said “Muhammad, you should not deceive yourself (taking pride) that you had killed a few persons of the Quariash who were inexperienced and did not know how to fight. Had you fought with us, you would have known us. You have never met people like us.” Allah Most High revealed about this the following verse “Say to those who reject faith, soon will ye be vanished... one army was fighting in the cause of Allaah, the other resisting Allaah.”}}
\hadithdefcmd{abudawud}{3002}{حَدَّثَنَا مُصَرِّفُ بْنُ عَمْرٍو، حَدَّثَنَا يُونُسُ، قَالَ ابْنُ إِسْحَاقَ حَدَّثَنِي مَوْلًى، لِزَيْدِ بْنِ ثَابِتٍ حَدَّثَتْنِي ابْنَةُ مُحَيِّصَةَ، عَنْ أَبِيهَا، مُحَيِّصَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ظَفِرْتُمْ بِهِ مِنْ رِجَالِ يَهُودَ فَاقْتُلُوهُ ‏"‏ ‏.‏ فَوَثَبَ مُحَيِّصَةُ عَلَى شَبِيبَةَ رَجُلٍ مِنْ تُجَّارِ يَهُودَ كَانَ يُلاَبِسُهُمْ فَقَتَلَهُ وَكَانَ حُوَيِّصَةُ إِذْ ذَاكَ لَمْ يُسْلِمْ وَكَانَ أَسَنَّ مِنْ مُحَيِّصَةَ فَلَمَّا قَتَلَهُ جَعَلَ حُوَيِّصَةُ يَضْرِبُهُ وَيَقُولُ يَا عَدُوَّ اللَّهِ أَمَا وَاللَّهِ لَرُبَّ شَحْمٍ فِي بَطْنِكَ مِنْ مَالِهِ ‏.‏\hadithno{3002}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muhayyisah: The Messenger of Allah (ﷺ) said: If you gain a victory over the men of Jews, kill them. So Muhayyisah jumped over Shubaybah, a man of the Jewish merchants. He had close relations with them. He then killed him. At that time Huwayyisah (brother of Muhayyisah) had not embraced Islam. He was older than Muhayyisah. When he killed him, Huwayyisah beat him and said: O enemy of Allah, I swear by Allah, you have a good deal of fat in your belly from his property}}
\hadithdefcmd{abudawud}{3003}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ بَيْنَا نَحْنُ فِي الْمَسْجِدِ إِذْ خَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْطَلِقُوا إِلَى يَهُودَ ‏"‏ ‏.‏ فَخَرَجْنَا مَعَهُ حَتَّى جِئْنَاهُمْ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَادَاهُمْ فَقَالَ يَا مَعْشَرَ يَهُودَ أَسْلِمُوا تَسْلَمُوا ‏"‏ ‏.‏ فَقَالُوا قَدْ بَلَّغْتَ يَا أَبَا الْقَاسِمِ ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَسْلِمُوا تَسْلَمُوا ‏"‏ ‏.‏ فَقَالُوا قَدْ بَلَّغْتَ يَا أَبَا الْقَاسِمِ ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَلِكَ أُرِيدُ ‏"‏ ‏.‏ ثُمَّ قَالَهَا الثَّالِثَةَ ‏"‏ اعْلَمُوا أَنَّمَا الأَرْضُ لِلَّهِ وَرَسُولِهِ وَإِنِّي أُرِيدُ أَنْ أُجْلِيَكُمْ مِنْ هَذِهِ الأَرْضِ فَمَنْ وَجَدَ مِنْكُمْ بِمَالِهِ شَيْئًا فَلْيَبِعْهُ وَإِلاَّ فَاعْلَمُوا أَنَّمَا الأَرْضُ لِلَّهِ وَرَسُولِهِ صلى الله عليه وسلم ‏"‏ ‏.‏\hadithno{3003}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3167) Sahih Muslim (1765)}\hadithtrans{Abu Hurairah said, While we were in the mosque, the Apostle of Allaah(ﷺ) came out and said “Come on to the Jews. So we went out with him and came to them”. The Apostle of Allaah(ﷺ) stood up, called them and said “If you, the community of Jews accept Islam you will be safe”. They said “You have given the message Abu Al Qasim”. The Apostle of Allaah(ﷺ) said “Accept Islam you will be safe”. They said “You have given the message Abu Al Qasim”. The Apostle of Allaah(ﷺ) said “that I intended”. He then said the third time “Know that the land belongs to Allaah and His Apostle and I intend to deport you from this land. So, if any of you has property (he cannot take it away), he must sell it, otherwise know that the land belongs to Allaah and His Apostle (ﷺ).”}}
\hadithdefcmd{abudawud}{3004}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ كُفَّارَ قُرَيْشٍ كَتَبُوا إِلَى ابْنِ أُبَىٍّ وَمَنْ كَانَ يَعْبُدُ مَعَهُ الأَوْثَانَ مِنَ الأَوْسِ وَالْخَزْرَجِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ بِالْمَدِينَةِ قَبْلَ وَقْعَةِ بَدْرٍ إِنَّكُمْ آوَيْتُمْ صَاحِبَنَا وَإِنَّا نُقْسِمُ بِاللَّهِ لَتُقَاتِلُنَّهُ أَوْ لَتُخْرِجُنَّهُ أَوْ لَنَسِيرَنَّ إِلَيْكُمْ بِأَجْمَعِنَا حَتَّى نَقْتُلَ مُقَاتِلَتَكُمْ وَنَسْتَبِيحَ نِسَاءَكُمْ ‏.‏ فَلَمَّا بَلَغَ ذَلِكَ عَبْدَ اللَّهِ بْنَ أُبَىٍّ وَمَنْ كَانَ مَعَهُ مِنْ عَبَدَةِ الأَوْثَانِ اجْتَمَعُوا لِقِتَالِ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا بَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم لَقِيَهُمْ فَقَالَ ‏"‏ لَقَدْ بَلَغَ وَعِيدُ قُرَيْشٍ مِنْكُمُ الْمَبَالِغَ مَا كَانَتْ تَكِيدُكُمْ بِأَكْثَرَ مِمَّا تُرِيدُونَ أَنْ تَكِيدُوا بِهِ أَنْفُسَكُمْ تُرِيدُونَ أَنْ تُقَاتِلُوا أَبْنَاءَكُمْ وَإِخْوَانَكُمْ ‏"‏ ‏.‏ فَلَمَّا سَمِعُوا ذَلِكَ مِنَ النَّبِيِّ صلى الله عليه وسلم تَفَرَّقُوا فَبَلَغَ ذَلِكَ كُفَّارَ قُرَيْشٍ فَكَتَبَتْ كُفَّارُ قُرَيْشٍ بَعْدَ وَقْعَةِ بَدْرٍ إِلَى الْيَهُودِ إِنَّكُمْ أَهْلُ الْحَلْقَةِ وَالْحُصُونِ وَإِنَّكُمْ لَتُقَاتِلُنَّ صَاحِبَنَا أَوْ لَنَفْعَلَنَّ كَذَا وَكَذَا وَلاَ يَحُولُ بَيْنَنَا وَبَيْنَ خَدَمِ نِسَائِكُمْ شَىْءٌ - وَهِيَ الْخَلاَخِيلُ - فَلَمَّا بَلَغَ كِتَابُهُمُ النَّبِيَّ صلى الله عليه وسلم أَجْمَعَتْ بَنُو النَّضِيرِ بِالْغَدْرِ فَأَرْسَلُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم اخْرُجْ إِلَيْنَا فِي ثَلاَثِينَ رَجُلاً مِنْ أَصْحَابِكَ وَلْيَخْرُجْ مِنَّا ثَلاَثُونَ حَبْرًا حَتَّى نَلْتَقِيَ بِمَكَانِ الْمَنْصَفِ فَيَسْمَعُوا مِنْكَ ‏.‏ فَإِنْ صَدَّقُوكَ وَآمَنُوا بِكَ آمَنَّا بِكَ فَقَصَّ خَبَرَهُمْ فَلَمَّا كَانَ الْغَدُ غَدَا عَلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْكَتَائِبِ فَحَصَرَهُمْ فَقَالَ لَهُمْ ‏"‏ إِنَّكُمْ وَاللَّهِ لاَ تَأْمَنُونَ عِنْدِي إِلاَّ بِعَهْدٍ تُعَاهِدُونِي عَلَيْهِ ‏"‏ ‏.‏ فَأَبَوْا أَنْ يُعْطُوهُ عَهْدًا فَقَاتَلَهُمْ يَوْمَهُمْ ذَلِكَ ثُمَّ غَدَا الْغَدُ عَلَى بَنِي قُرَيْظَةَ بِالْكَتَائِبِ وَتَرَكَ بَنِي النَّضِيرِ وَدَعَاهُمْ إِلَى أَنْ يُعَاهِدُوهُ فَعَاهَدُوهُ فَانْصَرَفَ عَنْهُمْ وَغَدَا عَلَى بَنِي النَّضِيرِ بِالْكَتَائِبِ فَقَاتَلَهُمْ حَتَّى نَزَلُوا عَلَى الْجَلاَءِ فَجَلَتْ بَنُو النَّضِيرِ وَاحْتَمَلُوا مَا أَقَلَّتِ الإِبِلُ مِنْ أَمْتِعَتِهِمْ وَأَبْوَابِ بُيُوتِهِمْ وَخَشَبِهَا فَكَانَ نَخْلُ بَنِي النَّضِيرِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَاصَّةً أَعْطَاهُ اللَّهُ إِيَّاهَا وَخَصَّهُ بِهَا فَقَالَ ‏\{‏ وَمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْهُمْ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلاَ رِكَابٍ ‏\}‏ يَقُولُ بِغَيْرِ قِتَالٍ فَأَعْطَى النَّبِيُّ صلى الله عليه وسلم أَكْثَرَهَا لِلْمُهَاجِرِينَ وَقَسَمَهَا بَيْنَهُمْ وَقَسَمَ مِنْهَا لِرَجُلَيْنِ مِنَ الأَنْصَارِ وَكَانَا ذَوِي حَاجَةٍ لَمْ يَقْسِمْ لأَحَدٍ مِنَ الأَنْصَارِ غَيْرَهُمَا وَبَقِيَ مِنْهَا صَدَقَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي فِي أَيْدِي بَنِي فَاطِمَةَ رَضِيَ اللَّهُ عَنْهَا ‏.‏\hadithno{3004}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated A man from the companions of the Prophet: AbdurRahman ibn Ka'b ibn Malik reported on the authority of a man from among the companions of the Prophet (ﷺ): The infidels of the Quraysh wrote (a letter) to Ibn Ubayy and to those who worshipped idols from al-Aws and al-Khazraj, while the Messenger of Allah (ﷺ) was at that time at Medina before the battle of Badr. (They wrote): You gave protection to our companion. We swear by Allah, you should fight him or expel him, or we shall come to you in full force, until we kill your fighters and appropriate your women. When this (news) reached Abdullah ibn Ubayy and those who were worshippers of idols, with him they gathered together to fight the Messenger of Allah (ﷺ). When this news reached the Messenger of Allah (ﷺ), he visited them and said: The threat of the Quraysh to you has reached its end. They cannot contrive a plot against you, greater than what you yourselves intended to harm you. Are you willing to fight your sons and brethren? When they heard this from the Prophet (ﷺ), they scattered. This reached the infidels of the Quraysh. The infidels of the Quraysh again wrote (a letter) to the Jews after the battle of Badr: You are men of weapons and fortresses. You should fight our companion or we shall deal with you in a certain way. And nothing will come between us and the anklets of your women. When their letter reached the Prophet (ﷺ), they gathered Banu an-Nadir to violate the treaty. They sent a message to the Prophet (ﷺ): Come out to us with thirty men from your companions, and thirty rabbis will come out from us till we meet at a central place where they will hear you. If they testify to you and believe in you, we shall believe in you. The narrator then narrated the whole story. When the next day came, the Messenger of Allah (ﷺ) went out in the morning with an army, and surrounded them. He told them: I swear by Allah, you will have no peace from me until you conclude a treaty with me. But they refused to conclude a treaty with him. He therefore fought them the same day. Next he attacked Banu Quraysh with an army in the morning, and left Banu an-Nadir. He asked them to sign a treaty and they signed it. He turned away from them and attacked Banu an-Nadir with an army. He fought with them until they agreed to expulsion. Banu an-Nadir were deported, and they took with them whatever their camels could carry, that is, their property, the doors of their houses, and their wood. Palm-trees were exclusively reserved for the Messenger of Allah (ﷺ). Allah bestowed them upon him and gave them him as a special portion. He (Allah), the Exalted, said: What Allah has bestowed on His Apostle (and taken away) from them, for this ye made no expedition with either camel corps or cavalry." He said: "Without fighting." So the Prophet (ﷺ) gave most of it to the emigrants and divided it among them; and he divided some of it between two men from the helpers, who were needy, and he did not divide it among any of the helpers except those two. The rest of it survived as the sadaqah of the Messenger of Allah (ﷺ) which is in the hands of the descendants of Fatimah (Allah be pleased with her)}}
\hadithdefcmd{abudawud}{3005}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ يَهُودَ بَنِي النَّضِيرِ، وَقُرَيْظَةَ، حَارَبُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَجْلَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَنِي النَّضِيرِ وَأَقَرَّ قُرَيْظَةَ وَمَنَّ عَلَيْهِمْ حَتَّى حَارَبَتْ قُرَيْظَةُ بَعْدَ ذَلِكَ فَقَتَلَ رِجَالَهُمْ وَقَسَمَ نِسَاءَهُمْ وَأَوْلاَدَهُمْ وَأَمْوَالَهُمْ بَيْنَ الْمُسْلِمِينَ إِلاَّ بَعْضَهُمْ لَحِقُوا بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَّنَهُمْ وَأَسْلَمُوا وَأَجْلَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَهُودَ الْمَدِينَةِ كُلَّهُمْ بَنِي قَيْنُقَاعَ وَهُمْ قَوْمُ عَبْدِ اللَّهِ بْنِ سَلاَمٍ وَيَهُودَ بَنِي حَارِثَةَ وَكُلَّ يَهُودِيٍّ كَانَ بِالْمَدِينَةِ ‏.‏\hadithno{3005}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4028) Sahih Muslim (1766)}\hadithtrans{Ibn ‘Umar said “The Jews Al Nadir and Quraizah fought with the Apostle of Allaah(ﷺ), so the Apostle of Allaah(ﷺ) expelled Banu Al Nadir and allowed the Quraizah to stay and favored them. The Quraizah thereafter fought (with the Prophet).” So he killed their men and divided their women, property and children among Muslims except some of them who associated with the Apostle of Allaah(ﷺ). He gave them protection and later on they embraced Islam. The Apostle of Allaah(ﷺ) expelled all the Jews of Madeenah in Toto, Banu Qainuqa, they were the people of ‘Abd Allaah bin Salam, the Jews of Banu Harith and any of Jews who resided in Madeenah}}
\hadithdefcmd{abudawud}{3006}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، قَالَ - أَحْسِبُهُ - عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَاتَلَ أَهْلَ خَيْبَرَ فَغَلَبَ عَلَى النَّخْلِ وَالأَرْضِ وَأَلْجَأَهُمْ إِلَى قَصْرِهِمْ فَصَالَحُوهُ عَلَى أَنَّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم الصَّفْرَاءَ وَالْبَيْضَاءَ وَالْحَلْقَةَ وَلَهُمْ مَا حَمَلَتْ رِكَابُهُمْ عَلَى أَنْ لاَ يَكْتُمُوا وَلاَ يُغَيِّبُوا شَيْئًا فَإِنْ فَعَلُوا فَلاَ ذِمَّةَ لَهُمْ وَلاَ عَهْدَ فَغَيَّبُوا مَسْكًا لِحُيَىِّ بْنِ أَخْطَبَ وَقَدْ كَانَ قُتِلَ قَبْلَ خَيْبَرَ كَانَ احْتَمَلَهُ مَعَهُ يَوْمَ بَنِي النَّضِيرِ حِينَ أُجْلِيَتِ النَّضِيرُ فِيهِ حُلِيُّهُمْ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِسَعْيَةَ ‏ "‏ أَيْنَ مَسْكُ حُيَىِّ بْنِ أَخْطَبَ ‏"‏ ‏.‏ قَالَ أَذْهَبَتْهُ الْحُرُوبُ وَالنَّفَقَاتُ ‏.‏ فَوَجَدُوا الْمَسْكَ فَقَتَلَ ابْنَ أَبِي الْحُقَيْقِ وَسَبَى نِسَاءَهُمْ وَذَرَارِيَّهُمْ وَأَرَادَ أَنْ يُجْلِيَهُمْ فَقَالُوا يَا مُحَمَّدُ دَعْنَا نَعْمَلْ فِي هَذِهِ الأَرْضِ وَلَنَا الشَّطْرُ مَا بَدَا لَكَ وَلَكُمُ الشَّطْرُ ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْطِي كُلَّ امْرَأَةٍ مِنْ نِسَائِهِ ثَمَانِينَ وَسْقًا مِنْ تَمْرٍ وَعِشْرِينَ وَسْقًا مِنْ شَعِيرٍ ‏.‏\hadithno{3006}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah Ibn Umar: The Prophet fought with the people of Khaybar, and captured their palm-trees and land, and forced them to remain confined to their fortresses. So they concluded a treaty of peace providing that gold, silver and weapons would go to the Messenger of Allah (ﷺ), and whatever they took away on their camels would belong to them, on condition that they would not hide and carry away anything. If they did (so), there would be no protection for them and no treaty (with Muslims). They carried away a purse of Huyayy ibn Akhtab who was killed before (the battle of) Khaybar. He took away the ornaments of Banu an-Nadir when they were expelled. The Prophet (ﷺ) asked Sa'yah: Where is the purse of Huyayy ibn Akhtab? He replied: The contents of this purse were spent on battles and other expenses. (Later on) they found the purse. So he killed Ibn AbulHuqayq, captured their women and children, and intended to deport them. They said: Muhammad, leave us to work on this land; we shall have half (of the produce) as you wish, and you will have half. The Messenger of Allah (ﷺ) used to make a contribution of eighty wasqs of dates and twenty wasqs of wheat to each of his wives}}
\hadithdefcmd{abudawud}{3007}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي نَافِعٌ، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ، قَالَ أَيُّهَا النَّاسُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَامَلَ يَهُودَ خَيْبَرَ عَلَى أَنَّا نُخْرِجُهُمْ إِذَا شِئْنَا فَمَنْ كَانَ لَهُ مَالٌ فَلْيَلْحَقْ بِهِ فَإِنِّي مُخْرِجٌ يَهُودَ ‏.‏ فَأَخْرَجَهُمْ ‏.‏\hadithno{3007}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: Umar said: The Messenger of Allah (ﷺ) had transaction with the Jews of Khaybar on condition that we should expel them when we wish. If anyone has property (with them), he should take it back, for I am going to expel the Jews. So he expelled them}}
\hadithdefcmd{abudawud}{3008}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ اللَّيْثِيُّ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ لَمَّا افْتُتِحَتْ خَيْبَرُ سَأَلَتْ يَهُودُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُقِرَّهُمْ عَلَى أَنْ يَعْمَلُوا عَلَى النِّصْفِ مِمَّا خَرَجَ مِنْهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُقِرُّكُمْ فِيهَا عَلَى ذَلِكَ مَا شِئْنَا ‏"‏ ‏.‏ فَكَانُوا عَلَى ذَلِكَ وَكَانَ التَّمْرُ يُقْسَمُ عَلَى السُّهْمَانِ مِنْ نِصْفِ خَيْبَرَ وَيَأْخُذُ رَسُولُ اللَّهِ صلى الله عليه وسلم الْخُمُسَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَطْعَمَ كُلَّ امْرَأَةٍ مِنْ أَزْوَاجِهِ مِنَ الْخُمُسِ مِائَةَ وَسْقٍ تَمْرًا وَعِشْرِينَ وَسْقًا شَعِيرًا فَلَمَّا أَرَادَ عُمَرُ إِخْرَاجَ الْيَهُودِ أَرْسَلَ إِلَى أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُنَّ مَنْ أَحَبَّ مِنْكُنَّ أَنْ أَقْسِمَ لَهَا نَخْلاً بِخَرْصِهَا مِائَةَ وَسْقٍ فَيَكُونَ لَهَا أَصْلُهَا وَأَرْضُهَا وَمَاؤُهَا وَمِنَ الزَّرْعِ مَزْرَعَةُ خَرْصٍ عِشْرِينَ وَسْقًا فَعَلْنَا وَمَنْ أَحَبَّ أَنْ نَعْزِلَ الَّذِي لَهَا فِي الْخُمُسِ كَمَا هُوَ فَعَلْنَا ‏.‏\hadithno{3008}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Sahih Muslim (1551)}\hadithtrans{‘Abd Allah bin ‘Umar reported that ‘Umar said “When Khaibar was conquered, the Jews asked the Apostle of Allaah(ﷺ) to confirm that they would do all the cultivation and have half the produce. The Apostle of Allaah(ﷺ) said “I shall confirm you on that condition as long as we wish. So they were confirmed on that (condition). The dates from half the produce of Khaibar were divided into a number of portions. The Apostle of Allaah(ﷺ) would take the fifth. The Apostle of Allaah(ﷺ) used to contribute from the fifth one hundred wasqs of dates and twenty wasqs of wheat to each of his wives. When ‘Umar intended to expel the Jews from Khaibar he sent a message to the wives of the Prophet (ﷺ) and said to them “If any of you wishes that I divide the palm trees for her by their assessment that amounts one hundred wasqs (of dates) and to her belongs their root, their land and their water and (likewise) twenty wasqs from the produce of the cultivated land by assessment, I shall (do that). And if any of you wishes that we take out her portion from the fifth, we shall do (that)}}
\hadithdefcmd{abudawud}{3009}{حَدَّثَنَا دَاوُدُ بْنُ مُعَاذٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، ح وَحَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، وَزِيَادُ بْنُ أَيُّوبَ، أَنَّ إِسْمَاعِيلَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُمْ عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَزَا خَيْبَرَ فَأَصَبْنَاهَا عَنْوَةً فَجَمَعَ السَّبْىَ ‏.‏\hadithno{3009}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (371) Sahih Muslim (1365 After  1427)}\hadithtrans{Anas bin Malik said “The Apostle of Allaah(ﷺ) attacked Khaibar and we captured it by conquest. He then gathered the captives of war.”}}
\hadithdefcmd{abudawud}{3010}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ، حَدَّثَنَا أَسَدُ بْنُ مُوسَى، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا، حَدَّثَنِي سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ نِصْفَيْنِ نِصْفًا لِنَوَائِبِهِ وَحَاجَتِهِ وَنِصْفًا بَيْنَ الْمُسْلِمِينَ قَسَمَهَا بَيْنَهُمْ عَلَى ثَمَانِيَةَ عَشَرَ سَهْمًا ‏.‏\hadithno{3010}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Sahl bin Abi Hathmah said “The Apostle of Allaah(ﷺ) divide Khaibar into two halves. One half was reserved for his emergency and needs, the other half was meant for the Muslims. He divided among them into eighteen portions.”}}
\hadithdefcmd{abudawud}{3011}{حَدَّثَنَا حُسَيْنُ بْنُ عَلِيِّ بْنِ الأَسْوَدِ، أَنَّ يَحْيَى بْنَ آدَمَ، حَدَّثَهُمْ عَنْ أَبِي شِهَابٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، أَنَّهُ سَمِعَ نَفَرًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالُوا فَذَكَرَ هَذَا الْحَدِيثَ قَالَ فَكَانَ النِّصْفُ سِهَامَ الْمُسْلِمِينَ وَسَهْمَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَزَلَ النِّصْفَ لِلْمُسْلِمِينَ لِمَا يَنُوبُهُ مِنَ الأُمُورِ وَالنَّوَائِبِ ‏.‏\hadithno{3011}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bashir bin Yasar said that he heard a number of the Companions of the Prophet (ﷺ) say. He then narrated the tradition (mentioned above). He said “One half comprised the portions of the Muslims and the portion of the Apostle of Allaah(ﷺ). He separated the other half for the Muslims for any calamity that befalls him and for emergent needs.”}}
\hadithdefcmd{abudawud}{3012}{حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، مَوْلَى الأَنْصَارِ عَنْ رِجَالٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا ظَهَرَ عَلَى خَيْبَرَ قَسَمَهَا عَلَى سِتَّةٍ وَثَلاَثِينَ سَهْمًا جَمَعَ كُلُّ سَهْمٍ مِائَةَ سَهْمٍ فَكَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَلِلْمُسْلِمِينَ النِّصْفُ مِنْ ذَلِكَ وَعَزَلَ النِّصْفَ الْبَاقِيَ لِمَنْ نَزَلَ بِهِ مِنَ الْوُفُودِ وَالأُمُورِ وَنَوَائِبِ النَّاسِ ‏.‏\hadithno{3012}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated A Group of Companions of the Prophet: Bashir ibn Yasar, the client of the Ansar, reported on the authority of a group of the Companions of the Prophet (ﷺ): When the Messenger of Allah (ﷺ) conquered Khaybar, he divided it into thirty-six lots, each lot comprising one hundred portions. One half of it was for the Messenger of Allah (ﷺ) and for the Muslims; and he separated the remaining half for the deputations which came to him, other matters and emergent needs of the people}}
\hadithdefcmd{abudawud}{3013}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي سُلَيْمَانَ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، قَالَ لَمَّا أَفَاءَ اللَّهُ عَلَى نَبِيِّهِ صلى الله عليه وسلم خَيْبَرَ قَسَمَهَا عَلَى سِتَّةٍ وَثَلاَثِينَ سَهْمًا جَمَعَ كُلُّ سَهْمٍ مِائَةَ سَهْمٍ فَعَزَلَ نِصْفَهَا لِنَوَائِبِهِ وَمَا يَنْزِلُ بِهِ الْوَطِيحَةَ وَالْكُتَيْبَةَ وَمَا أُحِيزَ مَعَهُمَا وَعَزَلَ النِّصْفَ الآخَرَ فَقَسَمَهُ بَيْنَ الْمُسْلِمِينَ الشَّقَّ وَالنَّطَاةَ وَمَا أُحِيزَ مَعَهُمَا وَكَانَ سَهْمُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيمَا أُحِيزَ مَعَهُمَا ‏.‏\hadithno{3013}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Bashir bin Yasar said “When Allaah bestowed Khaibar on His Prophet (ﷺ) as fai’ (spoils), he divided it into thirty six lots. Each lot comprised one hundred portions. He separated its half for his emergent needs and whatever befalls him. Al Watih and Al Kutaibah and Al Salalim and whatever acquired with them. He separated the other half and he divided Al Shaqq and Nata’ and whatever acquired with them. The portion of the Apostle of Allaah(ﷺ) lay in the property acquired with them}}
\hadithdefcmd{abudawud}{3014}{حَدَّثَنَا مُحَمَّدُ بْنُ مِسْكِينٍ الْيَمَامِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا أَفَاءَ اللَّهُ عَلَيْهِ خَيْبَرَ قَسَمَهَا سِتَّةً وَثَلاَثِينَ سَهْمًا جَمْعًا فَعَزَلَ لِلْمُسْلِمِينَ الشَّطْرَ ثَمَانِيَةَ عَشَرَ سَهْمًا يَجْمَعُ كُلُّ سَهْمٍ مِائَةً النَّبِيُّ صلى الله عليه وسلم مَعَهُمْ لَهُ سَهْمٌ كَسَهْمِ أَحَدِهِمْ وَعَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَمَانِيَةَ عَشَرَ سَهْمًا وَهُوَ الشَّطْرُ لِنَوَائِبِهِ وَمَا يَنْ��ِلُ بِهِ مِنْ أَمْرِ الْمُسْلِمِينَ فَكَانَ ذَلِكَ الْوَطِيحَ وَالْكُتَيْبَةَ وَالسُّلاَلِمَ وَتَوَابِعَهَا فَلَمَّا صَارَتِ الأَمْوَالُ بِيَدِ النَّبِيِّ صلى الله عليه وسلم وَالْمُسْلِمِينَ لَمْ يَكُنْ لَهُمْ عُمَّالٌ يَكْفُونَهُمْ عَمَلَهَا فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْيَهُودَ فَعَامَلَهُمْ ‏.‏\hadithno{3014}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Bashir ibn Yasar: When Allah bestowed Khaybar on the Messenger of Allah (ﷺ) as fay' (spoils of war without fighting), he divided the whole into thirty six lots. He put aside a half, i.e. eighteen lots, for the Muslims. Each lot comprised one hundred shares, and the Prophet (ﷺ) was with them. He received a share like the share of one of them. The Messenger of Allah (ﷺ) separated eighteen lots, that is, half, for his future needs and whatever befell the Muslims. These were al-Watih, al-Kutaybah, as-Salalim and their colleagues. When all this property came in the possession of the Prophet (ﷺ) and of the Muslims, they did not have sufficient labourers to work on it. The Messenger of Allah (ﷺ) called Jews and employed them on contract}}
\hadithdefcmd{abudawud}{3015}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا مُجَمِّعُ بْنُ يَعْقُوبَ بْنِ مُجَمِّعِ بْنِ يَزِيدَ الأَنْصَارِيُّ، قَالَ سَمِعْتُ أَبِي يَعْقُوبَ بْنَ مُجَمِّعٍ، يَذْكُرُ لِي عَنْ عَمِّهِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ الأَنْصَارِيِّ، عَنْ عَمِّهِ، مُجَمِّعِ بْنِ جَارِيَةَ الأَنْصَارِيِّ - وَكَانَ أَحَدَ الْقُرَّاءِ الَّذِينَ قَرَءُوا الْقُرْآنَ - قَالَ قُسِمَتْ خَيْبَرُ عَلَى أَهْلِ الْحُدَيْبِيَةِ فَقَسَمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ثَمَانِيَةَ عَشَرَ سَهْمًا وَكَانَ الْجَيْشُ أَلْفًا وَخَمْسَمِائَةٍ فِيهِمْ ثَلاَثُمِائَةِ فَارِسٍ فَأَعْطَى الْفَارِسَ سَهْمَيْنِ وَأَعْطَى الرَّاجِلَ سَهْمًا ‏.‏\hadithno{3015}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Mujammi' ibn Jariyah al-Ansari,: Khaybar was divided among the people of al-Hudaybiyyah. The Messenger of Allah (ﷺ) divided it into eighteen portions. The army contained one thousand and five hundred people. There were three hundred horsemen among them. He gave double share to the horsemen, and a single to the footmen}}
\hadithdefcmd{abudawud}{3016}{حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْعِجْلِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ آدَمَ - حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، وَعَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، وَبَعْضِ، وَلَدِ مُحَمَّدِ بْنِ مَسْلَمَةَ قَالُوا بَقِيَتْ بَقِيَّةٌ مِنْ أَهْلِ خَيْبَرَ تَحَصَّنُوا فَسَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَحْقِنَ دِمَاءَهُمْ وَيُسَيِّرَهُمْ فَفَعَلَ فَسَمِعَ بِذَلِكَ أَهْلُ فَدَكَ فَنَزَلُوا عَلَى مِثْلِ ذَلِكَ فَكَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَاصَّةً لأَنَّهُ لَمْ يُوجِفْ عَلَيْهَا بِخَيْلٍ وَلاَ رِكَابٍ ‏.‏\hadithno{3016}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn AbuBakr: Abdullah ibn AbuBakr and some children of Muhammad ibn Maslamah said: There remained some people of Khaybar and they confined themselves to the fortresses. They asked the Messenger of Allah (ﷺ) to protect their lives and let them go. He did so. The people of Fadak heard this; they also adopted a similar way. (Fadak) was, therefore, exclusively reserved for the Messenger of Allah (ﷺ), for it was not captured by the expedition of cavalry and camelry}}
\hadithdefcmd{abudawud}{3017}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، عَنْ جُوَيْرِيَةَ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم افْتَتَحَ بَعْضَ خَيْبَرَ عَنْوَةً ‏.‏ قَالَ أَبُو دَاوُدَ وَقُرِئَ عَلَى الْحَارِثِ بْنِ مِسْكِينٍ وَأَنَا شَاهِدٌ أَخْبَرَكُمُ ابْنُ وَهْبٍ قَالَ حَدَّثَنِي مَالِكٌ عَنِ ابْنِ شِهَابٍ أَنَّ خَيْبَرَ كَانَ بَعْضُهَا عَنْوَةً وَبَعْضُهَا صُلْحًا وَالْكُتَيْبَةُ أَكْثَرُهَا عَنْوَةً وَفِيهَا صُلْحٌ ‏.‏ قُلْتُ لِمَالِكٍ وَمَا الْكُتَيْبَةُ قَالَ أَرْضُ خَيْبَرَ وَهِيَ أَرْبَعُونَ أَلْفَ عَذْقٍ ‏.‏\hadithno{3017}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa’id bin Al Musayyab said “The Apostle of Allaah(ﷺ) conquered a portion of Khaibar by force.” Abu Dawud said “This tradition was read out to Al Harith bin Miskin while I was a witness”. Ibn Wahb said “Malik told me on the authority of Ibn Shihab, Khaibar was captured by force in part and by peace in part. Most of Al Kutaibah was captured by force and a portion by peace.” I asked Malik “What is Al Kutaibah?” He replied “The land of Khaibar. It had forty thousand palm trees.”}}
\hadithdefcmd{abudawud}{3018}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم افْتَتَحَ خَيْبَرَ عَنْوَةً بَعْدَ الْقِتَالِ وَنَزَلَ مَنْ نَزَلَ مِنْ أَهْلِهَا عَلَى الْجَلاَءِ بَعْدَ الْقِتَالِ ‏.‏\hadithno{3018}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Shihab said “It has reached me that the Apostle of Allaah(ﷺ) conquered Khaibar by force. Its inhabitants who came down (from their fortress) for expulsion came down after fighting.”}}
\hadithdefcmd{abudawud}{3019}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ خَمَّسَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ ثُمَّ قَسَّمَ سَائِرَهَا عَلَى مَنْ شَهِدَهَا وَمَنْ غَابَ عَنْهَا مِنْ أَهْلِ الْحُدَيْبِيَةِ ‏.‏\hadithno{3019}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Shihab: The Messenger of Allah (ﷺ) took out his fifth from the booty of Khaybar, and divided the rest of it among those who attended the battle and among those who were away from it but attend the expedition of al-Hudaybiyyah}}
\hadithdefcmd{abudawud}{3020}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ، قَالَ لَوْلاَ آخِرُ الْمُسْلِمِينَ مَا فَتَحْتُ قَرْيَةً إِلاَّ قَسَمْتُهَا كَمَا قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ ‏.‏\hadithno{3020}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2334)}\hadithtrans{‘Umar said “Had I not considered the last Muslim, I would have any town I conquered divided as the Apostle of Allaah(ﷺ) had divided Khaibar.”}}
\hadithdefcmd{abudawud}{3021}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ جَاءَهُ الْعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ بِأَبِي سُفْيَانَ بْنِ حَرْبٍ فَأَسْلَمَ بِمَرِّ الظَّهْرَانِ فَقَالَ لَهُ الْعَبَّاسُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ يُحِبُّ هَذَا الْفَخْرَ فَلَوْ جَعَلْتَ لَهُ شَيْئًا ‏.‏ قَالَ ‏ "‏ نَعَمْ مَنْ دَخَلَ دَارَ أَبِي سُفْيَانَ فَهُوَ آمِنٌ وَمَنْ أَغْلَقَ عَلَيْهِ بَابَهُ فَهُوَ آمِنٌ ‏"‏ ‏.‏\hadithno{3021}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: Al-Abbas ibn AbdulMuttalib brought AbuSufyan ibn Harb to the Messenger of Allah (ﷺ) in the year of the conquest (of Mecca). So he embraced Islam at Marr az-Zahran. Al-Abbas said to him: Messenger of Allah, AbuSufyan is a man who likes taking this pride, if you may do something for him. He said: Yes, he who enters the house of AbuSufyan is safe, and he who closes his door is safe}}
\hadithdefcmd{abudawud}{3022}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الْفَضْلِ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ، عَنْ بَعْضِ، أَهْلِهِ عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَرَّ الظَّهْرَانِ قَالَ الْعَبَّاسُ قُلْتُ وَاللَّهِ لَئِنْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ عَنْوَةً قَبْلَ أَنْ يَأْتُوهُ فَيَسْتَأْمِنُوهُ إِنَّهُ لَهَلاَكُ قُرَيْشٍ فَجَلَسْتُ عَلَى بَغْلَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَعَلِّي أَجِدُ ذَا حَاجَةٍ يَأْتِي أَهْلَ مَكَّةَ فَيُخْبِرُهُمْ بِمَكَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم لِيَخْرُجُوا إِلَيْهِ فَيَسْتَأْمِنُوهُ فَإِنِّي لأَسِيرُ إِذْ سَمِعْتُ كَلاَمَ أَبِي سُفْيَانَ وَبُدَيْلِ بْنِ وَرْقَاءَ فَقُلْتُ يَا أَبَا حَنْظَلَةَ فَعَرَفَ صَوْتِي فَقَالَ أَبُو الْفَضْلِ قُلْتُ نَعَمْ ‏.‏ قَالَ مَا لَكَ فِدَاكَ أَبِي وَأُمِّي قُلْتُ هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ ‏.‏ قَالَ فَمَا الْحِيلَةُ قَالَ فَرَكِبَ خَلْفِي وَرَجَعَ صَاحِبُهُ فَلَمَّا أَصْبَحَ غَدَوْتُ بِهِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَسْلَمَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ يُحِبُّ هَذَا الْفَخْرَ فَاجْعَلْ لَهُ شَيْئًا ‏.‏ قَالَ ‏ "‏ نَعَمْ مَنْ دَخَلَ دَارَ أَبِي سُفْيَانَ فَهُوَ آمِنٌ وَمَنْ أَغْلَقَ عَلَيْهِ دَارَهُ فَهُوَ آمِنٌ وَمَنْ دَخَلَ الْمَسْجِدَ فَهُوَ آمِنٌ ‏"‏ ‏.‏ قَالَ فَتَفَرَّقَ النَّاسُ إِلَى دُورِهِمْ وَإِلَى الْمَسْجِدِ ‏.‏\hadithno{3022}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah Ibn Abbas: When the Prophet (ﷺ) alighted at Marr az-Zahran, al-Abbas said: I thought, I swear by Allah, if the Messenger of Allah (ﷺ) enters Mecca with the army by force before the Quraysh come to him and seek protection from him, it will be their total ruin. So I rode on the mule of the Messenger of Allah (ﷺ) and thought, Perhaps I may find a man coming for his needs who will to the people of Mecca and inform them of the position of the Messenger of Allah (ﷺ), so that they may come to him and seek protection from him. While I was on my way, I heard AbuSufyan and Budayl ibn Warqa' speaking. I said: O AbuHanzalah! He recognized my voice and said: AbulFadl? I replied: Yes. He said: who is with you, may my parents be a sacrifice for you? I said: Here are the Messenger of Allah (ﷺ) and his people (with him). He asked: Which is the way out? He said: He rode behind me, and his companion returned. When the morning came, I brought him to the Messenger of Allah (ﷺ) and he embraced Islam. I said: Messenger of Allah, AbuSufyan is a man who likes this pride, do something for him. He said: Yes, he who enters the house of AbuSufyan is safe; he who closes the door upon him is safe; and he who enters the mosque is safe. The people scattered to their houses and in the mosque}}
\hadithdefcmd{abudawud}{3023}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عَبْدِ الْكَرِيمِ - حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَقِيلِ بْنِ مَعْقِلٍ، عَنْ أَبِيهِ، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، قَالَ سَأَلْتُ جَابِرًا هَلْ غَنِمُوا يَوْمَ الْفَتْحِ شَيْئًا قَالَ لاَ ‏.‏\hadithno{3023}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Wahb bin Munabbih said “I sked Jabir “Did they get any booty on the day of conquest (of Makkah)? He replied, No}}
\hadithdefcmd{abudawud}{3024}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا سَلاَّمُ بْنُ مِسْكِينٍ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ الأَنْصَارِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا دَخَلَ مَكَّةَ سَرَّحَ الزُّبَيْرَ بْنَ الْعَوَّامِ وَأَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ وَخَالِدَ بْنَ الْوَلِيدِ عَلَى الْخَيْلِ وَقَالَ ‏"‏ يَا أَبَا هُرَيْرَةَ اهْتِفْ بِالأَنْصَارِ ‏"‏ ‏.‏ قَالَ اسْلُكُوا هَذَا الطَّرِيقَ فَلاَ يُشْرِفَنَّ لَكُمْ أَحَدٌ إِلاَّ أَنَمْتُمُوهُ ‏.‏ فَنَادَى مُنَادٍ لاَ قُرَيْشَ بَعْدَ الْيَوْمِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ دَخَلَ دَارًا فَهُوَ آمِنٌ وَمَنْ أَلْقَى السِّلاَحَ فَهُوَ آمِنٌ ‏"‏ ‏.‏ وَعَمَدَ صَنَادِيدُ قُرَيْشٍ فَدَخَلُوا الْكَعْبَةَ فَغَصَّ بِهِمْ وَطَافَ النَّبِيُّ صلى الله عليه وسلم وَصَلَّى خَلْفَ الْمَقَامِ ثُمَّ أَخَذَ بِجَنْبَتَىِ الْبَابِ فَخَرَجُوا فَبَايَعُوا النَّبِيَّ صلى الله عليه وسلم عَلَى الإِسْلاَمِ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ سَأَلَهُ رَجُلٌ قَالَ مَكَّةَ عَنْوَةً هِيَ قَالَ أَيْشٍ يَضُرُّكَ مَا كَانَتْ قَالَ فَصُلْحٌ قَالَ لاَ ‏.‏\hadithno{3024}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said “When the Prophet (ﷺ) entered Makkah he left Al Zubair bin Al Awwam, Abu ‘Ubaidah bin Al Jarrah and Khalid bin Al Walid on the horses and he said “Abu Hurairah call the helpers.” He said”Go this way. Whoever appears before you kill him”. A man called “the Quraish will be no more after today.” The Apostle of Allaah(ﷺ) said “he who entered house is safe, he who throws the weapon is safe. The chiefs of the Quraish intended (to have a resort in the Ka’bah), they entered the Ka’bah and it was full of them. The Prophet (ﷺ) took rounds of Ka’bah and prayed behind the station. He then held the sides of the gate (of the Ka’bah). They (the people) came out and took the oath of allegiance (at the hands) of the Prophet (ﷺ) on Islam. Abu Dawud said “I heard Ahmad bin Hanbal (say) when he was asked by a man “Was Makkah captured by force?” He said “What harms you whatever it was? He said “Then by peace?” He said, No}}
\hadithdefcmd{abudawud}{3025}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عَبْدِ الْكَرِيمِ - حَدَّثَنِي إِبْرَاهِيمُ، - يَعْنِي ابْنَ عَقِيلِ بْنِ مُنَبِّهٍ - عَنْ أَبِيهِ، عَنْ وَهْبٍ، قَالَ سَأَلْتُ جَابِرًا عَنْ شَأْنِ، ثَقِيفٍ إِذْ بَايَعَتْ قَالَ اشْتَرَطَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم أَنْ لاَ صَدَقَةَ عَلَيْهَا وَلاَ جِهَادَ وَأَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم بَعْدَ ذَلِكَ يَقُولُ ‏ "‏ سَيَتَصَدَّقُونَ وَيُجَاهِدُونَ إِذَا أَسْلَمُوا ‏"‏ ‏.‏\hadithno{3025}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: Wahb said: I asked Jabir about the condition of Thaqif when they took the oath of allegiance. He said: They stipulated to the Prophet (ﷺ) that there would be no sadaqah (i.e. zakat) on them nor Jihad (striving in the way of Allah). He then heard the Prophet (ﷺ) say: Later on they will give sadaqah (zakat) and will strive in the way of Allah when they embrace Islam}}
\hadithdefcmd{abudawud}{3026}{حَدَّثَنَا أَحْمَدُ بْنُ عَلِيِّ بْنِ سُوَيْدٍ، - يَعْنِي ابْنَ مَنْجُوفٍ - حَدَّثَنَا أَبُو دَاوُدَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنِ الْحَسَنِ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، أَنَّ وَفْدَ، ثَقِيفٍ لَمَّا قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْزَلَهُمُ الْمَسْجِدَ لِيَكُونَ أَرَقَّ لِقُلُوبِهِمْ فَاشْتَرَطُوا عَلَيْهِ أَنْ لاَ يُحْشَرُوا وَلاَ يُعْشَرُوا وَلاَ يُجَبُّوا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَكُمْ أَنْ لاَ تُحْشَرُوا وَلاَ تُعْشَرُوا وَلاَ خَيْرَ فِي دِينٍ لَيْسَ فِيهِ رُكُوعٌ ‏"‏ ‏.‏\hadithno{3026}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Uthman ibn Abul'As: When the deputation of Thaqif came to the Messenger of Allah (ﷺ), he made them stay in the mosque, so that it might soften their hearts. They stipulated to him that they would not be called to participate in Jihad, to pay zakat and to offer prayer. The Messenger of Allah (ﷺ) said: You may have the concession that you will not be called to participate in jihad and pay zakat, but there is no good in a religion which has no bowing (i.e. prayer)}}
\hadithdefcmd{abudawud}{3027}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي أُسَامَةَ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ عَامِرِ بْنِ شَهْرٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لِي هَمْدَانُ هَلْ أَنْتَ آتٍ هَذَا الرَّجُلَ وَمُرْتَادٌ لَنَا فَإِنْ رَضِيتَ لَنَا شَيْئًا قَبِلْنَاهُ وَإِنْ كَرِهْتَ شَيْئًا كَرِهْنَاهُ قُلْتُ نَعَمْ ‏.‏ فَجِئْتُ حَتَّى قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَضِيتُ أَمْرَهُ وَأَسْلَمَ قَوْمِي وَكَتَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَذَا الْكِتَابَ إِلَى عُمَيْرٍ ذِي مَرَّانَ قَالَ وَبَعَثَ مَالِكَ بْنَ مِرَارَةَ الرَّهَاوِيَّ إِلَى الْيَمَنِ جَمِيعًا فَأَسْلَمَ عَكٌّ ذُو خَيْوَانَ ‏.‏ قَالَ فَقِيلَ لِعَكٍّ انْطَلِقْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَخُذْ مِنْهُ الأَمَانَ عَلَى قَرْيَتِكَ وَمَالِكَ فَقَدِمَ وَكَتَبَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ لِعَكٍّ ذِي خَيْوَانَ إِنْ كَانَ صَادِقًا فِي أَرْضِهِ وَمَالِهِ وَرَقِيقِهِ فَلَهُ الأَمَانُ وَذِمَّةُ اللَّهِ وَذِمَّةُ مُحَمَّدٍ رَسُولِ اللَّهِ ‏"‏ ‏.‏ وَكَتَبَ خَالِدُ بْنُ سَعِيدِ بْنِ الْعَاصِ ‏.‏\hadithno{3027}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amir ibn Shahr: When the Messenger of Allah (ﷺ) appeared as a prophet, Hamdan said to me: Will you go to this man and negotiate for us (with him)? If you accept something, we shall accept it, and if you disapprove of something, we shall disapprove of it. I said: Yes. So I proceeded until I came to the Messenger of Allah (ﷺ). I liked his motive and my people embraced Islam. The Messenger of Allah (ﷺ) wrote the document for Umayr Dhu Marran. He also sent Malik ibn Murarah ar-Rahawi to all the (people of) Yemen. So Akk Dhu Khaywan embraced Islam. Akk was told: Go to the Messenger of Allah (ﷺ), and obtain his protection for your town and property. He therefore came (to him) and the Messenger of Allah (ﷺ) wrote a document for him: "In the name of Allah, Most Beneficent, Most Merciful. From Muhammad, the Messenger of Allah, to Akk Dhu Khaywan. If he is true his land, property and slave, he has the security and the protection of Allah, and Muhammad, the Messenger of Allah. Written by Khalid ibn Sa'id ibn al-'As}}
\hadithdefcmd{abudawud}{3028}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ الْقُرَشِيُّ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، حَدَّثَهُمْ حَدَّثَنَا فَرَجُ بْنُ سَعِيدٍ، حَدَّثَنِي عَمِّي، ثَابِتُ بْنُ سَعِيدٍ عَنْ أَبِيهِ، سَعِيدٍ - يَعْنِي ابْنَ أَبْيَضَ - عَنْ جَدِّهِ، أَبْيَضَ بْنِ حَمَّالٍ أَنَّهُ كَلَّمَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الصَّدَقَةِ حِينَ وَفَدَ عَلَيْهِ فَقَالَ ‏ "‏ يَا أَخَا سَبَإٍ لاَ بُدَّ مِنْ صَدَقَةٍ ‏"‏ ‏.‏ فَقَالَ إِنَّمَا زَرْعُنَا الْقُطْنُ يَا رَسُولَ اللَّهِ وَقَدْ تَبَدَّدَتْ سَبَأٌ وَلَمْ يَبْقَ مِنْهُمْ إِلاَّ قَلِيلٌ بِمَأْرِبٍ ‏.‏ فَصَالَحَ نَبِيَّ اللَّهِ صلى الله عليه وسلم عَلَى سَبْعِينَ حُلَّةِ بَزٍّ مِنْ قِيمَةِ وَفَاءِ بَزِّ الْمَعَافِرِ كُلَّ سَنَةٍ عَمَّنْ بَقِيَ مِنْ سَبَإٍ بِمَأْرِبَ فَلَمْ يَزَالُوا يُؤَدُّونَهَا حَتَّى قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِنَّ الْعُمَّالَ انْتَقَضُوا عَلَيْهِمْ بَعْدَ قَبْضِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيمَا صَالَحَ أَبْيَضُ بْنُ حَمَّالٍ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْحُلَلِ السَّبْعِينَ فَرَدَّ ذَلِكَ أَبُو بَكْرٍ عَلَى مَا وَضَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى مَاتَ أَبُو بَكْرٍ فَلَمَّا مَاتَ أَبُو بَكْرٍ رضى الله عنه انْتَقَضَ ذَلِكَ وَصَارَتْ عَلَى الصَّدَقَةِ ‏.‏\hadithno{3028}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abyad ibn Hammal: Abyad spoke to the Messenger of Allah (ﷺ) about sadaqah when he came along with a deputation to him. He replied: O brother of Saba', sadaqah is unavoidable. He said: We cultivated cotton, Messenger of Allah. The people of Saba' scattered, and there remained only a few at Ma'arib. He therefore concluded a treaty of peace with the Messenger of Allah (ﷺ) to give seventy suits of cloth, equivalent to the price of the Yemeni garments known as al-mu'afir, to be paid every year on behalf of those people of Saba' who remained at Ma'arib. They continued to pay them till the Messenger of Allah (ﷺ) died. The governors after the death of the Messenger of Allah (ﷺ) broke the treaty concluded by Abyad by Hammal with the Messenger of Allah (ﷺ) to give seventy suits of garments. AbuBakr then revived it as the Messenger of Allah (ﷺ) had done till AbuBakr died. When AbuBakr died, it was discontinued and the sadaqah was levied}}
\hadithdefcmd{abudawud}{3029}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَوْصَى بِثَلاَثَةٍ فَقَالَ ‏ "‏ أَخْرِجُوا الْمُشْرِكِينَ مِنْ جَزِيرَةِ الْعَرَبِ وَأَجِيزُوا الْوَفْدَ بِنَحْوٍ مِمَّا كُنْتُ أُجِيزُهُمْ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَسَكَتَ عَنِ الثَّالِثَةِ أَوْ قَالَ فَأُنْسِيتُهَا ‏.‏ وَقَالَ الْحُمَيْدِيُّ عَنْ سُفْيَانَ قَالَ سُلَيْمَانُ لاَ أَدْرِي أَذَكَرَ سَعِيدٌ الثَّالِثَةَ فَنَسِيتُهَا أَوْ سَكَتَ عَنْهَا\hadithno{3029}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3053) Sahih Muslim (1637)}\hadithtrans{Ibn ‘Abbas said that the Prophet (ﷺ) gave three instructions saying “Expel the polytheists from Arabia, reward deputations as I did”. Ibn ‘Abbas said “He either did not mention the third or I have been caused to forget it. Al Humaidi said on the authority of Sufyan that Sulaiman said “I do not know whether Sa’id mentioned the third and I forgot or he himself did not mention it.”}}
\hadithdefcmd{abudawud}{3030}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، وَعَبْدُ الرَّزَّاقِ، قَالاَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَخْبَرَنِي عُمَرُ بْنُ الْخَطَّابِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لأُخْرِجَنَّ الْيَهُودَ وَالنَّصَارَى مِنْ جَزِيرَةِ الْعَرَبِ فَلاَ أَتْرُكُ فِيهَا إِلاَّ مُسْلِمًا ‏"‏ ‏.‏\hadithno{3030}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim (1767)}\hadithtrans{Jabir bin ‘Abd Allah said that he was told by ‘Umar bin Al Khattab that he heard the Apostle of Allaah(ﷺ) say “I will certainly expel the Jews and the Christians from Arabia and I shall leave only Muslims in it.”}}
\hadithdefcmd{abudawud}{3031}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو أَحْمَدَ، مُحَمَّدُ بْنُ عَبْدِ اللَّهِ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَعْنَاهُ وَالأَوَّلُ أَتَمُّ ‏.‏\hadithno{3031}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by ‘Umar through a different chain of narrators.” He said “The Apostle of Allaah(ﷺ) said to the same effect. The former version is ore perfect.”}}
\hadithdefcmd{abudawud}{3032}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا جَرِيرٌ، عَنْ قَابُوسَ بْنِ أَبِي ظَبْيَانَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَكُونُ قِبْلَتَانِ فِي بَلَدٍ وَاحِدٍ ‏"‏ ‏.‏\hadithno{3032}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Two qiblahs in one land are not right}}
\hadithdefcmd{abudawud}{3033}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا عُمَرُ، - يَعْنِي ابْنَ عَبْدِ الْوَاحِدِ - قَالَ قَالَ سَعِيدٌ - يَعْنِي ابْنَ عَبْدِ الْعَزِيزِ - جَزِيرَةُ الْعَرَبِ مَا بَيْنَ الْوَادِي إِلَى أَقْصَى الْيَمَنِ إِلَى تُخُومِ الْعِرَاقِ إِلَى الْبَحْرِ ‏.‏ قَالَ أَبُو دَاوُدَ قُرِئَ عَلَى الْحَارِثِ بْنِ مِسْكِينٍ وَأَنَا شَاهِدٌ أَخْبَرَكَ أَشْهَبُ بْنُ عَبْدِ الْعَزِيزِ قَالَ قَالَ مَالِكٌ عُمَرُ أَجْلَى أَهْلَ نَجْرَانَ وَلَمْ يُجْلَوْا مِنْ تَيْمَاءَ لأَنَّهَا لَيْسَتْ مِنْ بِلاَدِ الْعَرَبِ فَأَمَّا الْوَادِي فَإِنِّي أَرَى إِنَّمَا لَمْ يُجْلَ مَنْ فِيهَا مِنَ الْيَهُودِ أَنَّهُمْ لَمْ يَرَوْهَا مِنْ أَرْضِ الْعَرَبِ ‏.‏\hadithno{3033}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Sa’id bin Abd Al ‘Aziz said “Arabia lies between Al Wadi to the extremes of the Yemen extending to the frontiers of Al Iraq and the sea.” Abu Dawud said “This tradition was read out to Al Harith bin Miskin while I was a witness”. Ashhab bin ‘Abd Al Aziz reported it to you on the authority of Malik who said ‘Umar expelled the people of Najran, but he did not expel (them) from Taima. For it did not fall within the territory of Arabia. As for Al Wadi, I think the Jews were not expelled from there. They did not think it a part of the land of Arabia}}
\hadithdefcmd{abudawud}{3034}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ قَالَ مَالِكٌ قَدْ أَجْلَى عُمَرُ رَحِمَهُ اللَّهُ يَهُودَ نَجْرَانَ وَفَدَكَ ‏.‏\hadithno{3034}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Mauquf}\hadithtrans{Malik said “’Umar expelled the Jews of Najran and Fadak.”}}
\hadithdefcmd{abudawud}{3035}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنَعَتِ الْعِرَاقُ قَفِيزَهَا وَدِرْهَمَهَا وَمَنَعَتِ الشَّامُ مُدْيَهَا وَدِينَارَهَا وَمَنَعَتْ مِصْرُ إِرْدَبَّهَا وَدِينَارَهَا ثُمَّ عُدْتُمْ مِنْ حَيْثُ بَدَأْتُمْ ‏"‏ ‏.‏ قَالَهَا زُهَيْرٌ ثَلاَثَ مَرَّاتٍ شَهِدَ عَلَى ذَلِكَ لَحْمُ أَبِي هُرَيْرَةَ وَدَمُهُ ‏.‏\hadithno{3035}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2896)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying “Iraq will prevent its measure (qafiz) and dirham. Syria will prevent its measure (mudi) and dinar. Egypt will prevent its measure (irdabb) and dinar. Then you will return to the position where you started. Zuhair said this three times. The flesh and blood of Abu Hurairah witnessed it}}
\hadithdefcmd{abudawud}{3036}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا بِهِ أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا قَرْيَةٍ أَتَيْتُمُوهَا وَأَقَمْتُمْ فِيهَا فَسَهْمُكُمْ فِيهَا وَأَيُّمَا قَرْيَةٍ عَصَتِ اللَّهَ وَرَسُولَهُ فَإِنَّ خُمُسَهَا لِلَّهِ وَلِلرَّسُولِ ثُمَّ هِيَ لَكُمْ ‏"‏ ‏.‏\hadithno{3036}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1756)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “Whatever town you come to and stay in , your portion is in it, but whatever town disobeys Allaah and His Apostle a fifth of it goes to Allaah and His Apostle and what remains is yours.”}}
\hadithdefcmd{abudawud}{3037}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا سَهْلُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عُمَرَ، عَنْ أَنَسِ بْنِ مَالِكٍ، وَعَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ خَالِدَ بْنَ الْوَلِيدِ إِلَى أُكَيْدِرِ دُومَةَ فَأُخِذَ فَأَتَوْهُ بِهِ فَحَقَنَ لَهُ دَمَهُ وَصَالَحَهُ عَلَى الْجِزْيَةِ ‏.‏\hadithno{3037}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik ; Uthman ibn AbuSulayman: The Prophet (ﷺ) sent Khalid ibn al-Walid to Ukaydir of Dumah. He was seized and they brought him to him (i.e. the Prophet). He spared his life and made peace with him on condition that he should pay jizyah (poll-tax)}}
\hadithdefcmd{abudawud}{3038}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مُعَاذٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا وَجَّهَهُ إِلَى الْيَمَنِ أَمَرَهُ أَنْ يَأْخُذَ مِنْ كُلِّ حَالِمٍ - يَعْنِي مُحْتَلِمًا - دِينَارًا أَوْ عِدْلَهُ مِنَ الْمَعَافِرِيِّ ثِيَابٌ تَكُونُ بِالْيَمَنِ ‏.‏\hadithno{3038}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: When the Prophet (ﷺ) sent him to the Yemen, he ordered to take from everyone who had reached puberty one dinar or its equivalent in Mu'afiri garment of Yemen origin}}
\hadithdefcmd{abudawud}{3039}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{3039}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{A simiar tradition from the Prophet(ﷺ) has also been transmitted by Mu’adh through a different chain of narrators}}
\hadithdefcmd{abudawud}{3040}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ هَانِئٍ أَبُو نُعَيْمٍ النَّخَعِيُّ، أَخْبَرَنَا شَرِيكٌ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ زِيَادِ بْنِ حُدَيْرٍ، قَالَ قَالَ عَلِيٌّ لَئِنْ بَقِيتُ لِنَصَارَى بَنِي تَغْلِبَ لأَقْتُلَنَّ الْمُقَاتِلَةَ وَلأَسْبِيَنَّ الذُّرِّيَّةَ فَإِنِّي كَتَبْتُ الْكِتَابَ بَيْنَهُمْ وَبَيْنَ النَّبِيِّ صلى الله عليه وسلم عَلَى أَنْ لاَ يُنَصِّرُوا أَبْنَاءَهُمْ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثٌ مُنْكَرٌ بَلَغَنِي عَنْ أَحْمَدَ أَنَّهُ كَانَ يُنْكِرُ هَذَا الْحَدِيثَ إِنْكَارًا شَدِيدًا وَهُوَ عِنْدَ بَعْضِ النَّاسِ شِبْهُ الْمَتْرُوكِ وَأَنْكَرُوا هَذَا الْحَدِيثَ عَلَى عَبْدِ الرَّحْمَنِ بْنِ هَانِئٍ قَالَ أَبُو عَلِيٍّ وَلَمْ يَقْرَأْهُ أَبُو دَاوُدَ فِي الْعَرْضَةِ الثَّانِيَةِ ‏.‏\hadithno{3040}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Ali said “If I survive for the Christians of Banu Taghlib I shall kill fighters and captivate children for I had written a document between them and the Prophet(ﷺ) to the effect that they would not make their children Christian. Abu Dawud said “This is rejected (munkar) tradition and it has reached me from Ahmad (bin Hanbal) that he used to reject this tradition seriously. Abu ‘Ali said “Abu Dawud did not present this (tradition) in this second reading.”}}
\hadithdefcmd{abudawud}{3041}{حَدَّثَنَا مُصَرِّفُ بْنُ عَمْرٍو الْيَامِيُّ، حَدَّثَنَا يُونُسُ، - يَعْنِي ابْنَ بُكَيْرٍ - حَدَّثَنَا أَسْبَاطُ بْنُ نَصْرٍ الْهَمْدَانِيُّ، عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ الرَّحْمَنِ الْقُرَشِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَالَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَهْلَ نَجْرَانَ عَلَى أَلْفَىْ حُلَّةٍ النِّصْفُ فِي صَفَرٍ وَالْبَقِيَّةُ فِي رَجَبٍ يُؤَدُّونَهَا إِلَى الْمُسْلِمِينَ وَعَارِيَةِ ثَلاَثِينَ دِرْعًا وَثَلاَثِينَ فَرَسًا وَثَلاَثِينَ بَعِيرًا وَثَلاَثِينَ مِنْ كُلِّ صِنْفٍ مِنْ أَصْنَافِ السِّلاَحِ يَغْزُونَ بِهَا وَالْمُسْلِمُونَ ضَامِنُونَ لَهَا حَتَّى يَرُدُّوهَا عَلَيْهِمْ إِنْ كَانَ بِالْيَمَنِ كَيْدٌ أَوْ غَدْرَةٌ عَلَى أَنْ لاَ تُهْدَمَ لَهُمْ بَيْعَةٌ وَلاَ يُخْرَجُ لَهُمْ قَسٌّ وَلاَ يُفْتَنُوا عَنْ دِينِهِمْ مَا لَمْ يُحْدِثُوا حَدَثًا أَوْ يَأْكُلُوا الرِّبَا ‏.‏ قَالَ إِسْمَاعِيلُ فَقَدْ أَكَلُوا الرِّبَا ‏.‏ قَالَ أَبُو دَاوُدَ إِذَا نَقَضُوا بَعْضَ مَا اشْتَرَطَ عَلَيْهِمْ فَقَدْ أَحْدَثُوا ‏.‏\hadithno{3041}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) concluded peace with the people of Najran on condition that they would pay to Muslims two thousand suits of garments, half of Safar, and the rest in Rajab, and they would lend (Muslims) thirty coats of mail, thirty horses, thirty camels, and thirty weapons of each type used in battle. Muslims will stand surely for them until they return them in case there is any plot or treachery in the Yemen. No church of theirs will be demolished and no clergyman of theirs will be turned out. There will be no interruption in their religion until they bring something new or take usury. Isma'il said: They took usury. Abu Dawud said: If they violate any provision of the treaty, they will be deemed as bringing something new}}
\hadithdefcmd{abudawud}{3042}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ الْوَاسِطِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ بِلاَلٍ، عَنْ عِمْرَانَ الْقَطَّانِ، عَنْ أَبِي جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ أَهْلَ فَارِسَ لَمَّا مَاتَ نَبِيُّهُمْ كَتَبَ لَهُمْ إِبْلِيسُ الْمَجُوسِيَّةَ ‏.‏\hadithno{3042}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Abbas said “When the Prophet of the Persians dies, Iblis (satan) led them to Mazdaism.”}}
\hadithdefcmd{abudawud}{3043}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، سَمِعَ بَجَالَةَ، يُحَدِّثُ عَمْرَو بْنَ أَوْسٍ وَأَبَا الشَّعْثَاءِ قَالَ كُنْتُ كَاتِبًا لِجَزْءِ بْنِ مُعَاوِيَةَ عَمِّ الأَحْنَفِ بْنِ قَيْسٍ إِذْ جَاءَنَا كِتَابُ عُمَرَ قَبْلَ مَوْتِهِ بِسَنَةٍ اقْتُلُوا كُلَّ سَاحِرٍ وَفَرِّقُوا بَيْنَ كُلِّ ذِي مَحْرَمٍ مِنَ الْمَجُوسِ وَانْهَوْهُمْ عَنِ الزَّمْزَمَةِ فَقَتَلْنَا فِي يَوْمٍ ثَلاَثَةَ سَوَاحِرَ وَفَرَّقْنَا بَيْنَ كُلِّ رَجُلٍ مِنَ الْمَجُوسِ وَحَرِيمِهِ فِي كِتَابِ اللَّهِ وَصَنَعَ طَعَامًا كَثِيرًا فَدَعَاهُمْ فَعَرَضَ السَّيْفَ عَلَى فَخِذِهِ فَأَكَلُوا وَلَمْ يُزَمْزِمُوا وَأَلْقَوْا وِقْرَ بَغْلٍ أَوْ بَغْلَيْنِ مِنَ الْوَرِقِ وَلَمْ يَكُنْ عُمَرُ أَخَذَ الْجِزْيَةَ مِنَ الْمَجُوسِ حَتَّى شَهِدَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَهَا مِنْ مَجُوسِ هَجَرَ ‏.‏\hadithno{3043}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3156، 3157)}\hadithtrans{Narrated Umar ibn al-Khattab: Amr ibn Aws and AbulSha'tha' reported that Bujalah said: I was secretary to Jaz' ibn Mu'awiyah, the uncle of Ahnaf ibn Qays. A letter came to us from Umar one year before his death, saying: Kill every magician, separate the relatives of prohibited degrees from the Magians, and forbid them to murmur (before eating). So we killed three magicians in one day, and separated from a Magian husband his wife of a prohibited degree according to the Book of Allah. He prepared abundant food and called them, and placed the sword on his thigh. They ate (the food) but did not murmur. They threw (on the ground) one or two mule-loads of silver. Umar did not take jizyah from Magians until AbdurRahman ibn Awf witnessed that the Messenger of Allah (ﷺ) had taken jizyah from the Magians of Hajar}}
\hadithdefcmd{abudawud}{3044}{حَدَّثَنَا مُحَمَّدُ بْنُ مِسْكِينٍ الْيَمَامِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ قُشَيْرِ بْنِ عَمْرٍو، عَنْ بَجَالَةَ بْنِ عَبْدَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ مِنَ الأَسْبَذِيِّينَ مِنْ أَهْلِ الْبَحْرَيْنِ - وَهُمْ مَجُوسُ أَهْلِ هَجَرَ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَكَثَ عِنْدَهُ ثُمَّ خَرَجَ فَسَأَلْتُهُ مَا قَضَى اللَّهُ وَرَسُولُهُ فِيكُمْ قَالَ شَرٌّ ‏.‏ قُلْتُ مَهْ قَالَ الإِسْلاَمُ أَوِ الْقَتْلُ ‏.‏ قَالَ وَقَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ قَبِلَ مِنْهُمُ الْجِزْيَةَ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَأَخَذَ النَّاسُ بِقَوْلِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَتَرَكُوا مَا سَمِعْتُ أَنَا مِنَ الأَسْبَذِيِّ ‏.‏\hadithno{3044}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: A man belonging to Usbadhiyin of the people of Bahrayn, who were the Magians of Hajar, came to the Messenger of Allah (ﷺ) and remained with him (for some time), and then came out. I asked him: What have Allah and His Messenger of Allah decided for you? He replied: Evil. I said: Silent. He said: Islam or killing. AbdurRahman ibn Awf said: He accepted jizyah from them. Ibn Abbas said: The people followed the statement of AbdurRahman ibn Awf, and they left that which I heard from the Usbadhi}}
\hadithdefcmd{abudawud}{3045}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ هِشَامَ بْنَ حَكِيمِ بْنِ حِزَامٍ، وَجَدَ رَجُلاً وَهُوَ عَلَى حِمْصَ يُشَمِّسُ نَاسًا مِنَ النَّبَطِ فِي أَدَاءِ الْجِزْيَةِ فَقَالَ مَا هَذَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يُعَذِّبُ الَّذِينَ يُعَذِّبُونَ النَّاسَ فِي الدُّنْيَا ‏"‏ ‏.‏\hadithno{3045}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2613)}\hadithtrans{‘Urwa bin Al Zubair said “Hisham bin Halim bin Hizam found a man who was the governor of Hims making some Copts stand in the sun for the payment of jizyah. He said “What is this?” I heard the Apostle (ﷺ) as saying “Allaah Most High will punish those who punish the people in this world.”}}
\hadithdefcmd{abudawud}{3046}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ حَرْبِ بْنِ عُبَيْدِ اللَّهِ، عَنْ جَدِّهِ أَبِي أُمِّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْعُشُورُ عَلَى الْيَهُودِ وَالنَّصَارَى وَلَيْسَ عَلَى الْمُسْلِمِينَ عُشُورٌ ‏"‏ ‏.‏\hadithno{3046}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubaydullah: Harb ibn Ubaydullah told on the authority of his grandfather, his mother's father, that he had it on the authority of his father that the Messenger of Allah (ﷺ) said: Tithes are to be levied on Jews and Christians, but not on Muslims}}
\hadithdefcmd{abudawud}{3047}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ حَرْبِ بْنِ عُبَيْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ ‏"‏ خَرَاجٌ ‏"‏ ‏.‏ مَكَانَ ‏"‏ الْعُشُورُ ‏"‏ ‏.‏\hadithno{3047}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Harb bin ‘Ubaid Allah from the Prophet (ﷺ) to the same effect through a different chain of narrators. This version has the word kharaj(land tax) instead of ‘ushr (tithes)}}
\hadithdefcmd{abudawud}{3048}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَطَاءٍ، عَنْ رَجُلٍ، مِنْ بَكْرِ بْنِ وَائِلٍ عَنْ خَالِهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أُعَشِّرُ قَوْمِي قَالَ ‏ "‏ إِنَّمَا الْعُشُورُ عَلَى الْيَهُودِ وَالنَّصَارَى ‏"‏ ‏.‏\hadithno{3048}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{A man reported from Bakr bin Wa’il on the authority of his maternal uncle as saying, I said “Apostle of Allaah(ﷺ) may I levy tithe on my people.?” He replied “Tithes are to be levied on Jews and Christians.”}}
\hadithdefcmd{abudawud}{3049}{حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ الْبَزَّازُ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ حَرْبِ بْنِ عُبَيْدِ اللَّهِ بْنِ عُمَيْرٍ الثَّقَفِيِّ، عَنْ جَدِّهِ، - رَجُلٍ مِنْ بَنِي تَغْلِبَ - قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَأَسْلَمْتُ وَعَلَّمَنِي الإِسْلاَمَ وَعَلَّمَنِي كَيْفَ آخُذُ الصَّدَقَةَ مِنْ قَوْمِي مِمَّنْ أَسْلَمَ ثُمَّ رَجَعْتُ إِلَيْهِ فَقُلْتُ يَا رَسُولَ اللَّهِ كُلُّ مَا عَلَّمْتَنِي قَدْ حَفِظْتُهُ إِلاَّ الصَّدَقَةَ أَفَأُعَشِّرُهُمْ قَالَ ‏ "‏ لاَ إِنَّمَا الْعُشُورُ عَلَى النَّصَارَى وَالْيَهُودِ ‏"‏ ‏.‏\hadithno{3049}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated A man of Banu Taghlib: Harb ibn Ubaydullah ibn Umayr ath-Thaqafi told on the authority of his grandfather, a man of Banu Taghlib: I came to the Prophet (ﷺ), embraced Islam, and he taught me Islam. He also taught me how I should take sadaqah from my people who had become Muslim. I then returned to him and said: Messenger of Allah, I remembered whatever you taught me except the sadaqah. Should I levy tithe on them? He replied: No, tithes are to be levied on Christians and Jews}}
\hadithdefcmd{abudawud}{3050}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا أَشْعَثُ بْنُ شُعْبَةَ، حَدَّثَنَا أَرْطَاةُ بْنُ الْمُنْذِرِ، قَالَ سَمِعْتُ حَكِيمَ بْنَ عُمَيْرٍ أَبَا الأَحْوَصِ، يُحَدِّثُ عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ السُّلَمِيِّ، قَالَ نَزَلْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم خَيْبَرَ وَمَعَهُ مَنْ مَعَهُ مِنْ أَصْحَابِهِ وَكَانَ صَاحِبُ خَيْبَرَ رَجُلاً مَارِدًا مُنْكَرًا فَأَقْبَلَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ أَلَكُمْ أَنْ تَذْبَحُوا حُمُرَنَا وَتَأْكُلُوا ثَمَرَنَا وَتَضْرِبُوا نِسَاءَنَا فَغَضِبَ يَعْنِي النَّبِيَّ صلى الله عليه وسلم وَقَالَ ‏"‏ يَا ابْنَ عَوْفٍ ارْكَبْ فَرَسَكَ ثُمَّ نَادِ أَلاَ إِنَّ الْجَنَّةَ لاَ تَحِلُّ إِلاَّ لِمُؤْمِنٍ وَأَنِ اجْتَمِعُوا لِلصَّلاَةِ ‏"‏ ‏.‏ قَالَ فَاجْتَمَعُوا ثُمَّ صَلَّى بِهِمُ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَامَ فَقَالَ ‏"‏ أَيَحْسَبُ أَحَدُكُمْ مُتَّكِئًا عَلَى أَرِيكَتِهِ قَدْ يَظُنُّ أَنَّ اللَّهَ لَمْ يُحَرِّمْ شَيْئًا إِلاَّ مَا فِي هَذَا الْقُرْآنِ أَلاَ وَإِنِّي وَاللَّهِ قَدْ وَعَظْتُ وَأَمَرْتُ وَنَهَيْتُ عَنْ أَشْيَاءَ إِنَّهَا لَمِثْلُ الْقُرْآنِ أَوْ أَكْثَرُ وَأَنَّ اللَّهَ عَزَّ وَجَلَّ لَمْ يُحِلَّ لَكُمْ أَنْ تَدْخُلُوا بُيُوتَ أَهْلِ الْكِتَابِ إِلاَّ بِإِذْنٍ وَلاَ ضَرْبَ نِسَائِهِمْ وَلاَ أَكْلَ ثِمَارِهِمْ إِذَا أَعْطَوْكُمُ الَّذِي عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{3050}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Irbad ibn Sariyah as-Sulami: We alighted with the Prophet (ﷺ) at Khaybar, and he had his companions with him. The chief of Khaybar was a defiant and abominable man. He came to the Prophet (ﷺ) and said: Is it proper for you, Muhammad, that you slaughter our donkeys, eat our fruit, and beat our women? The Prophet (ﷺ) became angry and said: Ibn Awf, ride your horse, and call loudly: Beware, Paradise is lawful only for a believer, and that they (the people) should gather for prayer. They gathered and the Prophet (ﷺ) led them in prayer, stood up and said: Does any of you, while reclining on his couch, imagine that Allah has prohibited only that which is to be found in this Qur'an? By Allah, I have preached, commanded and prohibited various matters as numerous as that which is found in the Qur'an, or more numerous. Allah has not permitted you to enter the houses of the people of the Book without permission, or beat their women, or eat their fruits when they give you that which is imposed on them}}
\hadithdefcmd{abudawud}{3051}{حَدَّثَنَا مُسَدَّدٌ، وَسَعِيدُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ هِلاَلٍ، عَنْ رَجُلٍ، مِنْ ثَقِيفٍ عَنْ رَجُلٍ، مِنْ جُهَيْنَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَعَلَّكُمْ تُقَاتِلُونَ قَوْمًا فَتَظْهَرُونَ عَلَيْهِمْ فَيَتَّقُونَكُمْ بِأَمْوَالِهِمْ دُونَ أَنْفُسِهِمْ وَأَبْنَائِهِمْ ‏"‏ ‏.‏ قَالَ سَعِيدٌ فِي حَدِيثِهِ ‏"‏ فَيُصَالِحُونَكُمْ عَلَى صُلْحٍ ‏"‏ ‏.‏ ثُمَّ اتَّفَقَا ‏"‏ فَلاَ تُصِيبُوا مِنْهُمْ شَيْئًا فَوْقَ ذَلِكَ فَإِنَّهُ لاَ يَصْلُحُ لَكُمْ ‏"‏ ‏.‏\hadithno{3051}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated A man of Juhaynah: The Prophet (ﷺ) said: Probably you will fight with a people, you will dominate them, and they will save themselves and their children by their property. The version of Sa'id has You will then conclude peace with them. The agreed version goes: Then do no take anything from them more than that, for it is not proper for you}}
\hadithdefcmd{abudawud}{3052}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أَبُو صَخْرٍ الْمَدِينِيُّ، أَنَّ صَفْوَانَ بْنَ سُلَيْمٍ، أَخْبَرَهُ عَنْ عِدَّةٍ، مِنْ أَبْنَاءِ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ آبَائِهِمْ دِنْيَةً عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ مَنْ ظَلَمَ مُعَاهِدًا أَوِ انْتَقَصَهُ أَوْ كَلَّفَهُ فَوْقَ طَاقَتِهِ أَوْ أَخَذَ مِنْهُ شَيْئًا بِغَيْرِ طِيبِ نَفْسٍ فَأَنَا حَجِيجُهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3052}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated A number of Companions of the Prophet: Safwan reported from a number of Companions of the Messenger of Allah (ﷺ) on the authority of their fathers who were relatives of each other. The Messenger of Allah (ﷺ) said: Beware, if anyone wrongs a contracting man, or diminishes his right, or forces him to work beyond his capacity, or takes from him anything without his consent, I shall plead for him on the Day of Judgment}}
\hadithdefcmd{abudawud}{3053}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، عَنْ جَرِيرٍ، عَنْ قَابُوسَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ جِزْيَةٌ ‏"‏ ‏.‏\hadithno{3053}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Jizyah is not to be levied on a Muslim}}
\hadithdefcmd{abudawud}{3054}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ سُئِلَ سُفْيَانُ عَنْ تَفْسِيرِ، هَذَا فَقَالَ إِذَا أَسْلَمَ فَلاَ جِزْيَةَ عَلَيْهِ ‏.‏\hadithno{3054}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Kathir said “Sufyan was asked to explain the tradition mentioned above.” He said “When he embraces Islam, no jizyah will be levied on him.”}}
\hadithdefcmd{abudawud}{3055}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ زَيْدٍ، أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ الْهَوْزَنِيُّ، قَالَ لَقِيتُ بِلاَلاً مُؤَذِّنَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِحَلَبَ فَقُلْتُ يَا بِلاَلُ حَدِّثْنِي كَيْفَ كَانَتْ نَفَقَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ مَا كَانَ لَهُ شَىْءٌ كُنْتُ أَنَا الَّذِي أَلِي ذَلِكَ مِنْهُ مُنْذُ بَعَثَهُ اللَّهُ إِلَى أَنْ تُوُفِّيَ وَكَانَ إِذَا أَتَاهُ الإِنْسَانُ مُسْلِمًا فَرَآهُ عَارِيًا يَأْمُرُنِي فَأَنْطَلِقُ فَأَسْتَقْرِضُ فَأَشْتَرِي لَهُ الْبُرْدَةَ فَأَكْسُوهُ وَأُطْعِمُهُ حَتَّى اعْتَرَضَنِي رَجُلٌ مِنَ الْمُشْرِكِينَ فَقَالَ يَا بِلاَلُ إِنَّ عِنْدِي سَعَةً فَلاَ تَسْتَقْرِضْ مِنْ أَحَدٍ إِلاَّ مِنِّي فَفَعَلْتُ فَلَمَّا أَنْ كَانَ ذَاتَ يَوْمٍ تَوَضَّأْتُ ثُمَّ قُمْتُ لأُؤَذِّنَ بِالصَّلاَةِ فَإِذَا الْمُشْرِكُ قَدْ أَقْبَلَ فِي عِصَابَةٍ مِنَ التُّجَّارِ فَلَمَّا أَنْ رَآنِي قَالَ يَا حَبَشِيُّ ‏.‏ قُلْتُ يَا لَبَّاهُ ‏.‏ فَتَجَهَّمَنِي وَقَالَ لِي قَوْلاً غَلِيظًا وَقَالَ لِي أَتَدْرِي كَمْ بَيْنَكَ وَبَيْنَ الشَّهْرِ قَالَ قُلْتُ قَرِيبٌ ‏.‏ قَالَ إِنَّمَا بَيْنَكَ وَبَيْنَهُ أَرْبَعٌ فَآخُذُكَ بِالَّذِي عَلَيْكَ فَأَرُدُّكَ تَرْعَى الْغَنَمَ كَمَا كُنْتَ قَبْلَ ذَلِكَ فَأَخَذَ فِي نَفْسِي مَا يَأْخُذُ فِي أَنْفُسِ النَّاسِ حَتَّى إِذَا صَلَّيْتُ الْعَتَمَةَ رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَهْلِهِ فَاسْتَأْذَنْتُ عَلَيْهِ فَأَذِنَ لِي فَقُلْتُ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي إِنَّ الْمُشْرِكَ الَّذِي كُنْتُ أَتَدَيَّنُ مِنْهُ قَالَ لِي كَذَا وَكَذَا وَلَيْسَ عِنْدَكَ مَا تَقْضِي عَنِّي وَلاَ عِنْدِي وَهُوَ فَاضِحِي فَأْذَنْ لِي أَنْ آبِقَ إِلَى بَعْضِ هَؤُلاَءِ الأَحْيَاءِ الَّذِينَ قَدْ أَسْلَمُوا حَتَّى يَرْزُقَ اللَّهُ رَسُولَهُ صلى الله عليه وسلم مَا يَقْضِي عَنِّي فَخَرَجْتُ حَتَّى إِذَا أَتَيْتُ مَنْزِلِي فَجَعَلْتُ سَيْفِي وَجِرَابِي وَنَعْلِي وَمِجَنِّي عِنْدَ رَأْسِي حَتَّى إِذَا انْشَقَّ عَمُودُ الصُّبْحِ الأَوَّلِ أَرَدْتُ أَنْ أَنْطَلِقَ فَإِذَا إِنْسَانٌ يَسْعَى يَدْعُو يَا بِلاَلُ أَجِبْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَانْطَلَقْتُ حَتَّى أَتَيْتُهُ فَإِذَا أَرْبَعُ رَكَائِبَ مُنَاخَاتٍ عَلَيْهِنَّ أَحْمَالُهُنَّ فَاسْتَأْذَنْتُ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبْشِرْ فَقَدْ جَاءَكَ اللَّهُ بِقَضَائِكَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلَمْ تَرَ الرَّكَائِبَ الْمُنَاخَاتِ الأَرْبَعَ ‏"‏ ‏.‏ فَقُلْتُ بَلَى ‏.‏ فَقَالَ ‏"‏ إِنَّ لَكَ رِقَابَهُنَّ وَمَا عَلَيْهِنَّ فَإِنَّ عَلَيْهِنَّ كِسْوَةً وَطَعَامًا أَهْدَاهُنَّ إِلَىَّ عَظِيمُ فَدَكَ فَاقْبِضْهُنَّ وَاقْضِ دَيْنَكَ ‏"‏ ‏.‏ فَفَعَلْتُ فَذَكَرَ الْحَدِيثَ ثُمَّ انْطَلَقْتُ إِلَى الْمَسْجِدِ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدٌ فِي الْمَسْجِدِ فَسَلَّمْتُ عَلَيْهِ فَقَالَ ‏"‏ مَا فَعَلَ مَا قِبَلَكَ ‏"‏ ‏.‏ قُلْتُ قَدْ قَضَى اللَّهُ كُلَّ شَىْءٍ كَانَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يَبْقَ شَىْءٌ ‏.‏ قَالَ ‏"‏ أَفَضَلَ شَىْءٌ ‏"‏ ‏.‏ قُلْتُ نَعَمْ قَالَ ‏"‏ انْظُرْ أَنْ تُرِيحَنِي مِنْهُ فَإِنِّي لَسْتُ بِدَاخِلٍ عَلَى أَحَدٍ مِنْ أَهْلِي حَتَّى تُرِيحَنِي مِنْهُ ‏"‏ ‏.‏ فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَتَمَةَ دَعَانِي فَقَالَ ‏"‏ مَا فَعَلَ الَّذِي قِبَلَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ هُوَ مَعِي لَمْ يَأْتِنَا أَحَدٌ ‏.‏ فَبَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ وَقَصَّ الْحَدِيثَ حَتَّى إِذَا صَلَّى الْعَتَمَةَ - يَعْنِي مِنَ الْغَدِ - دَعَانِي قَالَ ‏"‏ مَا فَعَلَ الَّذِي قِبَلَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ قَدْ أَرَاحَكَ اللَّهُ مِنْهُ يَا رَسُولَ اللَّهِ ‏.‏ فَكَبَّرَ وَحَمِدَ اللَّهَ شَفَقًا مِنْ أَنْ يُدْرِكَهُ الْمَوْتُ وَعِنْدَهُ ذَلِكَ ثُمَّ اتَّبَعْتُهُ حَتَّى إِذَا جَاءَ أَزْوَاجَهُ فَسَلَّمَ عَلَى امْرَأَةٍ امْرَأَةٍ حَتَّى أَتَى مَبِيتَهُ فَهَذَا الَّذِي سَأَلْتَنِي عَنْهُ ‏.‏\hadithno{3055}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah al-Hawzani: I met Bilal, the Mu'adhdhin of the Messenger of Allah (ﷺ) at Aleppo, and said: Bilal, tell me, what was the financial position of the Messenger of Allah (ﷺ)? He said: He had nothing. It was I who managed it on his behalf since the day Allah made him Prophet of Allah (ﷺ) until he died. When a Muslim man came to him and he found him naked, he ordered me (to clothe him). I would go, borrow (some money), and purchase a cloak for him. I would then clothe him and feed him. A man from the polytheists met me and said: I am well off, Bilal. Do not borrow money from anyone except me. So I did accordingly. One day when I performed ablution and stood up to make call to prayer, the same polytheist came along with a body of merchants. When he saw me, he said: O Abyssinian. I said: I am at your service. He met me with unpleasant looks and said harsh words to me. He asked me: Do you know how many days remain in the completion of this month? I replied: The time is near. He said: Only four days remain in the completion of this month. I shall then take that which is due from you (i.e. loan), and then shall return you to tend the sheep as you did before. I began to think in my mind what people think in their minds (on such occasions). When I offered the night prayer, the Messenger of Allah (ﷺ) returned to his family. I sought permission from him and he gave me permission. I said: Messenger of Allah, may my parents be sacrificed for you, the polytheist from whom I used to borrow money said to me such-and-such. Neither you nor I have anything to pay him for me, and he will disgrace me. So give me permission to run away to some of those tribes who have recently embraced Islam until Allah gives His Apostle (ﷺ) something with which he can pay (the debt) for me. So I came out and reached my house. I placed my sword, waterskin (or sheath), shoes and shield near my head. When dawn broke, I intended to be on my way. All of a sudden I saw a man running towards me and calling: Bilal, return to the Messenger of Allah (ﷺ). So I went till I reached him. I found four mounts kneeling on the ground with loads on them. I sought permission. The Messenger of Allah (ﷺ) said to me: Be glad, Allah has made arrangements for the payment (of your debt). He then asked: Have you not seen the four mounts kneeling on the ground? I replied: Yes. He said: You may have these mounts and what they have on them. There are clothes and food on them, presented to me by the ruler of Fadak. Take them away and pay off your debt. I did so. He then mentioned the rest of the tradition. I then went to the mosque and found that the Messenger of Allah (ﷺ) was sitting there. I greeted him. He asked: What benefit did you have from your property? I replied: Allah Most High paid everything which was due from the Messenger of Allah (ﷺ). Nothing remains now. He asked: Did anything remain (from that property)? I said: Yes. He said: Look, if you can give me some comfort from it, for I shall not visit any member of my family until you give me some comfort from it. When the Messenger of Allah (ﷺ) offered the night prayer, he called me and said: What is the position of that which you had with you (i.e. property)? I said: I still have it, no one came to me. The Messenger of Allah (ﷺ) passed the night in the mosque. He then narrated the rest of the tradition. Next day when he offered the night prayer, he called me and asked: What is the position of that which you had (i.e. the rest of the property)? I replied: Allah has given you comfort from it, Messenger of Allah. He said: Allah is Most Great, and praised Allah, fearing lest he should die while it was with him. I then followed him until he came to his wives and greeted each one of them and finally he came to his place where he had to pass the night. This is all for which you asked me}}
\hadithdefcmd{abudawud}{3056}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ، بِمَعْنَى إِسْنَادِ أَبِي تَوْبَةَ وَحَدِيثِهِ قَالَ عِنْدَ قَوْلِهِ ‏ "‏ مَا يَقْضِي عَنِّي ‏"‏ ‏.‏ فَسَكَتَ عَنِّي رَسُولُ اللَّهِ صلى الله عليه وسلم فَاغْتَمَزْتُهَا ‏.‏\hadithno{3056}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Mu’awiyah through a different chain of narrators to the same effect as narrated by Abu Taubah. This version has “I have nothing to pay from me. The Apostle of Allaah(ﷺ) thereupon kept silence and this displeased me.”}}
\hadithdefcmd{abudawud}{3057}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا عِمْرَانُ، عَنْ قَتَادَةَ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عِيَاضِ بْنِ حِمَارٍ، قَالَ أَهْدَيْتُ لِلنَّبِيِّ صلى الله عليه وسلم نَاقَةً فَقَالَ ‏"‏ أَسْلَمْتَ ‏"‏ ‏.‏ فَقُلْتُ لاَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي نُهِيتُ عَنْ زَبْدِ الْمُشْرِكِينَ ‏"‏ ‏.‏\hadithno{3057}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Iyad ibn Himar: I presented a she-camel to the Prophet (ﷺ). He asked: Have you embraced Islam? I replied: No. The Prophet (ﷺ) said: I have been prohibited to accept the present of polytheists}}
\hadithdefcmd{abudawud}{3058}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ سِمَاكٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَقْطَعَهُ أَرْضًا بِحَضْرَمَوْتَ ‏.‏\hadithno{3058}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Alqamah ibn Wa'il: The Prophet (ﷺ) bestowed land in Hadramawt as fief}}
\hadithdefcmd{abudawud}{3059}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا جَامِعُ بْنُ مَطَرٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، بِإِسْنَادِهِ مِثْلَهُ ‏.‏\hadithno{3059}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by ‘Alqamah bin Wa’il through a different chain of narrators.”}}
\hadithdefcmd{abudawud}{3060}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ فِطْرٍ، حَدَّثَنِي أَبِي، عَنْ عَمْرِو بْنِ حُرَيْثٍ، قَالَ خَطَّ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم دَارًا بِالْمَدِينَةِ بِقَوْسٍ وَقَالَ ‏ "‏ أَزِيدُكَ أَزِيدُكَ ‏"‏ ‏.‏\hadithno{3060}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amr ibn Hurayth: The Messenger of Allah (ﷺ) demarcated a house with a bow at Medina for me. He said: I shall give you more. I shall give you more}}
\hadithdefcmd{abudawud}{3061}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ غَيْرِ، وَاحِدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقْطَعَ بِلاَلَ بْنَ الْحَارِثِ الْمُزَنِيَّ مَعَادِنَ الْقَبَلِيَّةِ وَهِيَ مِنْ نَاحِيَةِ الْفُرْعِ فَتِلْكَ الْمَعَادِنُ لاَ يُؤْخَذُ مِنْهَا إِلاَّ الزَّكَاةُ إِلَى الْيَوْمِ ‏.‏\hadithno{3061}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Rabi'ah ibn AbuAbdurRahman: Rabi'ah reported on the authority of more than one person saying: The Messenger of Allah (ﷺ) assigned as a fief to Bilal ibn al-Harith al-Muzani the mines of al-Qabaliyyah which is in the neighbourhood of al-Fur', and only zakat is levied on those mines up to the present day}}
\hadithdefcmd{abudawud}{3062}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدِ بْنِ حَاتِمٍ، وَغَيْرُهُ، قَالَ الْعَبَّاسُ حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا أَبُو أُوَيْسٍ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ الْمُزَنِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَقْطَعَ بِلاَلَ بْنَ الْحَارِثِ الْمُزَنِيَّ مَعَادِنَ الْقَبَلِيَّةِ جَلْسِيَّهَا وَغَوْرِيَّهَا - وَقَالَ غَيْرُ الْعَبَّاسِ جَلْسَهَا وَغَوْرَهَا - وَحَيْثُ يَصْلُحُ الزَّرْعُ مِنْ قُدْسٍ وَلَمْ يُعْطِهِ حَقَّ مُسْلِمٍ وَكَتَبَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ هَذَا مَا أَعْطَى مُحَمَّدٌ رَسُولُ اللَّهِ بِلاَلَ بْنَ الْحَارِثِ الْمُزَنِيَّ أَعْطَاهُ مَعَادِنَ الْقَبَلِيَّةِ جَلْسِيَّهَا وَغَوْرِيَّهَا ‏"‏ ‏.‏ وَقَالَ غَيْرُ الْعَبَّاسِ ‏"‏ جَلْسَهَا وَغَوْرَهَا ‏"‏ ‏.‏ ‏"‏ وَحَيْثُ يَصْلُحُ الزَّرْعُ مِنْ قُدْسٍ وَلَمْ يُعْطِهِ حَقَّ مُسْلِمٍ ‏"‏ ‏.‏ قَالَ أَبُو أُوَيْسٍ وَحَدَّثَنِي ثَوْرُ بْنُ زَيْدٍ مَوْلَى بَنِي الدِّيلِ بْنِ بَكْرِ بْنِ كِنَانَةَ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ مِثْلَهُ ‏.‏\hadithno{3062}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Amr ibn Awf al-Muzani: The Prophet (ﷺ) assigned as a fief to Bilal ibn al-Muzani the mines of al-Qabaliyyah both which lay on the upper side and which lay on the lower side, and (the land) which was suitable for cultivation at Quds. He did not give him (the land which involved) the right of a Muslim. The Prophet (ﷺ) wrote a document for him. It goes: "In the name of Allah, the Compassionate, the Merciful. This is what the Messenger of Allah (ﷺ) assigned to Bilal ibn Harith al-Muzani. He gave him the mines of al-Qabaliyyah, both which lay on the upper side and which lay on the lower side, and (the land) which is suitable for cultivation at Quds. He did not give him the right of any Muslim." Abu Uwais said: A similar tradition has been narrated to me by Thawr b. Zaid, client of Banu al-Dail b. Bakr b. Kinahah from 'Ikrimah on the authority of Ibn 'Abbas}}
\hadithdefcmd{abudawud}{3063}{حَدَّثَنَا مُحَمَّدُ بْنُ النَّضْرِ، قَالَ سَمِعْتُ الْحُنَيْنِيَّ، قَالَ قَرَأْتُهُ غَيْرَ مَرَّةٍ يَعْنِي كِتَابَ قَطِيعَةِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدَّثَنَا غَيْرُ وَاحِدٍ عَنْ حُسَيْنِ بْنِ مُحَمَّدٍ أَخْبَرَنَا أَبُو أُوَيْسٍ حَدَّثَنِي كَثِيرُ بْنُ عَبْدِ اللَّهِ عَنْ أَبِيهِ عَنْ جَدِّهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَقْطَعَ بِلاَلَ بْنَ الْحَارِثِ الْمُزَنِيَّ مَعَادِنَ الْقَبَلِيَّةِ جَلْسِيَّهَا وَغَوْرِيَّهَا - قَالَ ابْنُ النَّضْرِ وَجَرْسَهَا وَذَاتَ النُّصُبِ ثُمَّ اتَّفَقَا - وَحَيْثُ يَصْلُحُ الزَّرْعُ مِنْ قُدْسٍ ‏.‏ وَلَمْ يُعْطِ بِلاَلَ بْنَ الْحَارِثِ حَقَّ مُسْلِمٍ وَكَتَبَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هَذَا مَا أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِلاَلَ بْنَ الْحَارِثِ الْمُزَنِيَّ أَعْطَاهُ مَعَادِنَ الْقَبَلِيَّةِ جَلْسَهَا وَغَوْرَهَا وَحَيْثُ يَصْلُحُ الزَّرْعُ مِنْ قُدْسٍ وَلَمْ يُعْطِهِ حَقَّ مُسْلِمٍ ‏"‏ ‏.‏ قَالَ أَبُو أُوَيْسٍ حَدَّثَنِي ثَوْرُ بْنُ زَيْدٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ زَادَ ابْنُ النَّضْرِ وَكَتَبَ أُبَىُّ بْنُ كَعْبٍ ‏.‏\hadithno{3063}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Amr ibn Awf al-Muzani: The Prophet (ﷺ) assigned as a fief to Bilal ibn Harith al-Muzani the mines of al-Qabaliyyah, both those which lay on the upper side those and which lay on the lower side. The narrator, Ibn an-Nadr, added: "also Jars and Dhat an-Nusub." The agreed version reads: "and (the land) which is suitable for cultivation at Quds". He did not assign to Bilal ibn al-Harith the right of any Muslim. The Prophet (ﷺ) wrote a document to him: "This is what the Messenger of Allah (ﷺ) assigned to Bilal ibn al-Harith al-Muzani. He gave him the mines of al-Qabaliyyah both those which lay on the upper and lower side, and that which is fit for cultivation at Quds. He did not give him the right of any Muslim." The narrator AbuUways said: A similar tradition has been transmitted to me by Thawr ibn Zayd from Ikrimah on the authority of Ibn Abbas from the Prophet (ﷺ). Ibn an-Nadr added: Ubayy ibn Ka'b wrote it}}
\hadithdefcmd{abudawud}{3064}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، وَمُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، - الْمَعْنَى وَاحِدٌ - أَنَّ مُحَمَّدَ بْنَ يَحْيَى بْنِ قَيْسٍ الْمَأْرِبِيَّ، حَدَّثَهُمْ أَخْبَرَنِي أَبِي، عَنْ ثُمَامَةَ بْنِ شُرَاحِيلَ، عَنْ سُمَىِّ بْنِ قَيْسٍ، عَنْ شُمَيْرٍ، - قَالَ ابْنُ الْمُتَوَكِّلِ ابْنِ عَبْدِ الْمَدَانِ - عَنْ أَبْيَضَ بْنِ حَمَّالٍ، أَنَّهُ وَفَدَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَقْطَعَهُ الْمِلْحَ - قَالَ ابْنُ الْمُتَوَكِّلِ الَّذِي بِمَأْرِبَ - فَقَطَعَهُ لَهُ فَلَمَّا أَنْ وَلَّى قَالَ رَجُلٌ مِنَ الْمَجْلِسِ أَتَدْرِي مَا قَطَعْتَ لَهُ إِنَّمَا قَطَعْتَ لَهُ الْمَاءَ الْعِدَّ ‏.‏ قَالَ فَانْتَزَعَ مِنْهُ قَالَ وَسَأَلَهُ عَمَّا يُحْمَى مِنَ الأَرَاكِ قَالَ ‏"‏ مَا لَمْ تَنَلْهُ خِفَافٌ ‏"‏ ‏.‏ وَقَالَ ابْنُ الْمُتَوَكِّلِ ‏"‏ أَخْفَافُ الإِبِلِ ‏"‏ ‏.‏\hadithno{3064}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abyad ibn Hammal: Abyad went to the Messenger of Allah (ﷺ) and asked him for assigning him (the mines of) salt as fief. (The narrator Ibn al-Mutawakkil said: which was in Ma'arib.) So he assigned it to him as a fief. When he returned, a man in the meeting asked: Do you know what you have assigned him as a fief? You have assigned him the perennial spring water. So he took it back from him. He asked him about protecting land which had arak trees growing in it. He replied: He could have such as was beyond the region where the hoofs (of camels) went. The narrator Ibn al-Mutwakkil said: "that is the camel hoofs}}
\hadithdefcmd{abudawud}{3065}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ قَالَ مُحَمَّدُ بْنُ الْحَسَنِ الْمَخْزُومِيُّ ‏ "‏ مَا لَمْ تَنَلْهُ أَخْفَافُ الإِبِلِ ‏"‏ يَعْنِي أَنَّ الإِبِلَ تَأْكُلُ مُنْتَهَى رُءُوسِهَا وَيُحْمَى مَا فَوْقَهُ ‏.‏\hadithno{3065}\hadithgrade{Al-Albani: Very Daif; Muhammad Muhyi Al-Din Abdul Hamid: Very Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Al hasan Al Mukhzumi said “The sentence “that which is not reached by the Camel hoofs” means that the Camels eat (the arak trees) within the reach of their heads. So the land (where the arak trees are growing) may be protected beyond such a region}}
\hadithdefcmd{abudawud}{3066}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ الْقُرَشِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ، حَدَّثَنَا فَرَجُ بْنُ سَعِيدٍ، حَدَّثَنِي عَمِّي، ثَابِتُ بْنُ سَعِيدٍ عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَبْيَضَ بْنِ حَمَّالٍ أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ حِمَى الأَرَاكِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ حِمَى فِي الأَرَاكِ ‏"‏ ‏.‏ فَقَالَ أَرَاكَةً فِي حِظَارِي ‏.‏ فَقَالَ النَّبِيُّ عَلَيْهِ السَّلاَمُ ‏"‏ لاَ حِمَى فِي الأَرَاكِ ‏"‏ ‏.‏ قَالَ فَرَجٌ يَعْنِي بِحِظَارِي الأَرْضَ الَّتِي فِيهَا الزَّرْعُ الْمُحَاطُ عَلَيْهَا ‏.‏\hadithno{3066}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abyad ibn Hammal: He asked the Messenger of Allah (ﷺ) for giving him some land which had arak trees growing in it. The Messenger of Allah (ﷺ) said: There is no (permission for) protecting a land which has arak trees growing in it. He said: These arak trees are within the boundaries of my field. The Prophet (ﷺ) said: There is no (permission for) protecting a land which has arak trees growing in it. The narrator Faraj said: By the phrase 'within the boundaries of my field' he meant the land which had crop growing in it and was surrounded on four sides}}
\hadithdefcmd{abudawud}{3067}{حَدَّثَنَا عُمَرُ بْنُ الْخَطَّابِ أَبُو حَفْصٍ، حَدَّثَنَا الْفِرْيَابِيُّ، حَدَّثَنَا أَبَانُ، قَالَ عُمَرُ - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ أَبِي حَازِمٍ - قَالَ حَدَّثَنِي عُثْمَانُ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، صَخْرٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَزَا ثَقِيفًا فَلَمَّا أَنْ سَمِعَ ذَلِكَ صَخْرٌ رَكِبَ فِي خَيْلٍ يُمِدُّ النَّبِيَّ صلى الله عليه وسلم فَوَجَدَ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَدِ انْصَرَفَ وَلَمْ يَفْتَحْ فَجَعَلَ صَخْرٌ يَوْمَئِذٍ عَهْدَ اللَّهِ وَذِمَّتَهُ أَنْ لاَ يُفَارِقَ هَذَا الْقَصْرَ حَتَّى يَنْزِلُوا عَلَى حُكْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يُفَارِقْهُمْ حَتَّى نَزَلُوا عَلَى حُكْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَتَبَ إِلَيْهِ صَخْرٌ أَمَّا بَعْدُ فَإِنَّ ثَقِيفًا قَدْ نَزَلَتْ عَلَى حُكْمِكَ يَا رَسُولَ اللَّهِ وَأَنَا مُقْبِلٌ إِلَيْهِمْ وَهُمْ فِي خَيْلٍ ‏.‏ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالصَّلاَةِ جَامِعَةً فَدَعَا لأَحْمَسَ عَشْرَ دَعَوَاتٍ ‏"‏ اللَّهُمَّ بَارِكْ لأَحْمَسَ فِي خَيْلِهَا وَرِجَالِهَا ‏"‏ ‏.‏ وَأَتَاهُ الْقَوْمُ فَتَكَلَّمَ الْمُغِيرَةُ بْنُ شُعْبَةَ فَقَالَ يَا نَبِيَّ اللَّهِ إِنَّ صَخْرًا أَخَذَ عَمَّتِي وَدَخَلَتْ فِيمَا دَخَلَ فِيهِ الْمُسْلِمُونَ ‏.‏ فَدَعَاهُ فَقَالَ ‏"‏ يَا صَخْرُ إِنَّ الْقَوْمَ إِذَا أَسْلَمُوا أَحْرَزُوا دِمَاءَهُمْ وَأَمْوَالَهُمْ فَادْفَعْ إِلَى الْمُغِيرَةِ عَمَّتَهُ ‏"‏ ‏.‏ فَدَفَعَهَا إِلَيْهِ وَسَأَلَ نَبِيَّ اللَّهِ صلى الله عليه وسلم مَاءً لِبَنِي سُلَيْمٍ قَدْ هَرَبُوا عَنِ الإِسْلاَمِ وَتَرَكُوا ذَلِكَ الْمَاءَ ‏.‏ فَقَالَ يَا نَبِيَّ اللَّهِ أَنْزِلْنِيهِ أَنَا وَقَوْمِي ‏.‏ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَأَنْزَلَهُ وَأَسْلَمَ - يَعْنِي السُّلَمِيِّينَ - فَأَتَوْا صَخْرًا فَسَأَلُوهُ أَنْ يَدْفَعَ إِلَيْهِمُ الْمَاءَ فَأَبَى فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا يَا نَبِيَّ اللَّهِ أَسْلَمْنَا وَأَتَيْنَا صَخْرًا لِيَدْفَعَ إِلَيْنَا مَاءَنَا فَأَبَى عَلَيْنَا ‏.‏ فَأَتَاهُ فَقَالَ ‏"‏ يَا صَخْرُ إِنَّ الْقَوْمَ إِذَا أَسْلَمُوا أَحْرَزُوا أَمْوَالَهُمْ وَدِمَاءَهُمْ فَادْفَعْ إِلَى الْقَوْمِ مَاءَهُمْ ‏"‏ ‏.‏ قَالَ نَعَمْ يَا نَبِيَّ اللَّهِ ‏.‏ فَرَأَيْتُ وَجْهَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَتَغَيَّرُ عِنْدَ ذَلِكَ حُمْرَةً حَيَاءً مِنْ أَخْذِهِ الْجَارِيَةَ وَأَخْذِهِ الْمَاءَ ‏.‏\hadithno{3067}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sakhr ibn al-Ayla al-Ahmasi: The Messenger of Allah (ﷺ) raided Thaqif. When Sakhr heard this, he proceeded on his horse along with some horsemen to support the Prophet (ﷺ). He found the Prophet of Allah (ﷺ) had returned and he did not conquer (Ta'if). On that day Sakhr made a covenant with Allah and had His protection that he would not depart from that fortress until they (the inhabitants) surrendered to the command of the Messenger of Allah (ﷺ). He did not leave them until they had surrendered to the command of the Messenger of Allah (ﷺ). Sakhr then wrote to him: To proceed: Thaqif have surrendered to your command, Messenger of Allah, and I am on my way to them. They have horses with them. The Messenger of Allah (ﷺ) then ordered prayers to be offered in congregation. He then prayed for Ahmas ten times: O Allah, send blessings the horses and the men of Ahmas. The people came and Mughirah ibn Shu'bah said to him: Prophet of Allah, Sakhr took my paternal aunt while she embraced Islam like other Muslims. He called him and said: Sakhr, when people embrace Islam, they have security of their blood and property. Give back to Mughirah his paternal aunt. So he returned his aunt to him and asked the Prophet of Allah (ﷺ): What about Banu Sulaym who have run away for (fear of) Islam and left that water? He said: Prophet of Allah, allow me and my people to settle there. He said: Yes. So he allowed him to settle there. Banu Sulaym then embraced Islam, and they came to Sakhr. They asked him to return their water to them. But he refused. So they came to the Prophet (ﷺ) and said: Prophet of Allah, we embraced Islam and came to Sakhr so that he might return our water to us. But he has refused. He (the Prophet) then came to him and said: When people embrace Islam, they secure their properties and blood. Return to the people their water. He said: Yes, Prophet of Allah. I saw that the face of the Messenger of Allah (ﷺ) was reddening at that moment, being ashamed of taking back from him the slave-girl and the water}}
\hadithdefcmd{abudawud}{3068}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي سَبْرَةُ بْنُ عَبْدِ الْعَزِيزِ بْنِ الرَّبِيعِ الْجُهَنِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَزَلَ فِي مَوْضِعِ الْمَسْجِدِ تَحْتَ دَوْمَةٍ فَأَقَامَ ثَلاَثًا ثُمَّ خَرَجَ إِلَى تَبُوكَ وَإِنَّ جُهَيْنَةَ لَحِقُوهُ بِالرَّحْبَةِ فَقَالَ لَهُمْ ‏"‏ مَنْ أَهْلُ ذِي الْمَرْوَةِ ‏"‏ ‏.‏ فَقَالُوا بَنُو رِفَاعَةَ مِنْ جُهَيْنَةَ ‏.‏ فَقَالَ ‏"‏ قَدْ أَقْطَعْتُهَا لِبَنِي رِفَاعَةَ ‏"‏ ‏.‏ فَاقْتَسَمُوهَا فَمِنْهُمْ مَنْ بَاعَ وَمِنْهُمْ مَنْ أَمْسَكَ فَعَمِلَ ثُمَّ سَأَلْتُ أَبَاهُ عَبْدَ الْعَزِيزِ عَنْ هَذَا الْحَدِيثِ فَحَدَّثَنِي بِبَعْضِهِ وَلَمْ يُحَدِّثْنِي بِهِ كُلِّهِ ‏.‏\hadithno{3068}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Saburah ibn Ma'bad al-Juhani: The Prophet (ﷺ) alighted at a place where a mosque has been built under a large tree. He tarried there for three days, and then proceeded to Tabuk. Juhaynah met him on a wide plain. He asked them: who are the people of Dhul-Marwah? They replied: Banu Rifa'ah of Juhaynah. He said: I have given this (land) to Banu Rifa'ah as a fief. Therefore, they divided it. Some of them sold (their share) and others retained and worked on it. (Sub-narrator Ibn Wahab said: I then asked AbdulAziz about this tradition. He narrated a part of it to me and did not narrate it in full)}}
\hadithdefcmd{abudawud}{3069}{حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ آدَمَ - حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقْطَعَ الزُّبَيْرَ نَخْلاً ‏.‏\hadithno{3069}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Asma' daughter of AbuBakr: The Messenger of Allah (ﷺ) assigned to az-Zubayr palm-trees as a fief}}
\hadithdefcmd{abudawud}{3070}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، - الْمَعْنَى وَاحِدٌ - قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ حَسَّانَ الْعَنْبَرِيُّ، حَدَّثَتْنِي جَدَّتَاىَ، صَفِيَّةُ وَدُحَيْبَةُ ابْنَتَا عُلَيْبَةَ وَكَانَتَا رَبِيبَتَىْ قَيْلَةَ بِنْتِ مَخْرَمَةَ وَكَانَتْ جَدَّةَ أَبِيهِمَا أَنَّهَا أَخْبَرَتْهُمَا قَالَتْ، قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ تَقَدَّمَ صَاحِبِي - تَعْنِي حُرَيْثَ بْنَ حَسَّانَ وَافِدَ بَكْرِ بْنِ وَائِلٍ - فَبَايَعَهُ عَلَى الإِسْلاَمِ عَلَيْهِ وَعَلَى قَوْمِهِ ثُمَّ قَالَ يَا رَسُولَ اللَّهِ اكْتُبْ بَيْنَنَا وَبَيْنَ بَنِي تَمِيمٍ بِالدَّهْنَاءِ أَنْ لاَ يُجَاوِزَهَا إِلَيْنَا مِنْهُمْ أَحَدٌ إِلاَّ مُسَافِرٌ أَوْ مُجَاوِرٌ ‏.‏ فَقَالَ ‏"‏ اكْتُبْ لَهُ يَا غُلاَمُ بِالدَّهْنَاءِ ‏"‏ ‏.‏ فَلَمَّا رَأَيْتُهُ قَدْ أَمَرَ لَهُ بِهَا شُخِصَ بِي وَهِيَ وَطَنِي وَدَارِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ لَمْ يَسْأَلْكَ السَّوِيَّةَ مِنَ الأَرْضِ إِذْ سَأَلَكَ إِنَّمَا هِيَ هَذِهِ الدَّهْنَاءُ عِنْدَكَ مُقَيَّدُ الْجَمَلِ وَمَرْعَى الْغَنَمِ وَنِسَاءُ بَنِي تَمِيمٍ وَأَبْنَاؤُهَا وَرَاءَ ذَلِكَ فَقَالَ ‏"‏ أَمْسِكْ يَا غُلاَمُ صَدَقَتِ الْمِسْكِينَةُ الْمُسْلِمُ أَخُو الْمُسْلِمِ يَسَعُهُمَا الْمَاءُ وَالشَّجَرُ وَيَتَعَاوَنَانِ عَلَى الْفُتَّانِ ‏"‏ ‏.‏\hadithno{3070}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qaylah bint Makhramah: Abdullah ibn Hasan al-Anbari said: My grandmothers, Safiyyah and Duhaybah, narrated to me, that hey were the daughters of Ulaybah and were nourished by Qaylah, daughter of Makhramah. She was the grandmother of their father. She reported to them, saying: We came upon the Messenger of Allah (ﷺ). My companion, Hurayth ibn Hassan, came to him as a delegate from Bakr ibn Wa'il. He took the oath of allegiance of Islam for himself and for his people. He then said: Messenger of Allah (ﷺ), write a document for us, giving us the land lying between us and Banu Tamim at ad-Dahna' to the effect that not one of them will cross it in our direction except a traveller or a passer-by. He said: Write down ad-Dahna' for them, boy. When I saw that he passed orders to give it to him, I became anxious, for it was my native land and my home. I said: Messenger of Allah, he did not ask you for a true border when he asked you. This land of Dahna' is a place where the camels have their home, and it is a pasture for the sheep. The women of Banu Tamim and their children are beyond it. He said: Stop, boy! A poor woman spoke the truth: a Muslim is a brother of a Muslim. Each one of them may benefit from water and trees, and they should cooperate with each other against Satan}}
\hadithdefcmd{abudawud}{3071}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ عَبْدِ الْوَاحِدِ، حَدَّثَتْنِي أُمُّ جَنُوبٍ بِنْتُ نُمَيْلَةَ، عَنْ أُمِّهَا، سُوَيْدَةَ بِنْتِ جَابِرٍ عَنْ أُمِّهَا، عَقِيلَةَ بِنْتِ أَسْمَرَ بْنِ مُضَرِّسٍ عَنْ أَبِيهَا، أَسْمَرَ بْنِ مُضَرِّسٍ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَبَايَعْتُهُ فَقَالَ ‏ "‏ مَنْ سَبَقَ إِلَى مَاءٍ لَمْ يَسْبِقْهُ إِلَيْهِ مُسْلِمٌ فَهُوَ لَهُ ‏"‏ ‏.‏ قَالَ فَخَرَجَ النَّاسُ يَتَعَادَوْنَ يَتَخَاطُّونَ ‏.‏\hadithno{3071}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Asmar ibn Mudarris: I came to the Prophet (ﷺ), and took the oath of allegiance to him. He said: If anyone reaches a water which has not been approached before by any Muslim, it belongs to him. The people, therefore, went out running and marking (on the land)}}
\hadithdefcmd{abudawud}{3072}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَقْطَعَ الزُّبَيْرَ حُضْرَ فَرَسِهِ فَأَجْرَى فَرَسَهُ حَتَّى قَامَ ثُمَّ رَمَى بِسَوْطِهِ فَقَالَ ‏ "‏ أَعْطُوهُ مِنْ حَيْثُ بَلَغَ السَّوْطُ ‏"‏ ‏.‏\hadithno{3072}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) gave az-Zubayr the land as a fief up to the reach of his horse when he runs. He, therefore, made his horse run until it stopped. He then threw his flog. Thereupon he said: Give him (the land) up to the point where his flog has reached}}
\hadithdefcmd{abudawud}{3073}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحْيَا أَرْضًا مَيْتَةً فَهِيَ لَهُ وَلَيْسَ لِعِرْقٍ ظَالِمٍ حَقٌّ ‏"‏ ‏.‏\hadithno{3073}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih}\hadithtrans{Narrated Sa'id ibn Zayd: The Prophet (ﷺ) said: If anyone brings barren land into cultivation, it belongs to him, and the unjust vein has no right}}
\hadithdefcmd{abudawud}{3074}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ إِسْحَاقَ - عَنْ يَحْيَى بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحْيَا أَرْضًا مَيْتَةً فَهِيَ لَهُ ‏"‏ ‏.‏ وَذَكَرَ مِثْلَهُ قَالَ فَلَقَدْ خَبَّرَنِي الَّذِي حَدَّثَنِي هَذَا الْحَدِيثَ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم غَرَسَ أَحَدُهُمَا نَخْلاً فِي أَرْضِ الآخَرِ فَقَضَى لِصَاحِبِ الأَرْضِ بِأَرْضِهِ وَأَمَرَ صَاحِبَ النَّخْلِ أَنْ يُخْرِجَ نَخْلَهُ مِنْهَا ‏.‏ قَالَ فَلَقَدْ رَأَيْتُهَا وَإِنَّهَا لَتُضْرَبُ أُصُولُهَا بِالْفُئُوسِ وَإِنَّهَا لَنَخْلٌ عُمٌّ حَتَّى أُخْرِجَتْ مِنْهَا ‏.‏\hadithno{3074}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Urwah: The Prophet (ﷺ) said: If anyone brings barren land into cultivation, it belong to him. He then transmitted a similar tradition mentioned above (No. 3067). He ('Urwah) said: One who transmitted this tradition to me said that two persons brought their dispute to the Messenger of Allah (ﷺ). One of them grew palm trees in the land of the other. He decided to return the land to its owner of the palm-trees to remove his palm-trees. He said: I saw when their roots were being struck with axes. The trees were fully grown up, but they were removed from there}}
\hadithdefcmd{abudawud}{3075}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا وَهْبٌ، عَنْ أَبِيهِ، عَنِ ابْنِ إِسْحَاقَ، بِإِسْنَادِهِ وَمَعْنَاهُ إِلاَّ أَنَّهُ قَالَ عِنْدَ قَوْلِهِ مَكَانَ الَّذِي حَدَّثَنِي هَذَا فَقَالَ رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَأَكْثَرُ ظَنِّي أَنَّهُ أَبُو سَعِيدٍ الْخُدْرِيُّ فَأَنَا رَأَيْتُ الرَّجُلَ يَضْرِبُ فِي أُصُولِ النَّخْلِ ‏.‏\hadithno{3075}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn Ishaq through a different chain of narrators and to the same effect. Instead of the phrase “one who transmitted this tradition to me” this version has “A man from among the Companions of the Prophet (ﷺ) and probably he was Abu Sa’id Al Khudri. I saw the man striking at the roots of the palm trees.”}}
\hadithdefcmd{abudawud}{3076}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الآمُلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُرْوَةَ، قَالَ أَشْهَدُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّ الأَرْضَ أَرْضُ اللَّهِ وَالْعِبَادَ عِبَادُ اللَّهِ وَمَنْ أَحْيَا مَوَاتًا فَهُوَ أَحَقُّ بِهِ جَاءَنَا بِهَذَا عَنِ النَّبِيِّ صلى الله عليه وسلم الَّذِينَ جَاءُوا بِالصَّلَوَاتِ عَنْهُ ‏.‏\hadithno{3076}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Urwah: I testify that the Messenger of Allah (ﷺ) decided that the land is the land of Allah, and the servants are the servants of Allah. If anyone brings barren land into cultivation, he has more right to it. This tradition has been transmitted to us from the Prophet (ﷺ) by those who transmitted the traditions about prayer from him}}
\hadithdefcmd{abudawud}{3077}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَاطَ حَائِطًا عَلَى أَرْضٍ فَهِيَ لَهُ ‏"‏ ‏.‏\hadithno{3077}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah: The Prophet (ﷺ) said: If anyone surrounds a land with a wall, it belongs to him}}
\hadithdefcmd{abudawud}{3078}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، قَالَ هِشَامٌ الْعِرْقُ الظَّالِمُ أَنْ يَغْرِسَ الرَّجُلُ فِي أَرْضِ غَيْرِهِ فَيَسْتَحِقَّهَا بِذَلِكَ ‏.‏ قَالَ مَالِكٌ وَالْعِرْقُ الظَّالِمُ كُلُّ مَا أُخِذَ وَاحْتُفِرَ وَغُرِسَ بِغَيْرِ حَقٍّ ‏.‏\hadithno{3078}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hisham said “The unjust vein means that a man implants a tree in the land of another man so that they may be entitled to it. Malik said “The unjust vein means that a man takes (a thing) digs a pit and implants a tree without (his) right}}
\hadithdefcmd{abudawud}{3079}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنِ الْعَبَّاسِ السَّاعِدِيِّ، - يَعْنِي ابْنَ سَهْلِ بْنِ سَعْدٍ - عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم تَبُوكَ فَلَمَّا أَتَى وَادِيَ الْقُرَى إِذَا امْرَأَةٌ فِي حَدِيقَةٍ لَهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ اخْرُصُوا ‏"‏ ‏.‏ فَخَرَصَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشَرَةَ أَوْسُقٍ فَقَالَ لِلْمَرْأَةِ ‏"‏ أَحْصِي مَا يَخْرُجُ مِنْهَا ‏"‏ ‏.‏ فَأَتَيْنَا تَبُوكَ فَأَهْدَى مَلِكُ أَيْلَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بَغْلَةً بَيْضَاءَ وَكَسَاهُ بُرْدَةً وَكَتَبَ لَهُ - يَعْنِي - بِبَحْرِهِ ‏.‏ قَالَ فَلَمَّا أَتَيْنَا وَادِيَ الْقُرَى قَالَ لِلْمَرْأَةِ ‏"‏ كَمْ كَانَ فِي حَدِيقَتِكِ ‏"‏ ‏.‏ قَالَتْ عَشَرَةَ أَوْسُقٍ خَرْصَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي مُتَعَجِّلٌ إِلَى الْمَدِينَةِ فَمَنْ أَرَادَ مِنْكُمْ أَنْ يَتَعَجَّلَ مَعِي فَلْيَتَعَجَّلْ ‏"‏ ‏.‏\hadithno{3079}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1481) Sahih Muslim (1392 After  2281)}\hadithtrans{Abu Humaid Al Sa’idi said “I went to Tabuk on an expedition along with the Apostle of Allaah(ﷺ). When he reached Wadi Al Qura, he found a woman in her garden. The Apostle of Allaah(ﷺ) said to his Companions “Assess (the quantity o fruits). The Apostle of Allaah(ﷺ) assessed ten wasqs.” He said to the woman “Count the produce of it. We then came to Tabuk.” The monarch of Ailah presented a white mule as a gift to the Apostle of Allaah(ﷺ). He presented a cloak as a gift o him and wrote a document for his land at sea coast. When we came to Wadi Al Qura he said to the woman “How much is the produce of your garden?” She replied “Ten wasqs which the Apostle of Allaah(ﷺ) had assessed.” The Apostle of Allaah(ﷺ) said “I am going quickly to Madeenah if any of you intend to go quickly with me , he should make haste.”}}
\hadithdefcmd{abudawud}{3080}{حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ غِيَاثٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ كُلْثُومٍ، عَنْ زَيْنَبَ، أَنَّهَا كَانَتْ تَفْلِي رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ امْرَأَةُ عُثْمَانَ بْنِ عَفَّانَ وَنِسَاءٌ مِنَ الْمُهَاجِرَاتِ وَهُنَّ يَشْتَكِينَ مَنَازِلَهُنَّ أَنَّهَا تَضِيقُ عَلَيْهِنَّ وَيُخْرَجْنَ مِنْهَا فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُوَرَّثَ دُورَ الْمُهَاجِرِينَ النِّسَاءُ فَمَاتَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ فَوَرِثَتْهُ امْرَأَتُهُ دَارًا بِالْمَدِينَةِ ‏.‏\hadithno{3080}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zaynab: She was picking lice from the head of the Messenger of Allah (ﷺ) while the wife of Uthman ibn Affan and the immigrant women were with him. They complained about their houses that they had been narrowed down to them and they were evicted from them. The Messenger of Allah (ﷺ) ordered that the houses of the Immigrants should be given to their wives. Thereafter Abdullah ibn Mas'ud died, and his wife inherited his house in Medina}}
\hadithdefcmd{abudawud}{3081}{حَدَّثَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ عِيسَى، - يَعْنِي ابْنَ سُمَيْعٍ - حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، حَدَّثَنِي أَبُو عَبْدِ اللَّهِ، عَنْ مُعَاذٍ، أَنَّهُ قَالَ مَنْ عَقَدَ الْجِزْيَةَ فِي عُنُقِهِ فَقَدْ بَرِئَ مِمَّا عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3081}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Jabal: He who put the necklace of jizyah in his neck abandoned the way followed by the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{3082}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحَضْرَمِيُّ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي عُمَارَةُ بْنُ أَبِي الشَّعْثَاءِ، حَدَّثَنِي سِنَانُ بْنُ قَيْسٍ، حَدَّثَنِي شَبِيبُ بْنُ نُعَيْمٍ، حَدَّثَنِي يَزِيدُ بْنُ خُمَيْرٍ، حَدَّثَنِي أَبُو الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَخَذَ أَرْضًا بِجِزْيَتِهَا فَقَدِ اسْتَقَالَ هِجْرَتَهُ وَمَنْ نَزَعَ صَغَارَ كَافِرٍ مِنْ عُنُقِهِ فَجَعَلَهُ فِي عُنُقِهِ فَقَدْ وَلَّى الإِسْلاَمَ ظَهْرَهُ ‏"‏ ‏.‏ قَالَ فَسَمِعَ مِنِّي خَالِدُ بْنُ مَعْدَانَ هَذَا الْحَدِيثَ فَقَالَ لِي أَشَبِيبٌ حَدَّثَكَ قُلْتُ نَعَمْ ‏.‏ قَالَ فَإِذَا قَدِمْتَ فَسَلْهُ فَلْيَكْتُبْ إِلَىَّ بِالْحَدِيثِ ‏.‏ قَالَ فَكَتَبَهُ لَهُ فَلَمَّا قَدِمْتُ سَأَلَنِي خَالِدُ بْنُ مَعْدَانَ الْقِرْطَاسَ فَأَعْطَيْتُهُ فَلَمَّا قَرَأَهُ تَرَكَ مَا فِي يَدَيْهِ مِنَ الأَرَضِينَ حِينَ سَمِعَ ذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا يَزِيدُ بْنُ خُمَيْرٍ الْيَزَنِيُّ لَيْسَ هُوَ صَاحِبَ شُعْبَةَ ‏.‏\hadithno{3082}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbudDarda': The Prophet (ﷺ) said: If anyone takes land by (paying) its jizyah, he renounces his immigration; and if anyone takes off the disgrace of an unbeliever from his neck he turns away his back from Islam. He (the narrator) said: Thereafter Khalid ibn Ma'dan heard this tradition from me, and he said: Has Shubayb narrated it to you? I said: Yes. He said! When you come to him, ask him to write this tradition to me. He said: He then wrote it for him. When I came, Khalid ibn Ma'dan asked me for the paper and I gave it to him. When he read (the paper), he abandoned the lands he had in his possession the moment he heard this. Abu Dawud said: This Yazid b. Khumair al-Yazani is not the disciple of Shu'bah}}
\hadithdefcmd{abudawud}{3083}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ حِمَى إِلاَّ لِلَّهِ وَلِرَسُولِهِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَبَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَمَى النَّقِيعَ ‏.‏\hadithno{3083}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2370)}\hadithtrans{Al Sa’b bin Jaththamah reported the Apostle of Allaah(ﷺ) as saying “There is no (permission for) protected land except for Allaah and His Prophet. Ibn Shihab said “It has reached me that the Apostle of Allaah(ﷺ) protected Naqi’.”}}
\hadithdefcmd{abudawud}{3084}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حَمَى النَّقِيعَ وَقَالَ ‏ "‏ لاَ حِمَى إِلاَّ لِلَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3084}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated As-Sa'b ibn Jaththamah: The Prophet (ﷺ) protected Naqi and said: There is no (permission for) protected land except for Allah Most High}}
\hadithdefcmd{abudawud}{3085}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ سَمِعَا أَبَا هُرَيْرَةَ، يُحَدِّثُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏\hadithno{3085}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1499) Sahih Muslim (1710)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A fifth is payable on buried treasure}}
\hadithdefcmd{abudawud}{3086}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ هِشَامٍ، عَنِ الْحَسَنِ، قَالَ الرِّكَازُ الْكَنْزُ الْعَادِيُّ\hadithno{3086}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Al hasan said “Rikaz means treasure buried in pre Islamic times.”}}
\hadithdefcmd{abudawud}{3087}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا الزَّمْعِيُّ، عَنْ عَمَّتِهِ، قُرَيْبَةَ بِنْتِ عَبْدِ اللَّهِ بْنِ وَهْبٍ عَنْ أُمِّهَا، كَرِيمَةَ بِنْتِ الْمِقْدَادِ عَنْ ضُبَاعَةَ بِنْتِ الزُّبَيْرِ بْنِ عَبْدِ الْمُطَّلِبِ بْنِ هَاشِمٍ، أَنَّهَا أَخْبَرَتْهَا قَالَتْ، ذَهَبَ الْمِقْدَادُ لِحَاجَتِهِ بِبَقِيعِ الْخَبْخَبَةِ فَإِذَا جُرَذٌ يُخْرِجُ مِنْ جُحْرٍ دِينَارًا ثُمَّ لَمْ يَزَلْ يُخْرِجُ دِينَارًا دِينَارًا حَتَّى أَخْرَجَ سَبْعَةَ عَشَرَ دِينَارًا ثُمَّ أَخْرَجَ خِرْقَةً حَمْرَاءَ - يَعْنِي فِيهَا دِينَارٌ - فَكَانَتْ ثَمَانِيَةَ عَشَرَ دِينَارًا فَذَهَبَ بِهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ وَقَالَ لَهُ خُذْ صَدَقَتَهَا ‏.‏ فَقَالَ لَهُ صلى الله عليه وسلم ‏"‏ هَلْ هَوَيْتَ إِلَى الْجُحْرِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَارَكَ اللَّهُ لَكَ فِيهَا ‏"‏ ‏.‏\hadithno{3087}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Duba'ah daughter of az-Zubayr ibn AbdulMuttalib: Al-Miqdad went to Baqi' al-Khabkhabah for a certain need. He found a mouse taking out a dinar from a hole. It then continued to take out dinars one by one until it took out seventeen dinars. It then took out a red purse containing a dinar. There were thus eighteen dinars. He took them to the Prophet (ﷺ), informed him and said to him: Take its sadaqah. The Prophet (ﷺ) asked him: Did you extend your hand toward the hole? He replied: No. The Messenger of Allah (ﷺ) then said: May Allah bless you in it}}
\hadithdefcmd{abudawud}{3088}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، سَمِعْتُ مُحَمَّدَ بْنَ إِسْحَاقَ، يُحَدِّثُ عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ بُجَيْرِ بْنِ أَبِي بُجَيْرٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ حِينَ خَرَجْنَا مَعَهُ إِلَى الطَّائِفِ فَمَرَرْنَا بِقَبْرٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَذَا قَبْرُ أَبِي رِغَالٍ وَكَانَ بِهَذَا الْحَرَمِ يَدْفَعُ عَنْهُ فَلَمَّا خَرَجَ أَصَابَتْهُ النِّقْمَةُ الَّتِي أَصَابَتْ قَوْمَهُ بِهَذَا الْمَكَانِ فَدُفِنَ فِيهِ وَآيَةُ ذَلِكَ أَنَّهُ دُفِنَ مَعَهُ غُصْنٌ مِنْ ذَهَبٍ إِنْ أَنْتُمْ نَبَشْتُمْ عَنْهُ أَصَبْتُمُوهُ مَعَهُ ‏"‏ ‏.‏ فَابْتَدَرَهُ النَّاسُ فَاسْتَخْرَجُوا الْغُصْنَ ‏.‏\hadithno{3088}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: When we went out along with the Messenger of Allah (ﷺ) to at-Ta'if we passed a grave. I heard the Messenger of Allah (ﷺ) say: This is the grave of AbuRighal. He was in this sacred mosque (sanctuary) protecting himself (from punishment). When he came out, he suffered the same punishment which his people suffered at this place, and he was buried in it. The sign of it is that a golden bough was buried with him. If you dig it out, you will find it with him. The people hastened to it and took out the bough}}
