% Auto-generated chapter 51 for nasai
% Hadiths in this chapter: 220

\hadithdefcmd{nasai}{5540}{أَخْبَرَنَا أَبُو بَكْرٍ، أَحْمَدُ بْنُ مُحَمَّدِ بْنِ إِسْحَاقَ السُّنِّيُّ قِرَاءَةً عَلَيْهِ فِي بَيْتِهِ قَالَ أَنْبَأَنَا الإِمَامُ أَبُو عَبْدِ الرَّحْمَنِ أَحْمَدُ بْنُ شُعَيْبٍ النَّسَائِيُّ رَحِمَهُ اللَّهُ تَعَالَى قَالَ أَنْبَأَنَا أَبُو دَاوُدَ قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى قَالَ أَنْبَأَنَا إِسْرَائِيلُ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي مَيْسَرَةَ عَنْ عُمَرَ رضى الله عنه قَالَ لَمَّا نَزَلَ تَحْرِيمُ الْخَمْرِ قَالَ عُمَرُ اللَّهُمَّ بَيِّنْ لَنَا فِي الْخَمْرِ بَيَانًا شَافِيًا‏.‏ فَنَزَلَتِ الآيَةُ الَّتِي فِي الْبَقَرَةِ فَدُعِيَ عُمَرُ فَقُرِئَتْ عَلَيْهِ فَقَالَ عُمَرُ اللَّهُمَّ بَيِّنْ لَنَا فِي الْخَمْرِ بَيَانًا شَافِيًا‏.‏ فَنَزَلَتِ الآيَةُ الَّتِي فِي النِّسَاءِ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَقْرَبُوا الصَّلاَةَ وَأَنْتُمْ سُكَارَى ‏\}‏ فَكَانَ مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا أَقَامَ الصَّلاَةَ نَادَى لاَ تَقْرَبُوا الصَّلاَةَ وَأَنْتُمْ سُكَارَى فَدُعِيَ عُمَرُ فَقُرِئَتْ عَلَيْهِ فَقَالَ اللَّهُمَّ بَيِّنْ لَنَا فِي الْخَمْرِ بَيَانًا شَافِيًا‏.‏ فَنَزَلَتِ الآيَةُ الَّتِي فِي الْمَائِدَةِ فَدُعِيَ عُمَرُ فَقُرِئَتْ عَلَيْهِ فَلَمَّا بَلَغَ ‏\{‏ فَهَلْ أَنْتُمْ مُنْتَهُونَ ‏\}‏ قَالَ عُمَرُ رضى الله عنه انْتَهَيْنَا انْتَهَيْنَا‏.‏\hadithno{5540}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Umar that:When the prohibition of Khamr was revealed, 'Umar said: "O Allah, give us a clear ruling on Khamr," and the Verse in Al-Baqarah was revealed. 'Umar was called and it was recited to him. Then 'Umar said: "O Allah, give us a clear ruling on Khamr," and the Verse in An-Nisa' was revealed: "O you who believe! Approach not As-Salah (the prayer) when you are in a drunken state". And when the Iqamah for prayer was said, the caller of the Messenger of Allah [SAW] would cry out: "O you who believe! Approach not As-Salah (the prayer) when you are in a drunken state." 'Umar was called and this was recited to him. Then he said: "O Allah, give us a clear ruling on Khamr." Then the Verse in Surat Al-Ma'idah was revealed, and 'Umar was called, and it was recited to him. When he reached the words, "So, will you not then abstain?," 'Umar said: "We have abstained, we have abstained}}
\hadithdefcmd{nasai}{5541}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ الْمُبَارَكِ - عَنْ سُلَيْمَانَ التَّيْمِيِّ، أَنَّ أَنَسَ بْنَ مَالِكٍ، أَخْبَرَهُمْ قَالَ بَيْنَا أَنَا قَائِمٌ، عَلَى الْحَىِّ وَأَنَا أَصْغَرُهُمْ، سِنًّا عَلَى عُمُومَتِي إِذْ جَاءَ رَجُلٌ فَقَالَ إِنَّهَا قَدْ حُرِّمَتِ الْخَمْرُ‏.‏ وَأَنَا قَائِمٌ عَلَيْهِمْ أَسْقِيهِمْ مِنْ فَضِيخٍ لَهُمْ فَقَالُوا اكْفَأْهَا‏.‏ فَكَفَأْتُهَا فَقُلْتُ لأَنَسٍ مَا هُوَ قَالَ الْبُسْرُ وَالتَّمْرُ‏.‏ قَالَ أَبُو بَكْرِ بْنُ أَنَسٍ كَانَتْ خَمْرُهُمْ يَوْمَئِذٍ فَلَمْ يُنْكِرْ أَنَسٌ‏.‏\hadithno{5541}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik said:"While I was taking care of a group of people, including my paternal uncles, and I was the youngest of them, a man came and said: 'Khamr has been forbidden.' I was taking care of them, and was pouring Fadikh (date-wine) for them. They said: 'Pour it away.' So I poured it away." I (the narrator) said to Anas: "What is that?" He said: "Unripe dates and dried dates." Abu Bakr bin Anas said: "That was their wine in those days." And Anas did not deny that}}
\hadithdefcmd{nasai}{5542}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ الْمُبَارَكِ - عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كُنْتُ أَسْقِي أَبَا طَلْحَةَ وَأُبَىَّ بْنَ كَعْبٍ وَأَبَا دُجَانَةَ فِي رَهْطٍ مِنَ الأَنْصَارِ فَدَخَلَ عَلَيْنَا رَجُلٌ فَقَالَ حَدَثَ خَبَرٌ نَزَلَ تَحْرِيمُ الْخَمْرِ‏.‏ فَكَفَأْنَا‏.‏ قَالَ وَمَا هِيَ يَوْمَئِذٍ إِلاَّ الْفَضِيخُ خَلِيطُ الْبُسْرِ وَالتَّمْرِ‏.‏ قَالَ وَقَالَ أَنَسٌ لَقَدْ حُرِّمَتِ الْخَمْرُ وَإِنَّ عَامَّةَ خُمُورِهِمْ يَوْمَئِذٍ الْفَضِيخُ‏.‏\hadithno{5542}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"I was pouring (wine) for Abu Talhah, Ubayy bin Ka'b and Abu Dujanah among a group of Ansar when a man came in and said: 'Something new has happened; the prohibition of Khamr has been revealed.' So we poured it away." He said: "The only intoxicant in those days was Fadikh, a mixture of unripe dates and dried dates." And Anas said: "Khamr was forbidden, and most of their Khamr in those days was Fadikh}}
\hadithdefcmd{nasai}{5543}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ حُرِّمَتِ الْخَمْرُ حِينَ حُرِّمَتْ وَإِنَّهُ لَشَرَابُهُمُ الْبُسْرُ وَالتَّمْرُ‏.‏\hadithno{5543}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"When Khamr was forbidden, their drink was (made from) unripe dates and dried dates}}
\hadithdefcmd{nasai}{5544}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ - قَالَ الْبُسْرُ وَالتَّمْرُ خَمْرٌ‏.‏\hadithno{5544}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir - meaning bin 'Abdullah - said:"Unripe dates and dried dates are Khamr}}
\hadithdefcmd{nasai}{5545}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ الْبُسْرُ وَالتَّمْرُ خَمْرٌ‏.‏ رَفَعَهُ الأَعْمَشُ‏.‏\hadithno{5545}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{Jabir bin 'Abdullah said:"Unripe dates and dried dates are Khamr." Al-A'mash narrated it in Marfu' form}}
\hadithdefcmd{nasai}{5546}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا، قَالَ أَنْبَأَنَا عُبَيْدُ اللَّهِ، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الزَّبِيبُ وَالتَّمْرُ هُوَ الْخَمْرُ ‏"‏‏.‏\hadithno{5546}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:The Prophet [SAW] said: "Raisins and dried dates are Khamr}}
\hadithdefcmd{nasai}{5547}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْبَلَحِ وَالتَّمْرِ وَالزَّبِيبِ وَالتَّمْرِ‏.‏\hadithno{5547}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Abi Laila, from one of the Companions of the Prophet [SAW], that:The Prophet [SAW] forbade (mixtures of) Al-Balh and dried dates, and of raisins and dried dates}}
\hadithdefcmd{nasai}{5548}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ حَبِيبِ بْنِ أَبِي عَمْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُزَفَّتِ وَالنَّقِيرِ وَأَنْ يُخْلَطَ الْبَلَحُ وَالزَّهْوُ‏.‏\hadithno{5548}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah [SAW] forbade Ad-Dubba', Al-Hantam, Al-Muzaffat, and An-Naqir, and (he forbade) mixing Al-Balh with Az-Zahuw}}
\hadithdefcmd{nasai}{5549}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ حَبِيبِ بْنِ أَبِي عَمْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْمُزَفَّتِ - وَزَادَ مَرَّةً أُخْرَى - وَالنَّقِيرِ وَأَنْ يُخْلَطَ التَّمْرُ بِالزَّبِيبِ وَالزَّهْوُ بِالتَّمْرِ‏.‏\hadithno{5549}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah [SAW] forbade Ad-Dubba', Al-Muzaffat," - and on one occasion he added: "An-Naqir," - "and (he forbade) mixing At-Tamr (dried dates) with raisins, and Az-Zahuw with At-Tamr}}
\hadithdefcmd{nasai}{5550}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ حَبِيبٍ، عَنْ أَبِي أَرْطَاةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الزَّهْوِ وَالتَّمْرِ وَالزَّبِيبِ وَالتَّمْرِ‏.‏\hadithno{5550}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah [SAW] forbade (mixing) Az-Zahuw and At-Tamr, and raisins and dried dates (At-Tamr)}}
\hadithdefcmd{nasai}{5551}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَجْمَعُوا بَيْنَ التَّمْرِ وَالزَّبِيبِ وَلاَ بَيْنَ الزَّهْوِ وَالرُّطَبِ ‏"‏‏.‏\hadithno{5551}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Abi Qatadah narrated from his father that:The Prophet [SAW] said: "Do not combine dried dates with raisins, nor Az-Zahuw with ripe dates}}
\hadithdefcmd{nasai}{5552}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا عَلِيٌّ، - وَهُوَ ابْنُ الْمُبَارَكِ - عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْبِذُوا الزَّهْوَ وَالرُّطَبَ جَمِيعًا وَلاَ تَنْبِذُوا الزَّبِيبَ وَالرُّطَبَ جَمِيعًا ‏"‏‏.‏\hadithno{5552}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Qatadah that:The Messenger of Allah [SAW] said: "Do not soak Az-Zahuw and ripe dates together, and do not soak raisins and ripe dates together}}
\hadithdefcmd{nasai}{5553}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، - هُوَ ابْنُ طَهْمَانَ - عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ، عَنْ مَالِكِ بْنِ الْحَارِثِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُخْلَطَ التَّمْرُ وَالزَّبِيبُ وَأَنْ يُخْلَطَ الزَّهْوُ وَالتَّمْرُ وَالزَّهْوُ وَالْبُسْرُ‏.‏\hadithno{5553}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah [SAW] forbade mixing dried dates and raisins, and mixing Az-Zahuw and dried dates, and Az-Zahuw and Al-Busr}}
\hadithdefcmd{nasai}{5554}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ خَلِيطِ التَّمْرِ وَالزَّبِيبِ وَالْبُسْرِ وَالرُّطَبِ‏.‏\hadithno{5554}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ata' narrated from Jabir that:The Prophet [SAW] forbade mixing dried dates and raisins, and Al-Busr and ripe dates}}
\hadithdefcmd{nasai}{5555}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ أَبِي دَاوُدَ، قَالَ حَدَّثَنَا بِسْطَامٌ، قَالَ حَدَّثَنَا مَالِكُ بْنُ دِينَارٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَخْلِطُوا الزَّبِيبَ وَالتَّمْرَ وَلاَ الْبُسْرَ وَالتَّمْرَ ‏"‏‏.‏\hadithno{5555}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir, that :The Messenger of Allah [SAW] said: "Do not mix raisins and dried dates, nor Al-Busr and dried dates}}
\hadithdefcmd{nasai}{5556}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يُنْبَذَ الزَّبِيبُ وَالتَّمْرُ جَمِيعًا وَنَهَى أَنْ يُنْبَذَ الْبُسْرُ وَالتَّمْرُ جَمِيعًا‏.‏\hadithno{5556}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:The Messenger of Allah [SAW] forbade soaking raisins and dried dates together, and he forbade soaking Al-Busr and dried dates together}}
\hadithdefcmd{nasai}{5557}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، عَنِ ابْنِ فُضَيْلٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُزَفَّتِ وَالنَّقِيرِ وَعَنِ الْبُسْرِ وَالتَّمْرِ أَنْ يُخْلَطَا وَعَنِ الزَّبِيبِ وَالتَّمْرِ أَنْ يُخْلَطَا وَكَتَبَ إِلَى أَهْلِ هَجَرَ ‏ "‏ أَنْ لاَ تَخْلِطُوا الزَّبِيبَ وَالتَّمْرَ جَمِيعًا ‏"‏‏.‏\hadithno{5557}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah [SAW] forbade Ad-Dubba', Al-Hantam, Al-Muzaffat, and An-Naqir, and that Al-Busr be mixed with dried dates, and that raisins be mixed with dried dates, and he wrote to the people of Hajar saying: 'Do not mix raisins and dried dates together}}
\hadithdefcmd{nasai}{5558}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا حُمَيْدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ الْبُسْرُ وَحْدَهُ حَرَامٌ وَمَعَ التَّمْرِ حَرَامٌ‏.‏\hadithno{5558}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"Al-Busr on their own are unlawful and with dried dates they are unlawful}}
\hadithdefcmd{nasai}{5559}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، وَعَلِيُّ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحِيمِ، عَنْ حَبِيبِ بْنِ أَبِي عَمْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ خَلِيطِ التَّمْرِ وَالزَّبِيبِ وَعَنِ التَّمْرِ وَالْبُسْرِ‏.‏\hadithno{5559}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah [SAW] forbade mixing dried dates and raisins, and dried dates and Al-Busr}}
\hadithdefcmd{nasai}{5560}{أَخْبَرَنَا قُرَيْشُ بْنُ عَبْدِ الرَّحْمَنِ الْبَاوَرْدِيُّ، عَنْ عَلِيِّ بْنِ الْحَسَنِ، قَالَ أَنْبَأَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، قَالَ حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّمْرِ وَالزَّبِيبِ وَنَهَى عَنِ التَّمْرِ وَالْبُسْرِ أَنْ يُنْبَذَا جَمِيعًا‏.‏\hadithno{5560}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir bin 'Abdullah said:"The Messenger of Allah [SAW] forbade dried dates and raisins, and he forbade dried dates and Al-Busr, if they are soaked together}}
\hadithdefcmd{nasai}{5561}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هِشَامٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْبِذُوا الزَّهْوَ وَالرُّطَبَ وَلاَ تَنْبِذُوا الرُّطَبَ وَالزَّبِيبَ جَمِيعًا ‏"‏‏.‏\hadithno{5561}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah, from his father, that:The Prophet [SAW] said: "Do not soak Az-Zahuw and ripe dates, and do not soak ripe dates and raisins together}}
\hadithdefcmd{nasai}{5562}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يُنْبَذَ الزَّبِيبُ وَالْبُسْرُ جَمِيعًا وَنَهَى أَنْ يُنْبَذَ الْبُسْرُ وَالرُّطَبُ جَمِيعًا‏.‏\hadithno{5562}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that :The Messenger of Allah [SAW] forbade soaking raisins and Al-Busr together, and he forbade soaking Al-Busr and ripe dates together}}
\hadithdefcmd{nasai}{5563}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ وِقَاءِ بْنِ إِيَاسٍ، عَنِ الْمُخْتَارِ بْنِ فُلْفُلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَجْمَعَ شَيْئَيْنِ نَبِيذًا يَبْغِي أَحَدُهُمَا عَلَى صَاحِبِهِ ‏.‏ قَالَ وَسَأَلْتُهُ عَنِ الْفَضِيخِ فَنَهَانِي عَنْهُ قَالَ كَانَ يَكْرَهُ الْمُذَنَّبَ مِنَ الْبُسْرِ مَخَافَةَ أَنْ يَكُونَا شَيْئَيْنِ فَكُنَّا نَقْطَعُهُ ‏.‏\hadithno{5563}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah [SAW] forbade us to soak two things together when one is more potent than the other. I asked him about Fadikh (a drink made from fresh dates cut open) and he forbade it. He disliked the extra bit on Al-Busr, fearing that that might make it two things, so we used to cut it off}}
\hadithdefcmd{nasai}{5564}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ أَبِي إِدْرِيسَ، قَالَ شَهِدْتُ أَنَسَ بْنَ مَالِكٍ أُتِيَ بِبُسْرٍ مُذَنَّبٍ فَجَعَلَ يَقْطَعُهُ مِنْهُ ‏.‏\hadithno{5564}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Idris said:"I saw Anas bin Malik when some Busr which had extra bits were brought to him, and he started to cut them off}}
\hadithdefcmd{nasai}{5564p2}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، قَالَ قَتَادَةُ كَانَ أَنَسٌ يَأْمُرُ بِالتَّذْنُوبِ فَيُقْرَضُ ‏.‏\hadithno{5564.2}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Isnaad}\hadithtrans{Qatadah said:"Anas used to tell us to cut off the extra bits}}
\hadithdefcmd{nasai}{5565}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّهُ كَانَ لاَ يَدَعُ شَيْئًا قَدْ أَرْطَبَ إِلاَّ عَزَلَهُ عَنْ فَضِيخِهِ ‏.‏\hadithno{5565}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that :Anas would not leave any dates that had become ripe but he would remove them from his Fadikh}}
\hadithdefcmd{nasai}{5566}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْبِذُوا الزَّهْوَ وَالرُّطَبَ جَمِيعًا وَلاَ الْبُسْرَ وَالزَّبِيبَ جَمِيعًا وَانْبِذُوا كُلَّ وَاحِدٍ مِنْهُمَا عَلَى حِدَتِهِ ‏"‏ ‏.‏\hadithno{5566}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Qatadah that:The Messenger of Allah [SAW] said: "Do not soak Az-Zahuw and ripe dates together, nor Al-Busr and raisins together. Soak each one of them on its own}}
\hadithdefcmd{nasai}{5567}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى، أَنَّ عَبْدَ اللَّهِ بْنَ أَبِي قَتَادَةَ، حَدَّثَهُ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ خَلِيطِ الزَّهْوِ وَالتَّمْرِ وَخَلِيطِ الْبُسْرِ وَالتَّمْرِ وَقَالَ ‏ "‏ لِتَنْبِذُوا كُلَّ وَاحِدٍ مِنْهُمَا عَلَى حِدَةٍ فِي الأَسْقِيَةِ الَّتِي يُلاَثُ عَلَى أَفْوَاهِهَا ‏"‏ ‏.‏\hadithno{5567}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yahya narrated that 'Abdullah bin Abi Qatadah said to him from his father, that:The Prophet [SAW] forbade mixing Az-Zahuw and dried dates, and mixing Al-Busr and dried dates, and he said: "Soak each one of them on its own in vessels that are tied shut}}
\hadithdefcmd{nasai}{5568}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ الْعَبْدِيِّ، قَالَ حَدَّثَنَا أَبُو الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُخْلَطَ بُسْرٌ بِتَمْرٍ أَوْ زَبِيبٌ بِتَمْرٍ أَوْ زَبِيبٌ بِبُسْرٍ وَقَالَ ‏ "‏ مَنْ شَرِبَهُ مِنْكُمْ فَلْيَشْرَبْ كُلَّ وَاحِدٍ مِنْهُ فَرْدًا تَمْرًا فَرْدًا أَوْ بُسْرًا فَرْدًا أَوْ زَبِيبًا فَرْدًا ‏"‏ ‏.‏\hadithno{5568}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah [SAW] forbade mixing Al-Busr with dried dates, or raisins with dried dates, or raisins with Al-Busr, and he said: 'Whoever among you (wants to) drink them, let him drink each one of them on its own: dried dates on their own, or Al-Busr on their own, or raisins on their own}}
\hadithdefcmd{nasai}{5569}{أَخْبَرَنِي أَحْمَدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا أَبُو الْمُتَوَكِّلِ النَّاجِيُّ، قَالَ حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَخْلِطَ بُسْرًا بِتَمْرٍ أَوْ زَبِيبًا بِتَمْرٍ أَوْ زَبِيبًا بِبُسْرٍ وَقَالَ ‏ "‏ مَنْ شَرِبَ مِنْكُمْ فَلْيَشْرَبْ كُلَّ وَاحِدٍ مِنْهُ فَرْدًا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا أَبُو الْمُتَوَكِّلِ اسْمُهُ عَلِيُّ بْنُ دَاوُدَ ‏.‏\hadithno{5569}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:The Prophet [SAW] forbade mixing Al-Busr with dried dates, or raisins with dried dates, or raisins with Al-Busr, and he said: "Whoever among you (wants to) drink them, let him drink each one on its own}}
\hadithdefcmd{nasai}{5570}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، قَالَ حَدَّثَنَا أَبُو كَثِيرٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُخْلَطَ الْبُسْرُ وَالزَّبِيبُ وَالْبُسْرُ وَالتَّمْرُ وَقَالَ ‏ "‏ انْبِذُوا كُلَّ وَاحِدٍ مِنْهُمَا عَلَى حِدَةٍ ‏"‏ ‏.‏\hadithno{5570}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] forbade mixing Al-Busr and raisins, and Al-Busr and dried dates, and he said: 'Soak each one of them on its own}}
\hadithdefcmd{nasai}{5571}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ، قَالَ حَدَّثَنَا الْمُعَافَى، - يَعْنِي ابْنَ عِمْرَانَ - عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُنْبَذَ التَّمْرُ وَالزَّبِيبُ وَالتَّمْرُ وَالْبُسْرُ وَقَالَ ‏ "‏ انْتَبِذُوا الزَّبِيبَ فَرْدًا وَالتَّمْرَ فَرْدًا وَالْبُسْرَ فَرْدًا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو كَثِيرٍ اسْمُهُ يَزِيدُ بْنُ عَبْدِ الرَّحْمَنِ ‏.‏\hadithno{5571}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Prophet [SAW] forbade soaking dried dates and raisins, and dried dates and Al-Busr, and he said: "Soak raisins on their own, and dried dates on their own, and Al-Busr on their own}}
\hadithdefcmd{nasai}{5572}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي أَبُو كَثِيرٍ، ح وَأَنْبَأَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ بْنِ حَبِيبٍ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنَا أَبُو كَثِيرٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَمْرُ مِنْ هَاتَيْنِ ‏"‏ ‏.‏ وَقَالَ سُوَيْدٌ فِي هَاتَيْنِ الشَّجَرَتَيْنِ النَّخْلَةُ وَالْعِنَبَةُ ‏.‏\hadithno{5572}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Khamr comes from these two.'" Suwaid (one of the narrators) said: "From these two trees: The date palm and the grapevine}}
\hadithdefcmd{nasai}{5573}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا الْحَجَّاجُ الصَّوَّافُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو كَثِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَمْرُ مِنْ هَاتَيْنِ الشَّجَرَتَيْنِ النَّخْلَةُ وَالْعِنَبَةُ ‏"‏ ‏.‏\hadithno{5573}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Khamr comes from these two trees: The date palm and the grapevine}}
\hadithdefcmd{nasai}{5574}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ شَرِيكٍ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، وَالشَّعْبِيِّ، قَالاَ السَّكَرُ خَمْرٌ ‏.‏\hadithno{5574}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Mughirah that Ibrahim and Al-Sha'bi said:"Strong drink is Khamr}}
\hadithdefcmd{nasai}{5575}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي عَمْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ السَّكَرُ خَمْرٌ ‏.‏\hadithno{5575}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"Strong drink is Khamr}}
\hadithdefcmd{nasai}{5576}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ حَبِيبٍ، - وَهُوَ ابْنُ أَبِي عَمْرَةَ - عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ السَّكَرُ خَمْرٌ ‏.‏\hadithno{5576}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"Strong drink is Khamr}}
\hadithdefcmd{nasai}{5577}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ أَبِي حَصِينٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ السَّكَرُ حَرَامٌ وَالرِّزْقُ الْحَسَنُ حَلاَلٌ ‏.‏\hadithno{5577}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"Strong drink is unlawful, and a 'goodly provision' (is lawful)}}
\hadithdefcmd{nasai}{5578}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا أَبُو حَيَّانَ، قَالَ حَدَّثَنَا الشَّعْبِيُّ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ عُمَرَ، رضى الله عنه يَخْطُبُ عَلَى مِنْبَرِ الْمَدِينَةِ فَقَالَ أَيُّهَا النَّاسُ أَلاَ إِنَّهُ نَزَلَ تَحْرِيمُ الْخَمْرِ يَوْمَ نَزَلَ وَهِيَ مِنْ خَمْسَةٍ مِنَ الْعِنَبِ وَالتَّمْرِ وَالْعَسَلِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالْخَمْرُ مَا خَامَرَ الْعَقْلَ ‏.‏\hadithno{5578}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"I heard 'Umar, may Allah be pleased with him, delivering a Khutbah on the Minbar of Al-Madinah and he said: 'O people, on the day that the prohibition of Khamr was revealed, it was made from five things: From grapes, dates, honey, wheat and barley. Khamr is that which overcomes the mind}}
\hadithdefcmd{nasai}{5579}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَنْبَأَنَا ابْنُ إِدْرِيسَ، عَنْ زَكَرِيَّا، وَأَبِي، حَيَّانَ عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، رضى الله عنه عَلَى مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ أَمَّا بَعْدُ فَإِنَّ الْخَمْرَ نَزَلَ تَحْرِيمُهَا وَهِيَ مِنْ خَمْسَةٍ مِنَ الْعِنَبِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالتَّمْرِ وَالْعَسَلِ ‏.‏\hadithno{5579}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"I heard 'Umar bin Al-Khattab, may Allah be pleased with him, on the Minbar of the Messenger of Allah [SAW], say: 'The prohibition of Khamr was revealed when it was made from five things: From grapes, wheat, barley, dates and honey}}
\hadithdefcmd{nasai}{5580}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي حَصِينٍ، عَنْ عَامِرٍ، عَنِ ابْنِ عُمَرَ، قَالَ الْخَمْرُ مِنْ خَمْسَةٍ مِنَ التَّمْرِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالْعَسَلِ وَالْعِنَبِ ‏.‏\hadithno{5580}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"Khamr is made from five things: From dates, wheat, barley, honey and grapes}}
\hadithdefcmd{nasai}{5581}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ عَوْنٍ، عَنِ ابْنِ سِيرِينَ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ عُمَرَ فَقَالَ إِنَّ أَهْلَنَا يَنْبِذُونَ لَنَا شَرَابًا عَشِيًّا فَإِذَا أَصْبَحْنَا شَرِبْنَا ‏.‏ قَالَ أَنْهَاكَ عَنِ الْمُسْكِرِ قَلِيلِهِ وَكَثِيرِهِ وَأُشْهِدُ اللَّهَ عَلَيْكَ أَنْهَاكَ عَنِ الْمُسْكِرِ قَلِيلِهِ وَكَثِيرِهِ وَأُشْهِدُ اللَّهَ عَلَيْكَ إِنَّ أَهْلَ خَيْبَرَ يَنْتَبِذُونَ شَرَابًا مِنْ كَذَا وَكَذَا وَيُسَمُّونَهُ كَذَا وَكَذَا وَهِيَ الْخَمْرُ وَإِنَّ أَهْلَ فَدَكٍ يَنْتَبِذُونَ شَرَابًا مِنْ كَذَا وَكَذَا يُسَمُّونَهُ كَذَا وَكَذَا وَهِيَ الْخَمْرُ حَتَّى عَدَّ أَشْرِبَةً أَرْبَعَةً أَحَدُهَا الْعَسَلُ ‏.‏\hadithno{5581}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Sirin said:"A man came to Ibn 'Umar and said: 'Our families make drinks for us by soaking (fruits) at night, and in the morning we drink them.' He said: 'I forbid you to drink intoxicants whether in small amounts or large. May Allah bear witness that I forbid you to drink intoxicants whether in small amounts or large. May Allah bear witness that the people of Khaibar used to make drinks by soaking such and such, and they called it such and such but it was Khamr. The people of Fadak used to make drinks by soaking such and such, and they called it such and such but it was Khamr.' And he listed four things, one of which was honey}}
\hadithdefcmd{nasai}{5582}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ حَمَّادِ بْنِ زَيْدٍ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ وَكُلُّ مُسْكِرٍ خَمْرٌ ‏"‏ ‏.‏\hadithno{5582}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:The Prophet [SAW] said: "Every intoxicant is unlawful and every intoxicant is Khamr}}
\hadithdefcmd{nasai}{5583}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ وَكُلُّ مُسْكِرٍ خَمْرٌ ‏"‏ ‏.‏ قَالَ الْحُسَيْنُ قَالَ أَحْمَدُ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{5583}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Every intoxicant is unlawful and every intoxicant is Khamr}}
\hadithdefcmd{nasai}{5584}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ خَمْرٌ ‏"‏ ‏.‏\hadithno{5584}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Every intoxicant is Khamr}}
\hadithdefcmd{nasai}{5585}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي رَوَّادٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ خَمْرٌ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5585}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Every intoxicant is Khamr and every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5586}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ وَكُلُّ مُسْكِرٍ خَمْرٌ ‏"‏ ‏.‏\hadithno{5586}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:The Prophet [SAW] said: "Every intoxicant is unlawful and every intoxicant is Khamr}}
\hadithdefcmd{nasai}{5587}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5587}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Prophet [SAW] said: "Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5588}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5588}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5589}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُنْبَذَ فِي الدُّبَّاءِ وَالْمُزَفَّتِ وَالنَّقِيرِ وَالْحَنْتَمِ ‏ "‏ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5589}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah [SAW] forbade soaking (fruits) in Ad-Dubba', Al-Muzaffat, An-Naqir, Al-Hantam, and every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5590}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ زَبْرٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْبِذُوا فِي الدُّبَّاءِ وَلاَ الْمُزَفَّتِ وَلاَ النَّقِيرِ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5590}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:The Prophet [SAW] said: "Do not soak (fruits) in Ad-Dubba', An-Naqir, Al-Hantam, and every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5591}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَقُتَيْبَةُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ ‏"‏ ‏.‏ قَالَ قُتَيْبَةُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{5591}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] said: 'Every drink that intoxicates is unlawful.'" Qutaibah (one of the narrators) said: "From the Prophet [SAW]}}
\hadithdefcmd{nasai}{5592}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، ح وَأَنْبَأَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الْبِتْعِ فَقَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ حَرَامٌ ‏"‏ ‏.‏ اللَّفْظُ لِسُوَيْدٍ ‏.‏\hadithno{5592}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah, may Allah be pleased with her, that :The Messenger of Allah [SAW] was asked about mead and he said: "Every drink that intoxicates is unlawful." This is the wording of Suwaid}}
\hadithdefcmd{nasai}{5593}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رضى اللَّهُ عَنْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الْبِتْعِ فَقَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ وَالْبِتْعُ مِنَ الْعَسَلِ ‏"‏ ‏.‏\hadithno{5593}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah, may Allah be pleased with her, that :The Messenger of Allah [SAW] was asked about mead and he said: "Every drink that intoxicates is unlawful," and mead is made from honey}}
\hadithdefcmd{nasai}{5594}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الْبِتْعِ فَقَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ ‏"‏ ‏.‏ وَالْبِتْعُ هُوَ نَبِيذُ الْعَسَلِ ‏.‏\hadithno{5594}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that:The Prophet [SAW] was asked about mead and he said: "Every drink that intoxicates is unlawful." And mead is a drink made of honey}}
\hadithdefcmd{nasai}{5595}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ سُوَيْدِ بْنِ مَنْجُوفٍ، وَعَبْدُ اللَّهِ بْنُ الْهَيْثَمِ، عَنْ أَبِي دَاوُدَ، عَنْ شُعْبَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5595}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah [SAW] said: 'Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5596}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَا وَمُعَاذٌ إِلَى الْيَمَنِ فَقَالَ مُعَاذٌ إِنَّكَ تَبْعَثُنَا إِلَى أَرْضٍ كَثِيرٌ شَرَابُ أَهْلِهَا فَمَا أَشْرَبُ قَالَ ‏ "‏ اشْرَبْ وَلاَ تَشْرَبْ مُسْكِرًا ‏"‏ ‏.‏\hadithno{5596}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Burdah that his father said:"The Messenger of Allah [SAW] sent Mu'adh and me to Yemen. Mu'adh said: 'You are sending us to a land where the people have many kinds of drinks. What should I drink?' He said: 'Drink, but do not drink any intoxicant}}
\hadithdefcmd{nasai}{5597}{أَخْبَرَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا حَرِيشُ بْنُ سُلَيْمٍ، قَالَ حَدَّثَنَا طَلْحَةُ الأَيَامِيُّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5597}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah [SAW] said: 'Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5598}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، قَالَ أَنْبَأَنَا الأَسْوَدُ بْنُ شَيْبَانَ السَّدُوسِيُّ، قَالَ سَمِعْتُ عَطَاءً، سَأَلَهُ رَجُلٌ فَقَالَ إِنَّا نَرْكَبُ أَسْفَارًا فَتُبْرَزُ لَنَا الأَشْرِبَةُ فِي الأَسْوَاقِ لاَ نَدْرِي أَوْعِيَتَهَا ‏.‏ فَقَالَ كُلُّ مُسْكِرٍ حَرَامٌ ‏.‏ فَذَهَبَ يُعِيدُ فَقَالَ كُلُّ مُسْكِرٍ حَرَامٌ ‏.‏ فَذَهَبَ يُعِيدُ فَقَالَ هُوَ مَا أَقُولُ لَكَ ‏.‏\hadithno{5598}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Aswad bin Shaiban As-Sadusi said:"I heard 'Ata' being asked by a man: 'We travel and drinks are offered to us in the marketplaces, and we do not know what kind of vessels they were prepared in.' He said: 'Every intoxicant is unlawful.' He repeated the question and he said: 'Every intoxicant is unlawful.' He repeated the question and he said: 'It is as I have told you}}
\hadithdefcmd{nasai}{5599}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هَارُونَ بْنِ إِبْرَاهِيمَ، عَنِ ابْنِ سِيرِينَ، قَالَ كُلُّ مُسْكِرٍ حَرَامٌ ‏.‏\hadithno{5599}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Sirin said:"Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5600}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ بْنِ الطُّفَيْلِ الْجَزَرِيِّ، قَالَ كَتَبَ إِلَيْنَا عُمَرُ بْنُ عَبْدِ الْعَزِيزِ لاَ تَشْرَبُوا مِنَ الطِّلاَءِ حَتَّى يَذْهَبَ ثُلُثَاهُ وَيَبْقَى ثُلُثُهُ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏.‏\hadithno{5600}\hadithgrade{Abu Ghuddah: Daif Isnaad Maqtu; Al-Albani: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdul-Malik bin At-Tufail Al-Jazari said:"Umar bin 'Abdul-Aziz wrote to us, saying: 'Do not drink the thickened juice of grapes (obtained by boiling it down) until two-third of it has gone and one-third is left. And every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5601}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الصَّعْقِ بْنِ حَزْنٍ، قَالَ كَتَبَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ إِلَى عَدِيِّ بْنِ أَرْطَاةَ كُلُّ مُسْكِرٍ حَرَامٌ ‏.‏\hadithno{5601}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that As-Sa'q bin Hazn said:"Umar bin 'Abdul-'Aziz wrote to 'Adiy bin Artah (saying): 'Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5602}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا حَرِيشُ بْنُ سُلَيْمٍ، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ مُصَرِّفٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5602}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Musa Al-Ash'ari that:The Messenger of Allah [SAW] said: "Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5603}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الأَجْلَحِ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي مُوسَى، عَنْ أَبِيهِ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ بِهَا أَشْرِبَةً فَمَا أَشْرَبُ وَمَا أَدَعُ قَالَ ‏"‏ وَمَا هِيَ ‏"‏ ‏.‏ قُلْتُ الْبِتْعُ وَالْمِزْرُ ‏.‏ قَالَ ‏"‏ وَمَا الْبِتْعُ وَالْمِزْرُ ‏"‏ ‏.‏ قُلْتُ أَمَّا الْبِتْعُ فَنَبِيذُ الْعَسَلِ وَأَمَّا الْمِزْرُ فَنَبِيذُ الذُّرَةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَشْرَبْ مُسْكِرًا فَإِنِّي حَرَّمْتُ كُلَّ مُسْكِرٍ ‏"‏ ‏.‏\hadithno{5603}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Abu Bakr bin Abi Musa narrated that his father said:"The Messenger of Allah [SAW] sent me to Yemen and I said: 'O Messenger of Allah, there are (different kinds of) drinks there, what should I drink, and what should I refrain from?' He said: 'What are they?' I said: 'Al-Bit' (mead) and Al-Mizr (beer).' He said: 'What are mead and beer?' I said: 'Mead is a drink made from honey and beer is a drink made from grains.' The Messenger of Allah [SAW] said: 'Do not drink any intoxicant, for I have forbidden all intoxicants}}
\hadithdefcmd{nasai}{5604}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ، عَنِ ابْنِ فُضَيْلٍ، عَنِ الشَّيْبَانِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ بِهَا أَشْرِبَةً يُقَالُ لَهَا الْبِتْعُ وَالْمِزْرُ قَالَ ‏"‏ وَمَا الْبِتْعُ وَالْمِزْرُ ‏"‏ ‏.‏ قُلْتُ شَرَابٌ يَكُونُ مِنَ الْعَسَلِ وَالْمِزْرُ يَكُونُ مِنَ الشَّعِيرِ ‏.‏ قَالَ ‏"‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5604}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Burdah that his father said:"The Messenger of Allah [SAW] sent me to Yemen and I said: 'O Messenger of Allah, there are drinks there which they call Al-Bit' (mead) and Al-Mizr (beer).' He said: 'What is mead (and beer)?' I said: 'A drink made from honey, and beer is made from barley.' He said: 'Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5605}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ أَخْبَرَنِي أَبِي قَالَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ آيَةَ الْخَمْرِ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَرَأَيْتَ الْمِزْرَ قَالَ ‏"‏ وَمَا الْمِزْرُ ‏"‏ ‏.‏ قَالَ حَبَّةٌ تُصْنَعُ بِالْيَمَنِ ‏.‏ فَقَالَ ‏"‏ تُسْكِرُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5605}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] delivered a Khutbah and quoted the Verse about Khamr. A man said: 'O Messenger of Allah, what do you think about Al-Mizr (beer)?' He said: 'What is beer?' He said: 'A (drink) from grains that is made in Yemen.' He said: 'Does it intoxicate?' He said: 'Yes.' He said: 'Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5606}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي الْجُوَيْرِيَةِ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، وَسُئِلَ، فَقِيلَ لَهُ أَفْتِنَا فِي الْبَاذَقِ ‏.‏ فَقَالَ سَبَقَ مُحَمَّدٌ الْبَاذَقَ وَمَا أَسْكَرَ فَهُوَ حَرَامٌ ‏.‏\hadithno{5606}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Al-Juwairiyah said:"I heard Ibn 'Abbas when he was asked: 'Advise us about Badhiq (a drink made from the juice of grapes slightly boiled).' He said: 'Muhammad came before Badhiq (i.e., it was not known during his time), but everything that intoxicates is unlawful}}
\hadithdefcmd{nasai}{5607}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنَا عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَسْكَرَ كَثِيرُهُ فَقَلِيلُهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{5607}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, that:The Prophet [SAW] said: "What intoxicates in large amounts, a small amount of it is unlawful}}
\hadithdefcmd{nasai}{5608}{أَخْبَرَنَا حُمَيْدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ الْحَكَمِ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي الضَّحَّاكُ بْنُ عُثْمَانَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَنْهَاكُمْ عَنْ قَلِيلِ مَا أَسْكَرَ كَثِيرُهُ ‏"‏ ‏.‏\hadithno{5608}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amir bin Sa'd, from his father, that:The Prophet [SAW] said: "I forbid to you small amounts of whatever intoxicates in large amounts}}
\hadithdefcmd{nasai}{5609}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ كَثِيرٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ قَلِيلِ مَا أَسْكَرَ كَثِيرُهُ ‏.‏\hadithno{5609}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amir bin Sa'd, from his father, that:The Prophet [SAW] forbade a small amount of whatever intoxicates in large amounts}}
\hadithdefcmd{nasai}{5610}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، عَنْ زَيْدِ بْنِ وَاقِدٍ، أَخْبَرَنِي خَالِدُ بْنُ عَبْدِ اللَّهِ بْنِ حُسَيْنٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ فَتَحَيَّنْتُ فِطْرَهُ بِنَبِيذٍ صَنَعْتُهُ لَهُ فِي دُبَّاءٍ فَجِئْتُهُ بِهِ فَقَالَ ‏"‏ أَدْنِهِ ‏"‏ ‏.‏ فَأَدْنَيْتُهُ مِنْهُ فَإِذَا هُوَ يَنِشُّ فَقَالَ ‏"‏ اضْرِبْ بِهَذَا الْحَائِطَ فَإِنَّ هَذَا شَرَابُ مَنْ لاَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَفِي هَذَا دَلِيلٌ عَلَى تَحْرِيمِ السَّكَرِ قَلِيلِهِ وَكَثِيرِهِ وَلَيْسَ كَمَا يَقُولُ الْمُخَادِعُونَ لأَنْفُسِهِمْ بِتَحْرِيمِهِمْ آخِرِ الشَّرْبَةِ وَتَحْلِيلِهِمْ مَا تَقَدَّمَهَا الَّذِي يُشْرَبُ فِي الْفَرَقِ قَبْلَهَا وَلاَ خِلاَفَ بَيْنَ أَهْلِ الْعِلْمِ أَنَّ السُّكْرَ بِكُلِّيَّتِهِ لاَ يَحْدُثُ عَلَى الشَّرْبَةِ الآخِرَةِ دُونَ الأُولَى وَالثَّانِيَةِ بَعْدَهَا وَبِاللَّهِ التَّوْفِيقُ ‏.‏\hadithno{5610}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"I know that the Messenger of Allah [SAW] was fasting, so I prepared some Nabidh for him to break his fast that I had prepared for him in a gourd. I brought it to him and he said: 'Bring it here.' So I brought it closer and it was bubbling. He said: 'Throw it against the wall (throw it away), for this is the drink of one who does not believe in Allah or the Last Day}}
\hadithdefcmd{nasai}{5611}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ صَعْصَعَةَ بْنِ صُوحَانَ، عَنْ عَلِيٍّ، كَرَّمَ اللَّهُ وَجْهَهُ قَالَ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنْ حَلْقَةِ الذَّهَبِ وَالْقَسِّيِّ وَالْمِيثَرَةِ وَالْجِعَةِ ‏.‏\hadithno{5611}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ali - may Allah honor his face - said:"The Prophet [SAW] forbade to me to use gold rings, Al-Qassi, Al-Mitharah and Al-Ji'ah (a barley drink)}}
\hadithdefcmd{nasai}{5612}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنْ إِسْمَاعِيلَ، - وَهُوَ ابْنُ سُمَيْعٍ - قَالَ حَدَّثَنِي مَالِكُ بْنُ عُمَيْرٍ، قَالَ قَالَ صَعْصَعَةُ لِعَلِيِّ بْنِ أَبِي طَالِبٍ كَرَّمَ اللَّهُ وَجْهَهُ انْهَنَا يَا أَمِيرَ الْمُؤْمِنِينَ عَمَّا نَهَاكَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ ‏.‏\hadithno{5612}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Sa'sa'ah said to 'Ali bin Abi Talib - may Allah honor his face - :"Forbid to us, O Commander of the Believers! What the Messenger of Allah [SAW] forbade to you." He said: "The Messenger of Allah [SAW] forbade me from using Ad-Dubba' and Al-Hantam}}
\hadithdefcmd{nasai}{5613}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُنْبَذُ لَهُ فِي تَوْرٍ مِنْ حِجَارَةٍ ‏.‏ ذِكْرُ الأَوْعِيَةِ الَّتِي نُهِيَ عَنْ الاِنْتِبَاذِ فِيهَا دُونَ مَا سِوَاهَا مِمَّا لاَ تَشْتَدُّ أَشْرِبَتُهَا كَاشْتِدَادِهِ فِيهَا\hadithno{5613}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that :(fruits) would be soaked for the Prophet [SAW] in a small vessel made of stone}}
\hadithdefcmd{nasai}{5614}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ طَاوُسٍ، قَالَ قَالَ رَجُلٌ لاِبْنِ عُمَرَ أَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نَبِيذِ الْجَرِّ قَالَ نَعَمْ ‏.‏ قَالَ طَاوُسٌ وَاللَّهِ إِنِّي سَمِعْتُهُ مِنْهُ ‏.‏\hadithno{5614}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Tawus said:"A man said to Ibn 'Umar: 'Did the Messenger of Allah [SAW] forbid soaking (fruits) in earthenware jars?' He said: 'Yes.' Tawus said: 'By Allah, I heard that from him}}
\hadithdefcmd{nasai}{5615}{أَخْبَرَنَا هَارُونُ بْنُ زَيْدِ بْنِ يَزِيدَ بْنِ أَبِي الزَّرْقَاءِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، وَإِبْرَاهِيمَ بْنِ مَيْسَرَةَ، قَالاَ سَمِعْنَا طَاوُسًا، يَقُولُ جَاءَ رَجُلٌ إِلَى ابْنِ عُمَرَ قَالَ أَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نَبِيذِ الْجَرِّ قَالَ نَعَمْ ‏.‏ زَادَ إِبْرَاهِيمُ فِي حَدِيثِهِ وَالدُّبَّاءِ ‏.‏\hadithno{5615}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sulaiman At-Taimi and Ibrahim bin Maisarah said:"We heard Tawus say: 'A man came to Ibn 'Umar and said: Did the Messenger of Allah [SAW] forbid soaking (fruits) in earthenware jars? He said: 'Yes.' Ibrahim added in his Hadith: "And Ad-Dubba' (gourds)}}
\hadithdefcmd{nasai}{5616}{أَخْبَرَنَا سُوَيْدٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، قَالَ قَالَ ابْنُ عَبَّاسٍ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نَبِيذِ الْجَرِّ ‏.‏\hadithno{5616}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Abbas said:"The Messenger of Allah [SAW] forbade soaking (fruits) in earthenware jars}}
\hadithdefcmd{nasai}{5617}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ، قَالَ حَدَّثَنَا أُمَيَّةُ، عَنْ شُعْبَةَ، عَنْ جَبَلَةَ بْنِ سُحَيْمٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحَنْتَمِ قُلْتُ مَا الْحَنْتَمُ قَالَ الْجَرُّ ‏.‏\hadithno{5617}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] forbade Al-Hantam. I (the narrator) said: "What is Al-Hantam?" He said: "The earthenware jar}}
\hadithdefcmd{nasai}{5618}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي مَسْلَمَةَ، قَالَ سَمِعْتُ عَبْدَ الْعَزِيزِ، - يَعْنِي ابْنَ أَسِيدٍ الطَّاحِيَّ بَصْرِيٌّ - يَقُولُ سُئِلَ ابْنُ الزُّبَيْرِ عَنْ نَبِيذِ الْجَرِّ، قَالَ نَهَانَا عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5618}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Maslamah said:"I heard 'Abdul-'Aziz - that is, bin Asid At-Tahi from Al-Basrah - say: 'Ibn Az-Zubair was asked about soaking (fruits) in earthenware jars and he said: "The Messenger of Allah [SAW] forbade us from that}}
\hadithdefcmd{nasai}{5619}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ عَلِيِّ بْنِ سُوَيْدِ بْنِ مَنْجُوفٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ هِشَامِ بْنِ أَبِي عَبْدِ اللَّهِ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سَأَلْنَا ابْنَ عُمَرَ عَنْ نَبِيذِ الْجَرِّ، فَقَالَ حَرَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَتَيْتُ ابْنَ عَبَّاسٍ فَقُلْتُ سَمِعْتُ الْيَوْمَ شَيْئًا عَجِبْتُ مِنْهُ ‏.‏ قَالَ مَا هُوَ قُلْتُ سَأَلْتُ ابْنَ عُمَرَ عَنْ نَبِيذِ الْجَرِّ فَقَالَ حَرَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ صَدَقَ ابْنُ عُمَرَ ‏.‏ قُلْتُ مَا الْجَرُّ قَالَ كُلُّ شَىْءٍ مِنْ مَدَرٍ ‏.‏\hadithno{5619}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"We asked Ibn 'Umar about Nabidh made in an earthenware jar and he said: 'The Messenger of Allah [SAW] forbade that.' So I went to Ibn 'Abbas and said to him: 'Today I heard something that surprised me.' He said: 'What was it?' I said: 'I asked Ibn 'Umar about Nabidh made in an earthenware jar and he said: The Messenger of Allah [SAW] forbade it.' He said: 'Ibn 'Umar spoke the truth.' I said: 'What is an earthenware jar?' He said: 'Anything that is made of clay}}
\hadithdefcmd{nasai}{5620}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ رَجُلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ كُنْتُ عِنْدَ ابْنِ عُمَرَ فَسُئِلَ عَنْ نَبِيذِ الْجَرِّ، فَقَالَ حَرَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَشَقَّ عَلَىَّ لَمَّا سَمِعْتُهُ فَأَتَيْتُ ابْنَ عَبَّاسٍ فَقُلْتُ إِنَّ ابْنَ عُمَرَ سُئِلَ عَنْ شَىْءٍ فَجَعَلْتُ أُعَظِّمُهُ ‏.‏ قَالَ مَا هُوَ قُلْتُ سُئِلَ عَنْ نَبِيذِ الْجَرِّ ‏.‏ فَقَالَ صَدَقَ حَرَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قُلْتُ وَمَا الْجَرُّ قَالَ كُلُّ شَىْءٍ صُنِعَ مِنْ مَدَرٍ ‏.‏\hadithno{5620}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"I was with Ibn 'Umar when he was asked about Nabidh made in an earthenware jar. He said: 'The Messenger of Allah [SAW] forbade it.' I got upset when I heard that, so I went to Ibn 'Abbas and said: 'Ibn 'Umar was asked about something, and I found it difficult.' He said: 'What was it?' I said: 'He was asked about Nabidh made in an earthenware jar.' He said: 'He spoke the truth; the Messenger of Allah [SAW] forbade it.' I said: 'What is an earthenware jar?' He said: 'Anything that is made of clay}}
\hadithdefcmd{nasai}{5621}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الشَّيْبَانِيِّ، قَالَ سَمِعْتُ ابْنَ أَبِي أَوْفَى، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نَبِيذِ الْجَرِّ الأَخْضَرِ ‏.‏ قُلْتُ فَالأَبْيَضُ قَالَ لاَ أَدْرِي ‏.‏\hadithno{5621}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ash-Shaibani said:"I heard Ibn Abi Awfa say: 'The Messenger of Allah [SAW] forbade Nabidh made in green earthenware jars.' I said: 'And white ones?' He said: 'I do not know}}
\hadithdefcmd{nasai}{5622}{أَخْبَرَنَا أَبُو عَبْدِ الرَّحْمَنِ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، قَالَ سَمِعْتُ ابْنَ أَبِي أَوْفَى، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نَبِيذِ الْجَرِّ الأَخْضَرِ وَالأَبْيَضِ ‏.‏\hadithno{5622}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Ishaq Ash-Shaibani said:"I heard Ibn Abi Awfa say: 'The Messenger of Allah [SAW] forbade Nabidh made in green and white earthenware jars}}
\hadithdefcmd{nasai}{5623}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي رَجَاءٍ، قَالَ سَأَلْتُ الْحَسَنَ عَنْ نَبِيذِ الْجَرِّ، أَحَرَامٌ هُوَ قَالَ حَرَامٌ قَدْ حَدَّثَنَا مَنْ لَمْ يَكْذِبْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ نَبِيذِ الْحَنْتَمِ وَالدُّبَّاءِ وَالْمُزَفَّتِ وَالنَّقِيرِ ‏.‏\hadithno{5623}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Raja' said:"I asked Al-Hasan about Nabidh made in earthenware jars - is it unlawful? He said: '(It is) unlawful. One who would not lie narrated to us that the Messenger of Allah [SAW] forbade Nabidh made in Al-Hantam, Ad-Dubba' (gourds), Al-Muzaffat and An-Naqir}}
\hadithdefcmd{nasai}{5624}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ ‏.‏\hadithno{5624}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] forbade Ad-Dubba' (gourds)}}
\hadithdefcmd{nasai}{5625}{أَخْبَرَنَا جَعْفَرُ بْنُ مُسَافِرٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ ‏.‏\hadithno{5625}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] forbade Ad-Dubba' (gourds)}}
\hadithdefcmd{nasai}{5626}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَحَمَّادٍ، وَسُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْمُزَفَّتِ ‏.‏\hadithno{5626}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah [SAW] forbade Ad-Dubba' (gourds) and Al-Muzaffat}}
\hadithdefcmd{nasai}{5627}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَلِيٍّ، كَرَّمَ اللَّهُ وَجْهَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ الدُّبَّاءِ وَالْمُزَفَّتِ ‏.‏\hadithno{5627}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Ali - may Allah honor his face - that:The Prophet [SAW] forbade Ad-Dubba' (gourds) and Al-Muzaffat}}
\hadithdefcmd{nasai}{5628}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَبَانَ، قَالَ حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ بُكَيْرِ بْنِ عَطَاءٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَعْمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ، وَالْمُزَفَّتِ، ‏.‏\hadithno{5628}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin Ya'mar that:The Prophet [SAW] forbade Ad-Dubba' and Al-Muzaffat}}
\hadithdefcmd{nasai}{5629}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ وَالْمُزَفَّتِ أَنْ يُنْبَذَ فِيهِمَا ‏.‏\hadithno{5629}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas bin Malik that:The Messenger of Allah [SAW] forbade soaking (fruits) in Ad-Dubba' (gourds) and Al-Muzaffat}}
\hadithdefcmd{nasai}{5630}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْمُزَفَّتِ أَنْ يُنْبَذَ فِيهِمَا ‏.‏\hadithno{5630}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] forbade soaking (fruits) in Ad-Dubba' (gourds) and Al-Muzaffat}}
\hadithdefcmd{nasai}{5631}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَفَّتِ وَالْقَرْعِ ‏.‏\hadithno{5631}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that :The Messenger of Allah [SAW] forbade Al-Muzaffat and squashes}}
\hadithdefcmd{nasai}{5632}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ بْنِ فَرْوَةَ، - يُقَالُ لَهُ ابْنُ كُرْدِيٍّ بَصْرِيٌّ - قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْخَالِقِ الشَّيْبَانِيِّ، قَالَ سَمِعْتُ سَعِيدًا، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالنَّقِيرِ ‏.‏\hadithno{5632}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that :The Messenger of Allah [SAW] forbade Ad-Dubba' (gourds), Al-Hantam and An-Naqir}}
\hadithdefcmd{nasai}{5633}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الشُّرْبِ فِي الْحَنْتَمِ وَالدُّبَّاءِ وَالنَّقِيرِ ‏.‏\hadithno{5633}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:The Messenger of Allah [SAW] forbade drinking from green pitchers, gourds and vessels carved from wood}}
\hadithdefcmd{nasai}{5634}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنْ مُحَارِبٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُزَفَّتِ ‏.‏\hadithno{5634}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Umar said:"The Messenger of Allah [SAW] forbade Ad-Dubba' (gourds), Al-Hantam and Al-Muzaffat}}
\hadithdefcmd{nasai}{5635}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي يَحْيَى، حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْجِرَارِ وَالدُّبَّاءِ وَالظُّرُوفِ الْمُزَفَّتَةِ ‏.‏\hadithno{5635}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] forbade earthenware jars, Ad-Dubba' (gourds), Al-Muzaffat containers}}
\hadithdefcmd{nasai}{5636}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَوْنِ بْنِ صَالِحٍ الْبَارِقِيِّ، عَنْ زَيْنَبَ بِنْتِ نَصْرٍ، وَجُمَيْلَةَ بِنْتِ عَبَّادٍ، أَنَّهُمَا سَمِعَتَا عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ شَرَابٍ صُنِعَ فِي دُبُّاءٍ أَوْ حَنْتَمٍ أَوْ مُزَفَّتٍ لاَ يَكُونُ زَيْتًا أَوْ خَلاًّ ‏.‏\hadithno{5636}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:"I heard the Messenger of Allah [SAW] forbidding drinks made in Dubba' (gourds), Hantam or Muzaffat, that were not oil or vinegar}}
\hadithdefcmd{nasai}{5637}{أَخْبَرَنَا قُرَيْشُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ أَنْبَأَنَا عَلِيُّ بْنُ الْحَسَنِ، قَالَ أَنْبَأَنَا الْحُسَيْنُ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالنَّقِيرِ وَالْمُزَفَّتِ ‏.‏\hadithno{5637}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah [SAW] forbade Ad-Dubba' (gourds), Al-Hantam, An-Naqir, and Al-Muzaffat}}
\hadithdefcmd{nasai}{5638}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الْقَاسِمِ بْنِ الْفَضْلِ، قَالَ حَدَّثَنَا ثُمَامَةُ بْنُ حَزْنٍ الْقُشَيْرِيُّ، قَالَ لَقِيتُ عَائِشَةَ فَسَأَلْتُهَا عَنِ النَّبِيذِ، فَقَالَتْ قَدِمَ وَفْدُ عَبْدِ الْقَيْسِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلُوهُ فِيمَا يَنْبِذُونَ فَنَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَنْبِذُوا فِي الدُّبَّاءِ وَالنَّقِيرِ وَالْمُقَيَّرِ وَالْحَنْتَمِ ‏.‏\hadithno{5638}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Thumamah bin Hazn Al-Qushairi said:"I met 'Aishah and asked her about Nabidh. She said: 'The delegation of 'Abdul-Qais came to the Messenger of Allah [SAW] and asked him in which vessels they should soak (fruits - to make Nabidh). The Prophet [SAW] forbade them to soak (fruits) in Ad-Dubba' (gourds), An-Naqir, Al-Muqayyar, and Al-Hantam}}
\hadithdefcmd{nasai}{5639}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ سُوَيْدٍ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ نَهَى عَنِ الدُّبَّاءِ، بِذَاتِهِ ‏.‏\hadithno{5639}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah, may Allah be pleased with her, said:"He forbade Ad-Dubba' (gourds) specifically}}
\hadithdefcmd{nasai}{5640}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ إِسْحَاقَ، - وَهُوَ ابْنُ سُوَيْدٍ - يَقُولُ حَدَّثَتْنِي مُعَاذَةُ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ نَبِيذِ النَّقِيرِ وَالْمُقَيَّرِ وَالدُّبَّاءِ وَالْحَنْتَمِ ‏.‏ فِي حَدِيثِ ابْنِ عُلَيَّةَ قَالَ إِسْحَاقُ وَذَكَرَتْ هُنَيْدَةُ عَنْ عَائِشَةَ مِثْلَ حَدِيثِ مُعَاذَةَ وَسَمَّتِ الْجِرَارَ ‏.‏ قُلْتُ لِهُنَيْدَةَ أَنْتِ سَمِعْتِيهَا سَمَّتِ الْجِرَارَ قَالَتْ نَعَمْ ‏.‏\hadithno{5640}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ishaq - he is Ibn Suwaid - that he said:"Mu'adhah narrated to me from 'Aishah, that the Messenger of Allah [SAW] forbade Nabidh made in An-Naqir, Al-Muqayyar, Ad-Dubba', and Al-Hantam." And in the narration of Ibn 'Ulayyah, Ishaq said: "And Hunaidah mentioned from 'Aishah similar to the narration of Mu'adhah, and she named earthenware containers. I said to Hunaidah: 'Did you hear her say earthenware containers?' She said: 'Yes}}
\hadithdefcmd{nasai}{5641}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ طَوْدِ بْنِ عَبْدِ الْمَلِكِ الْقَيْسِيِّ، - بَصْرِيٌّ - قَالَ حَدَّثَنِي أَبِي، عَنْ هُنَيْدَةَ بِنْتِ شَرِيكِ بْنِ زَبَّانَ، قَالَتْ لَقِيتُ عَائِشَةَ رَضِيَ اللَّهُ عَنْهَا بِالْخُرَيْبَةِ فَسَأَلْتُهَا عَنِ الْعَكَرِ فَنَهَتْنِي عَنْهُ وَقَالَتِ انْبِذِي عَشِيَّةً وَاشْرَبِيهِ غُدْوَةً وَأَوْكِي عَلَيْهِ ‏.‏ وَنَهَتْنِي عَنِ الدُّبَّاءِ وَالنَّقِيرِ وَالْمُزَفَّتِ وَالْحَنْتَمِ ‏.‏\hadithno{5641}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Hunaidah bint Sharik bin Aban said:"I met 'Aishah, may Allah be pleased with her, in Al-Khuraibah, and I asked her about the dregs and she forbade them to me and she said: 'Soak (the fruit) at night and drink it in the morning, and tie the vessel closed.' And she forbade me from using Ad-Dubba' (gourds), An-Naqir, Al-Muzaffat, and Al-Hantam}}
\hadithdefcmd{nasai}{5642}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ الْمُخْتَارَ بْنَ فُلْفُلٍ، عَنْ أَنَسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الظُّرُوفِ الْمُزَفَّتَةِ ‏.‏\hadithno{5642}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah [SAW] forbade Al-Muzaffat}}
\hadithdefcmd{nasai}{5643}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا مَنْصُورُ بْنُ حَيَّانَ، سَمِعَ سَعِيدَ بْنَ جُبَيْرٍ، يُحَدِّثُ أَنَّهُ سَمِعَ ابْنَ عُمَرَ، وَابْنَ، عَبَّاسٍ أَنَّهُمَا شَهِدَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُزَفَّتِ وَالنَّقِيرِ ثُمَّ تَلاَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَذِهِ الآيَةَ ‏\{‏ وَمَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ وَمَا نَهَاكُمْ عَنْهُ فَانْتَهُوا ‏\}‏ ‏.‏\hadithno{5643}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sa'eed bin Jubair narrated that:He heard Ibn 'Umar and Ibn 'Abbas testify that the Messenger of Allah [SAW] forbade Ad-Dubba' (gourds), Al-Hantam, Al-Muzaffat, and An-Naqir. Then the Messenger of Allah [SAW] recited this Verse: "And whatsoever the Messenger (Muhammad) gives you, take it; and whatsoever he forbids you, abstain (from it)}}
\hadithdefcmd{nasai}{5644}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، عَنِ ابْنِ عَمٍّ، لَهَا يُقَالُ لَهُ أَنَسٌ قَالَ قَالَ ابْنُ عَبَّاسٍ أَلَمْ يَقُلِ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ مَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ وَمَا نَهَاكُمْ عَنْهُ فَانْتَهُوا ‏\}‏ قُلْتُ بَلَى ‏.‏ قَالَ أَلَمْ يَقُلِ اللَّهُ ‏\{‏ وَمَا كَانَ لِمُؤْمِنٍ وَلاَ مُؤْمِنَةٍ إِذَا قَضَى اللَّهُ وَرَسُولُهُ أَمْرًا أَنْ يَكُونَ لَهُمُ الْخِيَرَةُ مِنْ أَمْرِهِمْ ‏\}‏ قُلْتُ بَلَى ‏.‏ قَالَ فَإِنِّي أَشْهَدُ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ النَّقِيرِ وَالْمُقَيَّرِ وَالدُّبَّاءِ وَالْحَنْتَمِ ‏.‏\hadithno{5644}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Asma' bint Yazid that:A paternal uncle of hers whose name was Anas said: "Ibn 'Abbas said: Does not Allah say: "And whatsoever the Messenger (Muhammad) gives you, take it; and whatsoever he forbids you, abstain (from it).'? He said: 'Yes.' He said: 'Does not Allah say: 'It is not for a believer, man or woman, when Allah and His Messenger have decreed a matter that they should have any option in their decision?' I said: 'Yes.' He said: 'I bear witness that the Prophet of Allah [SAW] forbade An-Naqir, Al-Muqayyar, Ad-Dubba', and Al-Hantam}}
\hadithdefcmd{nasai}{5645}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ مُرَّةَ، قَالَ سَمِعْتُ زَاذَانَ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ قُلْتُ حَدِّثْنِي بِشَىْءٍ، سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الأَوْعِيَةِ وَفَسِّرْهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحَنْتَمِ وَهُوَ الَّذِي تُسَمُّونَهُ أَنْتُمُ الْجَرَّةَ وَنَهَى عَنِ الدُّبَّاءِ وَهُوَ الَّذِي تُسَمُّونَهُ أَنْتُمُ الْقَرْعَ وَنَهَى عَنِ النَّقِيرِ وَهِيَ النَّخْلَةُ يَنْقُرُونَهَا وَنَهَى عَنِ الْمُزَفَّتِ وَهُوَ الْمُقَيَّرُ ‏.‏\hadithno{5645}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zadan said:"I asked 'Abdullah bin 'Umar: 'Tell me of something that you heard from the Messenger of Allah [SAW] concerning vessels and explain it.' He said: 'The Messenger of Allah [SAW] forbade Al-Hantam, which are what you call earthenware jars. And he forbade Ad-Dubba' which are what you call squash. And he forbade An-Naqir, which are hollowed-out date palm wood. And he forbade Al-Muzaffat which are (Al-Muqayyar) vessels daubed with tar}}
\hadithdefcmd{nasai}{5646}{أَخْبَرَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ بْنِ سَوَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم وَفْدَ عَبْدِ الْقَيْسِ حِينَ قَدِمُوا عَلَيْهِ عَنِ الدُّبَّاءِ وَعَنِ النَّقِيرِ وَعَنِ الْمُزَفَّتِ وَالْمَزَادَةِ الْمَجْبُوبَةِ وَقَالَ ‏"‏ انْتَبِذْ فِي سِقَائِكَ وَأَوْكِهِ وَاشْرَبْهُ حُلْوًا ‏"‏ ‏.‏ قَالَ بَعْضُهُمُ ائْذَنْ لِي يَا رَسُولَ اللَّهِ فِي مِثْلِ هَذَا ‏.‏ قَالَ ‏"‏ إِذًا تَجْعَلَهَا مِثْلَ هَذِهِ ‏"‏ ‏.‏ وَأَشَارَ بِيَدِهِ يَصِفُ ذَلِكَ ‏.‏\hadithno{5646}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] forbade the delegation of 'Abdul-Qais, when they came to him, Ad-Dubba', An-Naqir, Al-Muzaffat, and large water-skins that are cut from the top and can no longer be closed. He said: 'Make Nabidh in your water-skins, and close them and drink it sweet.' One of them said: 'O Messenger of Allah, give me permission concerning something like this. He said: 'If you make it like this,' and he gestured with his hand, showing him how}}
\hadithdefcmd{nasai}{5647}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ جُرَيْجٍ، قِرَاءَةً قَالَ وَقَالَ أَبُو الزُّبَيْرِ سَمِعْتُ جَابِرًا، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْجَرِّ الْمُزَفَّتِ وَالدُّبَّاءِ وَالنَّقِيرِ وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا لَمْ يَجِدْ سِقَاءً يُنْبَذْ لَهُ فِيهِ نُبِذَ لَهُ فِي تَوْرٍ مِنْ حِجَارَةٍ ‏.‏\hadithno{5647}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir said:"The Messenger of Allah [SAW] forbade Al-Muzaffat jars, Ad-Dubba' (gourds), An-Naqir, and if the Prophet [SAW] could not find a water-skin in which to make Nabidh, it would be made for him in a small vessel of stone}}
\hadithdefcmd{nasai}{5648}{أَخْبَرَنِي أَحْمَدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا إِسْحَاقُ، - يَعْنِي الأَزْرَقَ - قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنْبَذُ لَهُ فِي سِقَاءٍ فَإِذَا لَمْ يَكُنْ لَهُ سِقَاءٌ نَنْبِذُ لَهُ فِي تَوْرِ بِرَامٍ ‏.‏ قَالَ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالنَّقِيرِ وَالْمُزَفَّتِ ‏.‏\hadithno{5648}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"(Fruit) would be soaked for the Messenger of Allah [SAW] in a water skin, and if he did not have a water skin, it would be made for him in a small vessel of stone. And the Messenger of Allah [SAW] forbade Ad-Dubba' (gourds), An-Naqir, and Al-Muzaffat}}
\hadithdefcmd{nasai}{5649}{أَخْبَرَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ بْنِ سَوَّارٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ وَالنَّقِيرِ وَالْجَرِّ وَالْمُزَفَّتِ ‏.‏\hadithno{5649}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:The Messenger of Allah [SAW] forbade Ad-Dubba' (gourds), An-Naqir, earthenware jars, and Al-Muzaffat}}
\hadithdefcmd{nasai}{5650}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا سُلَيْمَانُ الأَحْوَلُ، عَنْ مُجَاهِدٍ، عَنْ أَبِي عِيَاضٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ فِي الْجَرِّ غَيْرَ مُزَفَّتٍ ‏.‏\hadithno{5650}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah that:The Prophet [SAW] granted a concession allowing earthenware jars that are not coated with pitch}}
\hadithdefcmd{nasai}{5651}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، عَنِ الأَحْوَصِ بْنِ جَوَّابٍ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، أَنَّهُ حَدَّثَهُمْ عَنْ أَبِي إِسْحَاقَ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي فَتَزَوَّدُوا وَادَّخِرُوا وَمَنْ أَرَادَ زِيَارَةَ الْقُبُورِ فَإِنَّهَا تُذَكِّرُ الآخِرَةَ وَاشْرَبُوا وَاتَّقُوا كُلَّ مُسْكِرٍ ‏"‏ ‏.‏\hadithno{5651}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Buraidah that his father said:"The Messenger of Allah [SAW] said: 'I used to forbid you (to store) the sacrificial meat, but now eat it and store it; and whosoever wants to visit graves (may do so), for they are a reminder of the Hereafter; and drink but avoid all intoxicants}}
\hadithdefcmd{nasai}{5652}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ، عَنِ ابْنِ فُضَيْلٍ، عَنْ أَبِي سِنَانٍ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا وَنَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي فَوْقَ ثَلاَثَةِ أَيَّامٍ فَأَمْسِكُوا مَا بَدَا لَكُمْ وَنَهَيْتُكُمْ عَنِ النَّبِيذِ إِلاَّ فِي سِقَاءٍ فَاشْرَبُوا فِي الأَسْقِيَةِ كُلِّهَا وَلاَ تَشْرَبُوا مُسْكِرًا ‏"‏ ‏.‏\hadithno{5652}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that his father said:"The Messenger of Allah [SAW] said: 'I used to forbid you to visit graves, but (now) visit them. And I forbade you (to keep) the sacrificial meat for three days, but now keep whatever you wish. And I forbade Nabidh to you, unless it was (made) in a water skin, but now drink from all kinds of vessels but do not drink any intoxicant}}
\hadithdefcmd{nasai}{5653}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْدَانَ بْنِ عِيسَى بْنِ مَعْدَانَ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا زُبَيْدٌ، عَنْ مُحَارِبٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنْ ثَلاَثٍ زِيَارَةِ الْقُبُورِ فَزُورُوهَا وَلْتَزِدْكُمْ زِيَارَتُهَا خَيْرًا وَنَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي بَعْدَ ثَلاَثٍ فَكُلُوا مِنْهَا مَا شِئْتُمْ وَنَهَيْتُكُمْ عَنِ الأَشْرِبَةِ فِي الأَوْعِيَةِ فَاشْرَبُوا فِي أَىِّ وِعَاءٍ شِئْتُمْ وَلاَ تَشْرَبُوا مُسْكِرًا ‏"‏ ‏.‏\hadithno{5653}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Buraidah that his father said:"The Messenger of Allah [SAW] said: 'I used to forbid three things to you: Visiting graves, but now visit them, and may visiting them increase you in goodness; and I forbade you (to store) the sacrificial meat for more than three days, but now eat whatever you wish of it. And I forbade to you drinks in (certain kinds of ) vessels, but now drink from whatever vessel you wish, but do not drink any intoxicant}}
\hadithdefcmd{nasai}{5654}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَجَّاجِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حَمَّادِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُنْتُ نَهَيْتُكُمْ عَنِ الأَوْعِيَةِ فَانْتَبِذُوا فِيمَا بَدَا لَكُمْ وَإِيَّاكُمْ وَكُلَّ مُسْكِرٍ ‏"‏ ‏.‏\hadithno{5654}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that his father said:"The Messenger of Allah [SAW] said: 'I used to forbid certain kinds of vessels to you. Now soak (fruits) in whatever you wish, but beware of any intoxicant}}
\hadithdefcmd{nasai}{5655}{أَخْبَرَنَا أَبُو عَلِيٍّ، مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ - مَرْوَزِيٌّ - قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا عِيسَى بْنُ عُبَيْدٍ الْكِنْدِيُّ، - خُرَاسَانِيٌّ - قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَا هُوَ يَسِيرُ إِذْ حَلَّ بِقَوْمٍ فَسَمِعَ لَهُمْ لَغَطًا فَقَالَ ‏"‏ مَا هَذَا الصَّوْتُ ‏"‏ ‏.‏ قَالُوا يَا نَبِيَّ اللَّهِ لَهُمْ شَرَابٌ يَشْرَبُونَهُ ‏.‏ فَبَعَثَ إِلَى الْقَوْمِ فَدَعَاهُمْ فَقَالَ ‏"‏ فِي أَىِّ شَىْءٍ تَنْتَبِذُونَ ‏"‏ ‏.‏ قَالُوا نَنْتَبِذُ فِي النَّقِيرِ وَالدُّبَّاءِ وَلَيْسَ لَنَا ظُرُوفٌ ‏.‏ فَقَالَ ‏"‏ لاَ تَشْرَبُوا إِلاَّ فِيمَا أَوْكَيْتُمْ عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَلَبِثَ بِذَلِكَ مَا شَاءَ اللَّهُ أَنْ يَلْبَثَ ثُمَّ رَجَعَ عَلَيْهِمْ فَإِذَا هُمْ قَدْ أَصَابَهُمْ وَبَاءٌ وَاصْفَرُّوا ‏.‏ قَالَ ‏"‏ مَا لِي أَرَاكُمْ قَدْ هَلَكْتُمْ ‏"‏ ‏.‏ قَالُوا يَا نَبِيَّ اللَّهِ أَرْضُنَا وَبِيئَةٌ وَحَرَّمْتَ عَلَيْنَا إِلاَّ مَا أَوْكَيْنَا عَلَيْهِ ‏.‏ قَالَ ‏"‏ اشْرَبُوا وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5655}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Buraidah (narrated) from his father that:While the Messenger of Allah [SAW] was walking, he approached some people and heard a confused noise coming from them. He said: "What is this noise?" They said: "O Messenger of Allah, they have a drink that they drink." He sent for those people and said: "In what do you soak (fruit - to make that drink)?" They said: "We soak (fruits) in vessels carved from wood and gourds, and we have no water skins (that can be closed)." He said: "Do not drink except from a vessel that can be tied closed." Then as much time as Allah willed passed, then he went back to them and they had fallen sick and become pallid. He said: "Why do you look so ill?" They said: "O Messenger of Allah, our land is unhealthy and you forbade to us everything except that which was in a vessel that could be tied closed." He said: "Drink, but every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5656}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، وَأَبُو أَحْمَدَ الزُّبَيْرِيُّ عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا نَهَى عَنِ الظُّرُوفِ شَكَتِ الأَنْصَارُ فَقَالَتْ يَا رَسُولَ اللَّهِ لَيْسَ لَنَا وِعَاءٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{5656}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir that :When the Messenger of Allah [SAW] forbade large water skins that are cut from the top and can no longer be closed, Ansar complained and said: "O Messenger of Allah, we do not have any vessels." The Prophet [SAW] said: "Then there is no harm}}
\hadithdefcmd{nasai}{5657}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ بِقَدَحَيْنِ مِنْ خَمْرٍ وَلَبَنٍ فَنَظَرَ إِلَيْهِمَا فَأَخَذَ اللَّبَنَ فَقَالَ لَهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ الْحَمْدُ لِلَّهِ الَّذِي هَدَاكَ لِلْفِطْرَةِ لَوْ أَخَذْتَ الْخَمْرَ غَوَتْ أُمَّتُكَ ‏.‏\hadithno{5657}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"On the night on which he was taken on the Night Journey (Al-Isra'), two cups, of wine and milk, were brought to the Messenger of Allah [SAW]. He looked at them and chose the milk. Jibril, peace be upon him, said to him: 'Praise be to Allah Who has guided you to the Fitrah. If you have chosen the wine, your Ummah would have gone astray}}
\hadithdefcmd{nasai}{5658}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، عَنْ خَالِدٍ، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ شُعْبَةَ، قَالَ سَمِعْتُ أَبَا بَكْرِ بْنَ حَفْصٍ، يَقُولُ سَمِعْتُ ابْنَ مُحَيْرِيزٍ، يُحَدِّثُ عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَشْرَبُ نَاسٌ مِنْ أُمَّتِي الْخَمْرَ يُسَمُّونَهَا بِغَيْرِ اسْمِهَا ‏"‏ ‏.‏\hadithno{5658}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Muhairiz narrated from a man among the Companions of the Prophet [SAW] that :The Prophet [SAW] said: "People among my Ummah will drink Khamr, calling it by another name}}
\hadithdefcmd{nasai}{5659}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهُوَ مُؤْمِنٌ وَلاَ يَشْرَبُ الْخَمْرَ شَارِبُهَا حِينَ يَشْرَبُهَا وَهُوَ مُؤْمِنٌ وَلاَ يَسْرِقُ السَّارِقُ حِينَ يَسْرِقُ وَهُوَ مُؤْمِنٌ وَلاَ يَنْتَهِبُ نُهْبَةً يَرْفَعُ النَّاسُ إِلَيْهِ فِيهَا أَبْصَارَهُمْ حِينَ يَنْتَهِبُهَا وَهُوَ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{5659}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'The adulterer is not a believer at the moment when he is committing adultery, and the wine drinker is not a believer at the moment when he is drinking wine, and the thief is not a believer at the moment when he is stealing, and the robber is not a believer at the moment when he is robbing and people are looking on}}
\hadithdefcmd{nasai}{5660}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ وَأَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ كُلُّهُمْ حَدَّثُونِي عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهُوَ مُؤْمِنٌ وَلاَ يَسْرِقُ السَّارِقُ حِينَ يَسْرِقُ وَهُوَ مُؤْمِنٌ وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُهَا وَهُوَ مُؤْمِنٌ وَلاَ يَنْتَهِبُ نُهْبَةً ذَاتَ شَرَفٍ يَرْفَعُ الْمُسْلِمُونَ إِلَيْهِ أَبْصَارَهُمْ وَهُوَ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{5660}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet [SAW] said: "The adulterer is not a believer at the moment when he is committing adultery, and the thief is not a believer at the moment when he is stealing, and the wine drinker is not a believer at the moment when he is drinking wine, and the robber is not a believer at the moment when he is robbing and taking something valuable by force while the Muslims are looking at it}}
\hadithdefcmd{nasai}{5661}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي نُعْمٍ، عَنِ ابْنِ عُمَرَ، وَنَفَرٍ، مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم قَالُوا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فَاجْلِدُوهُ ثُمَّ إِنْ شَرِبَ فَاجْلِدُوهُ ثُمَّ إِنْ شَرِبَ فَاجْلِدُوهُ ثُمَّ إِنْ شَرِبَ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{5661}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar and a number of the Companions of Muhammad [SAW] said:"The Messenger of Allah [SAW] said: 'Whoever drinks Khamr, whip him; then if he drinks (again), whip him; then if he drinks (again), whip him; then if he drinks (again), kill him}}
\hadithdefcmd{nasai}{5662}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا شَبَابَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ خَالِهِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا سَكِرَ فَاجْلِدُوهُ ثُمَّ إِنْ سَكِرَ فَاجْلِدُوهُ ثُمَّ إِنْ سَكِرَ فَاجْلِدُوهُ ‏"‏ ‏.‏ ثُمَّ قَالَ فِي الرَّابِعَةِ ‏"‏ فَاضْرِبُوا عُنُقَهُ ‏"‏ ‏.‏\hadithno{5662}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that :The Messenger of Allah [SAW] said: "If he becomes drunk, whip him; then if he becomes drunk, whip him; then if he becomes drunk, whip him." Then he said concerning the fourth time, "Strike his neck (i.e., kill him)}}
\hadithdefcmd{nasai}{5663}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، عَنِ ابْنِ فُضَيْلٍ، عَنْ وَائِلٍ أَبِي بَكْرٍ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، رضى الله عنه أَنَّهُ كَانَ يَقُولُ مَا أُبَالِي شَرِبْتُ الْخَمْرَ أَوْ عَبَدْتُ هَذِهِ السَّارِيَةَ مِنْ دُونِ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{5663}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Burdah bin Abi Musa, :That his father used to say: "I do not see any difference between drinking Khamr and worshipping this column instead of Allah the Mighty and Sublime}}
\hadithdefcmd{nasai}{5664}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عُثْمَانُ بْنُ حِصْنِ بْنِ عَلاَّقٍ، - دِمَشْقِيٌّ - قَالَ حَدَّثَنَا عُرْوَةُ بْنُ، رُوَيْمٍ أَنَّ ابْنَ الدَّيْلَمِيِّ رَكِبَ يَطْلُبُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ قَالَ ابْنُ الدَّيْلَمِيِّ فَدَخَلْتُ عَلَيْهِ فَقُلْتُ هَلْ سَمِعْتَ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو، رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ شَأْنَ الْخَمْرِ بِشَىْءٍ فَقَالَ نَعَمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَشْرَبُ الْخَمْرَ رَجُلٌ مِنْ أُمَّتِي فَيَقْبَلُ اللَّهُ مِنْهُ صَلاَةً أَرْبَعِينَ يَوْمًا ‏"‏ ‏.‏\hadithno{5664}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Urwah bin Ruwaim narrated that :Ibn Ad-Dailami rode looking for 'Abdullah bin 'Amr bin Al-'As. Ibn Ad-Dailami said: "I entered upon him and said: 'O 'Abdullah bin 'Amr, did you hear the Messenger of Allah [SAW] say anything concerning Khamr?' He said: 'Yes, I heard the Messenger of Allah [SAW] say: If a man among my Ummah drinks Khamr, Allah will not accept his Salah for forty days}}
\hadithdefcmd{nasai}{5665}{أَخْبَرَنَا قُتَيْبَةُ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا خَلَفٌ، - يَعْنِي ابْنَ خَلِيفَةَ - عَنْ مَنْصُورِ بْنِ زَاذَانَ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، قَالَ الْقَاضِي إِذَا أَكَلَ الْهَدِيَّةَ فَقَدْ أَكَلَ السُّحْتَ وَإِذَا قَبِلَ الرِّشْوَةَ بَلَغَتْ بِهِ الْكُفْرَ ‏.‏ وَقَالَ مَسْرُوقٌ مَنْ شَرِبَ الْخَمْرَ فَقَدْ كَفَرَ وَكُفْرُهُ أَنْ لَيْسَ لَهُ صَلاَةٌ ‏.‏\hadithno{5665}\hadithgrade{Abu Ghuddah: Daif Isnaad Maqtu; Al-Albani: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Masruq said:"If a judge accepts a gift he has consumed something unlawful, and if he accepts a bribe, that takes him to the level of Kufr." Masruq said: "Whoever drinks Khamr, he has committed (an act of) Kufr, and his Kufr is that his Salah does not count}}
\hadithdefcmd{nasai}{5666}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُثْمَانَ، رضى الله عنه يَقُولُ اجْتَنِبُوا الْخَمْرَ فَإِنَّهَا أُمُّ الْخَبَائِثِ إِنَّهُ كَانَ رَجُلٌ مِمَّنْ خَلاَ قَبْلَكُمْ تَعَبَّدَ فَعَلِقَتْهُ امْرَأَةٌ غَوِيَّةٌ فَأَرْسَلَتْ إِلَيْهِ جَارِيَتَهَا فَقَالَتْ لَهُ إِنَّا نَدْعُوكَ لِلشَّهَادَةِ فَانْطَلَقَ مَعَ جَارِيَتِهَا فَطَفِقَتْ كُلَّمَا دَخَلَ بَابًا أَغْلَقَتْهُ دُونَهُ حَتَّى أَفْضَى إِلَى امْرَأَةٍ وَضِيئَةٍ عِنْدَهَا غُلاَمٌ وَبَاطِيَةُ خَمْرٍ فَقَالَتْ إِنِّي وَاللَّهِ مَا دَعَوْتُكَ لِلشَّهَادَةِ وَلَكِنْ دَعَوْتُكَ لِتَقَعَ عَلَىَّ أَوْ تَشْرَبَ مِنْ هَذِهِ الْخَمْرَةِ كَأْسًا أَوْ تَقْتُلَ هَذَا الْغُلاَمَ ‏.‏ قَالَ فَاسْقِينِي مِنْ هَذَا الْخَمْرِ كَأْسًا فَسَقَتْهُ كَأْسًا ‏.‏ قَالَ زِيدُونِي فَلَمْ يَرِمْ حَتَّى وَقَعَ عَلَيْهَا وَقَتَلَ النَّفْسَ فَاجْتَنِبُوا الْخَمْرَ فَإِنَّهَا وَاللَّهِ لاَ يَجْتَمِعُ الإِيمَانُ وَإِدْمَانُ الْخَمْرِ إِلاَّ لَيُوشِكُ أَنْ يُخْرِجَ أَحَدُهُمَا صَاحِبَهُ ‏.‏\hadithno{5666}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Bakr bin 'Abdur-Rahman bin Al-Harith that his father said:"I heard 'Uthman, may Allah be pleased with him, say: 'Avoid Khamr for it is the mother of all evils. There was a man among those who came before you who was a devoted worshipper. An immoral woman fell in love with him. She sent her slave girl to him, saying: We are calling you to bear witness. So he set out with her slave girl, and every time he entered a door, she locked it behind him, until he reached a beautiful woman who has with her a boy and a vessel of wine. She said: 'By Allah, I did not call you to bear witness, rather I called you to have intercourse with me, or to drink a cup of this wine, or to kill this boy.' He said: 'Pour me a cup of this wine.' So she poured him a cup. He said: 'Give me more.' And soon he had intercourse with her and killed the boy. So avoid Khamr, for by Allah faith and addiction to Khamr cannot coexist but, one of them will soon expel the other}}
\hadithdefcmd{nasai}{5667}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ الْمُبَارَكِ - عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، أَنَّ أَبَاهُ، قَالَ سَمِعْتُ عُثْمَانَ، يَقُولُ اجْتَنِبُوا الْخَمْرَ فَإِنَّهَا أُمُّ الْخَبَائِثِ فَإِنَّهُ كَانَ رَجُلٌ مِمَّنْ خَلاَ قَبْلَكُمْ يَتَعَبَّدُ وَيَعْتَزِلُ النَّاسَ فَذَكَرَ مِثْلَهُ قَالَ فَاجْتَنِبُوا الْخَمْرَ فَإِنَّهُ وَاللَّهِ لاَ يَجْتَمِعُ وَالإِيمَانُ أَبَدًا إِلاَّ يُوشِكُ أَحَدُهُمَا أَنْ يُخْرِجَ صَاحِبَهُ ‏.‏\hadithno{5667}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Bakr bin 'Abdur-Rahman bin Al-Harith narrated that his father said:"I heard 'Uthman say: 'Avoid Khamr for it is the mother of all evils. There was a man among those who came before you who was a devoted worshipper and used to stay away from people.'" And he mentioned something similar. He said: "Avoid Khamr for, by Allah, it can never coexist with Faith, but soon one of them will expel the other}}
\hadithdefcmd{nasai}{5668}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ عَبْدِ الْمَلِكِ، عَنِ الْعَلاَءِ، - وَهُوَ ابْنُ الْمُسَيَّبِ - عَنْ فُضَيْلٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَنْ شَرِبَ الْخَمْرَ فَلَمْ يَنْتَشِ لَمْ تُقْبَلْ لَهُ صَلاَةٌ مَادَامَ فِي جَوْفِهِ أَوْ عُرُوقِهِ مِنْهَا شَىْءٌ وَإِنْ مَاتَ مَاتَ كَافِرًا وَإِنِ انْتَشَى لَمْ تُقْبَلْ لَهُ صَلاَةٌ أَرْبَعِينَ لَيْلَةً وَإِنْ مَاتَ فِيهَا مَاتَ كَافِرًا ‏.‏ خَالَفَهُ يَزِيدُ بْنُ أَبِي زِيَادٍ ‏.‏\hadithno{5668}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"Whoever drinks Khamr and does not get intoxicated, his Salah will not be accepted so long as any trace of it remains in his belly or his veins, and if he dies he will die a Kafir. If he becomes intoxicated his Salah will not be accepted for 40 nights, and if he dies during them, he will die a Kafir." (Sahih Mawquf)}}
\hadithdefcmd{nasai}{5669}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ، عَنْ عَبْدِ الرَّحِيمِ، عَنْ يَزِيدَ، ح وَأَنْبَأَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ مُحَمَّدُ بْنُ آدَمَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ شَرِبَ الْخَمْرَ فَجَعَلَهَا فِي بَطْنِهِ لَمْ يَقْبَلِ اللَّهُ مِنْهُ صَلاَةً سَبْعًا إِنْ مَاتَ فِيهَا ‏"‏ ‏.‏ وَقَالَ ابْنُ آدَمَ ‏"‏ فِيهِنَّ مَاتَ كَافِرًا فَإِنْ أَذْهَبَتْ عَقْلَهُ عَنْ شَىْءٍ مِنَ الْفَرَائِضِ ‏"‏ ‏.‏ وَقَالَ ابْنُ آدَمَ ‏"‏ الْقُرْآنِ لَمْ تُقْبَلْ لَهُ صَلاَةٌ أَرْبَعِينَ يَوْمًا إِنْ مَاتَ فِيهَا ‏"‏ ‏.‏ وَقَالَ ابْنُ آدَمَ ‏"‏ فِيهِنَّ مَاتَ كَافِرًا ‏"‏ ‏.‏\hadithno{5669}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that:The Prophet [SAW] said: "Whoever drinks Khamr and puts it in his belly, Allah will not accept his Salah for seven (days), if he dies during them" - Muhammad bin Adam (One of the narrators) said: "he will die a Kafir. If he was too intoxicated to offer any of the obligatory" - Ibn Adam said: "or recite Qur'an, his Salah will not be accepted for 40 days, and if he dies during them," And Ibn Adam said: "He will die a Kafir}}
\hadithdefcmd{nasai}{5670}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ، ح وَأَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، عَنْ بَقِيَّةَ، عَنْ أَبِي عَمْرٍو، - وَهُوَ الأَوْزَاعِيُّ - عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ الدَّيْلَمِيِّ، قَالَ دَخَلْتُ عَلَى عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ وَهُوَ فِي حَائِطٍ لَهُ بِالطَّائِفِ يُقَالُ لَهُ الْوَهْطُ وَهُوَ مُخَاصِرٌ فَتًى مِنْ قُرَيْشٍ يُزَنُّ ذَلِكَ الْفَتَى بِشُرْبِ الْخَمْرِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ شَرْبَةً لَمْ تُقْبَلْ لَهُ تَوْبَةٌ أَرْبَعِينَ صَبَاحًا فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ فَإِنْ عَادَ لَمْ تُقْبَلْ تَوْبَتُهُ أَرْبَعِينَ صَبَاحًا فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ فَإِنْ عَادَ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يَسْقِيَهُ مِنْ طِينَةِ الْخَبَالِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ اللَّفْظُ لِعَمْرٍو ‏.‏\hadithno{5670}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Ad-Dailami said:"I entered upon 'Abdullah bin 'Amr bin Al-'As when he was in a garden of his in At-Ta'if called Al-Waht. He was walking and holding hands with a young man of Quraish who was suspected of drinking Khamr. He said: 'I heard the Messenger of Allah [SAW] say: Whoever drinks Khamr once, his repentance will not be accepted for 40 days, then if he repents, Allah will accept his repentance. If he does it again, his repentance will not be accepted for 40 days, then if he repents, Allah will accept his repentance. If he does it again, his repentance will not be accepted for 40 days, then if he repents, Allah will accept his repentance. If he does it again (a fourth time), then it is a right upon Allah to make him drink from the mud of Khibal on the Day of Resurrection." This is the wording of 'Amr}}
\hadithdefcmd{nasai}{5671}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا ثُمَّ لَمْ يَتُبْ مِنْهَا حُرِمَهَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5671}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah [SAW] said: "Whoever drinks Khamr in this world and does not repent from that, will be denied it in the Hereafter}}
\hadithdefcmd{nasai}{5672}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ نُبَيْطٍ، عَنْ جَابَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ مَنَّانٌ وَلاَ عَاقٌّ وَلاَ مُدْمِنُ خَمْرٍ ‏"‏ ‏.‏\hadithno{5672}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that:The Prophet [SAW] said: "No one who reminds others of his favors, no one who is disobedient to his parents and no drunkard, will enter Paradise}}
\hadithdefcmd{nasai}{5673}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حَمَّادِ بْنِ زَيْدٍ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا فَمَاتَ وَهُوَ يُدْمِنُهَا لَمْ يَتُبْ مِنْهَا لَمْ يَشْرَبْهَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5673}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that :The Prophet [SAW] said: "Whoever drinks Khamr in this world and dies addicted to it, and not having repented, will not drink it in the Hereafter}}
\hadithdefcmd{nasai}{5674}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا فَمَاتَ وَهُوَ يُدْمِنُهَا لَمْ يَشْرَبْهَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5674}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Whoever drinks Khamr in this world and dies addicted to it, will not drink it in the Hereafter}}
\hadithdefcmd{nasai}{5675}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الْحَسَنِ بْنِ يَحْيَى، عَنِ الضَّحَّاكِ، قَالَ مَنْ مَاتَ مُدْمِنًا لِلْخَمْرِ نُضِحَ فِي وَجْهِهِ بِالْحَمِيمِ حِينَ يُفَارِقُ الدُّنْيَا ‏.‏\hadithno{5675}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ad-Dahhak said:"Whoever dies addicted to Khamr will have boiling water thrown in his face when he departs this world}}
\hadithdefcmd{nasai}{5676}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ غَرَّبَ عُمَرُ رضى الله عنه رَبِيعَةَ بْنَ أُمَيَّةَ فِي الْخَمْرِ إِلَى خَيْبَرَ فَلَحِقَ بِهِرَقْلَ فَتَنَصَّرَ فَقَالَ عُمَرُ رَضِيَ اللَّهُ عَنْهُ لاَ أُغَرِّبُ بَعْدَهُ مُسْلِمًا ‏.‏\hadithno{5676}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"'Umar, may Allah be pleased with him, banished Rabi'ah bin Umaiyah to Khaibar for drinking Khamr, and he went and joined Heraclius and became a Christian. 'Umar, may Allah be pleased with him, said: 'I will never expel any Muslim after this}}
\hadithdefcmd{nasai}{5677}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ سِمَاكٍ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي بُرْدَةَ بْنِ نِيَارٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْرَبُوا فِي الظُّرُوفِ وَلاَ تَسْكَرُوا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا حَدِيثٌ مُنْكَرٌ غَلِطَ فِيهِ أَبُو الأَحْوَصِ سَلاَّمُ بْنُ سُلَيْمٍ لاَ نَعْلَمُ أَنَّ أَحَدًا تَابَعَهُ عَلَيْهِ مِنْ أَصْحَابِ سِمَاكِ بْنِ حَرْبٍ وَسِمَاكٌ لَيْسَ بِالْقَوِيِّ وَكَانَ يَقْبَلُ التَّلْقِينَ ‏.‏ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ كَانَ أَبُو الأَحْوَصِ يُخْطِئُ فِي هَذَا الْحَدِيثِ ‏.‏ خَالَفَهُ شَرِيكٌ فِي إِسْنَادِهِ وَفِي لَفْظِهِ ‏.‏\hadithno{5677}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Burdah bin Niyar said:"The Messenger of Allah [SAW] said: 'Drink from vessels but do not become intoxicated}}
\hadithdefcmd{nasai}{5678}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالنَّقِيرِ وَالْمُزَفَّتِ ‏.‏ خَالَفَهُ أَبُو عَوَانَةَ ‏.‏\hadithno{5678}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Buraidah, from his father, that:The Messenger of Allah [SAW] forbade Ad-Dubba', Al-Hantam, An-Naqir, and Al-Muzaffat}}
\hadithdefcmd{nasai}{5679}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا إِبْرَاهِيمُ بْنُ حَجَّاجٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكٍ، عَنْ قُرْصَافَةَ، - امْرَأَةٌ مِنْهُمْ - عَنْ عَائِشَةَ، قَالَتِ اشْرَبُوا وَلاَ تَسْكَرُوا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا أَيْضًا غَيْرُ ثَابِتٍ وَقُرْصَافَةُ هَذِهِ لاَ نَدْرِي مَنْ هِيَ وَالْمَشْهُورُ عَنْ عَائِشَةَ خِلاَفُ مَا رَوَتْ عَنْهَا قُرْصَافَةُ ‏.‏\hadithno{5679}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Simak, from Qirsafah, one of their womenfolk, that:'Aishah said: "Drink but do not become intoxicated}}
\hadithdefcmd{nasai}{5680}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ قُدَامَةَ الْعَامِرِيِّ، أَنَّ جَسْرَةَ بِنْتَ دَجَاجَةَ الْعَامِرِيَّةَ، حَدَّثَتْهُ قَالَتْ، سَمِعْتُ عَائِشَةَ، سَأَلَهَا أُنَاسٌ كُلُّهُمْ يَسْأَلُ عَنِ النَّبِيذِ، يَقُولُ نَنْبِذُ التَّمْرَ غُدْوَةً وَنَشْرَبُهُ عَشِيًّا وَنَنْبِذُهُ عَشِيًّا وَنَشْرَبُهُ غُدْوَةً ‏.‏ قَالَتْ لاَ أُحِلُّ مُسْكِرًا وَإِنْ كَانَ خُبْزًا وَإِنْ كَانَتْ مَاءً ‏.‏ قَالَتْهَا ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{5680}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Qudamah Al-'Amiri that Jasrah bint Dijajah Al-'Amiriyyah told him:"I heard 'Aishah when some people asked her about Nabidh, saying we soak dates in the morning and drink it in the evening, or we soak them in the evening and drink them in the morning. She said: 'I do not permit any intoxicant even if it were bread or even if it were water.' She said that three times}}
\hadithdefcmd{nasai}{5681}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَتْنَا كَرِيمَةُ بِنْتُ هَمَّامٍ، أَنَّهَا سَمِعَتْ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، تَقُولُ نُهِيتُمْ عَنِ الدُّبَّاءِ، نُهِيتُمْ عَنِ الْحَنْتَمِ، نُهِيتُمْ عَنِ الْمُزَفَّتِ، ‏.‏ ثُمَّ أَقْبَلَتْ عَلَى النِّسَاءِ فَقَالَتْ إِيَّاكُنَّ وَالْجَرَّ الأَخْضَرَ وَإِنْ أَسْكَرَكُنَّ مَاءُ حُبِّكُنَّ فَلاَ تَشْرَبْنَهُ ‏.‏\hadithno{5681}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Al-Mubarak said:"Karimah bint Hammam told me that she heard 'Aishah, the Mother of the Believers, say: 'You have been forbidden Ad-Dubba' (gourds), you have been forbidden Al-Hantam, you have been forbidden Al-Muzaffat.' Then she turned to women and said: 'Beware of green earthenware jars, and if the water in your clay vessels intoxicates you, do not drink it}}
\hadithdefcmd{nasai}{5682}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا أَبَانُ بْنُ صَمْعَةَ، قَالَ حَدَّثَتْنِي وَالِدَتِي، عَنْ عَائِشَةَ، أَنَّهَا سُئِلَتْ عَنِ الأَشْرِبَةِ، فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ كُلِّ مُسْكِرٍ ‏.‏ وَاعْتَلُّوا بِحَدِيثِ عَبْدِ اللَّهِ بْنِ شَدَّادٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ‏.‏\hadithno{5682}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah was asked about drinks and she said:"The Messenger of Allah [SAW] used to forbid all intoxicants." And they use the narration of 'Abdullah bin Shaddad from 'Abdullah bin 'Abbas}}
\hadithdefcmd{nasai}{5683}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا الْقَوَارِيرِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ سَمِعْتُ ابْنَ شُبْرُمَةَ، يَذْكُرُهُ عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادِ بْنِ الْهَادِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حُرِّمَتِ الْخَمْرُ قَلِيلُهَا وَكَثِيرُهَا وَالسُّكْرُ مِنْ كُلِّ شَرَابٍ ‏.‏ ابْنُ شُبْرُمَةَ لَمْ يَسْمَعْهُ مِنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ ‏.‏\hadithno{5683}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Shubrumah who mentioned it from 'Abdullah bin Shaddad bin Al-Had, from Ibn 'Abbas, who said:"Khamr was forbidden in small or large amounts, as was every kind of intoxicating drink}}
\hadithdefcmd{nasai}{5684}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنِ ابْنِ شُبْرُمَةَ، قَالَ حَدَّثَنِي الثِّقَةُ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حُرِّمَتِ الْخَمْرُ بِعَيْنِهَا قَلِيلُهَا وَكَثِيرُهَا وَالسُّكْرُ مِنْ كُلِّ شَرَابٍ ‏.‏ خَالَفَهُ أَبُو عَوْنٍ مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ الثَّقَفِيُّ ‏.‏\hadithno{5684}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"Khamr was forbidden in and of itself in small or large amounts, as was every kind of intoxicating drink}}
\hadithdefcmd{nasai}{5685}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، ح وَأَنْبَأَنَا الْحُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مِسْعَرٍ، عَنْ أَبِي عَوْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حُرِّمَتِ الْخَمْرُ بِعَيْنِهَا قَلِيلُهَا وَكَثِيرُهَا وَالسُّكْرُ مِنْ كُلِّ شَرَابٍ ‏.‏ لَمْ يَذْكُرِ ابْنُ الْحَكَمِ قَلِيلُهَا وَكَثِيرُهَا ‏.‏\hadithno{5685}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"Khamr was forbidden in and of itself, in small or large amounts, as was every kind of intoxicating drink}}
\hadithdefcmd{nasai}{5686}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْعَبَّاسِ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ عَبَّاسِ بْنِ ذَرِيحٍ، عَنْ أَبِي عَوْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حُرِّمَتِ الْخَمْرُ قَلِيلُهَا وَكَثِيرُهَا وَمَا أَسْكَرَ مِنْ كُلِّ شَرَابٍ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا أَوْلَى بِالصَّوَابِ مِنْ حَدِيثِ ابْنِ شُبْرُمَةَ وَهُشَيْمُ بْنُ بَشِيرٍ كَانَ يُدَلِّسُ وَلَيْسَ فِي حَدِيثِهِ ذِكْرُ السَّمَاعِ مِنِ ابْنِ شُبْرُمَةَ وَرِوَايَةُ أَبِي عَوْنٍ أَشْبَهُ بِمَا رَوَاهُ الثِّقَاتُ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{5686}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"Khamr was forbidden in small or large amounts, as was every kind of drink that intoxicates}}
\hadithdefcmd{nasai}{5687}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ سُفْيَانَ، عَنْ أَبِي الْجُوَيْرِيَةِ الْجَرْمِيِّ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ وَهُوَ مُسْنِدٌ ظَهْرَهُ إِلَى الْكَعْبَةِ عَنِ الْبَاذَقِ، فَقَالَ سَبَقَ مُحَمَّدٌ الْبَاذَقَ وَمَا أَسْكَرَ فَهُوَ حَرَامٌ ‏.‏ قَالَ أَنَا أَوَّلُ الْعَرَبِ سَأَلَهُ ‏.‏\hadithno{5687}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Al-Juwairiyah Al-Jarmi said:"I asked Ibn 'Abbas, when he was leaning back against the Ka'bah, about Badhaq (a drink made from the juice of grapes slightly boiled). He said: 'Muhammad came before Badhaq (i.e., it was not known during his time), but everything that intoxicates in unlawful.'" He said: "I was the first of the 'Arabs to ask him}}
\hadithdefcmd{nasai}{5688}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو عَامِرٍ، وَالنَّضْرُ بْنُ شُمَيْلٍ، وَوَهْبُ بْنُ جَرِيرٍ، قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ سَمِعْتُ أَبَا الْحَكَمِ، يُحَدِّثُ قَالَ ابْنُ عَبَّاسٍ مَنْ سَرَّهُ أَنْ يُحَرِّمَ، - إِنْ كَانَ مُحَرِّمًا مَا حَرَّمَ اللَّهُ وَرَسُولُهُ - فَلْيُحَرِّمِ النَّبِيذَ ‏.‏\hadithno{5688}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Abbas said:"Whoever would like to regard as forbidden that which Allah and His Messenger [SAW] regard as forbidden, let him regard Nabidh as forbidden}}
\hadithdefcmd{nasai}{5689}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، قَالَ قَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ إِنِّي امْرُؤٌ مِنْ أَهْلِ خُرَاسَانَ وَإِنَّ أَرْضَنَا أَرْضٌ بَارِدَةٌ وَإِنَّا نَتَّخِذُ شَرَابًا نَشْرَبُهُ مِنَ الزَّبِيبِ وَالْعِنَبِ وَغَيْرِهِ وَقَدْ أُشْكِلَ عَلَىَّ ‏.‏ فَذَكَرَ لَهُ ضُرُوبًا مِنَ الأَشْرِبَةِ فَأَكْثَرَ حَتَّى ظَنَنْتُ أَنَّهُ لَمْ يَفْهَمْهُ فَقَالَ لَهُ ابْنُ عَبَّاسٍ إِنَّكَ قَدْ أَكْثَرْتَ عَلَىَّ اجْتَنِبْ مَا أَسْكَرَ مِنْ تَمْرٍ أَوْ زَبِيبٍ أَوْ غَيْرِهِ ‏.‏\hadithno{5689}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Uyainah bin 'Abdur-Rahman that his father said:"A man said to Ibn 'Abbas: 'I am a man from Khurasan, and our land is a cold land. We have a drink that is made from raisins and grapes and other things, and I am confused about it.' He mentioned different kinds of drinks to him and mentioned many, until I thought that he had not understood him. Ibn 'Abbas said to him: 'You have told me too many. Avoid whatever intoxicates, whether it is made of dates, raisins or anything else}}
\hadithdefcmd{nasai}{5690}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا الْقَوَارِيرِيُّ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَبِيذُ الْبُسْرِ بَحْتًا لاَ يَحِلُّ ‏.‏\hadithno{5690}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"Nabidh made from Al-Busr is forbidden and is not permissible}}
\hadithdefcmd{nasai}{5691}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، قَالَ كُنْتُ أُتَرْجِمُ بَيْنَ ابْنِ عَبَّاسٍ وَبَيْنَ النَّاسِ فَأَتَتْهُ امْرَأَةٌ تَسْأَلُهُ عَنْ نَبِيذِ الْجَرِّ، فَنَهَى عَنْهُ ‏.‏ قُلْتُ يَا أَبَا عَبَّاسٍ إِنِّي أَنْتَبِذُ فِي جَرَّةٍ خَضْرَاءَ نَبِيذًا حُلْوًا فَأَشْرَبُ مِنْهُ فَيُقَرْقِرُ بَطْنِي ‏.‏ قَالَ لاَ تَشْرَبْ مِنْهُ وَإِنْ كَانَ أَحْلَى مِنَ الْعَسَلِ ‏.‏\hadithno{5691}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hamzah said:"I used to interpret between Ibn 'Abbas and the people. A woman came to him and asked him about Nabidh made in earthenware jars, and he forbade it. I said: 'O Abu 'Abbas, I make a sweet Nabidh in a green earthenware jar; when I drink it, my stomach makes noises.' He said: 'Do not drink it even if it is sweeter than honey}}
\hadithdefcmd{nasai}{5692}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو عَتَّابٍ، - وَهُوَ سَهْلُ بْنُ حَمَّادٍ - قَالَ حَدَّثَنَا قُرَّةُ، قَالَ حَدَّثَنَا أَبُو جَمْرَةَ، نَصْرٌ قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ إِنَّ جَدَّةً لِي تَنْبِذُ نَبِيذًا فِي جَرٍّ أَشْرَبُهُ حُلْوًا إِنْ أَكْثَرْتُ مِنْهُ فَجَالَسْتُ الْقَوْمَ خَشِيتُ أَنْ أَفْتَضِحَ ‏.‏ فَقَالَ قَدِمَ وَفْدُ عَبْدِ الْقَيْسِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَرْحَبًا بِالْوَفْدِ لَيْسَ بِالْخَزَايَا وَلاَ النَّادِمِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّ بَيْنَنَا وَبَيْنَكَ الْمُشْرِكِينَ وَإِنَّا لاَ نَصِلُ إِلَيْكَ إِلاَّ فِي أَشْهُرِ الْحُرُمِ فَحَدِّثْنَا بِأَمْرٍ إِنْ عَمِلْنَا بِهِ دَخَلْنَا الْجَنَّةَ وَنَدْعُو بِهِ مَنْ وَرَاءَنَا ‏.‏ قَالَ ‏"‏ آمُرُكُمْ بِثَلاَثٍ وَأَنْهَاكُمْ عَنْ أَرْبَعٍ آمُرُكُمْ بِالإِيمَانِ بِاللَّهِ وَهَلْ تَدْرُونَ مَا الإِيمَانُ بِاللَّهِ ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ شَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَإِقَامُ الصَّلاَةِ وَإِيتَاءُ الزَّكَاةِ وَأَنْ تُعْطُوا مِنَ الْمَغَانِمِ الْخُمُسَ وَأَنْهَاكُمْ عَنْ أَرْبَعٍ عَمَّا يُنْبَذُ فِي الدُّبَّاءِ وَالنَّقِيرِ وَالْحَنْتَمِ وَالْمُزَفَّتِ ‏"‏ ‏.‏\hadithno{5692}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hamzah Nasr said:"I said to Ibn 'Abbas that my grandmother makes Nabidh in an earthenware jar and it is sweet. If I drink a lot of it and sit with people, I am worried that they will find out. He said: 'The delegation of 'Abdul-Qais came to the Messenger of Allah [SAW] and he said: Welcome to a delegation that is not disgraced or filled with regret. They said: O Messenger of Allah, the idolators are between us and you, and we can only reach you during the sacred months. Tell us of something which, if we do it, we will enter Paradise, and we can tell it to those whom we left behind. He said: I will enjoin three things upon you, and forbid four things to you. I order you to have faith in Allah, and do you know what faith in Allah is? They said: Allah and His Messenger know best. He said: (It means) testifying that there is none worthy of worship except Allah, establishing Salah, paying Zakah and giving one-fifth (the Khums) of the spoils of war. And I forbid four things to you: That which is soaked in Ad-Dubba', An-Naqir, Al-Hantam, and Al-Muzaffat}}
\hadithdefcmd{nasai}{5693}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ قَيْسِ بْنِ هُنَانٍ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ قُلْتُ إِنَّ لِي جُرَيْرَةً أَنْتَبِذُ فِيهَا حَتَّى إِذَا غَلَى وَسَكَنَ شَرِبْتُهُ ‏.‏ قَالَ مُذْ كَمْ هَذَا شَرَابُكَ قُلْتُ مُذْ عِشْرُونَ سَنَةً أَوْ قَالَ مُذْ أَرْبَعُونَ سَنَةً ‏.‏ قَالَ طَالَمَا تَرَوَّتْ عُرُوقُكَ مِنَ الْخَبَثِ ‏.‏ وَمِمَّا اعْتَلُّوا بِهِ حَدِيثُ عَبْدِ الْمَلِكِ بْنِ نَافِعٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏\hadithno{5693}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qais bin Wahban said:"I asked Ibn 'Abbas: 'I have a small jar in which I make Nabidh and when it has bubbled and settled down again, I drink it.' He said: 'For how long you have been drinking that?' He said: 'For twenty years'" - or he said: 'for forty years.' He said: 'For a long time you have been quenching your thirst with something forbidden}}
\hadithdefcmd{nasai}{5694}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا الْعَوَّامُ، عَنْ عَبْدِ الْمَلِكِ بْنِ نَافِعٍ، قَالَ قَالَ ابْنُ عُمَرَ رَأَيْتُ رَجُلاً جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِقَدَحٍ فِيهِ نَبِيذٌ وَهُوَ عِنْدَ الرُّكْنِ وَدَفَعَ إِلَيْهِ الْقَدَحَ فَرَفَعَهُ إِلَى فِيهِ فَوَجَدَهُ شَدِيدًا فَرَدَّهُ عَلَى صَاحِبِهِ فَقَالَ لَهُ رَجُلٌ مِنَ الْقَوْمِ يَا رَسُولَ اللَّهِ أَحَرَامٌ هُوَ فَقَالَ ‏"‏ عَلَىَّ بِالرَّجُلِ ‏"‏ ‏.‏ فَأُتِيَ بِهِ فَأَخَذَ مِنْهُ الْقَدَحَ ثُمَّ دَعَا بِمَاءٍ فَصَبَّهُ فِيهِ فَرَفَعَهُ إِلَى فِيهِ فَقَطَّبَ ثُمَّ دَعَا بِمَاءٍ أَيْضًا فَصَبَّهُ فِيهِ ثُمَّ قَالَ ‏"‏ إِذَا اغْتَلَمَتْ عَلَيْكُمْ هَذِهِ الأَوْعِيَةُ فَاكْسِرُوا مُتُونَهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{5694}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Umar said:"While he was at the Rukn, I saw a man bring a cup to the Messenger of Allah [SAW] in which there was Nabidh. He gave the cup to him and he raised it to his mouth, but he found it to be strong, so he gave it back to him and a man among the people said: 'O Messenger of Allah, is it unlawful?' He said: 'Bring the man to me.' So he was brought to him. He took the cup from him and called for water. He poured it into the cup, which he raised to his mouth and frowned. Then he called for more water and poured it into it. Then he said: 'When these vessels become strong in taste, pour water on them to weaken them}}
\hadithdefcmd{nasai}{5695}{وَأَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، عَنْ أَبِي مُعَاوِيَةَ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عَبْدُ الْمَلِكِ بْنُ نَافِعٍ لَيْسَ بِالْمَشْهُورِ وَلاَ يُحْتَجُّ بِحَدِيثِهِ وَالْمَشْهُورُ عَنِ ابْنِ عُمَرَ خِلاَفُ حِكَايَتِهِ ‏.‏\hadithno{5695}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated from 'Abdul-Malik bin Nafi' from Ibn 'Umar:A similar report was narrated from 'Abdul-Malik bin Nafi' from Ibn 'Umar, from the Prophet [SAW]}}
\hadithdefcmd{nasai}{5696}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ أَبِي عَوَانَةَ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ عَنِ الأَشْرِبَةِ، فَقَالَ اجْتَنِبْ كُلَّ شَىْءٍ يَنِشُّ ‏.‏\hadithno{5696}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:A man asked about drinks and he said: "Avoid everything that intoxicates}}
\hadithdefcmd{nasai}{5697}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ أَنْبَأَنَا أَبُو عَوَانَةَ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنِ الأَشْرِبَةِ، فَقَالَ اجْتَنِبْ كُلَّ شَىْءٍ يَنِشُّ ‏.‏\hadithno{5697}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Zaid bin Jubair said:"I asked Ibn 'Umar about drinks and he said: 'Avoid everything that intoxicates}}
\hadithdefcmd{nasai}{5698}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنِ ابْنِ عُمَرَ، قَالَ الْمُسْكِرُ قَلِيلُهُ وَكَثِيرُهُ حَرَامٌ ‏.‏\hadithno{5698}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"Intoxicants are unlawful in small or large amounts}}
\hadithdefcmd{nasai}{5699}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، أَخْبَرَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُلُّ مُسْكِرٍ خَمْرٌ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏.‏\hadithno{5699}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"Every intoxicant is Khamr and every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5700}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ شَبِيبًا، - وَهُوَ ابْنُ عَبْدِ الْمَلِكِ - يَقُولُ حَدَّثَنِي مُقَاتِلُ بْنُ حَيَّانَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ حَرَّمَ اللَّهُ الْخَمْرَ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5700}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Salim bin 'Abdullah, from his father, that:The Messenger of Allah [SAW] said: "Allah has forbidden Khamr, and every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5701}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورٍ، - يَعْنِي ابْنَ جَعْفَرٍ النَّيْسَابُورِيَّ - قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ وَكُلُّ مُسْكِرٍ خَمْرٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَؤُلاَءِ أَهْلُ الثَّبْتِ وَالْعَدَالَةِ مَشْهُورُونَ بِصِحَّةِ النَّقْلِ وَعَبْدِ الْمَلِكِ لاَ يَقُومُ مَقَامَ وَاحِدٍ مِنْهُمْ وَلَوْ عَاضَدَهُ مِنْ أَشْكَالِهِ جَمَاعَةٌ وَبِاللَّهِ التَّوْفِيقُ ‏.‏\hadithno{5701}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Every intoxicant is unlawful and every intoxicant is Khamr}}
\hadithdefcmd{nasai}{5702}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ السَّعِيدِيِّ، قَالَ حَدَّثَتْنِي رُقَيَّةُ بِنْتُ عَمْرِو بْنِ سَعِيدٍ، قَالَتْ كُنْتُ فِي حَجْرِ ابْنِ عُمَرَ فَكَانَ يُنْقَعُ لَهُ الزَّبِيبُ فَيَشْرَبُهُ مِنَ الْغَدِ ثُمَّ يُجَفَّفُ الزَّبِيبُ وَيُلْقَى عَلَيْهِ زَبِيبٌ آخَرُ وَيُجْعَلُ فِيهِ مَاءٌ فَيَشْرَبُهُ مِنَ الْغَدِ حَتَّى إِذَا كَانَ بَعْدَ الْغَدِ طَرَحَهُ ‏.‏ وَاحْتَجُّوا بِحَدِيثِ أَبِي مَسْعُودٍ عُقْبَةَ بْنِ عَمْرٍو ‏.‏\hadithno{5702}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ruqaiyah bint 'Amr bin Sa'd said:"I was under the care of Ibn 'Umar, and raisins would be soaked for him and he would drink them in the morning, then the raisins would be left to dry, and other raisins would be added to them, and water would be poured on top of them, and he would drink that in the morning. Then the day after he would throw them away}}
\hadithdefcmd{nasai}{5703}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْمَاعِيلَ بْنِ سُلَيْمَانَ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ يَمَانٍ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ خَالِدِ بْنِ سَعْدٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ عَطِشَ النَّبِيُّ صلى الله عليه وسلم حَوْلَ الْكَعْبَةِ فَاسْتَسْقَى فَأُتِيَ بِنَبِيذٍ مِنَ السِّقَايَةِ فَشَمَّهُ فَقَطَّبَ فَقَالَ ‏"‏ عَلَىَّ بِذَنُوبٍ مِنْ زَمْزَمَ ‏"‏ ‏.‏ فَصَبَّ عَلَيْهِ ثُمَّ شَرِبَ فَقَالَ رَجُلٌ أَحَرَامٌ هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ وَهَذَا خَبَرٌ ضَعِيفٌ لأَنَّ يَحْيَى بْنَ يَمَانٍ انْفَرَدَ بِهِ دُونَ أَصْحَابِ سُفْيَانَ وَيَحْيَى بْنُ يَمَانٍ لاَ يُحْتَجُّ بِحَدِيثِهِ لِسُوءِ حِفْظِهِ وَكَثْرَةِ خَطَئِهِ ‏.‏\hadithno{5703}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Mas'ud said:"The Prophet [SAW] became thirsty around the Ka'bah so he called for a drink. Some Nabidh was brought in a water skin and he smelled it and frowned. He said: 'Bring me a bucket of Zamzam (water).' He poured it over it and drank some. A man said: 'Is it unlawful, O Messenger of Allah?' He said: 'No}}
\hadithdefcmd{nasai}{5704}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ حِصْنٍ، قَالَ حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، عَنْ خَالِدِ بْنِ حُسَيْنٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ فِي بَعْضِ الأَيَّامِ الَّتِي كَانَ يَصُومُهَا فَتَحَيَّنْتُ فِطْرَهُ بِنَبِيذٍ صَنَعْتُهُ فِي دُبَّاءٍ فَلَمَّا كَانَ الْمَسَاءُ جِئْتُهُ أَحْمِلُهَا إِلَيْهِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي قَدْ عَلِمْتُ أَنَّكَ تَصُومُ فِي هَذَا الْيَوْمِ فَتَحَيَّنْتُ فِطْرَكَ بِهَذَا النَّبِيذِ ‏.‏ فَقَالَ ‏"‏ أَدْنِهِ مِنِّي يَا أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ فَرَفَعْتُهُ إِلَيْهِ فَإِذَا هُوَ يَنِشُّ فَقَالَ ‏"‏ خُذْ هَذِهِ فَاضْرِبْ بِهَا الْحَائِطَ فَإِنَّ هَذَا شَرَابُ مَنْ لاَ يُؤْمِنُ بِاللَّهِ وَلاَ بِالْيَوْمِ الآخِرِ ‏"‏ ‏.‏ وَمِمَّا احْتَجُّوا بِهِ فِعْلُ عُمَرَ بْنِ الْخَطَّابِ رضى الله عنه ‏.‏\hadithno{5704}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:"I knew that the Messenger of Allah [SAW] was fasting on certain days, so I prepared some Nabidh for him to break his fast, and made it in a gourd. When evening came I brought it to him, and said: 'O Messenger of Allah, I knew that you were fasting today, so I prepared this Nabidh for you to break your fast.' He said: 'Bring it to me, O Abu Hurairah.' I brought it to him, and it turned out to be something bubbling. He said: 'Take this and throw it against the wall (throw it away), for this is the drink of one who does not believe in Allah or the Last Day}}
\hadithdefcmd{nasai}{5705}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ السَّرِيِّ بْنِ يَحْيَى، قَالَ حَدَّثَنَا أَبُو حَفْصٍ، - إِمَامٌ لَنَا وَكَانَ مِنْ أَسْنَانِ الْحَسَنِ - عَنْ أَبِي رَافِعٍ أَنَّ عُمَرَ بْنَ الْخَطَّابِ رضى الله عنه قَالَ إِذَا خَشِيتُمْ مِنْ نَبِيذٍ شِدَّتَهُ فَاكْسِرُوهُ بِالْمَاءِ - قَالَ عَبْدُ اللَّهِ - مِنْ قَبْلِ أَنْ يَشْتَدَّ ‏.‏\hadithno{5705}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Rafi' that :'Umar bin Al-Khattab, may Allah be pleased with him, said: "If you fear that Nabidh may be too strong, then weaken it with water." 'Abdullah (one of the narrators) said: "Before it gets strong}}
\hadithdefcmd{nasai}{5706}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ تَلَقَّتْ ثَقِيفٌ عُمَرَ بِشَرَابٍ فَدَعَا بِهِ فَلَمَّا قَرَّبَهُ إِلَى فِيهِ كَرِهَهُ فَدَعَا بِهِ فَكَسَرَهُ بِالْمَاءِ فَقَالَ هَكَذَا فَافْعَلُوا ‏.‏\hadithno{5706}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Yahya bin Sa'eed who heard Sa'eed bin Al-Musayyab say:"Thaqif welcomed 'Umar with a drink. He called for it, but when he brought it close to his mouth, he did not like it. He called for water to weaken it, and said: 'Do like this}}
\hadithdefcmd{nasai}{5707}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو خَيْثَمَةَ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ، ‏\{‏ قَالَ حَدَّثَنَا أَبِي، ‏\}‏ عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عُتْبَةَ بْنِ فَرْقَدٍ، قَالَ كَانَ النَّبِيذُ الَّذِي يَشْرَبُهُ عُمَرُ بْنُ الْخَطَّابِ قَدْ خُلِّلَ ‏.‏ وَمِمَّا يَدُلُّ عَلَى صِحَّةِ هَذَا حَدِيثُ السَّائِبِ ‏.‏\hadithno{5707}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Utbah bin Farqad said:"The Nabidh that 'Umar bin Al-Khattab used to drink had turned to vinegar}}
\hadithdefcmd{nasai}{5708}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، أَنَّهُ أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ خَرَجَ عَلَيْهِمْ فَقَالَ إِنِّي وَجَدْتُ مِنْ فُلاَنٍ رِيحَ شَرَابٍ فَزَعَمَ أَنَّهُ شَرَابُ الطِّلاَءِ وَأَنَا سَائِلٌ عَمَّا شَرِبَ فَإِنْ كَانَ مُسْكِرًا جَلَدْتُهُ فَجَلَدَهُ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه الْحَدَّ تَامًّا ‏.‏\hadithno{5708}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from As-Sa'ib that :'Umar bin Al-Khattab went out t them and said: "I noticed the smell of drink on so-and-so, and he said that he had drunk At-Tila' (thickened juice of grapes). I am asking about what he drank. If it was an intoxicant I will flog him." So 'Umar bin Al-Khattab, may Allah be pleased with him, flogged him, carrying out the Hadd punishment in full}}
\hadithdefcmd{nasai}{5709}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنْ جَيْشَانَ - وَجَيْشَانُ مِنَ الْيَمَنِ - قَدِمَ فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ شَرَابٍ يَشْرَبُونَهُ بِأَرْضِهِمْ مِنَ الذُّرَةِ يُقَالُ لَهُ الْمِزْرُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمُسْكِرٌ هُوَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ مُسْكِرٍ حَرَامٌ إِنَّ اللَّهَ عَزَّ وَجَلَّ عَهِدَ لِمَنْ شَرِبَ الْمُسْكِرَ أَنْ يَسْقِيَهُ مِنْ طِينَةِ الْخَبَالِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا طِينَةُ الْخَبَالِ قَالَ ‏"‏ عَرَقُ أَهْلِ النَّارِ أَوْ قَالَ عُصَارَةُ أَهْلِ النَّارِ ‏"‏ ‏.‏\hadithno{5709}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:A man from (the tribe of) Jaishan, who are from Yemen, came and asked the Messenger of Allah [SAW] about a drink that they drank in his homeland that was made of corn and called Al-Mizr (beer). The Prophet [SAW] said to him: "Is it an intoxicant?" He said: "Yes." The Messenger of Allah [SAW] said: "Every intoxicant is unlawful. Allah, the Mighty and Sublime, has promised the one who drinks intoxicants that He will give him to drink from the mud of Khibal." They said: "O Messenger of Allah, what is the mud of Khibal?" He said: "The sweat of the people of Hell," or he said: "The juice of the people of Hell}}
\hadithdefcmd{nasai}{5710}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ زُرَيْعٍ - عَنِ ابْنِ عَوْنٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْحَلاَلَ بَيِّنٌ وَإِنَّ الْحَرَامَ بَيِّنٌ وَإِنَّ بَيْنَ ذَلِكَ أُمُورًا مُشْتَبِهَاتٍ ‏"‏ ‏.‏ وَرُبَّمَا قَالَ ‏"‏ وَإِنَّ بَيْنَ ذَلِكَ أُمُورًا مُشْتَبِهَةً وَسَأَضْرِبُ فِي ذَلِكَ مَثَلاً إِنَّ اللَّهَ عَزَّ وَجَلَّ حَمَى حِمًى وَإِنَّ حِمَى اللَّهِ مَا حَرَّمَ وَإِنَّهُ مَنْ يَرْعَ حَوْلَ الْحِمَى يُوشِكُ أَنْ يُخَالِطَ الْحِمَى ‏"‏ ‏.‏ وَرُبَّمَا قَالَ ‏"‏ يُوشِكُ أَنْ يَرْتَعَ وَإِنَّ مَنْ خَالَطَ الرِّيبَةَ يُوشِكُ أَنْ يَجْسُرَ ‏"‏ ‏.‏\hadithno{5710}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that An-Nu'man bin Bashir said:"I heard the Messenger of Allah [SAW] say: 'That which is lawful is clear and that which is unlawful is clear, but between them there are matters which are doubtful.'" And sometimes he said: "But between them are matters that are not as clear. I will describe the likeness of that for you. Allah, the Mighty and Sublime, has a sanctuary and the sanctuary of Allah is that which He has forbidden. Whoever grazes around the sanctuary will soon transgress into the sanctuary. And whoever approaches a matter that is unclear, he will soon wind up in the sanctuary." And sometimes he said: "He will soon transgress, and indeed whoever mixes in doubt, he will soon cross into it}}
\hadithdefcmd{nasai}{5711}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَبَانَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي الْحَوْرَاءِ السَّعْدِيِّ، قَالَ قُلْتُ لِلْحَسَنِ بْنِ عَلِيٍّ رضى الله عنهما مَا حَفِظْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ حَفِظْتُ مِنْهُ ‏ "‏ دَعْ مَا يَرِيبُكَ إِلَى مَا لاَ يَرِيبُكَ ‏"‏ ‏.‏\hadithno{5711}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Al-Hawra' As-Sa'di said:"I said to Al-Hasan bin 'Ali, may Allah be pleased with him: 'What did you memorize from the Messenger of Allah [SAW]?' He said: I memorized from him: 'Leave that which makes you doubt for that which does not make you doubt}}
\hadithdefcmd{nasai}{5712}{أَخْبَرَنَا الْجَارُودُ بْنُ مُعَاذٍ، - هُوَ بَاوَرْدِيٌّ - قَالَ حَدَّثَنَا أَبُو سُفْيَانَ، مُحَمَّدُ بْنُ حُمَيْدٍ عَنْ مَعْمَرٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَكْرَهُ أَنْ يَبِيعَ الزَّبِيبَ، لِمَنْ يَتَّخِذُهُ نَبِيذًا ‏.‏\hadithno{5712}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Tawus, from his father, that:He disliked to sell raisins to one who would use them to make Nabidh}}
\hadithdefcmd{nasai}{5713}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ بْنِ دِينَارٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ كَانَ لِسَعْدٍ كُرُومٌ وَأَعْنَابٌ كَثِيرَةٌ وَكَانَ لَهُ فِيهَا أَمِينٌ فَحَمَلَتْ عِنَبًا كَثِيرًا فَكَتَبَ إِلَيْهِ إِنِّي أَخَافُ عَلَى الأَعْنَابِ الضَّيْعَةَ فَإِنْ رَأَيْتَ أَنْ أَعْصُرَهُ عَصَرْتُهُ فَكَتَبَ إِلَيْهِ سَعْدٌ إِذَا جَاءَكَ كِتَابِي هَذَا فَاعْتَزِلْ ضَيْعَتِي فَوَاللَّهِ لاَ أَئْتَمِنُكَ عَلَى شَىْءٍ بَعْدَهُ أَبَدًا ‏.‏ فَعَزَلَهُ عَنْ ضَيْعَتِهِ ‏.‏\hadithno{5713}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Mus'ab bin Sa'd said:"Sa'd had many grapevines and he had someone looking after them for him. (The vines) bore many grapes, and that man wrote to him (saying): 'I am afraid that the grapes will be wasted; what do you think if I squeeze them to make juice? Sa'd wrote to him (saying): 'When this letter of mine reaches you, leave my land, for by Allah I cannot trust you with anything ever agin.' So he made him leave his land}}
\hadithdefcmd{nasai}{5714}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هَارُونَ بْنِ إِبْرَاهِيمَ، عَنِ ابْنِ سِيرِينَ، قَالَ بِعْهُ عَصِيرًا مِمَّنْ يَتَّخِذُهُ طِلاَءً وَلاَ يَتَّخِذُهُ خَمْرًا ‏.‏\hadithno{5714}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Sirin said:"Sell it as juice to one who will make At-Tila' (thickened grape juice) with it, and not Khamr (wine) with it}}
\hadithdefcmd{nasai}{5715}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ مَنْصُورًا، عَنْ إِبْرَاهِيمَ، عَنْ نُبَاتَةَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ كَتَبَ عُمَرُ بْنُ الْخَطَّابِ إِلَى بَعْضِ عُمَّالِهِ أَنِ ارْزُقِ، الْمُسْلِمِينَ مِنَ الطِّلاَءِ مَا ذَهَبَ ثُلُثَاهُ وَبَقِيَ ثُلُثُهُ ‏.‏\hadithno{5715}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Suwiad bin Ghafalah said:"Umar bin Al-Khattab wrote to some of his workers saying: 'Give to the Muslims thickened grape juice when two thirds of it have gone and one-third is left}}
\hadithdefcmd{nasai}{5716}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي مِجْلَزٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ قَرَأْتُ كِتَابَ عُمَرَ بْنِ الْخَطَّابِ إِلَى أَبِي مُوسَى أَمَّا بَعْدُ فَإِنَّهَا قَدِمَتْ عَلَىَّ عِيرٌ مِنَ الشَّامِ تَحْمِلُ شَرَابًا غَلِيظًا أَسْوَدَ كَطِلاَءِ الإِبِلِ وَإِنِّي سَأَلْتُهُمْ عَلَى كَمْ يَطْبُخُونَهُ فَأَخْبَرُونِي أَنَّهُمْ يَطْبُخُونَهُ عَلَى الثُّلُثَيْنِ ذَهَبَ ثُلُثَاهُ الأَخْبَثَانِ ثُلُثٌ بِبَغْيِهِ وَثُلُثٌ بِرِيحِهِ فَمُرْ مَنْ قِبَلَكَ يَشْرَبُونَهُ ‏.‏\hadithno{5716}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Amir bin 'Abdullah said:"I saw the letter of 'Umar bin Al-Khattab to Abu Musa (in which he said): 'A caravan came to me from Ash-Sham carrying a thick black paint like the pitch that is daubed on camels. I asked them how long they cooked it, and they told me that they cooked it until it was reduced by two-third. So the bad two-third had gone, one-third to take away evil and one-third to take away the bad smell. So let those who are with you drink it}}
\hadithdefcmd{nasai}{5717}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، أَنَّ عَبْدَ اللَّهِ بْنَ يَزِيدَ الْخَطْمِيَّ، قَالَ كَتَبَ إِلَيْنَا عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه أَمَّا بَعْدُ فَاطْبُخُوا شَرَابَكُمْ حَتَّى يَذْهَبُ مِنْهُ نَصِيبُ الشَّيْطَانِ فَإِنَّ لَهُ اثْنَيْنِ وَلَكُمْ وَاحِدٌ ‏.‏\hadithno{5717}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Yazid Al-Khatmi said:"Umar bin Al-Khattab, may Allah be pleased with him, wrote to us (saying): 'Cook your drinks until the share of the Shaitan is gone, for he has two (shares) and you have one}}
\hadithdefcmd{nasai}{5718}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ جَرِيرٍ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، قَالَ كَانَ عَلِيٌّ رضى الله عنه يَرْزُقُ النَّاسَ الطِّلاَءَ يَقَعُ فِيهِ الذُّبَابُ وَلاَ يَسْتَطِيعُ أَنْ يُخْرَجَ مِنْهُ ‏.‏\hadithno{5718}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ash-Sha'bi said:"Ali, may Allah be pleased with him, used to give the people thickened grape juice into which flies would fall and not be able to get out again}}
\hadithdefcmd{nasai}{5719}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ دَاوُدَ، قَالَ سَأَلْتُ سَعِيدًا مَا الشَّرَابُ الَّذِي أَحَلَّهُ عُمَرُ رضى الله عنه قَالَ الَّذِي يُطْبَخُ حَتَّى يَذْهَبَ ثُلُثَاهُ وَيَبْقَى ثُلُثُهُ ‏.‏\hadithno{5719}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Dawud said:"I asked Sa'eed: 'What is the drink that 'Umar bin Al-Khattab, may Allah be pleased with him, regarded as permissible?' He said: 'That which has been cooked until two-third has gone and one-third is left}}
\hadithdefcmd{nasai}{5720}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ دَاوُدَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَبَا الدَّرْدَاءِ، كَانَ يَشْرَبُ مَا ذَهَبَ ثُلُثَاهُ وَبَقِيَ ثُلُثُهُ ‏.‏\hadithno{5720}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sa'eed bin Al-Musayyab that :Abu Ad-Darda' used to drink that of which two-third had gone and one-third was left}}
\hadithdefcmd{nasai}{5721}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هُشَيْمٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّهُ كَانَ يَشْرَبُ مِنَ الطِّلاَءِ مَا ذَهَبَ ثُلُثَاهُ وَبَقِيَ ثُلُثُهُ ‏.‏\hadithno{5721}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Musa Al-'Ash'ari that:He used to drink thickened grape juice that of which two-third had gone and one-third was left}}
\hadithdefcmd{nasai}{5722}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسَأَلَهُ، أَعْرَابِيٌّ عَنْ شَرَابٍ، يُطْبَخُ عَلَى النِّصْفِ فَقَالَ لاَ حَتَّى يَذْهَبَ ثُلُثَاهُ وَيَبْقَى الثُّلُثُ ‏.‏\hadithno{5722}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ya'la bin 'Ata' said:"I heard Sa'eed bin Al-Musayyab say, when a Bedouin asked him about a drink that had been cooked and reduced by half: 'No, not until two-third has gone and one-third is left}}
\hadithdefcmd{nasai}{5723}{أَخْبَرَنَا أَحْمَدُ بْنُ خَالِدٍ، عَنْ مَعْنٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ إِذَا طُبِخَ الطِّلاَءُ عَلَى الثُّلُثِ فَلاَ بَأْسَ بِهِ ‏.‏\hadithno{5723}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"When At-Tila' (thickened grape juice) has been cooked and reduced to one-third, then there is nothing wrong with it}}
\hadithdefcmd{nasai}{5724}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يَزِيدَ بْنِ زُرَيْعٍ، قَالَ حَدَّثَنَا أَبُو رَجَاءٍ، قَالَ سَأَلْتُ الْحَسَنَ عَنِ الطِّلاَءِ الْمُنَصَّفِ، فَقَالَ لاَ تَشْرَبْهُ ‏.‏\hadithno{5724}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Raja' said:"I asked Al-Hasan about At-Tila' (thickened grape juice) that has been reduced to half. He said: 'Do not drink it}}
\hadithdefcmd{nasai}{5725}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ بَشِيرِ بْنِ الْمُهَاجِرِ، قَالَ سَأَلْتُ الْحَسَنَ عَمَّا يُطْبَخُ مِنَ الْعَصِيرِ قَالَ مَا تَطْبُخُهُ حَتَّى يَذْهَبَ الثُّلُثَانِ وَيَبْقَى الثُّلُثُ ‏.‏\hadithno{5725}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Bushair bin Al-Muhajir said:"I asked Al-Hasan about juice that has been cooked. He said: 'That which has been cooked until two-third of it has gone and one-third is left}}
\hadithdefcmd{nasai}{5726}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سَعْدُ بْنُ أَوْسٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنَّ نُوحًا صلى الله عليه وسلم نَازَعَهُ الشَّيْطَانُ فِي عُودِ الْكَرْمِ فَقَالَ هَذَا لِي وَقَالَ هَذَا لِي فَاصْطَلَحَا عَلَى أَنَّ لِنُوحٍ ثُلُثَهَا وَلِلشَّيْطَانِ ثُلُثَيْهَا ‏.‏\hadithno{5726}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas bin Sirin said:"I heard Anas bin Malik say: 'The Shaitan disputed with Nuh, peace be upon him, concerning the grapevine. One said: "This is for me," and the other said: "This is for me." Then they agreed that Nuh would have one-third and the Shaitan would have two-thirds}}
\hadithdefcmd{nasai}{5727}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ بْنِ طُفَيْلٍ الْجَزَرِيِّ، قَالَ كَتَبَ إِلَيْنَا عُمَرُ بْنُ عَبْدِ الْعَزِيزِ أَنْ لاَ، تَشْرَبُوا مِنَ الطِّلاَءِ حَتَّى يَذْهَبَ ثُلُثَاهُ وَيَبْقَى ثُلُثُهُ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏.‏\hadithno{5727}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdul-Malik bin Tufail Al-Jazari said:"Umar bin 'Abdul-'Aziz wrote to us (saying): 'Do not drink At-Tila' (thickened grape juice) until two-third of it are gone and one-third remains, and every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5728}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ بُرْدٍ، عَنْ مَكْحُولٍ، قَالَ كُلُّ مُسْكِرٍ حَرَامٌ ‏.‏\hadithno{5728}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Makhul said:"Every intoxicant is unlawful}}
\hadithdefcmd{nasai}{5729}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ أَبِي يَعْفُورٍ السَّلَمِيِّ، عَنْ أَبِي ثَابِتٍ الثَّعْلَبِيِّ، قَالَ كُنْتُ عِنْدَ ابْنِ عَبَّاسٍ فَجَاءَهُ رَجُلٌ فَسَأَلَهُ عَنِ الْعَصِيرِ، فَقَالَ اشْرَبْهُ مَا كَانَ طَرِيًّا ‏.‏ قَالَ إِنِّي طَبَخْتُ شَرَابًا وَفِي نَفْسِي مِنْهُ ‏.‏ قَالَ أَكُنْتَ شَارِبَهُ قَبْلَ أَنْ تَطْبُخَهُ قَالَ لاَ ‏.‏ قَالَ فَإِنَّ النَّارَ لاَ تُحِلُّ شَيْئًا قَدْ حَرُمَ ‏.‏\hadithno{5729}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Thabit Ath-Tha'labi said:"I was with Ibn 'Abbas when a man came to him and asked him about juice. He said: 'Drink that which is fresh.' He said: 'I cooked a drink on the fire and I am not sure about it.' He said: 'Did you drink it before you cooked it?' He said: 'No.' He said: 'Fire does not make permissible something that is forbidden.'" (Sahih Mawquf)}}
\hadithdefcmd{nasai}{5730}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ جُرَيْجٍ، قِرَاءَةً أَخْبَرَنِي عَطَاءٌ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ وَاللَّهِ مَا تُحِلُّ النَّارُ شَيْئًا وَلاَ تُحَرِّمُهُ ‏.‏ قَالَ ثُمَّ فَسَّرَ لِي قَوْلَهُ لاَ تُحِلُّ شَيْئًا لِقَوْلِهِمْ فِي الطِّلاَءِ وَلاَ تُحَرِّمُهُ ‏.‏\hadithno{5730}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ata' said:"I heard Ibn 'Abbas say: 'By Allah, fire does not make anything permissible or forbidden.'" He said: "Then he explained what he meant by 'it does not make permissible' as referring to what they said about At-Tila' (thickened grape juice), and he explained what he said about 'it does not make forbidden' as referring to performing Wudu' after eating something that has been touched by fire}}
\hadithdefcmd{nasai}{5731}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، قَالَ أَخْبَرَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ اشْرَبِ الْعَصِيرَ مَا لَمْ يُزْبِدْ ‏.‏\hadithno{5731}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"Drink juice so long as it does not have any foam}}
\hadithdefcmd{nasai}{5732}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هِشَامِ بْنِ عَائِذٍ الأَسَدِيِّ، قَالَ سَأَلْتُ إِبْرَاهِيمَ عَنِ الْعَصِيرِ، قَالَ اشْرَبْهُ حَتَّى يَغْلِيَ مَا لَمْ يَتَغَيَّرْ ‏.‏\hadithno{5732}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Hisham bin 'A'idh Al-Asadi said:"I asked Ibrahim about juice and he said: 'Drink it, unless it bubbles, so long as it doesn't change}}
\hadithdefcmd{nasai}{5733}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، فِي الْعَصِيرِ قَالَ اشْرَبْهُ حَتَّى يَغْلِيَ ‏.‏\hadithno{5733}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ata' that :He said, concerning juice: "Drink it unless it is bubbling}}
\hadithdefcmd{nasai}{5734}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، قَالَ اشْرَبْهُ ثَلاَثَةَ أَيَّامٍ إِلاَّ أَنْ يَغْلِيَ ‏.‏\hadithno{5734}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ash-Sha'bi said:"Drink it for three days unless it bubbles}}
\hadithdefcmd{nasai}{5735}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنِي الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ الدَّيْلَمِيِّ، عَنْ أَبِيهِ، فَيْرُوزَ قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا أَصْحَابُ كَرْمٍ وَقَدْ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ تَحْرِيمَ الْخَمْرِ فَمَاذَا نَصْنَعُ قَالَ ‏"‏ تَتَّخِذُونَهُ زَبِيبًا ‏"‏ ‏.‏ قُلْتُ فَنَصْنَعُ بِالزَّبِيبِ مَاذَا قَالَ ‏"‏ تَنْقَعُونَهُ عَلَى غَدَائِكُمْ وَتَشْرَبُونَهُ عَلَى عَشَائِكُمْ وَتَنْقَعُونَهُ عَلَى عَشَائِكُمْ وَتَشْرَبُونَهُ عَلَى غَدَائِكُمْ ‏"‏ ‏.‏ قُلْتُ أَفَلاَ نُؤَخِّرُهُ حَتَّى يَشْتَدَّ قَالَ ‏"‏ لاَ تَجْعَلُوهُ فِي الْقُلَلِ وَاجْعَلُوهُ فِي الشِّنَانِ فَإِنَّهُ إِنْ تَأَخَّرَ صَارَ خَلاًّ ‏"‏ ‏.‏\hadithno{5735}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah Ad-Dailami that his father Fairuz said:"I came to the Messenger of Allah [SAW] and said: 'O Messenger of Allah, we have grapevines and Allah, the Mighty and Sublime, has revealed that Khamr (wine) is forbidden, so what should we do?' He said: 'Make raisins.' I said: 'What should we do with the raisins?' He said: 'Soak them in the morning and drink them in the evening, and soak them in the evening and drink them in the morning.' I said: 'Can we leave it until it gets stronger?' He said: 'Do not put it in clay vessels, rather put it in skins, for if it stays there for a long time, it will turn into vinegar}}
\hadithdefcmd{nasai}{5736}{أَخْبَرَنَا عِيسَى بْنُ مُحَمَّدٍ أَبُو عُمَيْرِ بْنُ النَّحَّاسِ، عَنْ ضَمْرَةَ، عَنِ الشَّيْبَانِيِّ، عَنِ ابْنِ الدَّيْلَمِيِّ، عَنْ أَبِيهِ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّ لَنَا أَعْنَابًا فَمَاذَا نَصْنَعُ بِهَا قَالَ ‏"‏ زَبِّبُوهَا ‏"‏ ‏.‏ قُلْنَا فَمَا نَصْنَعُ بِالزَّبِيبِ قَالَ ‏"‏ انْبِذُوهُ عَلَى غَدَائِكُمْ وَاشْرَبُوهُ عَلَى عَشَائِكُمْ وَانْبِذُوهُ عَلَى عَشَائِكُمْ وَاشْرَبُوهُ عَلَى غَدَائِكُمْ وَانْبِذُوهُ فِي الشِّنَانِ وَلاَ تَنْبِذُوهُ فِي الْقِلاَلِ فَإِنَّهُ إِنْ تَأَخَّرَ صَارَ خَلاًّ ‏"‏ ‏.‏\hadithno{5736}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Al-Dailami that his father said:"We said: 'O Messenger of Allah, we have grapevines; what should we do with them?' He said: 'Make raisins.' We said: 'What should we do with the raisins?' He said: 'Soak them in the morning and drink them in the evening, and soak them in the evening and drink them in the morning.' I said: 'Can we leave it until it gets stronger?' He said: 'Do not put it in clay vessels, rather put it in skins, for if it stays there for a long time, it will turn into vinegar}}
\hadithdefcmd{nasai}{5737}{أَخْبَرَنَا أَبُو دَاوُدَ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُطِيعٌ، عَنْ أَبِي عُمَرَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ يُنْبَذُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَيَشْرَبُهُ مِنَ الْغَدِ وَمِنْ بَعْدِ الْغَدِ فَإِذَا كَانَ مَسَاءُ الثَّالِثَةِ فَإِنْ بَقِيَ فِي الإِنَاءِ شَىْءٌ لَمْ يَشْرَبُوهُ أُهْرِيقَ ‏.‏\hadithno{5737}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"Nabidh would be made for the Messenger of Allah [SAW] and he would drink it in the morning, and on the following morning. Then on the evening before the third day, if there was anything left in the vessel, they would not drink it and it would be thrown away}}
\hadithdefcmd{nasai}{5738}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ يَحْيَى بْنِ عُبَيْدٍ الْبَهْرَانِيِّ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُنْقَعُ لَهُ الزَّبِيبُ فَيَشْرَبُهُ يَوْمَهُ وَالْغَدَ وَبَعْدَ الْغَدِ ‏.‏\hadithno{5738}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:Raisins would be soaked for the Messenger of Allah [SAW] and he would drink it that day, the following day, and the day after that}}
\hadithdefcmd{nasai}{5739}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، عَنِ ابْنِ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ يَحْيَى بْنِ أَبِي عُمَرَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنْبَذُ لَهُ نَبِيذُ الزَّبِيبِ مِنَ اللَّيْلِ فَيَجْعَلُهُ فِي سِقَاءٍ فَيَشْرَبُهُ يَوْمَهُ ذَلِكَ وَالْغَدَ وَبَعْدَ الْغَدِ فَإِذَا كَانَ مِنْ آخِرِ الثَّالِثَةِ سَقَاهُ أَوْ شَرِبَهُ فَإِنْ أَصْبَحَ مِنْهُ شَىْءٌ أَهْرَاقَهُ ‏.‏\hadithno{5739}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"Nabidh of raisins would be made for the Messenger of Allah [SAW] at night, and he would put it in a water skin and drink it during the next day, the day after, and the day after that. At the end of the third day, he would give it to others to drink, or drink it himself, and if anything was left the following morning, he would pour it away}}
\hadithdefcmd{nasai}{5740}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يُنْبَذُ لَهُ فِي سِقَاءِ الزَّبِيبِ غُدْوَةً فَيَشْرَبُهُ مِنَ اللَّيْلِ وَيُنْبَذُ لَهُ عَشِيَّةً فَيَشْرَبُهُ غُدْوَةً وَكَانَ يَغْسِلُ الأَسْقِيَةَ وَلاَ يَجْعَلُ فِيهَا دُرْدِيًّا وَلاَ شَيْئًا ‏.‏ قَالَ نَافِعٌ فَكُنَّا نَشْرَبُهُ مِثْلَ الْعَسَلِ ‏.‏\hadithno{5740}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:Nabidh of raisins would be made for him in a water skin in the morning, and he would drink it that night, and it would be made for him in the evening, and he would drink it in the morning. He would wash out the water skins and not leave any pieces or anything in them. Nafi' said: "We used to drink it like honey}}
\hadithdefcmd{nasai}{5741}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ بَسَّامٍ، قَالَ سَأَلْتُ أَبَا جَعْفَرٍ عَنِ النَّبِيذِ، قَالَ كَانَ عَلِيُّ بْنُ حُسَيْنٍ رضى الله عنه يُنْبَذُ لَهُ مِنَ اللَّيْلِ فَيَشْرَبُهُ غُدْوَةً وَيُنْبَذُ لَهُ غُدْوَةً فَيَشْرَبُهُ مِنَ اللَّيْلِ ‏.‏\hadithno{5741}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Bassam said:"I asked Abu Ja'far about Nabidh and he said: " 'Ali bin Husain, may Allah be pleased with him, would have Nabidh made for him at night, and he would drink it in the morning, and he would have Nabidh made in the morning and he would drink it at night}}
\hadithdefcmd{nasai}{5742}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، قَالَ سَمِعْتُ سُفْيَانَ، سُئِلَ عَنِ النَّبِيذِ، قَالَ انْتَبِذْ عَشِيًّا وَاشْرَبْهُ غُدْوَةً ‏.‏\hadithno{5742}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah said:"I heard Sufyan being asked about Nabidh. He said: 'Make Nabidh at night and drink it in the morning}}
\hadithdefcmd{nasai}{5743}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، وَلَيْسَ، بِالنَّهْدِيِّ أَنَّ أُمَّ الْفَضْلِ، أَرْسَلَتْ إِلَى أَنَسِ بْنِ مَالِكٍ تَسْأَلُهُ عَنْ نَبِيذِ الْجَرِّ فَحَدَّثَهَا عَنِ النَّضْرِ ابْنِهِ أَنَّهُ كَانَ يُنْبَذُ فِي جَرٍّ يُنْبَذُ غُدْوَةً وَيَشْرَبُهُ عَشِيَّةً ‏.‏\hadithno{5743}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu 'Uthman, who was not Al-Hindi, that:Umm Al-Fadl sent word to Anas bin Malik, asking him about Nabidh made in an earthenware jar. He told her about his son An-Nadr, who used to make Nabidh in an earthenware jar in the morning and drink it in the evening}}
\hadithdefcmd{nasai}{5744}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَكْرَهُ أَنْ يَجْعَلَ، نَطْلَ النَّبِيذِ فِي النَّبِيذِ لِيَشْتَدَّ بِالنَّطْلِ ‏.‏\hadithno{5744}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa'eed bin Al-Musayyib that:He disliked putting the dregs of Nabidh into (new) Nabidh lest it become strong because of the dregs}}
\hadithdefcmd{nasai}{5745}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ فِي النَّبِيذِ خَمْرُهُ دُرْدِيُّهُ ‏.‏\hadithno{5745}\hadithgrade{Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said concerning Nabidh:"The dregs are what intoxicates}}
\hadithdefcmd{nasai}{5746}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ إِنَّمَا سُمِّيَتِ الْخَمْرُ لأَنَّهَا تُرِكَتْ حَتَّى مَضَى صَفْوُهَا وَبَقِيَ كَدَرُهَا ‏.‏ وَكَانَ يَكْرَهُ كُلَّ شَىْءٍ يُنْبَذُ عَلَى عَكَرٍ ‏.‏\hadithno{5746}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"Khamr is so called because it is left until the good parts are gone and the dregs remain." And he disliked everything that was made by using dregs (by adding new materials to the dregs)}}
\hadithdefcmd{nasai}{5747}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا الْقَوَارِيرِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ حَدَّثَنَا حَسَنُ بْنُ عَمْرٍو، عَنْ فُضَيْلِ بْنِ عَمْرٍو، عَنْ إِبْرَاهِيمَ، قَالَ كَانُوا يَرَوْنَ أَنَّ مَنْ، شَرِبَ شَرَابًا فَسَكِرَ مِنْهُ لَمْ يَصْلُحْ لَهُ أَنْ يَعُودَ فِيهِ ‏.‏\hadithno{5747}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibrahim said:"They used to think that whoever drank something and became intoxicated from it, it was not befitting for him to go back and drink more of the same}}
\hadithdefcmd{nasai}{5748}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ مُغِيرَةَ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، قَالَ لاَ بَأْسَ بِنَبِيذِ الْبُخْتُجِ ‏.‏\hadithno{5748}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibrahim said:"There is nothing wrong with Nabidh Al-Bukhtuj}}
\hadithdefcmd{nasai}{5749}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ أَبِي عَوَانَةَ، عَنْ أَبِي مِسْكِينٍ، قَالَ سَأَلْتُ إِبْرَاهِيمَ قُلْتُ إِنَّا نَأْخُذُ دُرْدِيَّ الْخَمْرِ أَوِ الطِّلاَءَ فَنُنَظِّفُهُ ثُمَّ نَنْقَعُ فِيهِ الزَّبِيبَ ثَلاَثًا ثُمَّ نُصَفِّيهِ ثُمَّ نَدَعُهُ حَتَّى يَبْلُغَ فَنَشْرَبُهُ قَالَ يُكْرَهُ ‏.‏\hadithno{5749}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Al-Miskin said:"I asked Ibrahim: 'We take the dregs of Khamr or Tila' (thickened grape juice) and clean them, then we soak it with raisins for three days, then we strain it and leave it until it matures, then we drink it.' He said: 'That is Makruh}}
\hadithdefcmd{nasai}{5750}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ ابْنِ شُبْرُمَةَ، قَالَ رَحِمَ اللَّهُ إِبْرَاهِيمَ شَدَّدَ النَّاسُ فِي النَّبِيذِ وَرَخَّصَ فِيهِ ‏.‏\hadithno{5750}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Shubrumah said:"May Allah have mercy on Ibrahim. Other scholars had strict views on Nabidh but he was lenient}}
\hadithdefcmd{nasai}{5751}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ أَبِي أُسَامَةَ، قَالَ سَمِعْتُ ابْنَ الْمُبَارَكِ، يَقُولُ مَا وَجَدْتُ الرُّخْصَةَ فِي الْمُسْكِرِ عَنْ أَحَدٍ صَحِيحًا إِلاَّ عَنْ إِبْرَاهِيمَ ‏.‏\hadithno{5751}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Al-Mubarak said:"I have never found any sound report, giving a concession on intoxicants, except the report narrated from Ibrahim}}
\hadithdefcmd{nasai}{5752}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا أُسَامَةَ، يَقُولُ مَا رَأَيْتُ رَجُلاً أَطْلَبَ لِلْعِلْمِ مِنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الشَّامَاتِ وَمِصْرَ وَالْيَمَنَ وَالْحِجَازَ ‏.‏\hadithno{5752}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ubaidullah bin Sa'eed said:"I heard Abu Usamah say: 'I never saw any man more assiduous in seeking knowledge than 'Abdullah bin Al-Mubarak, not in Ash-Sham, Egypt, Yemen or the Hijaz}}
\hadithdefcmd{nasai}{5753}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَسَدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، رضى الله عنه قَالَ كَانَ لأُمِّ سُلَيْمٍ قَدَحٌ مِنْ عَيْدَانٍ فَقَالَتْ سَقَيْتُ فِيهِ رَسُولَ اللَّهِ صلى الله عليه وسلم كُلَّ الشَّرَابِ الْمَاءَ وَالْعَسَلَ وَاللَّبَنَ وَالنَّبِيذَ ‏.‏\hadithno{5753}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:Umm Sulaim had a wooden cup and she said: "I gave the Messenger of Allah [SAW] all kinds of things to drink in it: Water, honey, milk and Nabidh}}
\hadithdefcmd{nasai}{5754}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ ذَرِّ بْنِ عَبْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، قَالَ سَأَلْتُ أُبَىَّ بْنَ كَعْبٍ عَنِ النَّبِيذِ، فَقَالَ اشْرَبِ الْمَاءَ وَاشْرَبِ الْعَسَلَ وَاشْرَبِ السَّوِيقَ وَاشْرَبِ اللَّبَنَ الَّذِي نُجِعَتْ بِهِ ‏.‏ فَعَاوَدْتُهُ فَقَالَ الْخَمْرَ تُرِيدُ الْخَمْرَ تُرِيدُ ‏.‏\hadithno{5754}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa'eed bin 'Abdur-Rahman bin Abza that his father said:"I asked Ubayy bin Ka'b about Nabidh, and he said: 'Drink water, drink honey, drink Sawiq (barley gruel) and drink milk that you have been nourished with since childhood.' I repeated the question and he said: 'Is it wine you want? Is it wine you want?}}
\hadithdefcmd{nasai}{5755}{أَخْبَرَنِي أَحْمَدُ بْنُ عَلِيِّ بْنِ سَعِيدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا الْقَوَارِيرِيُّ، قَالَ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ أَحْدَثَ النَّاسُ أَشْرِبَةً مَا أَدْرِي مَا هِيَ فَمَا لِي شَرَابٌ مُنْذُ عِشْرِينَ سَنَةً أَوْ قَالَ أَرْبَعِينَ سَنَةً إِلاَّ الْمَاءُ وَالسَّوِيقُ غَيْرَ أَنَّهُ لَمْ يَذْكُرِ النَّبِيذَ ‏.‏\hadithno{5755}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Mas'ud said:"The people have invented new drinks and I do not know what they are. I have not drunk anything for 20 years (or he said: 40 years) except water and Sawiq (barley gruel), and he did not mention Nabidh}}
\hadithdefcmd{nasai}{5756}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبِيدَةَ، قَالَ أَحْدَثَ النَّاسُ أَشْرِبَةً مَا أَدْرِي مَا هِيَ وَمَا لِي شَرَابٌ مُنْذُ عِشْرِينَ سَنَةً إِلاَّ الْمَاءُ وَاللَّبَنُ وَالْعَسَلُ ‏.‏\hadithno{5756}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abidah said:"The people have invented drinks and I do not know what they are. I have not drunk anything for 20 years except water, milk and honey}}
\hadithdefcmd{nasai}{5757}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ ابْنِ شُبْرُمَةَ، قَالَ قَالَ طَلْحَةُ لأَهْلِ الْكُوفَةِ فِي النَّبِيذِ فِتْنَةٌ يَرْبُو فِيهَا الصَّغِيرُ وَيَهْرَمُ فِيهَا الْكَبِيرُ قَالَ وَكَانَ إِذَا كَانَ فِيهِمْ عُرْسٌ كَانَ طَلْحَةُ وَزُبَيْرٌ يَسْقِيَانِ اللَّبَنَ وَالْعَسَلَ ‏.‏ فَقِيلَ لِطَلْحَةَ أَلاَ تَسْقِيهِمُ النَّبِيذَ قَالَ إِنِّي أَكْرَهُ أَنْ يَسْكَرَ مُسْلِمٌ فِي سَبَبِي ‏.‏\hadithno{5757}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn Shubrumah said:"Talhah said to the people of Al-Kufah concerning Nabidh: 'It is a test whereby a young man may benefit but an old man may be harmed.' If there was a wedding among them, Talhah and Zubaid would offer milk and honey to drink. It was said to Talhah: 'Why don't you offer Nabidh?' He said: 'I would not like a Muslim to become intoxicated because of me}}
\hadithdefcmd{nasai}{5758}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، قَالَ كَانَ ابْنُ شُبْرُمَةَ لاَ يَشْرَبُ إِلاَّ الْمَاءَ وَاللَّبَنَ ‏.‏\hadithno{5758}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jarir said:"Ibn Shubrumah would not drink anything except water and milk}}
