% Auto-generated chapter 56 for bukhari
% Hadiths in this chapter: 294

\hadithdefcmd{bukhari}{2782}{حَدَّثَنَا الْحَسَنُ بْنُ صَبَّاحٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، قَالَ سَمِعْتُ الْوَلِيدَ بْنَ الْعَيْزَارِ، ذَكَرَ عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ـ رضى الله عنه ـ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الْعَمَلِ أَفْضَلُ قَالَ ‏"‏ الصَّلاَةُ عَلَى مِيقَاتِهَا ‏"‏‏.‏ قُلْتُ ثُمَّ أَىٌّ‏.‏ قَالَ ‏"‏ ثُمَّ بِرُّ الْوَالِدَيْنِ ‏"‏‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ فَسَكَتُّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوِ اسْتَزَدْتُهُ لَزَادَنِي‏.‏\hadithno{2782}\hadithtrans{Narrated `Abdullah bin Masud:I asked Allah's Messenger (ﷺ), "O Allah's Messenger (ﷺ)! What is the best deed?" He replied, "To offer the prayers at their early stated fixed times." I asked, "What is next in goodness?" He replied, "To be good and dutiful to your parents." I further asked, what is next in goodness?" He replied, "To participate in Jihad in Allah's Cause." I did not ask Allah's Messenger (ﷺ) anymore and if I had asked him more, he would have told me more}}
\hadithdefcmd{bukhari}{2783}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏لاَ هِجْرَةَ بَعْدَ الْفَتْحِ وَلَكِنْ جِهَادٌ وَنِيَّةٌ، وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏‏.‏\hadithno{2783}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said, "There is no Hijra (i.e. migration) (from Mecca to Medina) after the Conquest (of Mecca), but Jihad and good intention remain; and if you are called (by the Muslim ruler) for fighting, go forth immediately}}
\hadithdefcmd{bukhari}{2784}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي عَمْرَةَ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ تُرَى الْجِهَادَ أَفْضَلَ الْعَمَلِ، أَفَلاَ نُجَاهِدُ قَالَ ‏ "‏ لَكِنَّ أَفْضَلَ الْجِهَادِ حَجٌّ مَبْرُورٌ ‏"‏‏.‏\hadithno{2784}\hadithtrans{Narrated `Aisha:(That she said), "O Allah's Messenger (ﷺ)! We consider Jihad as the best deed. Should we not fight in Allah's Cause?" He said, "The best Jihad (for women) is Hajj-Mabrur (i.e. Hajj which is done according to the Prophet's tradition and is accepted by Allah)}}
\hadithdefcmd{bukhari}{2785}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، قَالَ أَخْبَرَنِي أَبُو حَصِينٍ، أَنَّ ذَكْوَانَ، حَدَّثَهُ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ دُلَّنِي عَلَى عَمَلٍ يَعْدِلُ الْجِهَادَ‏.‏ قَالَ ‏ "‏ لاَ أَجِدُهُ ـ قَالَ ـ هَلْ تَسْتَطِيعُ إِذَا خَرَجَ الْمُجَاهِدُ أَنْ تَدْخُلَ مَسْجِدَكَ فَتَقُومَ وَلاَ تَفْتُرَ وَتَصُومَ وَلاَ تُفْطِرَ ‏"‏‏.‏ قَالَ وَمَنْ يَسْتَطِيعُ ذَلِكَ قَالَ أَبُو هُرَيْرَةَ إِنَّ فَرَسَ الْمُجَاهِدِ لَيَسْتَنُّ فِي طِوَلِهِ فَيُكْتَبُ لَهُ حَسَنَاتٍ‏.‏\hadithno{2785}\hadithtrans{Narrated Abu Huraira:A man came to Allah's Messenger (ﷺ) and said, "Instruct me as to such a deed as equals Jihad (in reward)." He replied, "I do not find such a deed." Then he added, "Can you, while the Muslim fighter is in the battle-field, enter your mosque to perform prayers without cease and fast and never break your fast?" The man said, "But who can do that?" Abu Huraira added, "The Mujahid (i.e. Muslim fighter) is rewarded even for the footsteps of his horse while it wanders about (for grazing) tied in a long rope}}
\hadithdefcmd{bukhari}{2786}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ يَزِيدَ اللَّيْثِيُّ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ قِيلَ يَا رَسُولَ اللَّهِ، أَىُّ النَّاسِ أَفْضَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مُؤْمِنٌ يُجَاهِدُ فِي سَبِيلِ اللَّهِ بِنَفْسِهِ وَمَالِهِ ‏"‏‏.‏ قَالُوا ثُمَّ مَنْ قَالَ ‏"‏ مُؤْمِنٌ فِي شِعْبٍ مِنَ الشِّعَابِ يَتَّقِي اللَّهَ، وَيَدَعُ النَّاسَ مِنْ شَرِّهِ ‏"‏‏.‏\hadithno{2786}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Somebody asked, "O Allah's Messenger (ﷺ)! Who is the best among the people?" Allah's Messenger (ﷺ) replied "A believer who strives his utmost in Allah's Cause with his life and property." They asked, "Who is next?" He replied, "A believer who stays in one of the mountain paths worshipping Allah and leaving the people secure from his mischief}}
\hadithdefcmd{bukhari}{2787}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَثَلُ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ ـ وَاللَّهُ أَعْلَمُ بِمَنْ يُجَاهِدُ فِي سَبِيلِهِ ـ كَمَثَلِ الصَّائِمِ الْقَائِمِ، وَتَوَكَّلَ اللَّهُ لِلْمُجَاهِدِ فِي سَبِيلِهِ بِأَنْ يَتَوَفَّاهُ أَنْ يُدْخِلَهُ الْجَنَّةَ، أَوْ يَرْجِعَهُ سَالِمًا مَعَ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏‏.‏\hadithno{2787}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "The example of a Mujahid in Allah's Cause-- and Allah knows better who really strives in His Cause----is like a person who fasts and prays continuously. Allah guarantees that He will admit the Mujahid in His Cause into Paradise if he is killed, otherwise He will return him to his home safely with rewards and war booty}}
\hadithdefcmd{bukhari}{2788}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، فَتُطْعِمُهُ، وَكَانَتْ أُمُّ حَرَامٍ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ، فَدَخَلَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَطْعَمَتْهُ وَجَعَلَتْ تَفْلِي رَأْسَهُ، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ‏.‏ قَالَتْ فَقُلْتُ وَمَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ، يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ، مُلُوكًا عَلَى الأَسِرَّةِ، أَوْ مِثْلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ شَكَّ إِسْحَاقُ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَدَعَا لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ وَضَعَ رَأْسَهُ، ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ فَقُلْتُ وَمَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ كَمَا قَالَ فِي الأَوَّلِ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏‏.‏ فَرَكِبَتِ الْبَحْرَ فِي زَمَانِ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ، فَهَلَكَتْ‏.‏\hadithno{2788}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) used to visit Umm Haram bint Milhan, who would offer him meals. Umm Haram was the wife of Ubada bin As-Samit. Allah's Messenger (ﷺ), once visited her and she provided him with food and started looking for lice in his head. Then Allah's Messenger (ﷺ) slept, and afterwards woke up smiling. Umm Haram asked, "What causes you to smile, O Allah's Messenger (ﷺ)?" He said. "Some of my followers who (in a dream) were presented before me as fighters in Allah's cause (on board a ship) amidst this sea caused me to smile; they were as kings on the thrones (or like kings on the thrones)." (Ishaq, a sub-narrator is not sure as to which expression the Prophet (ﷺ) used.) Umm Haram said, "O Allah's Messenger (ﷺ)! Invoke Allah that he makes me one of them. Allah's Messenger (ﷺ) invoked Allah for her and slept again and woke up smiling. Once again Umm Haram asked, "What makes you smile, O Allah's Messenger (ﷺ)?" He replied, "Some of my followers were presented to me as fighters in Allah's Cause," repeating the same dream. Umm Haram said, "O Allah's Messenger (ﷺ)! Invoke Allah that He makes me one of them." He said, "You are amongst the first ones." It happened that she sailed on the sea during the Caliphate of Mu'awiya bin Abi Sufyan, and after she disembarked, she fell down from her riding animal and died}}
\hadithdefcmd{bukhari}{2790}{حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا فُلَيْحٌ، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ آمَنَ بِاللَّهِ وَبِرَسُولِهِ وَأَقَامَ الصَّلاَةَ وَصَامَ رَمَضَانَ، كَانَ حَقًّا عَلَى اللَّهِ أَنْ يُدْخِلَهُ الْجَنَّةَ جَاهَدَ فِي سَبِيلِ اللَّهِ، أَوْ جَلَسَ فِي أَرْضِهِ الَّتِي وُلِدَ فِيهَا ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ أَفَلاَ نُبَشِّرُ النَّاسَ‏.‏ قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ مِائَةَ دَرَجَةٍ أَعَدَّهَا اللَّهُ لِلْمُجَاهِدِينَ فِي سَبِيلِ اللَّهِ، مَا بَيْنَ الدَّرَجَتَيْنِ كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ، فَإِذَا سَأَلْتُمُ اللَّهَ فَاسْأَلُوهُ الْفِرْدَوْسَ، فَإِنَّهُ أَوْسَطُ الْجَنَّةِ وَأَعْلَى الْجَنَّةِ، أُرَاهُ فَوْقَهُ عَرْشُ الرَّحْمَنِ، وَمِنْهُ تَفَجَّرُ أَنْهَارُ الْجَنَّةِ ‏"‏‏.‏ قَالَ مُحَمَّدُ بْنُ فُلَيْحٍ عَنْ أَبِيهِ ‏"‏ وَفَوْقَهُ عَرْشُ الرَّحْمَنِ ‏"‏‏.‏\hadithno{2790}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever believes in Allah and His Apostle, offers prayer perfectly and fasts the month of Ramadan, will rightfully be granted Paradise by Allah, no matter whether he fights in Allah's Cause or remains in the land where he is born." The people said, "O Allah's Messenger (ﷺ) ! Shall we acquaint the people with this good news?" He said, "Paradise has one-hundred grades which Allah has reserved for the Mujahidin who fight in His Cause, and the distance between each of two grades is like the distance between the Heaven and the Earth. So, when you ask Allah (for something), ask for Al-firdaus which is the best and highest part of Paradise." (The sub-narrator added, "I think the Prophet also said, 'Above it (i.e. Al-Firdaus) is the Throne of Beneficent (i.e. Allah), and from it originate the rivers of Paradise}}
\hadithdefcmd{bukhari}{2791}{حَدَّثَنَا مُوسَى، حَدَّثَنَا جَرِيرٌ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ سَمُرَةَ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ اللَّيْلَةَ رَجُلَيْنِ أَتَيَانِي فَصَعِدَا بِي الشَّجَرَةَ، فَأَدْخَلاَنِي دَارًا هِيَ أَحْسَنُ وَأَفْضَلُ، لَمْ أَرَ قَطُّ أَحْسَنَ مِنْهَا قَالاَ أَمَّا هَذِهِ الدَّارُ فَدَارُ الشُّهَدَاءِ ‏"‏‏.‏\hadithno{2791}\hadithtrans{Narrated Samura:The Prophet (ﷺ) said, "Last night two men came to me (in a dream) and made me ascend a tree and then admitted me into a better and superior house, better of which I have never seen. One of them said, 'This house is the house of martyrs}}
\hadithdefcmd{bukhari}{2792}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَغَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏‏.‏\hadithno{2792}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "A single endeavor (of fighting) in Allah's Cause in the forenoon or in the afternoon is better than the world and whatever is in it}}
\hadithdefcmd{bukhari}{2793}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏لَقَابُ قَوْسٍ فِي الْجَنَّةِ خَيْرٌ مِمَّا تَطْلُعُ عَلَيْهِ الشَّمْسُ وَتَغْرُبُ ‏"‏‏.‏ وَقَالَ ‏"‏ لَغَدْوَةٌ أَوْ رَوْحَةٌ فِي سَبِيلِ اللَّهِ خَيْرٌ مِمَّا تَطْلُعُ عَلَيْهِ الشَّمْسُ وَتَغْرُبُ ‏"‏‏.‏\hadithno{2793}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A place in Paradise as small as a bow is better than all that on which the sun rises and sets (i.e. all the world)." He also said, "A single endeavor in Allah's Cause in the afternoon or in the forenoon is better than all that on which the sun rises and sets}}
\hadithdefcmd{bukhari}{2794}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الرَّوْحَةُ وَالْغَدْوَةُ فِي سَبِيلِ اللَّهِ أَفْضَلُ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏‏.‏\hadithno{2794}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said, "A single endeavor in Allah's Cause in the afternoon and in the forenoon is better than the world and whatever is in it}}
\hadithdefcmd{bukhari}{2795}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ عَبْدٍ يَمُوتُ لَهُ عِنْدَ اللَّهِ خَيْرٌ، يَسُرُّهُ أَنْ يَرْجِعَ إِلَى الدُّنْيَا، وَأَنَّ لَهُ الدُّنْيَا وَمَا فِيهَا، إِلاَّ الشَّهِيدَ، لِمَا يَرَى مِنْ فَضْلِ الشَّهَادَةِ، فَإِنَّهُ يَسُرُّهُ أَنْ يَرْجِعَ إِلَى الدُّنْيَا فَيُقْتَلَ مَرَّةً أُخْرَى ‏"‏‏.‏\hadithno{2795}\hadithtrans{Narrated Anas bin Malik: The Prophet (ﷺ) said, "Nobody who dies and finds good from Allah (in the Hereafter) would wish to come back to this world even if he were given the whole world and whatever is in it, except the martyr who, on seeing the superiority of martyrdom, would like to come back to the world and get killed again (in Allah's Cause)}}
\hadithdefcmd{bukhari}{2796}{وَسَمِعْتُ أَنَسَ بْنَ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لَرَوْحَةٌ فِي سَبِيلِ اللَّهِ أَوْ غَدْوَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا، وَلَقَابُ قَوْسِ أَحَدِكُمْ مِنَ الْجَنَّةِ أَوْ مَوْضِعُ قِيدٍ ـ يَعْنِي سَوْطَهُ ـ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا، وَلَوْ أَنَّ امْرَأَةً مِنْ أَهْلِ الْجَنَّةِ اطَّلَعَتْ إِلَى أَهْلِ الأَرْضِ لأَضَاءَتْ مَا بَيْنَهُمَا وَلَمَلأَتْهُ رِيحًا، وَلَنَصِيفُهَا عَلَى رَأْسِهَا خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏‏.‏\hadithno{2796}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "A single endeavor (of fighting) in Allah's Cause in the afternoon or in the forenoon is better than all the world and whatever is in it. A place in Paradise as small as the bow or lash of one of you is better than all the world and whatever is in it. And if a houri from Paradise appeared to the people of the earth, she would fill the space between Heaven and the Earth with light and pleasant scent and her head cover is better than the world and whatever is in it}}
\hadithdefcmd{bukhari}{2797}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ أَنَّ رِجَالاً مِنَ الْمُؤْمِنِينَ لاَ تَطِيبُ أَنْفُسُهُمْ أَنْ يَتَخَلَّفُوا عَنِّي، وَلاَ أَجِدُ مَا أَحْمِلُهُمْ عَلَيْهِ، مَا تَخَلَّفْتُ عَنْ سَرِيَّةٍ تَغْزُو فِي سَبِيلِ اللَّهِ، وَالَّذِي نَفْسِي بِيَدِهِ لَوَدِدْتُ أَنِّي أُقْتَلُ فِي سَبِيلِ اللَّهِ ثُمَّ أُحْيَا، ثُمَّ أُقْتَلُ ثُمَّ أُحْيَا، ثُمَّ أُقْتَلُ ثُمَّ أُحْيَا، ثُمَّ أُقْتَلُ ‏"‏‏.‏\hadithno{2797}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "By Him in Whose Hands my life is! Were it not for some men amongst the believers who dislike to be left behind me and whom I cannot provide with means of conveyance, I would certainly never remain behind any Sariya' (army-unit) setting out in Allah's Cause. By Him in Whose Hands my life is! I would love to be martyred in Allah's Cause and then get resurrected and then get martyred, and then get resurrected again and then get martyred and then get resurrected again and then get martyred}}
\hadithdefcmd{bukhari}{2798}{حَدَّثَنَا يُوسُفُ بْنُ يَعْقُوبَ الصَّفَّارُ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ خَطَبَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَخَذَ الرَّايَةَ زَيْدٌ فَأُصِيبَ، ثُمَّ أَخَذَهَا جَعْفَرٌ فَأُصِيبَ، ثُمَّ أَخَذَهَا عَبْدُ اللَّهِ بْنُ رَوَاحَةَ فَأُصِيبَ، ثُمَّ أَخَذَهَا خَالِدُ بْنُ الْوَلِيدِ عَنْ غَيْرِ إِمْرَةٍ فَفُتِحَ لَهُ ـ وَقَالَ ـ مَا يَسُرُّنَا أَنَّهُمْ عِنْدَنَا ‏"‏‏.‏ قَالَ أَيُّوبُ أَوْ قَالَ ‏"‏ مَا يَسُرُّهُمْ أَنَّهُمْ عِنْدَنَا ‏"‏‏.‏ وَعَيْنَاهُ تَذْرِفَانِ‏.‏\hadithno{2798}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) delivered a sermon and said, "Zaid took the flag and was martyred, and then Ja`far took the flag and was martyred, and then `Abdullah bin Rawaha took the flag and was martyred too, and then Khalid bin Al-Walid took the flag though he was not appointed as a commander and Allah made him victorious." The Prophet (ﷺ) further added, "It would not please us to have them with us." Aiyub, a sub-narrator, added, "Or the Prophet, shedding tears, said, 'It would not please them to be with us}}
\hadithdefcmd{bukhari}{2799}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنِي اللَّيْثُ، حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ خَالَتِهِ أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، قَالَتْ نَامَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا قَرِيبًا مِنِّي، ثُمَّ اسْتَيْقَظَ يَتَبَسَّمُ‏.‏ فَقُلْتُ مَا أَضْحَكَكَ قَالَ ‏"‏ أُنَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ يَرْكَبُونَ هَذَا الْبَحْرَ الأَخْضَرَ، كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ قَالَتْ فَادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَدَعَا لَهَا، ثُمَّ نَامَ الثَّانِيَةَ، فَفَعَلَ مِثْلَهَا، فَقَالَتْ مِثْلَ قَوْلِهَا، فَأَجَابَهَا مِثْلَهَا‏.‏ فَقَالَتِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَقَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏‏.‏ فَخَرَجَتْ مَعَ زَوْجِهَا عُبَادَةَ بْنِ الصَّامِتِ غَازِيًا أَوَّلَ مَا رَكِبَ الْمُسْلِمُونَ الْبَحْرَ مَعَ مُعَاوِيَةَ، فَلَمَّا انْصَرَفُوا مِنْ غَزْوِهِمْ قَافِلِينَ فَنَزَلُوا الشَّأْمَ، فَقُرِّبَتْ إِلَيْهَا دَابَّةٌ لِتَرْكَبَهَا فَصَرَعَتْهَا فَمَاتَتْ‏.‏\hadithno{2799}\hadithtrans{Narrated Anas bin Malik:Um Haram said, "Once the Prophet (ﷺ) slept in my house near to me and got up smiling. I said, 'What makes you smile?' He replied, 'Some of my followers who (i.e. in a dream) were presented to me sailing on this green sea like kings on thrones.' I said, 'O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." So the Prophet (ﷺ) invoked Allah for her and went to sleep again. He did the same (i.e. got up and told his dream) and Um Haram repeated her question and he gave the same reply. She said, "Invoke Allah to make me one of them." He said, "You are among the first batch." Later on it happened that she went out in the company of her husband 'Ubada bin As-Samit who went for Jihad and it was the first time the Muslims undertook a naval expedition led by Mu'awiya. When the expedition came to an end and they were returning to Sham, a riding animal was presented to her to ride, but the animal let her fall and thus she died}}
\hadithdefcmd{bukhari}{2801}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ الْحَوْضِيُّ، حَدَّثَنَا هَمَّامٌ، عَنْ إِسْحَاقَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم أَقْوَامًا مِنْ بَنِي سُلَيْمٍ إِلَى بَنِي عَامِرٍ فِي سَبْعِينَ، فَلَمَّا قَدِمُوا، قَالَ لَهُمْ خَالِي أَتَقَدَّمُكُمْ، فَإِنْ أَمَّنُونِي حَتَّى أُبَلِّغَهُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِلاَّ كُنْتُمْ مِنِّي قَرِيبًا‏.‏ فَتَقَدَّمَ، فَأَمَّنُوهُ، فَبَيْنَمَا يُحَدِّثُهُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم إِذْ أَوْمَئُوا إِلَى رَجُلٍ مِنْهُمْ، فَطَعَنَهُ فَأَنْفَذَهُ فَقَالَ اللَّهُ أَكْبَرُ، فُزْتُ وَرَبِّ الْكَعْبَةِ‏.‏ ثُمَّ مَالُوا عَلَى بَقِيَّةِ أَصْحَابِهِ فَقَتَلُوهُمْ، إِلاَّ رَجُلاً أَعْرَجَ صَعِدَ الْجَبَلَ‏.‏ قَالَ هَمَّامٌ فَأُرَاهُ آخَرَ مَعَهُ، فَأَخْبَرَ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ النَّبِيَّ صلى الله عليه وسلم أَنَّهُمْ قَدْ لَقُوا رَبَّهُمْ، فَرَضِيَ عَنْهُمْ وَأَرْضَاهُمْ، فَكُنَّا نَقْرَأُ أَنْ بَلِّغُوا قَوْمَنَا أَنْ قَدْ لَقِينَا رَبَّنَا فَرَضِيَ عَنَّا وَأَرْضَانَا‏.‏ ثُمَّ نُسِخَ بَعْدُ، فَدَعَا عَلَيْهِمْ أَرْبَعِينَ صَبَاحًا، عَلَى رِعْلٍ وَذَكْوَانَ وَبَنِي لِحْيَانَ وَبَنِي عُصَيَّةَ الَّذِينَ عَصَوُا اللَّهَ وَرَسُولَهُ صلى الله عليه وسلم‏.‏\hadithno{2801}\hadithtrans{Narrated Anas:The Prophet (ﷺ) sent seventy men from the tribe of Bani Sulaim to the tribe of Bani Amir. When they reached there, my maternal uncle said to them, "I will go ahead of you, and if they allow me to convey the message of Allah's Messenger (ﷺ) (it will be all right); otherwise you will remain close to me." So he went ahead of them and the pagans granted him security But while he was reporting the message of the Prophet (ﷺ) , they beckoned to one of their men who stabbed him to death. My maternal uncle said, "Allah is Greater! By the Lord of the Ka`ba, I am successful." After that they attacked the rest of the party and killed them all except a lame man who went up to the top of the mountain. (Hammam, a sub-narrator said, "I think another man was saved along with him)." Gabriel informed the Prophet (ﷺ) that they (i.e the martyrs) met their Lord, and He was pleased with them and made them pleased. We used to recite, "Inform our people that we have met our Lord, He is pleased with us and He has made us pleased " Later on this Qur'anic Verse was cancelled. The Prophet (ﷺ) invoked Allah for forty days to curse the murderers from the tribe of Ral, Dhakwan, Bani Lihyan and Bani Usaiya who disobeyed Allah and his Apostle}}
\hadithdefcmd{bukhari}{2802}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدُبِ بْنِ سُفْيَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ فِي بَعْضِ الْمَشَاهِدِ وَقَدْ دَمِيَتْ إِصْبَعُهُ، فَقَالَ ‏ "‏ هَلْ أَنْتِ إِلاَّ إِصْبَعٌ دَمِيتِ، وَفِي سَبِيلِ اللَّهِ مَا لَقِيتِ ‏"‏‏.‏\hadithno{2802}\hadithtrans{Narrated Jundab bin Sufyan:In one of the holy Battles a finger of Allah's Messenger (ﷺ) (got wounded and) bled. He said, "You are just a finger that bled, and what you got is in Allah's Cause}}
\hadithdefcmd{bukhari}{2803}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يُكْلَمُ أَحَدٌ فِي سَبِيلِ اللَّهِ ـ وَاللَّهُ أَعْلَمُ بِمَنْ يُكْلَمُ فِي سَبِيلِهِ ـ إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ وَاللَّوْنُ لَوْنُ الدَّمِ وَالرِّيحُ رِيحُ الْمِسْكِ ‏"‏‏.‏\hadithno{2803}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "By Him in Whose Hands my soul is! Whoever is wounded in Allah's Cause....and Allah knows well who gets wounded in His Cause....will come on the Day of Resurrection with his wound having the color of blood but the scent of musk}}
\hadithdefcmd{bukhari}{2804}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ أَبَا سُفْيَانَ أَخْبَرَهُ أَنَّ هِرَقْلَ قَالَ لَهُ سَأَلْتُكَ كَيْفَ كَانَ قِتَالُكُمْ إِيَّاهُ فَزَعَمْتَ أَنَّ الْحَرْبَ سِجَالٌ وَدُوَلٌ، فَكَذَلِكَ الرُّسُلُ تُبْتَلَى ثُمَّ تَكُونُ لَهُمُ الْعَاقِبَةُ‏.‏\hadithno{2804}\hadithtrans{Narrated `Abdullah bin `Abbas:That Abu Sufyan told him that Heraclius said to him, "I asked you about the outcome of your battles with him (i.e. the Prophet (ﷺ) ) and you told me that you fought each other with alternate success. So the Apostles are tested in this way but the ultimate victory is always theirs}}
\hadithdefcmd{bukhari}{2806}{حَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدٍ الْخُزَاعِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ حُمَيْدٍ، قَالَ سَأَلْتُ أَنَسًا‏.‏ حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، حَدَّثَنَا زِيَادٌ، قَالَ حَدَّثَنِي حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ غَابَ عَمِّي أَنَسُ بْنُ النَّضْرِ عَنْ قِتَالِ بَدْرٍ فَقَالَ يَا رَسُولَ اللَّهِ، غِبْتُ عَنْ أَوَّلِ قِتَالٍ قَاتَلْتَ الْمُشْرِكِينَ، لَئِنِ اللَّهُ أَشْهَدَنِي قِتَالَ الْمُشْرِكِينَ لَيَرَيَنَّ اللَّهُ مَا أَصْنَعُ، فَلَمَّا كَانَ يَوْمُ أُحُدٍ وَانْكَشَفَ الْمُسْلِمُونَ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أَعْتَذِرُ إِلَيْكَ مِمَّا صَنَعَ هَؤُلاَءِ ـ يَعْنِي أَصْحَابَهُ ـ وَأَبْرَأُ إِلَيْكَ مِمَّا صَنَعَ هَؤُلاَءِ ‏"‏ ـ يَعْنِي الْمُشْرِكِينَ ـ ثُمَّ تَقَدَّمَ، فَاسْتَقْبَلَهُ سَعْدُ بْنُ مُعَاذٍ، فَقَالَ يَا سَعْدُ بْنَ مُعَاذٍ، الْجَنَّةَ، وَرَبِّ النَّضْرِ إِنِّي أَجِدُ رِيحَهَا مِنْ دُونِ أُحُدٍ‏.‏ قَالَ سَعْدٌ فَمَا اسْتَطَعْتُ يَا رَسُولَ اللَّهِ مَا صَنَعَ‏.‏ قَالَ أَنَسٌ فَوَجَدْنَا بِهِ بِضْعًا وَثَمَانِينَ ضَرْبَةً بِالسَّيْفِ أَوْ طَعْنَةً بِرُمْحٍ أَوْ رَمْيَةً بِسَهْمٍ، وَوَجَدْنَاهُ قَدْ قُتِلَ وَقَدْ مَثَّلَ بِهِ الْمُشْرِكُونَ، فَمَا عَرَفَهُ أَحَدٌ إِلاَّ أُخْتُهُ بِبَنَانِهِ‏.‏ قَالَ أَنَسٌ كُنَّا نَرَى أَوْ نَظُنُّ أَنَّ هَذِهِ الآيَةَ نَزَلَتْ فِيهِ وَفِي أَشْبَاهِهِ ‏\{‏مِنَ الْمُؤْمِنِينَ رِجَالٌ صَدَقُوا مَا عَاهَدُوا اللَّهَ عَلَيْهِ‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏ وَقَالَ إِنَّ أُخْتَهُ وَهْىَ تُسَمَّى الرُّبَيِّعَ كَسَرَتْ ثَنِيَّةَ امْرَأَةٍ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْقِصَاصِ، فَقَالَ أَنَسٌ يَا رَسُولَ اللَّهِ، وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ تُكْسَرُ ثَنِيَّتُهَا‏.‏ فَرَضُوا بِالأَرْشِ وَتَرَكُوا الْقِصَاصَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏‏.‏\hadithno{2806}\hadithtrans{Narrated Anas:My uncle Anas bin An-Nadr was absent from the Battle of Badr. He said, "O Allah's Messenger (ﷺ)! I was absent from the first battle you fought against the pagans. (By Allah) if Allah gives me a chance to fight the pagans, no doubt. Allah will see how (bravely) I will fight." On the day of Uhud when the Muslims turned their backs and fled, he said, "O Allah! I apologize to You for what these (i.e. his companions) have done, and I denounce what these (i.e. the pagans) have done." Then he advanced and Sa`d bin Mu`adh met him. He said "O Sa`d bin Mu`adh ! By the Lord of An-Nadr, Paradise! I am smelling its aroma coming from before (the mountain of) Uhud," Later on Sa`d said, "O Allah's Apostle! I cannot achieve or do what he (i.e. Anas bin An-Nadr) did. We found more than eighty wounds by swords and arrows on his body. We found him dead and his body was mutilated so badly that none except his sister could recognize him by his fingers." We used to think that the following Verse was revealed concerning him and other men of his sort: "Among the believers are men who have been true to their covenant with Allah.........." (33.23) His sister Ar-Rubbaya' broke a front tooth of a woman and Allah's Messenger (ﷺ) ordered for retaliation. On that Anas (bin An-Nadr) said, "O Allah's Messenger (ﷺ)! By Him Who has sent you with the Truth, my sister's tooth shall not be broken." Then the opponents of Anas's sister accepted the compensation and gave up the claim of retaliation. So Allah's Messenger (ﷺ) said, "There are some people amongst Allah's slaves whose oaths are fulfilled by Allah when they take them}}
\hadithdefcmd{bukhari}{2807}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي إِسْمَاعِيلُ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، أُرَاهُ عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، عَنِ ابْنِ شِهَابٍ، عَنْ خَارِجَةَ بْنِ زَيْدٍ، أَنَّ زَيْدَ بْنَ ثَابِتٍ ـ رضى الله عنه ـ قَالَ نَسَخْتُ الصُّحُفَ فِي الْمَصَاحِفِ، فَفَقَدْتُ آيَةً مِنْ سُورَةِ الأَحْزَابِ، كُنْتُ أَسْمَعُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهَا، فَلَمْ أَجِدْهَا إِلاَّ مَعَ خُزَيْمَةَ بْنِ ثَابِتٍ الأَنْصَارِيِّ الَّذِي جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهَادَتَهُ شَهَادَةَ رَجُلَيْنِ، وَهْوَ قَوْلُهُ ‏\{‏مِنَ الْمُؤْمِنِينَ رِجَالٌ صَدَقُوا مَا عَاهَدُوا اللَّهَ عَلَيْهِ‏\}‏\hadithno{2807}\hadithtrans{Narrated Kharija bin Zaid:Zaid bin Thabit said, "When the Qur'an was compiled from various written manuscripts, one of the Verses of Surat Al-Ahzab was missing which I used to hear Allah's Messenger (ﷺ) reciting. I could not find it except with Khuza`ima bin Thabit Al-Ansari, whose witness Allah's Messenger (ﷺ) regarded as equal to the witness of two men. And the Verse was:-- "Among the believers are men who have been true to what they covenanted with Allah}}
\hadithdefcmd{bukhari}{2808}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ الْفَزَارِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ يَقُولُ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ مُقَنَّعٌ بِالْحَدِيدِ فَقَالَ يَا رَسُولَ اللَّهِ أُقَاتِلُ وَأُسْلِمُ‏.‏ قَالَ ‏"‏ أَسْلِمْ ثُمَّ قَاتِلْ ‏"‏‏.‏ فَأَسْلَمَ ثُمَّ قَاتَلَ، فَقُتِلَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَمِلَ قَلِيلاً وَأُجِرَ كَثِيرًا ‏"‏‏.‏\hadithno{2808}\hadithtrans{Narrated Al-Bara:A man whose face was covered with an iron mask (i.e. clad in armor) came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! Shall I fight or embrace Islam first? "The Prophet (ﷺ) said, "Embrace Islam first and then fight." So he embraced Islam, and was martyred. Allah's Messenger (ﷺ) said, A Little work, but a great reward. "(He did very little (after embracing Islam), but he will be rewarded in abundance}}
\hadithdefcmd{bukhari}{2809}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ أَبُو أَحْمَدَ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ أُمَّ الرُّبَيِّعِ بِنْتَ الْبَرَاءِ، وَهْىَ أُمُّ حَارِثَةَ بْنِ سُرَاقَةَ أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا نَبِيَّ اللَّهِ، أَلاَ تُحَدِّثُنِي عَنْ حَارِثَةَ وَكَانَ قُتِلَ يَوْمَ بَدْرٍ أَصَابَهُ سَهْمٌ غَرْبٌ، فَإِنْ كَانَ فِي الْجَنَّةِ، صَبَرْتُ، وَإِنْ كَانَ غَيْرَ ذَلِكَ اجْتَهَدْتُ عَلَيْهِ فِي الْبُكَاءِ‏.‏ قَالَ ‏ "‏ يَا أُمَّ حَارِثَةَ، إِنَّهَا جِنَانٌ فِي الْجَنَّةِ، وَإِنَّ ابْنَكِ أَصَابَ الْفِرْدَوْسَ الأَعْلَى ‏"‏‏.‏\hadithno{2809}\hadithtrans{Narrated Anas bin Malik:Um Ar-Rubai' bint Al-Bara', the mother of Haritha bin Suraqa came to the Prophet (ﷺ) and said, "O Allah's Prophet! Will you tell me about Haritha?" Haritha had been killed (i.e. martyred) on the day of Badr with an arrow thrown by an unidentified person. She added, "If he is in Paradise, I will be patient; otherwise, I will weep bitterly for him." He said, "O mother of Haritha! There are Gardens in Paradise and your son got the Firdaus al-ala (i.e. the best place in Paradise)}}
\hadithdefcmd{bukhari}{2810}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ الرَّجُلُ يُقَاتِلُ لِلْمَغْنَمِ، وَالرَّجُلُ يُقَاتِلُ لِلذِّكْرِ، وَالرَّجُلُ يُقَاتِلُ لِيُرَى مَكَانُهُ، فَمَنْ فِي سَبِيلِ اللَّهِ قَالَ ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا فَهُوَ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{2810}\hadithtrans{Narrated Abu Musa:A man came to the Prophet (ﷺ) and asked, "A man fights for war booty; another fights for fame and a third fights for showing off; which of them fights in Allah's Cause?" The Prophet (ﷺ) said, "He who fights that Allah's Word (i.e. Islam) should be superior, fights in Allah's Cause}}
\hadithdefcmd{bukhari}{2811}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا عَبَايَةُ بْنُ رَافِعِ بْنِ خَدِيجٍ، قَالَ أَخْبَرَنِي أَبُو عَبْسٍ، هُوَ عَبْدُ الرَّحْمَنِ بْنُ جَبْرٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا اغْبَرَّتْ قَدَمَا عَبْدٍ فِي سَبِيلِ اللَّهِ فَتَمَسَّهُ النَّارُ ‏"‏‏.‏\hadithno{2811}\hadithtrans{Narrated Abu `Abs:(who is `Abdur-Rahman bin Jabir) Allah's Messenger (ﷺ) said," Anyone whose both feet get covered with dust in Allah's Cause will not be touched by the (Hell) fire}}
\hadithdefcmd{bukhari}{2812}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، أَنَّ ابْنَ عَبَّاسٍ، قَالَ لَهُ وَلِعَلِيِّ بْنِ عَبْدِ اللَّهِ ائْتِيَا أَبَا سَعِيدٍ فَاسْمَعَا مِنْ حَدِيثِهِ‏.‏ فَأَتَيْنَاهُ وَهُوَ وَأَخُوهُ فِي حَائِطٍ لَهُمَا يَسْقِيَانِهِ، فَلَمَّا رَآنَا جَاءَ فَاحْتَبَى وَجَلَسَ فَقَالَ كُنَّا نَنْقُلُ لَبِنَ الْمَسْجِدِ لَبِنَةً لَبِنَةً، وَكَانَ عَمَّارٌ يَنْقُلُ لَبِنَتَيْنِ لَبِنَتَيْنِ، فَمَرَّ بِهِ النَّبِيُّ صلى الله عليه وسلم وَمَسَحَ عَنْ رَأْسِهِ الْغُبَارَ وَقَالَ ‏ "‏ وَيْحَ عَمَّارٍ، تَقْتُلُهُ الْفِئَةُ الْبَاغِيَةُ، عَمَّارٌ يَدْعُوهُمْ إِلَى اللَّهِ وَيَدْعُونَهُ إِلَى النَّارِ ‏"‏‏.‏\hadithno{2812}\hadithtrans{Narrated `Ikrima:that Ibn `Abbas told him and `Ali bin `Abdullah to go to Abu Sa`id and listen to some of his narrations; So they both went (and saw) Abu Sa`id and his brother irrigating a garden belonging to them. When he saw them, he came up to them and sat down with his legs drawn up and wrapped in his garment and said, "(During the construction of the mosque of the Prophet) we carried the adobe of the mosque, one brick at a time while `Ammar used to carry two at a time. The Prophet (ﷺ) passed by `Ammar and removed the dust off his head and said, "May Allah be merciful to `Ammar. He will be killed by a rebellious aggressive group. `Ammar will invite them to (obey) Allah and they will invite him to the (Hell) fire}}
\hadithdefcmd{bukhari}{2813}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا رَجَعَ يَوْمَ الْخَنْدَقِ وَوَضَعَ السِّلاَحَ وَاغْتَسَلَ، فَأَتَاهُ جِبْرِيلُ وَقَدْ عَصَبَ رَأْسَهُ الْغُبَارُ فَقَالَ وَضَعْتَ السِّلاَحَ، فَوَاللَّهِ مَا وَضَعْتُهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَأَيْنَ ‏"‏‏.‏ قَالَ هَا هُنَا‏.‏ وَأَوْمَأَ إِلَى بَنِي قُرَيْظَةَ‏.‏ قَالَتْ فَخَرَجَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2813}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) returned on the day (of the battle) of Al-Khandaq (i.e. Trench), he put down his arms and took a bath. Then Gabriel whose head was covered with dust, came to him saying, "You have put down your arms! By Allah, I have not put down my arms yet." Allah's Messenger (ﷺ) said, "Where (to go now)?" Gabriel said, "This way," pointing towards the tribe of Bani Quraiza. So Allah's Messenger (ﷺ) went out towards them}}
\hadithdefcmd{bukhari}{2814}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الَّذِينَ قَتَلُوا أَصْحَابَ بِئْرِ مَعُونَةَ ثَلاَثِينَ غَدَاةً، عَلَى رِعْلٍ وَذَكْوَانَ وَعُصَيَّةَ عَصَتِ اللَّهَ وَرَسُولَهُ، قَالَ أَنَسٌ أُنْزِلَ فِي الَّذِينَ قُتِلُوا بِبِئْرِ مَعُونَةَ قُرْآنٌ قَرَأْنَاهُ ثُمَّ نُسِخَ بَعْدُ بَلِّغُوا قَوْمَنَا أَنْ قَدْ لَقِينَا رَبَّنَا فَرَضِيَ عَنَّا وَرَضِينَا عَنْهُ‏.‏\hadithno{2814}\hadithtrans{Narrated Anas bin Malik:For thirty days Allah's Messenger (ﷺ) invoked Allah to curse those who had killed the companions of Bir- Mauna; he invoked evil upon the tribes of Ral, Dhakwan, and Usaiya who disobeyed Allah and His Apostle. There was revealed about those who were killed at Bir-Mauna a Qur'anic Verse we used to recite, but it was cancelled later on. The Verse was: "Inform our people that we have met our Lord. He is pleased with us and He has made us pleased}}
\hadithdefcmd{bukhari}{2815}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ اصْطَبَحَ نَاسٌ الْخَمْرَ يَوْمَ أُحُدٍ، ثُمَّ قُتِلُوا شُهَدَاءَ‏.‏ فَقِيلَ لِسُفْيَانَ مِنْ آخِرِ ذَلِكَ الْيَوْمِ قَالَ لَيْسَ هَذَا فِيهِ‏.‏\hadithno{2815}\hadithtrans{Narrated Jabir bin `Abdullah:"Some people drank alcohol in the morning of the day (of the battle) of Uhud and were martyred (on the same day)." Sufyan was asked, "(Were they martyred) in the last part of the day?)" He replied, "Such information does not occur in the narration}}
\hadithdefcmd{bukhari}{2816}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، قَالَ أَخْبَرَنَا ابْنُ عُيَيْنَةَ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ جِيءَ بِأَبِي إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ مُثِّلَ بِهِ وَوُضِعَ بَيْنَ يَدَيْهِ، فَذَهَبْتُ أَكْشِفُ عَنْ وَجْهِهِ، فَنَهَانِي قَوْمِي، فَسَمِعَ صَوْتَ صَائِحَةٍ فَقِيلَ ابْنَةُ عَمْرٍو، أَوْ أُخْتُ عَمْرٍو‏.‏ فَقَالَ ‏ "‏ لِمَ تَبْكِي أَوْ لاَ تَبْكِي، مَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا ‏"‏‏.‏ قُلْتُ لِصَدَقَةَ أَفِيهِ حَتَّى رُفِعَ قَالَ رُبَّمَا قَالَهُ‏.‏\hadithno{2816}\hadithtrans{Narrated Jabir:My father's mutilated body was brought to the Prophet (ﷺ) and was placed in front of him. I went to uncover his face but my companions forbade me. Then mourning cries of a lady were heard, and it was said that she was either the daughter or the sister of `Amr. The Prophet (ﷺ) said, "Why is she crying?" Or said, "Do not cry, for the angels are still shading him with their wings." (Al-Bukhari asked Sadaqa, a sub-narrator, "Does the narration include the expression: 'Till he was lifted?' " The latter replied, "Jabir may have said it)}}
\hadithdefcmd{bukhari}{2817}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَحَدٌ يَدْخُلُ الْجَنَّةَ يُحِبُّ أَنْ يَرْجِعَ إِلَى الدُّنْيَا وَلَهُ مَا عَلَى الأَرْضِ مِنْ شَىْءٍ، إِلاَّ الشَّهِيدُ، يَتَمَنَّى أَنْ يَرْجِعَ إِلَى الدُّنْيَا فَيُقْتَلَ عَشْرَ مَرَّاتٍ، لِمَا يَرَى مِنَ الْكَرَامَةِ ‏"‏‏.‏\hadithno{2817}\hadithtrans{Narrated Anas bin Malik: The Prophet (ﷺ) said, "Nobody who enters Paradise likes to go back to the world even if he got everything on the earth, except a Mujahid who wishes to return to the world so that he may be martyred ten times because of the dignity he receives (from Allah)}}
\hadithdefcmd{bukhari}{2818}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ وَكَانَ كَاتِبَهُ قَالَ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَاعْلَمُوا أَنَّ الْجَنَّةَ تَحْتَ ظِلاَلِ السُّيُوفِ ‏"‏‏.‏ تَابَعَهُ الأُوَيْسِيُّ عَنِ ابْنِ أَبِي الزِّنَادِ عَنْ مُوسَى بْنِ عُقْبَةَ‏.‏\hadithno{2818}\hadithtrans{Narrated `Abdullah bin Abi `Aufa:Allah's Messenger (ﷺ) said, "Know that Paradise is under the shades of swords}}
\hadithdefcmd{bukhari}{2819}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ ـ عَلَيْهِمَا السَّلاَمُ ـ لأَطُوفَنَّ اللَّيْلَةَ عَلَى مِائَةِ امْرَأَةٍ ـ أَوْ تِسْعٍ وَتِسْعِينَ ـ كُلُّهُنَّ يَأْتِي بِفَارِسٍ يُجَاهِدُ فِي سَبِيلِ اللَّهِ، فَقَالَ لَهُ صَاحِبُهُ إِنْ شَاءَ اللَّهُ‏.‏ فَلَمْ يَقُلْ إِنْ شَاءَ اللَّهُ‏.‏ فَلَمْ يَحْمِلْ مِنْهُنَّ إِلاَّ امْرَأَةٌ وَاحِدَةٌ، جَاءَتْ بِشِقِّ رَجُلٍ، وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ، لَوْ قَالَ إِنْ شَاءَ اللَّهُ، لَجَاهَدُوا فِي سَبِيلِ اللَّهِ فُرْسَانًا أَجْمَعُونَ ‏"‏‏.‏\hadithno{2819}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "Once Solomon, son of David said, '(By Allah) Tonight I will have sexual intercourse with one hundred (or ninety-nine) women each of whom will give birth to a knight who will fight in Allah's Cause.' On that, a companion (angel) said to him, "(Say) Allah willing", but he did not say, "Allah willing." Therefore only one of those women conceived and gave birth to a half-man. By Him in Whose Hands Muhammad's life is, if he had said, "Allah willing', (he would have begotten sons) all of whom would have been knights striving in Allah's Cause}}
\hadithdefcmd{bukhari}{2820}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الْمَلِكِ بْنِ وَاقِدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، رضى الله عنه قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم أَحْسَنَ النَّاسِ وَأَشْجَعَ النَّاسِ وَأَجْوَدَ النَّاسِ، وَلَقَدْ فَزِعَ أَهْلُ الْمَدِينَةِ، فَكَانَ النَّبِيُّ صلى الله عليه وسلم سَبَقَهُمْ عَلَى فَرَسٍ، وَقَالَ ‏ "‏ وَجَدْنَاهُ بَحْرًا ‏"‏‏.‏\hadithno{2820}\hadithtrans{Narrated Anas:The Prophet (ﷺ) was the best, the bravest and the most generous of all the people. Once when the people of Medina got frightened, the Prophet (ﷺ) rode a horse and went ahead of them and said, "We found this horse very fast}}
\hadithdefcmd{bukhari}{2821}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُمَرُ بْنُ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ مُحَمَّدَ بْنَ جُبَيْرٍ، قَالَ أَخْبَرَنِي جُبَيْرُ بْنُ مُطْعِمٍ، أَنَّهُ بَيْنَمَا هُوَ يَسِيرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَهُ النَّاسُ، مَقْفَلَهُ مِنْ حُنَيْنٍ، فَعَلِقَهُ النَّاسُ يَسْأَلُونَهُ حَتَّى اضْطَرُّوهُ إِلَى سَمُرَةٍ فَخَطِفَتْ رِدَاءَهُ، فَوَقَفَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَعْطُونِي رِدَائِي، لَوْ كَانَ لِي عَدَدُ هَذِهِ الْعِضَاهِ نَعَمًا لَقَسَمْتُهُ بَيْنَكُمْ، ثُمَّ لاَ تَجِدُونِي بَخِيلاً وَلاَ كَذُوبًا وَلاَ جَبَانًا ‏"‏‏.‏\hadithno{2821}\hadithtrans{Narrated Muhammad bin Jubair:Jubair bin Mut`im told me that while he was in the company of Allah's Messenger (ﷺ) with the people returning from Hunain, some people (bedouins) caught hold of the Prophet (ﷺ) and started begging of him so much so that he had to stand under a (kind of thorny tree (i.e. Samurah) and his cloak was snatched away. The Prophet (ﷺ) stopped and said, "Give me my cloak. If I had as many camels as these thorny trees, I would have distributed them amongst you and you will not find me a miser or a liar or a coward}}
\hadithdefcmd{bukhari}{2822}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، سَمِعْتُ عَمْرَو بْنَ مَيْمُونٍ الأَوْدِيَّ، قَالَ كَانَ سَعْدٌ يُعَلِّمُ بَنِيهِ هَؤُلاَءِ الْكَلِمَاتِ كَمَا يُعَلِّمُ الْمُعَلِّمُ الْغِلْمَانَ الْكِتَابَةَ، وَيَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ مِنْهُنَّ دُبُرَ الصَّلاَةِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُبْنِ، وَأَعُوذُ بِكَ أَنْ أُرَدَّ إِلَى أَرْذَلِ الْعُمُرِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا، وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏‏.‏ فَحَدَّثْتُ بِهِ مُصْعَبًا فَصَدَّقَهُ‏.‏\hadithno{2822}\hadithtrans{Narrated `Amr bin Maimun Al-Audi:Sa`d used to teach his sons the following words as a teacher teaches his students the skill of writing and used to say that Allah's Messenger (ﷺ) used to seek Refuge with Allah from them (i.e. the evils) at the end of every prayer. The words are: 'O Allah! I seek refuge with You from cowardice, and seek refuge with You from being brought back to a bad stage of old life and seek refuge with You from the afflictions of the world, and seek refuge with You from the punishments in the grave}}
\hadithdefcmd{bukhari}{2823}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْجُبْنِ وَالْهَرَمِ، وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ، وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ ‏"‏‏.‏\hadithno{2823}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) used to say, "O Allah! I seek refuge with You from helplessness, laziness, cowardice and feeble old age; I seek refuge with You from afflictions of life and death and seek refuge with You from the punishment in the grave}}
\hadithdefcmd{bukhari}{2824}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ صَحِبْتُ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ وَسَعْدًا وَالْمِقْدَادَ بْنَ الأَسْوَدِ وَعَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ ـ رضى الله عنهم ـ فَمَا سَمِعْتُ أَحَدًا، مِنْهُمْ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم، إِلاَّ أَنِّي سَمِعْتُ طَلْحَةَ يُحَدِّثُ عَنْ يَوْمِ أُحُدٍ‏.‏\hadithno{2824}\hadithtrans{Narrated As-Sa'-ib bin Yazid:I was in the company of Talha bin 'Ubaidullah, Sa`d, Al-Miqdad bin Al-Aswad and `Abdur Rahman bin `Auf and I heard none of them narrating anything from Allah's Messenger (ﷺ) but Talha was talking about the day (of the battle) of Uhud}}
\hadithdefcmd{bukhari}{2825}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ يَوْمَ الْفَتْحِ ‏ "‏ لاَ هِجْرَةَ بَعْدَ الْفَتْحِ وَلَكِنْ جِهَادٌ وَنِيَّةٌ، وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏‏.‏\hadithno{2825}\hadithtrans{Narrated Ibn `Abbas:On the day of the Conquest (of Mecca) the Prophet (ﷺ) said, "There is no emigration after the Conquest but Jihad and intentions. When you are called (by the Muslim ruler) for fighting, go forth immediately." (See Hadith No)}}
\hadithdefcmd{bukhari}{2826}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَضْحَكُ اللَّهُ إِلَى رَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا الآخَرَ يَدْخُلاَنِ الْجَنَّةَ، يُقَاتِلُ هَذَا فِي سَبِيلِ اللَّهِ فَيُقْتَلُ، ثُمَّ يَتُوبُ اللَّهُ عَلَى الْقَاتِلِ فَيُسْتَشْهَدُ ‏"‏‏.‏\hadithno{2826}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "Allah welcomes two men with a smile; one of whom kills the other and both of them enter Paradise. One fights in Allah's Cause and gets killed. Later on Allah forgives the killer who also gets martyred (in Allah's Cause)}}
\hadithdefcmd{bukhari}{2827}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي عَنْبَسَةُ بْنُ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ بِخَيْبَرَ بَعْدَ مَا افْتَتَحُوهَا، فَقُلْتُ يَا رَسُولَ اللَّهِ أَسْهِمْ لِي‏.‏ فَقَالَ بَعْضُ بَنِي سَعِيدِ بْنِ الْعَاصِ لاَ تُسْهِمْ لَهُ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ هَذَا قَاتِلُ ابْنِ قَوْقَلٍ‏.‏ فَقَالَ ابْنُ سَعِيدِ بْنِ الْعَاصِ وَاعَجَبًا لِوَبْرٍ تَدَلَّى عَلَيْنَا مِنْ قَدُومِ ضَأْنٍ، يَنْعَى عَلَىَّ قَتْلَ رَجُلٍ مُسْلِمٍ أَكْرَمَهُ اللَّهُ عَلَى يَدَىَّ وَلَمْ يُهِنِّي عَلَى يَدَيْهِ‏.‏ قَالَ فَلاَ أَدْرِي أَسْهَمَ لَهُ أَمْ لَمْ يُسْهِمْ لَهُ‏.‏ قَالَ سُفْيَانُ وَحَدَّثَنِيهِ السَّعِيدِيُّ عَنْ جَدِّهِ عَنْ أَبِي هُرَيْرَةَ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ السَّعِيدِيُّ عَمْرُو بْنُ يَحْيَى بْنِ سَعِيدِ بْنِ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِ‏.‏\hadithno{2827}\hadithtrans{Narrated Abu Huraira: I went to Allah's Messenger (ﷺ) while he was at Khaibar after it had fallen in the Muslims' hands. I said, "O Allah's Messenger (ﷺ)! Give me a share (from the land of Khaibar)." One of the sons of Sa'id bin Al-'As said, "O Allah's Messenger (ﷺ)! Do not give him a share." I said, "This is the murderer of Ibn Qauqal." The son of Sa`id bin Al-As said, "Strange! A Wabr (i.e. guinea pig) who has come down to us from the mountain of Qadum (i.e. grazing place of sheep) blames me for killing a Muslim who was given superiority by Allah because of me, and Allah did not disgrace me at his hands (i.e. was not killed as an infidel)." (The sub-narrator said "I do not know whether the Prophet (ﷺ) gave him a share or not}}
\hadithdefcmd{bukhari}{2828}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ أَبُو طَلْحَةَ لاَ يَصُومُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم مِنْ أَجْلِ الْغَزْوِ، فَلَمَّا قُبِضَ النَّبِيُّ صلى الله عليه وسلم لَمْ أَرَهُ مُفْطِرًا، إِلاَّ يَوْمَ فِطْرٍ أَوْ أَضْحَى‏.‏\hadithno{2828}\hadithtrans{Narrated Anas bin Malik:In the life-time of the Prophet, Abu Talha did not fast because of the Jihad, but after the Prophet (ﷺ) died I never saw him without fasting except on `Id-ul-Fitr and `Id-ul-Adha}}
\hadithdefcmd{bukhari}{2829}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّهَدَاءُ خَمْسَةٌ الْمَطْعُونُ، وَالْمَبْطُونُ، وَالْغَرِقُ وَصَاحِبُ الْهَدْمِ، وَالشَّهِيدُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{2829}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Five are regarded as martyrs: They are those who die because of plague, Abdominal disease, drowning or a falling building etc., and the martyrs in Allah's Cause}}
\hadithdefcmd{bukhari}{2830}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عَاصِمٌ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الطَّاعُونُ شَهَادَةٌ لِكُلِّ مُسْلِمٍ ‏"‏‏.‏\hadithno{2830}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Plague is the cause of martyrdom of every Muslim (who dies because of it)}}
\hadithdefcmd{bukhari}{2831}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ يَقُولُ لَمَّا نَزَلَتْ ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ‏\}‏ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدًا، فَجَاءَ بِكَتِفٍ فَكَتَبَهَا، وَشَكَا ابْنُ أُمِّ مَكْتُومٍ ضَرَارَتَهُ فَنَزَلَتْ ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ غَيْرُ أُولِي الضَّرَرِ ‏\}‏‏.‏\hadithno{2831}\hadithtrans{Narrated Al-Bara:When the Divine Inspiration: "Those of the believers who sit (at home), was revealed the Prophet (ﷺ) sent for Zaid (bin Thabit) who came with a shoulder-blade and wrote on it. Ibn Um-Maktum complained about his blindness and on that the following revelation came: "Not equal are those believers who sit (at home) except those who are disabled (by injury, or are blind or lame etc.) and those who strive hard and fight in the Way of Allah with their wealth and lives}}
\hadithdefcmd{bukhari}{2832}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ الزُّهْرِيُّ، قَالَ حَدَّثَنِي صَالِحُ بْنُ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّهُ قَالَ رَأَيْتُ مَرْوَانَ بْنَ الْحَكَمِ جَالِسًا فِي الْمَسْجِدِ، فَأَقْبَلْتُ حَتَّى جَلَسْتُ إِلَى جَنْبِهِ، فَأَخْبَرَنَا أَنَّ زَيْدَ بْنَ ثَابِتٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمْلَى عَلَيْهِ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ قَالَ فَجَاءَهُ ابْنُ أُمِّ مَكْتُومٍ وَهُوَ يُمِلُّهَا عَلَىَّ، فَقَالَ يَا رَسُولَ اللَّهِ، لَوْ أَسْتَطِيعُ الْجِهَادَ لَجَاهَدْتُ‏.‏ وَكَانَ رَجُلاً أَعْمَى، فَأَنْزَلَ اللَّهُ تَبَارَكَ وَتَعَالَى عَلَى رَسُولِهِ صلى الله عليه وسلم وَفَخِذُهُ عَلَى فَخِذِي، فَثَقُلَتْ عَلَىَّ حَتَّى خِفْتُ أَنْ تَرُضَّ فَخِذِي، ثُمَّ سُرِّيَ عَنْهُ، فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏غَيْرُ أُولِي الضَّرَرِ‏\}‏‏.‏\hadithno{2832}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:I saw Marwan bin Al-Hakam sitting in the Mosque. So I came forward and sat by his side. He told us that Zaid bin Thabit had told him that Allah's Messenger (ﷺ) had dictated to him the Divine Verse: "Not equal are those believers who sit (at home) and those who strive hard and fight in the Cause of Allah with their wealth and lives.' (4.95) Zaid said, "Ibn Um-Maktum came to the Prophet (ﷺ) while he was dictating to me that very Verse. On that Ibn Um Maktum said, "O Allah's Messenger (ﷺ)! If I had power, I would surely take part in Jihad." He was a blind man. So Allah sent down revelation to His Apostle while his thigh was on mine and it became so heavy for me that I feared that my thigh would be broken. Then that state of the Prophet (ﷺ) was over after Allah revealed "...except those who are disabled (by injury or are blind or lame etc)}}
\hadithdefcmd{bukhari}{2833}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، أَنَّ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، كَتَبَ فَقَرَأْتُهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا ‏"‏‏.‏\hadithno{2833}\hadithtrans{Narrated Salim Abu-An-Nadr:`Abdullah bin Abi `Aufa wrote and I read what he wrote that Allah's Messenger (ﷺ) said, "When you face them ( i.e. your enemy) then be patient}}
\hadithdefcmd{bukhari}{2834}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْخَنْدَقِ فَإِذَا الْمُهَاجِرُونَ وَالأَنْصَارُ يَحْفِرُونَ فِي غَدَاةٍ بَارِدَةٍ، فَلَمْ يَكُنْ لَهُمْ عَبِيدٌ يَعْمَلُونَ ذَلِكَ لَهُمْ، فَلَمَّا رَأَى مَا بِهِمْ مِنَ النَّصَبِ وَالْجُوعِ قَالَ اللَّهُمَّ إِنَّ الْعَيْشَ عَيْشُ الآخِرَهْ فَاغْفِرْ لِلأَنْصَارِ وَالْمُهَاجِرَهْ‏.‏ فَقَالُوا مُجِيبِينَ لَهُ نَحْنُ الَّذِينَ بَايَعُوا مُحَمَّدًا عَلَى الْجِهَادِ مَا بَقِينَا أَبَدًا\hadithno{2834}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) went towards the Khandaq (i.e. Trench) and saw the Emigrants and the Ansar digging in a very cold morning as they did not have slaves to do that for them. When he noticed their fatigue and hunger he said, "O Allah! The real life is that of the Here-after, (so please) forgive the Ansar and the Emigrants." In its reply the Emigrants and the Ansar said, "We are those who have given a pledge of allegiance to Muhammad that we will carry on Jihad as long as we live}}
\hadithdefcmd{bukhari}{2835}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ جَعَلَ الْمُهَاجِرُونَ وَالأَنْصَارُ يَحْفِرُونَ الْخَنْدَقَ حَوْلَ الْمَدِينَةِ، وَيَنْقُلُونَ التُّرَابَ عَلَى مُتُونِهِمْ وَيَقُولُونَ نَحْنُ الَّذِينَ بَايَعُوا مُحَمَّدًا عَلَى الإِسْلاَمِ مَا بَقِينَا أَبَدًا وَالنَّبِيُّ صلى الله عليه وسلم يُجِيبُهُمْ وَيَقُولُ اللَّهُمَّ إِنَّهُ لاَ خَيْرَ إِلاَّ خَيْرُ الآخِرَهْ فَبَارِكْ فِي الأَنْصَارِ وَالْمُهَاجِرَهْ‏.‏\hadithno{2835}\hadithtrans{Narrated Anas:The Emigrants and the Ansar started digging the trench around Medina carrying the earth on their backs and saying, "We are those who have given a pledge of allegiance to Muhammad that we will carry on Jihad as long as we live." The Prophet (ﷺ) kept on replying, "O Allah, there is no good except the good of the Hereafter; so confer Your Blessings on the Ansar and the Emigrants}}
\hadithdefcmd{bukhari}{2836}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ كَانَ النَّبِيُّ صلى الله عليه وسلم يَنْقُلُ وَيَقُولُ ‏ "‏ لَوْلاَ أَنْتَ مَا اهْتَدَيْنَا ‏"‏‏.‏\hadithno{2836}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) went on carrying (i.e. the earth) and saying, "Without You (O Allah!) we would have got no guidance}}
\hadithdefcmd{bukhari}{2837}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَحْزَابِ يَنْقُلُ التُّرَابَ وَقَدْ وَارَى التُّرَابُ بَيَاضَ بَطْنِهِ، وَهُوَ يَقُولُ لَوْلاَ أَنْتَ مَا اهْتَدَيْنَا وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا‏.‏ فَأَنْزِلِ السَّكِينَةَ عَلَيْنَا وَثَبِّتِ الأَقْدَامَ إِنْ لاَقَيْنَا‏.‏ إِنَّ الأُلَى قَدْ بَغَوْا عَلَيْنَا إِذَا أَرَادُوا فِتْنَةً أَبَيْنَا‏.‏\hadithno{2837}\hadithtrans{Narrated Al-Bara:On the day (of the battle) of Al-Ahzab (i.e. clans) I saw the Prophet (ﷺ) carrying earth, and the earth was covering the whiteness of his `Abdomen. And he was saying, "Without You (O Allah!) we would have got no guidance, nor given in charity, nor prayed. So please bless us with tranquility and make firm our feet when we meet our enemies. Indeed (these) people have rebelled against (oppressed) us but never shall we yield if they try to bring affliction upon us}}
\hadithdefcmd{bukhari}{2838}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا حُمَيْدٌ، أَنَّ أَنَسًا، حَدَّثَهُمْ قَالَ رَجَعْنَا مِنْ غَزْوَةِ تَبُوكَ مَعَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2838}\hadithtrans{Narrated Anas:We returned from the Ghazwa of Tabuk along with the Prophet. (See Hadith No. 92 below)}}
\hadithdefcmd{bukhari}{2839}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ ـ هُوَ ابْنُ زَيْدٍ ـ عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي غَزَاةٍ فَقَالَ ‏ "‏ إِنَّ أَقْوَامًا بِالْمَدِينَةِ خَلْفَنَا، مَا سَلَكْنَا شِعْبًا وَلاَ وَادِيًا إِلاَّ وَهُمْ مَعَنَا فِيهِ، حَبَسَهُمُ الْعُذْرُ ‏"‏‏.‏ وَقَالَ مُوسَى حَدَّثَنَا حَمَّادٌ، عَنْ حُمَيْدٍ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَبِيهِ، قَالَ النَّبِيُّ صلى الله عليه وسلم‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ الأَوَّلُ أَصَحُّ‏.‏\hadithno{2839}\hadithtrans{Narrated Anas:While the Prophet (ﷺ) was in a Ghazwa he said, "Some people have remained behind us in Medina and we never crossed a mountain path or a valley, but they were with us (i.e. sharing the reward with us), as they have been held back by a (legal) excuse}}
\hadithdefcmd{bukhari}{2840}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ سَعِيدٍ، وَسُهَيْلُ بْنُ أَبِي صَالِحٍ، أَنَّهُمَا سَمِعَا النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ بَعَّدَ اللَّهُ وَجْهَهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏‏.‏\hadithno{2840}\hadithtrans{Narrated Abu Sa`id:I heard the Prophet (ﷺ) saying, "Indeed, anyone who fasts for one day for Allah's Pleasure, Allah will keep his face away from the (Hell) fire for (a distance covered by a journey of) seventy years}}
\hadithdefcmd{bukhari}{2841}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ دَعَاهُ خَزَنَةُ الْجَنَّةِ، كُلُّ خَزَنَةِ باب أَىْ فُلُ هَلُمَّ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ، ذَاكَ الَّذِي لاَ تَوَى عَلَيْهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي لأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏‏.‏\hadithno{2841}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever spends two things in Allah's Cause, will be called by all the gate-keepers of Paradise who will be saying, 'O so-and-so! Come here.' " Abu Bakr said, "O Allah's Messenger (ﷺ)! Such persons will never be destroyed." The Prophet (ﷺ) said, "I hope you will be one of them}}
\hadithdefcmd{bukhari}{2842}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا هِلاَلٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ إِنَّمَا أَخْشَى عَلَيْكُمْ مِنْ بَعْدِي مَا يُفْتَحُ عَلَيْكُمْ مِنْ بَرَكَاتِ الأَرْضِ ‏"‏‏.‏ ثُمَّ ذَكَرَ زَهْرَةَ الدُّنْيَا، فَبَدَأَ بِإِحْدَاهُمَا وَثَنَّى بِالأُخْرَى، فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَوَيَأْتِي الْخَيْرُ بِالشَّرِّ فَسَكَتَ عَنْهُ النَّبِيُّ صلى الله عليه وسلم قُلْنَا يُوحَى إِلَيْهِ‏.‏ وَسَكَتَ النَّاسُ كَأَنَّ عَلَى رُءُوسِهِمِ الطَّيْرَ، ثُمَّ إِنَّهُ مَسَحَ عَنْ وَجْهِهِ الرُّحَضَاءَ، فَقَالَ ‏"‏ أَيْنَ السَّائِلُ آنِفًا أَوَخَيْرٌ هُوَ ـ ثَلاَثًا ـ إِنَّ الْخَيْرَ لاَ يَأْتِي إِلاَّ بِالْخَيْرِ، وَإِنَّهُ كُلُّ مَا يُنْبِتُ الرَّبِيعُ مَا يَقْتُلُ حَبَطًا أَوْ يُلِمُّ كُلَّمَا أَكَلَتْ، حَتَّى إِذَا امْتَلأَتْ خَاصِرَتَاهَا اسْتَقْبَلَتِ الشَّمْسَ، فَثَلَطَتْ وَبَالَتْ ثُمَّ رَتَعَتْ، وَإِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ، وَنِعْمَ صَاحِبُ الْمُسْلِمِ لِمَنْ أَخَذَهُ بِحَقِّهِ، فَجَعَلَهُ فِي سَبِيلِ اللَّهِ وَالْيَتَامَى وَالْمَسَاكِينِ، وَمَنْ لَمْ يَأْخُذْهُ بِحَقِّهِ فَهْوَ كَالآكِلِ الَّذِي لاَ يَشْبَعُ، وَيَكُونُ عَلَيْهِ شَهِيدًا يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{2842}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) ascended the pulpit and said, "Nothing worries me as to what will happen to you after me, except the temptation of worldly blessings which will be conferred on you." Then he mentioned the worldly pleasures. He started with the one (i.e. the blessings) and took up the other (i.e. the pleasures). A man got up saying, "O Allah's Messenger (ﷺ)! Can the good bring about evil?" The Prophet (ﷺ) remained silent and we thought that he was being inspired divinely, so all the people kept silent with awe. Then the Prophet (ﷺ) wiped the sweat off his face and asked, "Where is the present questioner?" "Do you think wealth is good?" he repeated thrice, adding, "No doubt, good produces nothing but good. Indeed it is like what grows on the banks of a stream which either kills or nearly kills the grazing animals because of gluttony except the vegetation-eating animal which eats till both its flanks are full (i.e. till it gets satisfied) and then stands in the sun and defecates and urinates and again starts grazing. This worldly property is sweet vegetation. How excellent the wealth of the Muslim is, if it is collected through legal means and is spent in Allah's Cause and on orphans, poor people and travelers. But he who does not take it legally is like an eater who is never satisfied and his wealth will be a witness against him on the Day of Resurrection}}
\hadithdefcmd{bukhari}{2843}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا الْحُسَيْنُ، قَالَ حَدَّثَنِي يَحْيَى، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ حَدَّثَنِي بُسْرُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي زَيْدُ بْنُ خَالِدٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ فَقَدْ غَزَا، وَمَنْ خَلَفَ غَازِيًا فِي سَبِيلِ اللَّهِ بِخَيْرٍ فَقَدْ غَزَا ‏"‏‏.‏\hadithno{2843}\hadithtrans{Narrated Zaid bin Khalid:Allah's Messenger (ﷺ) said, "He who prepares a Ghazi going in Allah's Cause is given a reward equal to that of) a Ghazi; and he who looks after properly the dependents of a Ghazi going in Allah's Cause is (given a reward equal to that of) a Ghazi}}
\hadithdefcmd{bukhari}{2844}{حَدَّثَنَا مُوسَى، حَدَّثَنَا هَمَّامٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَكُنْ يَدْخُلُ بَيْتًا بِالْمَدِينَةِ غَيْرَ بَيْتِ أُمِّ سُلَيْمٍ، إِلاَّ عَلَى أَزْوَاجِهِ فَقِيلَ لَهُ، فَقَالَ ‏ "‏ إِنِّي أَرْحَمُهَا، قُتِلَ أَخُوهَا مَعِي ‏"‏‏.‏\hadithno{2844}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used not to enter any house in Medina except the house of Um Sulaim besides those of his wives when he was asked why, he said, "I take pity on her as her brother was killed in my company}}
\hadithdefcmd{bukhari}{2845}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُوسَى بْنِ أَنَسٍ، قَالَ وَذَكَرَ يَوْمَ الْيَمَامَةِ قَالَ أَتَى أَنَسٌ ثَابِتَ بْنَ قَيْسٍ وَقَدْ حَسَرَ عَنْ فَخِذَيْهِ وَهْوَ يَتَحَنَّطُ فَقَالَ يَا عَمِّ مَا يَحْبِسُكَ أَنْ لاَ تَجِيءَ قَالَ الآنَ يَا ابْنَ أَخِي‏.‏ وَجَعَلَ يَتَحَنَّطُ، يَعْنِي مِنَ الْحَنُوطِ، ثُمَّ جَاءَ فَجَلَسَ، فَذَكَرَ فِي الْحَدِيثِ انْكِشَافًا مِنَ النَّاسِ، فَقَالَ هَكَذَا عَنْ وُجُوهِنَا حَتَّى نُضَارِبَ الْقَوْمَ، مَا هَكَذَا كُنَّا نَفْعَلُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم، بِئْسَ مَا عَوَّدْتُمْ أَقْرَانَكُمْ‏.‏ رَوَاهُ حَمَّادٌ عَنْ ثَابِتٍ عَنْ أَنَسٍ‏.‏\hadithno{2845}\hadithtrans{Narrated Ibn `Aun:Once Musa bin Anas while describing the battle of Yamama, said, "Anas bin Malik went to Thabit bin Qais, who had lifted his clothes from his thighs and was applying Hunut to his body. Anas asked, 'O Uncle! What is holding you back (from the battle)?' He replied, 'O my nephew! I am coming just now,' and went on perfuming himself with Hunut, then he came and sat (in the row). Anas then mentioned that the people fled from the battle-field. On that Thabit said, 'Clear the way for me to fight the enemy. We would never do so (i.e. flee) in the company of Allah's Messenger (ﷺ). How bad the habits you have acquired from your enemies}}
\hadithdefcmd{bukhari}{2846}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ يَأْتِينِي بِخَبَرِ الْقَوْمِ يَوْمَ الأَحْزَابِ ‏"‏‏.‏ قَالَ الزُّبَيْرُ أَنَا‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ يَأْتِينِي بِخَبَرِ الْقَوْمِ ‏"‏‏.‏ قَالَ الزُّبَيْرُ أَنَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ لِكُلِّ نَبِيٍّ حَوَارِيًّا، وَحَوَارِيَّ الزُّبَيْرُ ‏"‏‏.‏\hadithno{2846}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said, "Who will bring me the information about the enemy on the day (of the battle) of Al-Ahzab (i.e. Clans)?" Az-Zubair said, "I will." The Prophet (ﷺ) said again, "Who will bring me the information about the enemy?" Az-Zubair said again, "I will." The Prophet (ﷺ) said, "Every prophet had a disciple and my disciple is Az-Zubair}}
\hadithdefcmd{bukhari}{2847}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، حَدَّثَنَا ابْنُ الْمُنْكَدِرِ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ نَدَبَ النَّبِيُّ صلى الله عليه وسلم النَّاسَ ـ قَالَ صَدَقَةُ أَظُنُّهُ ـ يَوْمَ الْخَنْدَقِ فَانْتَدَبَ الزُّبَيْرُ، ثُمَّ نَدَبَ فَانْتَدَبَ الزُّبَيْرُ، ثُمَّ نَدَبَ النَّاسَ فَانْتَدَبَ الزُّبَيْرُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ لِكُلِّ نَبِيٍّ حَوَارِيًّا، وَإِنَّ حَوَارِيَّ الزُّبَيْرُ بْنُ الْعَوَّامِ ‏"‏‏.‏\hadithno{2847}\hadithtrans{Narrated Jabir bin `Abdullah:When the Prophet (ﷺ) called the people (Sadaqa, a sub-narrator, said, 'Most likely that happened on the day of Al-Khandaq) Az-Zubair responded to the call (i.e. to act as a scout). The Prophet) called the people again and Az-Zubair responded to the call. The Prophet (ﷺ) then said, "Every prophet had a disciple and my disciple is Zubair bin Al-`Awwam}}
\hadithdefcmd{bukhari}{2848}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ انْصَرَفْتُ مِنْ عِنْدِ النَّبِيِّ صلى الله عليه وسلم، فَقَالَ لَنَا أَنَا وَصَاحِبٌ لِي ‏ "‏ أَذِّنَا وَأَقِيمَا، وَلْيَؤُمَّكُمَا أَكْبَرُكُمَا ‏"‏‏.‏\hadithno{2848}\hadithtrans{Narrated Malik bin Al-Huwairith:On my departure from the Prophet (ﷺ) he said to me and to a friend of mine, "You two, pronounce the Adhan and the Iqama for the prayer and let the elder of you lead the prayer}}
\hadithdefcmd{bukhari}{2849}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْلُ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏\hadithno{2849}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Good will remain (as a permanent quality) in the foreheads of horses till the Day of Resurrection}}
\hadithdefcmd{bukhari}{2850}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ حُصَيْنٍ، وَابْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ الْجَعْدِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏ قَالَ سُلَيْمَانُ عَنْ شُعْبَةَ عَنْ عُرْوَةَ بْنِ أَبِي الْجَعْدِ‏.‏\hadithno{2850}\hadithtrans{Narrated Urwa bin Ja'd:The Prophet (ﷺ) said, "Good will remain (as a permanent quality) in the foreheads of horses till the Day of Resurrection}}
\hadithdefcmd{bukhari}{2851}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَرَكَةُ فِي نَوَاصِي الْخَيْلِ ‏"‏‏.‏\hadithno{2851}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "There is a blessing in the fore-heads of horses}}
\hadithdefcmd{bukhari}{2852}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، حَدَّثَنَا عُرْوَةُ الْبَارِقِيُّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْمَغْنَمُ ‏"‏‏.‏\hadithno{2852}\hadithtrans{Narrated `Urwa Al-Bariqi:The Prophet (ﷺ) said, "Good will remain (as a permanent quality) in the foreheads of horses (for Jihad) till the Day of Resurrection, for they bring about either a reward (in the Hereafter) or (war) booty (in this world)}}
\hadithdefcmd{bukhari}{2853}{حَدَّثَنَا عَلِيُّ بْنُ حَفْصٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا طَلْحَةُ بْنُ أَبِي سَعِيدٍ، قَالَ سَمِعْتُ سَعِيدًا الْمَقْبُرِيَّ، يُحَدِّثُ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنِ احْتَبَسَ فَرَسًا فِي سَبِيلِ اللَّهِ إِيمَانًا بِاللَّهِ وَتَصْدِيقًا بِوَعْدِهِ، فَإِنَّ شِبَعَهُ وَرِيَّهُ وَرَوْثَهُ وَبَوْلَهُ فِي مِيزَانِهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{2853}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If somebody keeps a horse in Allah's Cause motivated by his faith in Allah and his belief in His Promise, then he will be rewarded on the Day of Resurrection for what the horse has eaten or drunk and for its dung and urine}}
\hadithdefcmd{bukhari}{2854}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، عَنْ أَبِي حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّهُ خَرَجَ مَعَ النَّبِيِّ صلى الله عليه وسلم فَتَخَلَّفَ أَبُو قَتَادَةَ مَعَ بَعْضِ أَصْحَابِهِ وَهُمْ مُحْرِمُونَ وَهْوَ غَيْرُ مُحْرِمٍ، فَرَأَوْا حِمَارًا وَحْشِيًّا قَبْلَ أَنْ يَرَاهُ، فَلَمَّا رَأَوْهُ تَرَكُوهُ حَتَّى رَآهُ أَبُو قَتَادَةَ، فَرَكِبَ فَرَسًا لَهُ يُقَالُ لَهُ الْجَرَادَةُ، فَسَأَلَهُمْ أَنْ يُنَاوِلُوهُ سَوْطَهُ فَأَبَوْا، فَتَنَاوَلَهُ فَحَمَلَ فَعَقَرَهُ، ثُمَّ أَكَلَ فَأَكَلُوا، فَنَدِمُوا فَلَمَّا أَدْرَكُوهُ قَالَ ‏ "‏ هَلْ مَعَكُمْ مِنْهُ شَىْءٌ ‏"‏‏.‏ قَالَ مَعَنَا رِجْلُهُ، فَأَخَذَهَا النَّبِيُّ صلى الله عليه وسلم فَأَكَلَهَا‏.‏\hadithno{2854}\hadithtrans{Narrated `Abdullah bin Abi Qatada:(from his father) Abu Qatada went out (on a journey) with Allah's Messenger (ﷺ) but he was left behind with some of his companions who were in the state of Ihram. He himself was not in the state of Ihram. They saw an onager before he could see it. When they saw the onager, they did not speak anything till Abu Qatada saw it. So, he rode over his horse called Al-Jarada and requested them to give him his lash, but they refused. So, he himself took it and then attacked the onager and slaughtered it. He ate of its meat and his companions ate, too, but they regretted their eating. When they met the Prophet (they asked him about it) and he asked, "Have you some of its meat (left) with you?" Abu Qatada replied, "Yes, we have its leg with us." So, the Prophet (ﷺ) took and ate it}}
\hadithdefcmd{bukhari}{2855}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنَا أُبَىُّ بْنُ عَبَّاسِ بْنِ سَهْلٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم فِي حَائِطِنَا فَرَسٌ يُقَالُ لَهُ اللُّحَيْفُ‏.‏ قَالَ أَبُو عَبْد اللَّهِ وَقَالَ بَعْضُهُمُ اللُّخَيْفُ\hadithno{2855}\hadithtrans{Narrated Sahl:In our garden there was a horse belonging to the Prophet (ﷺ) called Al-Luhaif or Al-Lukhaif}}
\hadithdefcmd{bukhari}{2856}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ يَحْيَى بْنَ آدَمَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ مُعَاذٍ ـ رضى الله عنه ـ قَالَ كُنْتُ رِدْفَ النَّبِيِّ صلى الله عليه وسلم عَلَى حِمَارٍ يُقَالُ لَهُ عُفَيْرٌ، فَقَالَ ‏"‏ يَا مُعَاذُ، هَلْ تَدْرِي حَقَّ اللَّهِ عَلَى عِبَادِهِ وَمَا حَقُّ الْعِبَادِ عَلَى اللَّهِ ‏"‏‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ فَإِنَّ حَقَّ اللَّهِ عَلَى الْعِبَادِ أَنْ يَعْبُدُوهُ وَلاَ يُشْرِكُوا بِهِ شَيْئًا، وَحَقَّ الْعِبَادِ عَلَى اللَّهِ أَنْ لاَ يُعَذِّبَ مَنْ لاَ يُشْرِكُ بِهِ شَيْئًا ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ، أَفَلاَ أُبَشِّرُ بِهِ النَّاسَ قَالَ ‏"‏ لاَ تُبَشِّرْهُمْ فَيَتَّكِلُوا ‏"‏‏.‏\hadithno{2856}\hadithtrans{Narrated Mu`adh:I was a companion rider of the Prophet (ﷺ) on a donkey called 'Ufair. The Prophet (ﷺ) asked, "O Mu`adh! Do you know what Allah's right on His slaves is, and what the right of His slaves on Him is?" I replied, "Allah and His Apostle know better." He said, "Allah's right on His slaves is that they should worship Him (Alone) and should not worship any besides Him. And slave's right on Allah is that He should not punish him who worships none besides Him." I said, "O Allah's Messenger (ﷺ)! Should I not inform the people of this good news?" He said, "Do not inform them of it, lest they should depend on it (absolutely)}}
\hadithdefcmd{bukhari}{2857}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ فَزَعٌ بِالْمَدِينَةِ، فَاسْتَعَارَ النَّبِيُّ صلى الله عليه وسلم فَرَسًا لَنَا يُقَالُ لَهُ مَنْدُوبٌ‏.‏ فَقَالَ ‏ "‏ مَا رَأَيْنَا مِنْ فَزَعٍ، وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏‏.‏\hadithno{2857}\hadithtrans{Narrated Anas bin Malik:Once there was a feeling of fright in Medina, so the Prophet (ﷺ) borrowed a horse belonging to us called Mandub (and he rode away on it). (When the Prophet (ﷺ) returned) he said, "I have not seen anything of fright and I found it (i.e. this horse) very fast}}
\hadithdefcmd{bukhari}{2858}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا الشُّؤْمُ فِي ثَلاَثَةٍ فِي الْفَرَسِ وَالْمَرْأَةِ وَالدَّارِ ‏"‏‏.‏\hadithno{2858}\hadithtrans{Narrated `Abdullah bin `Umar:I heard the Prophet (ﷺ) saying. "Evil omen is in three things: The horse, the woman and the house}}
\hadithdefcmd{bukhari}{2859}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ فَفِي الْمَرْأَةِ وَالْفَرَسِ وَالْمَسْكَنِ ‏"‏‏.‏\hadithno{2859}\hadithtrans{Narrated Sahl bin Sa`d As-Saidi:Allah's Messenger (ﷺ) said, "If there is any evil omen in anything, then it is in the woman, the horse and the house}}
\hadithdefcmd{bukhari}{2860}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْخَيْلُ لِثَلاَثَةٍ لِرَجُلٍ أَجْرٌ، وَلِرَجُلٍ سِتْرٌ، وَعَلَى رَجُلٍ وِزْرٌ، فَأَمَّا الَّذِي لَهُ أَجْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ، فَأَطَالَ فِي مَرْجٍ أَوْ رَوْضَةٍ، فَمَا أَصَابَتْ فِي طِيَلِهَا ذَلِكَ مِنَ الْمَرْجِ أَوِ الرَّوْضَةِ كَانَتْ لَهُ حَسَنَاتٍ، وَلَوْ أَنَّهَا قَطَعَتْ طِيَلَهَا فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كَانَتْ أَرْوَاثُهَا وَآثَارُهَا حَسَنَاتٍ لَهُ، وَلَوْ أَنَّهَا مَرَّتْ بِنَهَرٍ فَشَرِبَتْ مِنْهُ وَلَمْ يُرِدْ أَنْ يَسْقِيَهَا كَانَ ذَلِكَ حَسَنَاتٍ لَهُ، وَرَجُلٌ رَبَطَهَا فَخْرًا وَرِئَاءً وَنِوَاءً لأَهْلِ الإِسْلاَمِ فَهْىَ وِزْرٌ عَلَى ذَلِكَ ‏"‏‏.‏ وَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحُمُرِ، فَقَالَ ‏"‏ مَا أُنْزِلَ عَلَىَّ فِيهَا إِلاَّ هَذِهِ الآيَةُ الْجَامِعَةُ الْفَاذَّةُ ‏\{‏فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ ‏\}‏‏"‏‏.‏\hadithno{2860}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, " Horses are kept for one of three purposes; for some people they are a source of reward, for some others they are a means of shelter and for some others they are a source of sins. The one for whom they are a source of reward, is he who keeps a horse for Allah's Cause (i.e. Jihad) tying it with a long tether on a meadow or in a garden with the result that whatever it eats from the area of the meadow or the garden where it is tied will be counted as good deeds for his benefit, and if it should break its rope and jump over one or two hillocks then all its dung and its foot marks will be written as good deeds for him; and if it passes by a river and drinks water from it even though he had no intention of watering it, even then he will get the reward for its drinking. As for the man for whom horses are a source of sins, he is the one who keeps a horse for the sake of pride and pretense and showing enmity for Muslims: such a horse will be a source of sins for him. When Allah's Messenger (ﷺ) was asked about donkeys, he replied, "Nothing has been revealed to me about them except this unique, comprehensive Verse: "Then anyone who does an atom's (or a small ant's) weight of good shall see it; And anyone who does an atom's (or a small ant's) weight of evil, shall see it}}
\hadithdefcmd{bukhari}{2861}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا أَبُو عَقِيلٍ، حَدَّثَنَا أَبُو الْمُتَوَكِّلِ النَّاجِيُّ، قَالَ أَتَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيَّ، فَقُلْتُ لَهُ حَدِّثْنِي بِمَا، سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَافَرْتُ مَعَهُ فِي بَعْضِ أَسْفَارِهِ ـ قَالَ أَبُو عَقِيلٍ لاَ أَدْرِي غَزْوَةً أَوْ عُمْرَةً ـ فَلَمَّا أَنْ أَقْبَلْنَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ أَنْ يَتَعَجَّلَ إِلَى أَهْلِهِ فَلْيُعَجِّلْ ‏"‏‏.‏ قَالَ جَابِرٌ فَأَقْبَلْنَا وَأَنَا عَلَى جَمَلٍ لِي أَرْمَكَ لَيْسَ فِيهِ شِيَةٌ، وَالنَّاسُ خَلْفِي، فَبَيْنَا أَنَا كَذَلِكَ إِذْ قَامَ عَلَىَّ، فَقَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا جَابِرُ اسْتَمْسِكْ ‏"‏‏.‏ فَضَرَبَهُ بِسَوْطِهِ ضَرْبَةً، فَوَثَبَ الْبَعِيرُ مَكَانَهُ‏.‏ فَقَالَ ‏"‏ أَتَبِيعُ الْجَمَلَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَلَمَّا قَدِمْنَا الْمَدِينَةَ وَدَخَلَ النَّبِيُّ صلى الله عليه وسلم الْمَسْجِدَ فِي طَوَائِفِ أَصْحَابِهِ، فَدَخَلْتُ إِلَيْهِ، وَعَقَلْتُ الْجَمَلَ فِي نَاحِيَةِ الْبَلاَطِ‏.‏ فَقُلْتُ لَهُ هَذَا جَمَلُكَ‏.‏ فَخَرَجَ، فَجَعَلَ يُطِيفُ بِالْجَمَلِ وَيَقُولُ ‏"‏ الْجَمَلُ جَمَلُنَا ‏"‏‏.‏ فَبَعَثَ النَّبِيُّ صلى الله عليه وسلم أَوَاقٍ مِنْ ذَهَبٍ فَقَالَ ‏"‏ أَعْطُوهَا جَابِرًا ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ اسْتَوْفَيْتَ الثَّمَنَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ الثَّمَنُ وَالْجَمَلُ لَكَ ‏"‏‏.‏\hadithno{2861}\hadithtrans{Narrated Muslim from Abu `Aqil from Abu Al-Mutawakkil An-Naji:I called on Jabir bin `Abdullah Al-Ansari and said to him, "Relate to me what you have heard from Allah's Messenger (ﷺ) ." He said, "I accompanied him on one of the journeys." (Abu `Aqil said, "I do not know whether that journey was for the purpose of Jihad or `Umra.") "When we were returning," Jabir continued, "the Prophet (ﷺ) said, 'Whoever wants to return earlier to his family, should hurry up.' We set off and I was on a black red tainted camel having no defect, and the people were behind me. While I was in that state the camel stopped suddenly (because of exhaustion). On that the Prophet (ﷺ) said to me, 'O Jabir, wait!' Then he hit it once with his lash and it started moving on a fast pace. He then said, 'Will you sell the camel?' I replied in the affirmative when we reached Medina, and the Prophet (ﷺ) went to the Mosque along with his companions. I, too, went to him after tying the camel on the pavement at the Mosque gate. Then I said to him, 'This is your camel.' He came out and started examining the camel and saying, 'The camel is ours.' Then the Prophet (ﷺ) sent some Awaq (i.e. an amount) of gold saying, 'Give it to Jabir.' Then he asked, 'Have you taken the full price (of the camel)?' I replied in the affirmative. He said, 'Both the price and the camel are for you}}
\hadithdefcmd{bukhari}{2862}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ بِالْمَدِينَةِ فَزَعٌ، فَاسْتَعَارَ النَّبِيُّ صلى الله عليه وسلم فَرَسًا لأَبِي طَلْحَةَ، يُقَالُ لَهُ مَنْدُوبٌ فَرَكِبَهُ، وَقَالَ ‏ "‏ مَا رَأَيْنَا مِنْ فَزَعٍ، وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏‏.‏\hadithno{2862}\hadithtrans{Narrated Anas bin Malik:There was a feeling of fright in Medina, so the Prophet (ﷺ) borrowed a horse called Mandub belonging 'to Abu Talha and mounted it. (On his return), he said, "I did not see anything of fright and I found this horse very fast}}
\hadithdefcmd{bukhari}{2863}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَعَلَ لِلْفَرَسِ سَهْمَيْنِ وَلِصَاحِبِهِ سَهْمًا‏.‏ وَقَالَ مَالِكٌ يُسْهَمُ لِلْخَيْلِ وَالْبَرَاذِينِ مِنْهَا لِقَوْلِهِ ‏\{‏وَالْخَيْلَ وَالْبِغَالَ وَالْحَمِيرَ لِتَرْكَبُوهَا‏\}‏ وَلاَ يُسْهَمُ لأَكْثَرَ مِنْ فَرَسٍ‏.‏\hadithno{2863}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) fixed two shares for the horse and one share for its rider (from the war booty)}}
\hadithdefcmd{bukhari}{2864}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سَهْلُ بْنُ يُوسُفَ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ،‏.‏ قَالَ رَجُلٌ لِلْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ أَفَرَرْتُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ قَالَ لَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَفِرَّ، إِنَّ هَوَازِنَ كَانُوا قَوْمًا رُمَاةً، وَإِنَّا لَمَّا لَقِينَاهُمْ حَمَلْنَا عَلَيْهِمْ فَانْهَزَمُوا، فَأَقْبَلَ الْمُسْلِمُونَ عَلَى الْغَنَائِمِ وَاسْتَقْبَلُونَا بِالسِّهَامِ، فَأَمَّا رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَفِرَّ، فَلَقَدْ رَأَيْتُهُ وَإِنَّهُ لَعَلَى بَغْلَتِهِ الْبَيْضَاءِ وَإِنَّ أَبَا سُفْيَانَ آخِذٌ بِلِجَامِهَا، وَالنَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا النَّبِيُّ لاَ كَذِبْ أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ ‏"‏‏.‏\hadithno{2864}\hadithtrans{Narrated Abu 'Is-haq:Somebody asked Al-Bar-a bin `Azib, "Did you flee deserting Allah's Messenger (ﷺ) during the battle of Hunain?" Al-Bara replied, "But Allah's Messenger (ﷺ) did not flee. The people of the Tribe of Hawazin were good archers. When we met them, we attacked them, and they fled. When the Muslims started collecting the war booty, the pagans faced us with arrows, but Allah's Messenger (ﷺ) did not flee. No doubt, I saw him on his white mule and Abu Sufyan was holding its reins and the Prophet (ﷺ) was saying, 'I am the Prophet (ﷺ) in truth: I am the son of `Abdul Muttalib}}
\hadithdefcmd{bukhari}{2865}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ أَنَّهُ كَانَ إِذَا أَدْخَلَ رِجْلَهُ فِي الْغَرْزِ وَاسْتَوَتْ بِهِ نَاقَتُهُ قَائِمَةً، أَهَلَّ مِنْ عِنْدِ مَسْجِدِ ذِي الْحُلَيْفَةِ‏.‏\hadithno{2865}\hadithtrans{Narrated Ibn'`Umar:When the Prophet (ﷺ) put his feet in the stirrup and the she-camel got up carrying him he would start reciting Talbiya at the mosque of Dhul-Hulaifa}}
\hadithdefcmd{bukhari}{2866}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه اسْتَقْبَلَهُمُ النَّبِيُّ صلى الله عليه وسلم عَلَى فَرَسٍ عُرْىٍ، مَا عَلَيْهِ سَرْجٌ، فِي عُنُقِهِ سَيْفٌ‏.‏\hadithno{2866}\hadithtrans{Narrated Anas:The Prophet (ﷺ) met them (i.e. the people) while he was riding an unsaddled horse with his sword slung over his shoulder}}
\hadithdefcmd{bukhari}{2867}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه أَنَّ أَهْلَ، الْمَدِينَةِ فَزِعُوا مَرَّةً، فَرَكِبَ النَّبِيُّ صلى الله عليه وسلم فَرَسًا لأَبِي طَلْحَةَ كَانَ يَقْطِفُ ـ أَوْ كَانَ فِيهِ قِطَافٌ ـ فَلَمَّا رَجَعَ قَالَ ‏ "‏ وَجَدْنَا فَرَسَكُمْ هَذَا بَحْرًا ‏"‏‏.‏ فَكَانَ بَعْدَ ذَلِكَ لاَ يُجَارَى‏.‏\hadithno{2867}\hadithtrans{Narrated Anas bin Malik:Once the people of Medina were frightened, so the Prophet (ﷺ) rode a horse belonging to Abu Talha and it ran slowly, or was of narrow paces. When he returned, he said, "I found your (i.e. Abu Talha's) horse very fast. After that the horse could not be surpassed in running}}
\hadithdefcmd{bukhari}{2868}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أَجْرَى النَّبِيُّ صلى الله عليه وسلم مَا ضُمِّرَ مِنَ الْخَيْلِ مِنَ الْحَفْيَاءِ إِلَى ثَنِيَّةِ الْوَدَاعِ، وَأَجْرَى مَا لَمْ يُضَمَّرْ مِنَ الثَّنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ‏.‏ قَالَ ابْنُ عُمَرَ وَكُنْتُ فِيمَنْ أَجْرَى‏.‏ قَالَ عَبْدُ اللَّهِ حَدَّثَنَا سُفْيَانُ قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ‏.‏ قَالَ سُفْيَانُ بَيْنَ الْحَفْيَاءِ إِلَى ثَنِيَّةِ الْوَدَاعِ خَمْسَةُ أَمْيَالٍ أَوْ سِتَّةٌ، وَبَيْنَ ثَنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ مِيلٌ‏.‏\hadithno{2868}\hadithtrans{Narrated (`Abdullah) bin `Umar:The Prophet (ﷺ) arranged for a horse race amongst the horses that had been made lean to take place between Al-Hafya'' and Thaniyat Al-Wada` (i.e. names of two places) and the horses which had not been made lean from Ath-Thaniyat to the mosque of Bani Zuraiq. I was also amongst those who took part in that horse race. Sufyan, a sub-narrator, said, "The distance between Al-Hafya and Thaniya Al- Wada` is five or six miles; and between Thaniya and the mosque of Bani Zuraiq is one mile}}
\hadithdefcmd{bukhari}{2869}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم سَابَقَ بَيْنَ الْخَيْلِ الَّتِي لَمْ تُضَمَّرْ، وَكَانَ أَمَدُهَا مِنَ الثَّنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ‏.‏ وَأَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ كَانَ سَابَقَ بِهَا‏.‏ قَالَ أَبُو عَبْد اللَّهِ أَمَدًا غَايَةً فَطَالَ عَلَيْهِمْ الْأَمَدُ\hadithno{2869}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) arranged for a horse race of the horses which had not been made lean; the area of the race was from Ath-Thaniya to the mosque of Bani Zuraiq. (The sub-narrator said, "`Abdullah bin `Umar was amongst those who participated in that horse race)}}
\hadithdefcmd{bukhari}{2870}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَابَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْخَيْلِ الَّتِي قَدْ أُضْمِرَتْ فَأَرْسَلَهَا مِنَ الْحَفْيَاءِ، وَكَانَ أَمَدُهَا ثَنِيَّةَ الْوَدَاعِ‏.‏ فَقُلْتُ لِمُوسَى فَكَمْ كَانَ بَيْنَ ذَلِكَ قَالَ سِتَّةُ أَمْيَالٍ أَوْ سَبْعَةٌ‏.‏ وَسَابَقَ بَيْنَ الْخَيْلِ الَّتِي لَمْ تُضَمَّرْ، فَأَرْسَلَهَا مِنْ ثَنِيَّةِ الْوَدَاعِ، وَكَانَ أَمَدُهَا مَسْجِدَ بَنِي زُرَيْقٍ، قُلْتُ فَكَمْ بَيْنَ ذَلِكَ قَالَ مِيلٌ أَوْ نَحْوُهُ‏.‏ وَكَانَ ابْنُ عُمَرَ مِمَّنْ سَابَقَ فِيهَا‏.‏\hadithno{2870}\hadithtrans{Narrated Abu 'Is-haq from Musa bin `Uqba from Nafi` from Ibn `Umar who said:"Allah's Messenger (ﷺ) arranged a horse race amongst the horses that had been made lean, letting them start from Al-Hafya' and their limit (distance of running) was up to Thaniyat-al-Wada`. I asked Musa, 'What was the distance between the two places?' Musa replied, 'Six or seven miles. He arranged a race of the horses which had not been made lean sending them from Thaniyat-al-Wada`, and their limit was up to the mosque of Bani Zuraiq.' I asked, 'What was the distance between those two places?' He replied 'One mile or so.' Ibn `Umar was amongst those who participated in that horse race}}
\hadithdefcmd{bukhari}{2871}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ كَانَتْ نَاقَةُ النَّبِيِّ صلى الله عليه وسلم يُقَالُ لَهَا الْعَضْبَاءُ‏.‏\hadithno{2871}\hadithtrans{Narrated Anas:The she camel of the Prophet (ﷺ) was called Al-Adba}}
\hadithdefcmd{bukhari}{2872}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم نَاقَةٌ تُسَمَّى الْعَضْبَاءَ لاَ تُسْبَقُ ـ قَالَ حُمَيْدٌ أَوْ لاَ تَكَادُ تُسْبَقُ ـ فَجَاءَ أَعْرَابِيٌّ عَلَى قَعُودٍ فَسَبَقَهَا، فَشَقَّ ذَلِكَ عَلَى الْمُسْلِمِينَ، حَتَّى عَرَفَهُ فَقَالَ ‏ "‏ حَقٌّ عَلَى اللَّهِ أَنْ لاَ يَرْتَفِعَ شَىْءٌ مِنَ الدُّنْيَا إِلاَّ وَضَعَهُ ‏"‏‏.‏ طَوَّلَهُ مُوسَى عَنْ حَمَّادٍ عَنْ ثَابِتٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2872}\hadithtrans{Narrated Anas:The Prophet (ﷺ) had a she camel called Al-Adba which could not be excelled in a race. (Humaid, a subnarrator said, "Or could hardly be excelled.") Once a bedouin came riding a camel below six years of age which surpassed it (i.e. Al-`Adba') in the race. The Muslims felt it so much that the Prophet (ﷺ) noticed their distress. He then said, "It is Allah's Law that He brings down whatever rises high in the world}}
\hadithdefcmd{bukhari}{2873}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ عَمْرَو بْنَ الْحَارِثِ، قَالَ مَا تَرَكَ النَّبِيُّ صلى الله عليه وسلم إِلاَّ بَغْلَتَهُ الْبَيْضَاءَ وَسِلاَحَهُ وَأَرْضًا تَرَكَهَا صَدَقَةً‏.‏\hadithno{2873}\hadithtrans{Narrated `Amr bin Al-Harith:The Prophet (ﷺ) did not leave anything behind him after his death except a white mule, his arms and a piece of land which he left to be given in charity}}
\hadithdefcmd{bukhari}{2874}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ لَهُ رَجُلٌ يَا أَبَا عُمَارَةَ وَلَّيْتُمْ يَوْمَ حُنَيْنٍ قَالَ لاَ، وَاللَّهِ مَا وَلَّى النَّبِيُّ صلى الله عليه وسلم وَلَكِنْ وَلَّى سَرَعَانُ النَّاسِ، فَلَقِيَهُمْ هَوَازِنُ بِالنَّبْلِ وَالنَّبِيُّ صلى الله عليه وسلم عَلَى بَغْلَتِهِ الْبَيْضَاءِ، وَأَبُو سُفْيَانَ بْنُ الْحَارِثِ آخِذٌ بِلِجَامِهَا، وَالنَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا النَّبِيُّ لاَ كَذِبْ أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ‏"‏\hadithno{2874}\hadithtrans{Narrated Al-Bara:that a man asked him. "O Abu '`Umara! Did you flee on the day (of the battle) of Hunain?" He replied, "No, by Allah, the Prophet (ﷺ) did not flee but the hasty people fled and the people of the Tribe of Hawazin attacked them with arrows, while the Prophet (ﷺ) was riding his white mule and Abu Sufyan bin Al-Harith was holding its reins, and the Prophet (ﷺ) was saying, 'I am the Prophet (ﷺ) in truth, I am the son of `Abdul Muttalib}}
\hadithdefcmd{bukhari}{2875}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مُعَاوِيَةَ بْنِ إِسْحَاقَ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ قَالَتِ اسْتَأْذَنْتُ النَّبِيَّ صلى الله عليه وسلم فِي الْجِهَادِ‏.‏ فَقَالَ ‏ "‏ جِهَادُكُنَّ الْحَجُّ ‏"‏‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْوَلِيدِ حَدَّثَنَا سُفْيَانُ عَنْ مُعَاوِيَةَ بِهَذَا‏.‏\hadithno{2875}\hadithtrans{Narrated `Aisha:the mother of the faithful believers, I requested the Prophet (ﷺ) to permit me to participate in Jihad, but he said, "Your Jihad is the performance of Hajj}}
\hadithdefcmd{bukhari}{2876}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ مُعَاوِيَةَ، بِهَذَا‏.‏ وَعَنْ حَبِيبِ بْنِ أَبِي عَمْرَةَ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، عَنِ النَّبِيِّ صلى الله عليه وسلم سَأَلَهُ نِسَاؤُهُ عَنِ الْجِهَادِ فَقَالَ ‏ "‏ نِعْمَ الْجِهَادُ الْحَجُّ ‏"‏‏.‏\hadithno{2876}\hadithtrans{Narrated `Aisha:the mother of the faithful believers: The Prophet (ﷺ) was asked by his wives about Jihad and he replied, "The best Jihad (for you) is (the performance of) Hajj}}
\hadithdefcmd{bukhari}{2877}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ الأَنْصَارِيِّ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ابْنَةِ مِلْحَانَ فَاتَّكَأَ عِنْدَهَا، ثُمَّ ضَحِكَ فَقَالَتْ لِمَ تَضْحَكُ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي يَرْكَبُونَ الْبَحْرَ الأَخْضَرَ فِي سَبِيلِ اللَّهِ، مَثَلُهُمْ مَثَلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اجْعَلْهَا مِنْهُمْ ‏"‏‏.‏ ثُمَّ عَادَ فَضَحِكَ، فَقَالَتْ لَهُ مِثْلَ أَوْ مِمَّ ذَلِكَ فَقَالَ لَهَا مِثْلَ ذَلِكَ، فَقَالَتِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ، وَلَسْتِ مِنَ الآخِرِينَ ‏"‏‏.‏ قَالَ قَالَ أَنَسٌ فَتَزَوَّجَتْ عُبَادَةَ بْنَ الصَّامِتِ، فَرَكِبَتِ الْبَحْرَ مَعَ بِنْتِ قَرَظَةَ، فَلَمَّا قَفَلَتْ رَكِبَتْ دَابَّتَهَا فَوَقَصَتْ بِهَا، فَسَقَطَتْ عَنْهَا فَمَاتَتْ‏.‏\hadithno{2877}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) went to the daughter of Milhan and reclined there (and slept) and then (woke up) smiling. She asked, "O Allah's Messenger (ﷺ)! What makes you smile?" He replied, (I dreamt that) some people amongst my followers were sailing on the green sea in Allah's Cause, resembling kings on thrones." She said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." He said, "O Allah! Let her be one of them." Then he (slept again and woke up and) smiled. She asked him the same question and he gave the same reply. She said, "Invoke Allah to make me one of them." He replied, ''You will be amongst the first group of them; you will not be amongst the last." Later on she married 'Ubada bin As-Samit and then she sailed on the sea with bint Qaraza, Mu'awiya's wife (for Jihad). On her return, she mounted her riding animal, which threw her down breaking her neck, and she died on falling down}}
\hadithdefcmd{bukhari}{2879}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ النُّمَيْرِيُّ، حَدَّثَنَا يُونُسُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، قَالَ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، وَسَعِيدَ بْنَ الْمُسَيَّبِ، وَعَلْقَمَةَ بْنَ وَقَّاصٍ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، عَنْ حَدِيثِ، عَائِشَةَ، كُلٌّ حَدَّثَنِي طَائِفَةً، مِنَ الْحَدِيثِ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَخْرُجَ أَقْرَعَ بَيْنَ نِسَائِهِ، فَأَيَّتُهُنَّ يَخْرُجُ سَهْمُهَا خَرَجَ بِهَا النَّبِيُّ صلى الله عليه وسلم، فَأَقْرَعَ بَيْنَنَا فِي غَزْوَةٍ غَزَاهَا، فَخَرَجَ فِيهَا سَهْمِي، فَخَرَجْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بَعْدَ مَا أُنْزِلَ الْحِجَابُ‏.‏\hadithno{2879}\hadithtrans{Narrated `Aisha:Whenever the Prophet (ﷺ) intended to proceed on a journey, he used to draw lots amongst his wives and would take the one upon whom the lot fell. Once, before setting out for Jihad, he drew lots amongst us and the lot came to me; so I went with the Prophet; and that happened after the revelation of the Verse of Hijab (i.e. veiling)}}
\hadithdefcmd{bukhari}{2880}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمَّا كَانَ يَوْمُ أُحُدٍ انْهَزَمَ النَّاسُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ وَلَقَدْ رَأَيْتُ عَائِشَةَ بِنْتَ أَبِي بَكْرٍ وَأُمَّ سُلَيْمٍ وَإِنَّهُمَا لَمُشَمِّرَتَانِ أَرَى خَدَمَ سُوقِهِمَا، تَنْقُزَانِ الْقِرَبَ ـ وَقَالَ غَيْرُهُ تَنْقُلاَنِ الْقِرَبَ ـ عَلَى مُتُونِهِمَا، ثُمَّ تُفْرِغَانِهِ فِي أَفْوَاهِ الْقَوْمِ، ثُمَّ تَرْجِعَانِ فَتَمْلآنِهَا، ثُمَّ تَجِيئَانِ فَتُفْرِغَانِهَا فِي أَفْوَاهِ الْقَوْمِ‏.‏\hadithno{2880}\hadithtrans{Narrated Anas:On the day (of the battle) of Uhud when (some) people retreated and left the Prophet, I saw `Aisha bint Abu Bakr and Um Sulaim, with their robes tucked up so that the bangles around their ankles were visible hurrying with their water skins (in another narration it is said, "carrying the water skins on their backs"). Then they would pour the water in the mouths of the people, and return to fill the water skins again and come back again to pour water in the mouths of the people}}
\hadithdefcmd{bukhari}{2881}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ ثَعْلَبَةُ بْنُ أَبِي مَالِكٍ إِنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ قَسَمَ مُرُوطًا بَيْنَ نِسَاءٍ مِنْ نِسَاءِ الْمَدِينَةِ، فَبَقِيَ مِرْطٌ جَيِّدٌ فَقَالَ لَهُ بَعْضُ مَنْ عِنْدَهُ يَا أَمِيرَ الْمُؤْمِنِينَ أَعْطِ هَذَا ابْنَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي عِنْدَكَ‏.‏ يُرِيدُونَ أُمَّ كُلْثُومٍ بِنْتَ عَلِيٍّ‏.‏ فَقَالَ عُمَرُ أُمُّ سَلِيطٍ أَحَقُّ‏.‏ وَأُمُّ سَلِيطٍ مِنْ نِسَاءِ الأَنْصَارِ، مِمَّنْ بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ عُمَرُ فَإِنَّهَا كَانَتْ تَزْفِرُ لَنَا الْقِرَبَ يَوْمَ أُحُدٍ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ تَزْفِرُ تَخِيطُ‏.‏\hadithno{2881}\hadithtrans{Narrated Tha`laba bin Abi Malik:`Umar bin Al-Khattab distributed some garments amongst the women of Medina. One good garment remained, and one of those present with him said, "O chief of the believers! Give this garment to your wife, the (grand) daughter of Allah's Messenger (ﷺ)." They meant Um Kulthum, the daughter of `Ali. `Umar said, Um Salit has more right (to have it)." Um Salit was amongst those Ansari women who had given the pledge of allegiance to Allah's Messenger (ﷺ).' `Umar said, "She (i.e. Um Salit) used to carry the water skins for us on the day of Uhud}}
\hadithdefcmd{bukhari}{2882}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا خَالِدُ بْنُ ذَكْوَانَ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذٍ، قَالَتْ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم نَسْقِي، وَنُدَاوِي الْجَرْحَى، وَنَرُدُّ الْقَتْلَى إِلَى الْمَدِينَةِ‏.‏\hadithno{2882}\hadithtrans{Narrated Ar-Rubayyi 'bint Mu'auwidh:We were in the company of the Prophet (ﷺ) providing the wounded with water and treating them and bringing the killed to Medina (from the battle field)}}
\hadithdefcmd{bukhari}{2883}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ خَالِدِ بْنِ ذَكْوَانَ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذٍ، قَالَتْ كُنَّا نَغْزُو مَعَ النَّبِيِّ صلى الله عليه وسلم فَنَسْقِي الْقَوْمَ وَنَخْدُمُهُمْ، وَنَرُدُّ الْجَرْحَى وَالْقَتْلَى إِلَى الْمَدِينَةِ‏.‏\hadithno{2883}\hadithtrans{Narrated Ar-Rubai' bint Mu'auwidh:We used to take part in holy battles with the Prophet (ﷺ) by providing the people with water and serving them and bringing the killed and the wounded back to Medina}}
\hadithdefcmd{bukhari}{2884}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ رُمِيَ أَبُو عَامِرٍ فِي رُكْبَتِهِ، فَانْتَهَيْتُ إِلَيْهِ قَالَ انْزِعْ هَذَا السَّهْمَ‏.‏ فَنَزَعْتُهُ، فَنَزَا مِنْهُ الْمَاءُ، فَدَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرْتُهُ، فَقَالَ ‏ "‏ اللَّهُمَّ اغْفِرْ لِعُبَيْدٍ أَبِي عَامِرٍ ‏"‏‏.‏\hadithno{2884}\hadithtrans{Narrated Abu Musa:Abu 'Amir was hit with an arrow in his knee, so I went to him and he asked me to remove the arrow. When I removed it, the water started dribbling from it. Then I went to the Prophet (ﷺ) and told him about it. He said, "O Allah! Forgive `Ubaid Abu 'Amir}}
\hadithdefcmd{bukhari}{2885}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ خَلِيلٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ رَبِيعَةَ، قَالَ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم سَهِرَ فَلَمَّا قَدِمَ الْمَدِينَةَ قَالَ ‏"‏ لَيْتَ رَجُلاً مِنْ أَصْحَابِي صَالِحًا يَحْرُسُنِي اللَّيْلَةَ ‏"‏‏.‏ إِذْ سَمِعْنَا صَوْتَ سِلاَحٍ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏‏.‏ فَقَالَ أَنَا سَعْدُ بْنُ أَبِي وَقَّاصٍ، جِئْتُ لأَحْرُسَكَ‏.‏ وَنَامَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{2885}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) was vigilant one night and when he reached Medina, he said, "Would that a pious man from my companions guard me tonight!" Suddenly we heard the clatter of arms. He said, "Who is that? " He (The new comer) replied, " I am Sa`d bin Abi Waqqas and have come to guard you." So, the Prophet (ﷺ) slept (that night)}}
\hadithdefcmd{bukhari}{2886}{حَدَّثَنَا يَحْيَى بْنُ يُوسُفَ، أَخْبَرَنَا أَبُو بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَعِسَ عَبْدُ الدِّينَارِ وَالدِّرْهَمِ وَالْقَطِيفَةِ وَالْخَمِيصَةِ، إِنْ أُعْطِيَ رَضِيَ، وَإِنْ لَمْ يُعْطَ لَمْ يَرْضَ ‏"‏‏.‏ لَمْ يَرْفَعْهُ إِسْرَائِيلُ عَنْ أَبِي حَصِينٍ‏.‏\hadithno{2886}\hadithtrans{Narrated Abu Huraira: The Prophet (ﷺ) said, "Let the slave of Dinar and Dirham, and of Qatifah and Khamisa (i.e. money and luxurious clothes) perish for he is pleased if these things are given to him, and if not, he is displeased}}
\hadithdefcmd{bukhari}{2887}{وَزَادَنَا عَمْرٌو قَالَ أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِيهِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَعِسَ عَبْدُ الدِّينَارِ وَعَبْدُ الدِّرْهَمِ وَعَبْدُ الْخَمِيصَةِ، إِنْ أُعْطِيَ رَضِيَ، وَإِنْ لَمْ يُعْطَ سَخِطَ، تَعِسَ وَانْتَكَسَ، وَإِذَا شِيكَ فَلاَ انْتَقَشَ، طُوبَى لِعَبْدٍ آخِذٍ بِعِنَانِ فَرَسِهِ فِي سَبِيلِ اللَّهِ، أَشْعَثَ رَأْسُهُ مُغْبَرَّةٍ قَدَمَاهُ، إِنْ كَانَ فِي الْحِرَاسَةِ كَانَ فِي الْحِرَاسَةِ، وَإِنْ كَانَ فِي السَّاقَةِ كَانَ فِي السَّاقَةِ، إِنِ اسْتَأْذَنَ لَمْ يُؤْذَنْ لَهُ، وَإِنْ شَفَعَ لَمْ يُشَفَّعْ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ لَمْ يَرْفَعْهُ إِسْرَائِيلُ وَمُحَمَّدُ بْنُ جُحَادَةَ عَنْ أَبِي حَصِينٍ وَقَالَ تَعْسًا‏.‏ كَأَنَّهُ يَقُولُ فَأَتْعَسَهُمُ اللَّهُ‏.‏ طُوبَى فُعْلَى مِنْ كُلِّ شَىْءٍ طَيِّبٍ، وَهْىَ يَاءٌ حُوِّلَتْ إِلَى الْوَاوِ وَهْىَ مِنْ يَطِيبُ‏.‏\hadithno{2887}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, " Let the slave of Dinar and Dirham, of Qatifah and Khamisa perish as he is pleased if these things are given to him, and if not, he is displeased. Let such a person perish and relapse, and if he is pierced with a thorn, let him not find anyone to take it out for him. Paradise is for him who holds the reins of his horse to strive in Allah's Cause, with his hair unkempt and feet covered with dust: if he is appointed in the vanguard, he is perfectly satisfied with his post of guarding, and if he is appointed in the rearward, he accepts his post with satisfaction; (he is so simple and unambiguous that) if he asks for permission he is not permitted, and if he intercedes, his intercession is not accepted}}
\hadithdefcmd{bukhari}{2888}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ صَحِبْتُ جَرِيرَ بْنَ عَبْدِ اللَّهِ، فَكَانَ يَخْدُمُنِي‏.‏ وَهْوَ أَكْبَرُ مِنْ أَنَسٍ قَالَ جَرِيرٌ إِنِّي رَأَيْتُ الأَنْصَارَ يَصْنَعُونَ شَيْئًا لاَ أَجِدُ أَحَدًا مِنْهُمْ إِلاَّ أَكْرَمْتُهُ‏.‏\hadithno{2888}\hadithtrans{Narrated Anas:I was in the company of Jabir bin `Abdullah on a journey and he used to serve me though he was older than I. Jarir said, "I saw the Ansar doing a thing (i.e. showing great reverence to the Prophet (ﷺ) ) for which I have vowed that whenever I meet any of them, I will serve him}}
\hadithdefcmd{bukhari}{2889}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ بْنِ حَنْطَبٍ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى خَيْبَرَ أَخْدُمُهُ، فَلَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم رَاجِعًا، وَبَدَا لَهُ أُحُدٌ قَالَ ‏"‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏‏.‏ ثُمَّ أَشَارَ بِيَدِهِ إِلَى الْمَدِينَةِ قَالَ اللَّهُمَّ إِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا كَتَحْرِيمِ إِبْرَاهِيمَ مَكَّةَ ‏"‏ اللَّهُمَّ بَارِكْ لَنَا فِي صَاعِنَا وَمُدِّنَا ‏"‏‏.‏\hadithno{2889}\hadithtrans{Narrated Anas bin Malik:I went along with the Prophet (ﷺ) to Khaibar so as to serve him. (Later on) when the Prophet (ﷺ) returned he, on seeing the Uhud mountain, said, "This is a mountain that loves us and is loved by us." Then he pointed to Medina with his hand saying, "O Allah! I make the area which is in between Medina's two mountains a sanctuary, as Abraham made Mecca a sanctuary. O Allah! Bless us in our Sa` and Mudd (i.e. units of measuring)}}
\hadithdefcmd{bukhari}{2890}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ أَبُو الرَّبِيعِ، عَنْ إِسْمَاعِيلَ بْنِ زَكَرِيَّاءَ، حَدَّثَنَا عَاصِمٌ، عَنْ مُوَرِّقٍ الْعِجْلِيِّ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم أَكْثَرُنَا ظِلاًّ الَّذِي يَسْتَظِلُّ بِكِسَائِهِ، وَأَمَّا الَّذِينَ صَامُوا فَلَمْ يَعْمَلُوا شَيْئًا، وَأَمَّا الَّذِينَ أَفْطَرُوا فَبَعَثُوا الرِّكَابَ وَامْتَهَنُوا وَعَالَجُوا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ذَهَبَ الْمُفْطِرُونَ الْيَوْمَ بِالأَجْرِ ‏"‏‏.‏\hadithno{2890}\hadithtrans{Narrated Anas:We were with the Prophet (on a journey) and the only shade one could have was the shade made by one's own garment. Those who fasted did not do any work and those who did not fast served the camels and brought the water on them and treated the sick and (wounded). So, the Prophet (ﷺ) said, "Today, those who were not fasting took (all) the reward}}
\hadithdefcmd{bukhari}{2891}{حَدَّثَنِي إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ سُلاَمَى عَلَيْهِ صَدَقَةٌ كُلَّ يَوْمٍ، يُعِينُ الرَّجُلَ فِي دَابَّتِهِ يُحَامِلُهُ عَلَيْهَا أَوْ يَرْفَعُ عَلَيْهَا مَتَاعَهُ صَدَقَةٌ، وَالْكَلِمَةُ الطَّيِّبَةُ، وَكُلُّ خَطْوَةٍ يَمْشِيهَا إِلَى الصَّلاَةِ صَدَقَةٌ، وَدَلُّ الطَّرِيقِ صَدَقَةٌ ‏"‏‏.‏\hadithno{2891}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Charity is obligatory everyday on every joint of a human being. If one helps a person in matters concerning his riding animal by helping him to ride it or by lifting his luggage on to it, all this will be regarded as charity. A good word, and every step one takes to offer the compulsory Congregational prayer, is regarded as charity; and guiding somebody on the road is regarded as charity}}
\hadithdefcmd{bukhari}{2892}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ أَبَا النَّضْرِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رِبَاطُ يَوْمٍ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا عَلَيْهَا، وَمَوْضِعُ سَوْطِ أَحَدِكُمْ مِنَ الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا عَلَيْهَا، وَالرَّوْحَةُ يَرُوحُهَا الْعَبْدُ فِي سَبِيلِ اللَّهِ أَوِ الْغَدْوَةُ خَيْرٌ مِنَ الدُّنْيَا وَمَا عَلَيْهَا ‏"‏‏.‏\hadithno{2892}\hadithtrans{Narrated Sahl bin Sa`d As-Sa'idi:Allah's Messenger (ﷺ) said, "To guard Muslims from infidels in Allah's Cause for one day is better than the world and whatever is on its surface, and a place in Paradise as small as that occupied by the whip of one of you is better than the world and whatever is on its surface; and a morning's or an evening's journey which a slave (person) travels in Allah's Cause is better than the world and whatever is on its surface}}
\hadithdefcmd{bukhari}{2893}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ، عَنْ عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأَبِي طَلْحَةَ ‏"‏ الْتَمِسْ غُلاَمًا مِنْ غِلْمَانِكُمْ يَخْدُمُنِي حَتَّى أَخْرُجَ إِلَى خَيْبَرَ ‏"‏‏.‏ فَخَرَجَ بِي أَبُو طَلْحَةَ مُرْدِفِي، وَأَنَا غُلاَمٌ رَاهَقْتُ الْحُلُمَ، فَكُنْتُ أَخْدُمُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا نَزَلَ، فَكُنْتُ أَسْمَعُهُ كَثِيرًا يَقُولُ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَالْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَالْجُبْنِ وَضَلَعِ الدَّيْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏‏.‏ ثُمَّ قَدِمْنَا خَيْبَرَ، فَلَمَّا فَتَحَ اللَّهُ عَلَيْهِ الْحِصْنَ ذُكِرَ لَهُ جَمَالُ صَفِيَّةَ بِنْتِ حُيَىِّ بْنِ أَخْطَبَ، وَقَدْ قُتِلَ زَوْجُهَا وَكَانَتْ عَرُوسًا، فَاصْطَفَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ، فَخَرَجَ بِهَا حَتَّى بَلَغْنَا سَدَّ الصَّهْبَاءِ حَلَّتْ، فَبَنَى بِهَا، ثُمَّ صَنَعَ حَيْسًا فِي نِطَعٍ صَغِيرٍ، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ آذِنْ مَنْ حَوْلَكَ ‏"‏‏.‏ فَكَانَتْ تِلْكَ وَلِيمَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى صَفِيَّةَ‏.‏ ثُمَّ خَرَجْنَا إِلَى الْمَدِينَةِ قَالَ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُحَوِّي لَهَا وَرَاءَهُ بِعَبَاءَةٍ، ثُمَّ يَجْلِسُ عِنْدَ بَعِيرِهِ فَيَضَعُ رُكْبَتَهُ، فَتَضَعُ صَفِيَّةُ رِجْلَهَا عَلَى رُكْبَتِهِ حَتَّى تَرْكَبَ، فَسِرْنَا حَتَّى إِذَا أَشْرَفْنَا عَلَى الْمَدِينَةِ نَظَرَ إِلَى أُحُدٍ فَقَالَ ‏"‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏‏.‏ ثُمَّ نَظَرَ إِلَى الْمَدِينَةِ فَقَالَ ‏"‏ اللَّهُمَّ إِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا بِمِثْلِ مَا حَرَّمَ إِبْرَاهِيمُ مَكَّةَ، اللَّهُمَّ بَارِكْ لَهُمْ فِي مُدِّهِمْ وَصَاعِهِمْ ‏"‏‏.‏\hadithno{2893}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said to Abu Talha, "Choose one of your boy servants to serve me in my expedition to Khaibar." So, Abu Talha took me letting me ride behind him while I was a boy nearing the age of puberty. I used to serve Allah's Messenger (ﷺ) when he stopped to rest. I heard him saying repeatedly, "O Allah! I seek refuge with You from distress and sorrow, from helplessness and laziness, from miserliness and cowardice, from being heavily in debt and from being overcome by men." Then we reached Khaibar; and when Allah enabled him to conquer the Fort (of Khaibar), the beauty of Safiya bint Huyai bin Akhtab was described to him. Her husband had been killed while she was a bride. So Allah's Messenger (ﷺ) selected her for himself and took her along with him till we reached a place called Sa`d-As-Sahba,' where her menses were over and he took her for his wife. Hais (a kind of dish) was served on a small leather sheet. Then Allah's Messenger (ﷺ) told me to call those who were around me. So, that was the marriage banquet of Allah's Messenger (ﷺ) and Safiya. Then we left for Medina. I saw Allah's Apostle folding a cloak round the hump of the camel so as to make a wide space for Safiya (to sit on behind him) He sat beside his camel letting his knees for Safiya to put her feet on so as to mount the camel. Then, we proceeded till we approached Medina; he looked at Uhud (mountain) and said, "This is a mountain which loves us and is loved by us." Then he looked at Medina and said, "O Allah! I make the area between its (i.e. Medina's) two mountains a sanctuary as Abraham made Mecca a sanctuary. O Allah! Bless them (i.e. the people of Medina) in their Mudd and Sa (i.e. measures)}}
\hadithdefcmd{bukhari}{2894}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ حَدَّثَتْنِي أُمُّ حَرَامٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ يَوْمًا فِي بَيْتِهَا، فَاسْتَيْقَظَ وَهْوَ يَضْحَكُ، قَالَتْ يَا رَسُولَ اللَّهِ، مَا يُضْحِكُكَ قَالَ ‏"‏ عَجِبْتُ مِنْ قَوْمٍ مِنْ أُمَّتِي يَرْكَبُونَ الْبَحْرَ، كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَقَالَ ‏"‏ أَنْتِ مَعَهُمْ ‏"‏‏.‏ ثُمَّ نَامَ، فَاسْتَيْقَظَ وَهْوَ يَضْحَكُ فَقَالَ مِثْلَ ذَلِكَ مَرَّتَيْنِ أَوْ ثَلاَثًا‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ، ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَيَقُولُ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ فَتَزَوَّجَ بِهَا عُبَادَةُ بْنُ الصَّامِتِ، فَخَرَجَ بِهَا إِلَى الْغَزْوِ، فَلَمَّا رَجَعَتْ قُرِّبَتْ دَابَّةٌ لِتَرْكَبَهَا، فَوَقَعَتْ فَانْدَقَّتْ عُنُقُهَا‏.‏\hadithno{2894}\hadithtrans{Narrated Anas bin Malik:Um Haram told me that the Prophet (ﷺ) one day took a midday nap in her house. Then he woke up smiling. Um Haram asked, "O Allah's Messenger (ﷺ)! What makes you smile?" He replied "I was astonished to see (in my dream) some people amongst my followers on a sea-voyage looking like kings on the thrones." She said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." He replied, "You are amongst them." He slept again and then woke up smiling and said the same as before twice or thrice. And she said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them." And he said, "You are amongst the first batch." 'Ubada bin As-Samit married her (i.e. Um Haram) and then he took her for Jihad. When she returned, an animal was presented to her to ride, but she fell down and her neck was broken}}
\hadithdefcmd{bukhari}{2896}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ طَلْحَةَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ رَأَى سَعْدٌ ـ رضى الله عنه ـ أَنَّ لَهُ فَضْلاً عَلَى مَنْ دُونَهُ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هَلْ تُنْصَرُونَ وَتُرْزَقُونَ إِلاَّ بِضُعَفَائِكُمْ ‏"‏‏.‏\hadithno{2896}\hadithtrans{Narrated Mus`ab bin Sa`d:Once Sa`d (bin Abi Waqqas) thought that he was superior to those who were below him in rank. On that the Prophet (ﷺ) said, "You gain no victory or livelihood except through (the blessings and invocations of) the poor amongst you}}
\hadithdefcmd{bukhari}{2897}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرًا، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنهم ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْتِي زَمَانٌ يَغْزُو فِئَامٌ مِنَ النَّاسِ، فَيُقَالُ فِيكُمْ مَنْ صَحِبَ النَّبِيَّ صلى الله عليه وسلم فَيُقَالُ نَعَمْ‏.‏ فَيُفْتَحُ عَلَيْهِ، ثُمَّ يَأْتِي زَمَانٌ فَيُقَالُ فِيكُمْ مَنْ صَحِبَ أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم فَيُقَالُ نَعَمْ‏.‏ فَيُفْتَحُ، ثُمَّ يَأْتِي زَمَانٌ فَيُقَالُ فِيكُمْ مَنْ صَحِبَ صَاحِبَ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَيُقَالُ نَعَمْ‏.‏ فَيُفْتَحُ ‏"‏‏.‏\hadithno{2897}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "A time will come when groups of people will go for Jihad and it will be asked, 'Is there anyone amongst you who has enjoyed the company of the Prophet?' The answer will be, 'Yes.' Then they will be given victory (by Allah) (because of him). Then a time will come when it will be asked. 'Is there anyone amongst you who has enjoyed the company of the companions of the Prophet?' It will be said, 'Yes,' and they will be given victory (by Allah). Then a time will come when it will be said. 'Is there anyone amongst you who has enjoyed the company of the companions of the companions of the Prophet?' It will be said, 'Yes,' and they will be given victory (by Allah)}}
\hadithdefcmd{bukhari}{2898}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم الْتَقَى هُوَ وَالْمُشْرِكُونَ فَاقْتَتَلُوا، فَلَمَّا مَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى عَسْكَرِهِ، وَمَالَ الآخَرُونَ إِلَى عَسْكَرِهِمْ، وَفِي أَصْحَابِ رَسُولِ اللَّه�� صلى الله عليه وسلم رَجُلٌ لاَ يَدَعُ لَهُمْ شَاذَّةً وَلاَ فَاذَّةً إِلاَّ اتَّبَعَهَا يَضْرِبُهَا بِسَيْفِهِ، فَقَالَ مَا أَجْزَأَ مِنَّا الْيَوْمَ أَحَدٌ كَمَا أَجْزَأَ فُلاَنٌ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا إِنَّهُ مِنْ أَهْلِ النَّارِ ‏"‏‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَنَا صَاحِبُهُ‏.‏ قَالَ فَخَرَجَ مَعَهُ كُلَّمَا وَقَفَ وَقَفَ مَعَهُ، وَإِذَا أَسْرَعَ أَسْرَعَ مَعَهُ قَالَ فَجُرِحَ الرَّجُلُ جُرْحًا شَدِيدًا، فَاسْتَعْجَلَ الْمَوْتَ، فَوَضَعَ نَصْلَ سَيْفِهِ بِالأَرْضِ وَذُبَابَهُ بَيْنَ ثَدْيَيْهِ، ثُمَّ تَحَامَلَ عَلَى سَيْفِهِ، فَقَتَلَ نَفْسَهُ، فَخَرَجَ الرَّجُلُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ اللَّهِ‏.‏ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏‏.‏ قَالَ الرَّجُلُ الَّذِي ذَكَرْتَ آنِفًا أَنَّهُ مِنْ أَهْلِ النَّارِ، فَأَعْظَمَ النَّاسُ ذَلِكَ‏.‏ فَقُلْتُ أَنَا لَكُمْ بِهِ‏.‏ فَخَرَجْتُ فِي طَلَبِهِ، ثُمَّ جُرِحَ جُرْحًا شَدِيدًا، فَاسْتَعْجَلَ الْمَوْتَ، فَوَضَعَ نَصْلَ سَيْفِهِ فِي الأَرْضِ وَذُبَابَهُ بَيْنَ ثَدْيَيْهِ، ثُمَّ تَحَامَلَ عَلَيْهِ، فَقَتَلَ نَفْسَهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ إِنَّ الرَّجُلَ لَيَعْمَلُ عَمَلَ أَهْلِ الْجَنَّةِ فِيمَا يَبْدُو لِلنَّاسِ، وَهْوَ مِنْ أَهْلِ النَّارِ، وَإِنَّ الرَّجُلَ لَيَعْمَلُ عَمَلَ أَهْلِ النَّارِ فِيمَا يَبْدُو لِلنَّاسِ، وَهْوَ مِنْ أَهْلِ الْجَنَّةِ ‏"‏‏.‏\hadithno{2898}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:Allah's Messenger (ﷺ) and the pagans faced each other and started fighting. When Allah's Messenger (ﷺ) returned to his camp and when the pagans returned to their camp, somebody talked about a man amongst the companions of Allah's Messenger (ﷺ) who would follow and kill with his sword any pagan going alone. He said, "Nobody did his job (i.e. fighting) so properly today as that man." Allah's Messenger (ﷺ) said, "Indeed, he is amongst the people of the (Hell) Fire." A man amongst the people said, "I shall accompany him (to watch what he does)" Thus he accompanied him, and wherever he stood, he would stand with him, and wherever he ran, he would run with him. Then the (brave) man got wounded seriously and he decided to bring about his death quickly. He planted the blade of the sword in the ground directing its sharp end towards his chest between his two breasts. Then he leaned on the sword and killed himself. The other man came to Allah's Messenger (ﷺ) and said, "I testify that you are Allah's Messenger (ﷺ)." The Prophet (ﷺ) asked, "What has happened?" He replied, "(It is about) the man whom you had described as one of the people of the (Hell) Fire. The people were greatly surprised at what you said, and I said, 'I will find out his reality for you.' So, I came out seeking him. He got severely wounded, and hastened to die by slanting the blade of his sword in the ground directing its sharp end towards his chest between his two breasts. Then he eased on his sword and killed himself." Then Allah's Messenger (ﷺ) said, "A man may seem to the people as if he were practising the deeds of the people of Paradise while in fact he is from the people of the Hell) Fire, another may seem to the people as if he were practicing the deeds of the people of Hell (Fire), while in fact he is from the people of Paradise}}
\hadithdefcmd{bukhari}{2899}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، قَالَ سَمِعْتُ سَلَمَةَ بْنَ الأَكْوَعِ ـ رضى الله عنه ـ قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم عَلَى نَفَرٍ مِنْ أَسْلَمَ يَنْتَضِلُونَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ارْمُوا بَنِي إِسْمَاعِيلَ، فَإِنَّ أَبَاكُمْ كَانَ رَامِيًا ارْمُوا وَأَنَا مَعَ بَنِي فُلاَنٍ ‏"‏‏.‏ قَالَ فَأَمْسَكَ أَحَدُ الْفَرِيقَيْنِ بِأَيْدِيهِمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكُمْ لاَ تَرْمُونَ ‏"‏‏.‏ قَالُوا كَيْفَ نَرْمِي وَأَنْتَ مَعَهُمْ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ارْمُوا فَأَنَا مَعَكُمْ كُلِّكُمْ ‏"‏‏.‏\hadithno{2899}\hadithtrans{Narrated Salama bin Al-Akwa`:The Prophet (ﷺ) passed by some people of the tribe of Bani Aslam who were practicing archery. The Prophet said, "O Bani Isma`il ! Practice archery as your father Isma`il was a great archer. Keep on throwing arrows and I am with Bani so-and-so." So one of the parties ceased throwing. Allah's Apostle said, "Why do you not throw?" They replied, "How should we throw while you are with them (i.e. on their side)?" On that the Prophet (ﷺ) said, "Throw, and I am with all of you}}
\hadithdefcmd{bukhari}{2900}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْغَسِيلِ، عَنْ حَمْزَةَ بْنِ أَبِي أُسَيْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ بَدْرٍ حِينَ صَفَفْنَا لِقُرَيْشٍ وَصَفُّوا لَنَا ‏ "‏ إِذَا أَكْثَبُوكُمْ فَعَلَيْكُمْ بِالنَّبْلِ ‏"‏‏.‏\hadithno{2900}\hadithtrans{Narrated Abu Usaid:On the day (of the battle) of Badr when we stood in rows against (the army of) Quraish and they stood in rows against us, the Prophet (ﷺ) said, "When they do come near you, throw arrows at them}}
\hadithdefcmd{bukhari}{2901}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَا الْحَبَشَةُ يَلْعَبُونَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم بِحِرَابِهِمْ دَخَلَ عُمَرُ، فَأَهْوَى إِلَى الْحَصَى فَحَصَبَهُمْ بِهَا‏.‏ فَقَالَ ‏ "‏ دَعْهُمْ يَا عُمَرُ ‏"‏‏.‏ وَزَادَ عَلِيٌّ حَدَّثَنَا عَبْدُ الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ فِي الْمَسْجِدِ‏.‏\hadithno{2901}\hadithtrans{Narrated Abu Huraira:While some Ethiopians were playing in the presence of the Prophet, `Umar came in, picked up a stone and hit them with it. On that the Prophet (ﷺ) said, "O `Umar! Allow them (to play)." Ma`mar (the subnarrator) added that they were playing in the Mosque}}
\hadithdefcmd{bukhari}{2902}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الأَوْزَاعِيُّ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ أَبُو طَلْحَةَ يَتَتَرَّسُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِتُرْسٍ وَاحِدٍ، وَكَانَ أَبُو طَلْحَةَ حَسَنَ الرَّمْىِ، فَكَانَ إِذَا رَمَى تَشَرَّفَ النَّبِيُّ صلى الله عليه وسلم فَيَنْظُرُ إِلَى مَوْضِعِ نَبْلِهِ‏.‏\hadithno{2902}\hadithtrans{Narrated Anas bin Malik:Abu Talha and the Prophet (ﷺ) used to shield themselves with one shield. Abu Talha was a good archer, and when he threw (his arrows) the Prophet (ﷺ) would look at the target of his arrows}}
\hadithdefcmd{bukhari}{2903}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلٍ، قَالَ لَمَّا كُسِرَتْ بَيْضَةُ النَّبِيِّ صلى الله عليه وسلم عَلَى رَأْسِهِ وَأُدْمِيَ وَجْهُهُ، وَكُسِرَتْ رَبَاعِيَتُهُ، وَكَانَ عَلِيٌّ يَخْتَلِفُ بِالْمَاءِ فِي الْمِجَنِّ، وَكَانَتْ فَاطِمَةُ تَغْسِلُهُ، فَلَمَّا رَأَتِ الدَّمَ يَزِيدُ عَلَى الْمَاءِ كَثْرَةً عَمَدَتْ إِلَى حَصِيرٍ، فَأَحْرَقَتْهَا وَأَلْصَقَتْهَا عَلَى جُرْحِهِ، فَرَقَأَ الدَّمُ‏.‏\hadithno{2903}\hadithtrans{Narrated Sahl:When the helmet of the Prophet (ﷺ) was smashed on his head and blood covered his face and one of his front teeth got broken, `Ali brought the water in his shield and Fatima the Prophet's daughter) washed him. But when she saw that the bleeding increased more by the water, she took a mat, burnt it, and placed the ashes on the wound of the Prophet (ﷺ) and so the blood stopped oozing out}}
\hadithdefcmd{bukhari}{2904}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، عَنْ عُمَرَ ـ رضى الله عنه ـ قَالَ كَانَتْ أَمْوَالُ بَنِي النَّضِيرِ مِمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم مِمَّا لَمْ يُوجِفِ الْمُسْلِمُونَ عَلَيْهِ بِخَيْلٍ وَلاَ رِكَابٍ، فَكَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَاصَّةً، وَكَانَ يُنْفِقُ عَلَى أَهْلِهِ نَفَقَةَ سَنَتِهِ، ثُمَّ يَجْعَلُ مَا بَقِيَ فِي السِّلاَحِ وَالْكُرَاعِ، عُدَّةً فِي سَبِيلِ اللَّهِ‏.‏\hadithno{2904}\hadithtrans{Narrated `Umar:The properties of Bani An-Nadir which Allah had transferred to His Apostle as Fai Booty were not gained by the Muslims with their horses and camels. The properties therefore, belonged especially to Allah's Messenger (ﷺ) who used to give his family their yearly expenditure and spend what remained thereof on arms and horses to be used in Allah's Cause}}
\hadithdefcmd{bukhari}{2905}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي سَعْدُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ عَلِيٍّ، حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ شَدَّادٍ، قَالَ سَمِعْتُ عَلِيًّا ـ رضى الله عنه ـ يَقُولُ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُفَدِّي رَجُلاً بَعْدَ سَعْدٍ، سَمِعْتُهُ يَقُولُ ‏ "‏ ارْمِ فِدَاكَ أَبِي وَأُمِّي ‏"‏‏.‏\hadithno{2905}\hadithtrans{Narrated `Ali:I never saw the Prophet (ﷺ) saying, "Let my parents sacrifice their lives for you," to any man after Sa`d. I heard him saying (to him), "Throw (the arrows)! Let my parents sacrifice their lives for you}}
\hadithdefcmd{bukhari}{2907}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ عَمْرٌو حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي جَارِيَتَانِ تُغَنِّيَانِ بِغِنَاءِ بُعَاثَ، فَاضْطَجَعَ عَلَى الْفِرَاشِ وَحَوَّلَ وَجْهَهُ، فَدَخَلَ أَبُو بَكْرٍ فَانْتَهَرَنِي وَقَالَ مِزْمَارَةُ الشَّيْطَانِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَأَقْبَلَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ دَعْهُمَا ‏"‏‏.‏ فَلَمَّا غَفَلَ غَمَزْتُهُمَا فَخَرَجَتَا‏.‏ قَالَتْ وَكَانَ يَوْمُ عِيدٍ يَلْعَبُ السُّودَانُ بِالدَّرَقِ وَالْحِرَابِ، فَإِمَّا سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَإِمَّا قَالَ ‏"‏ تَشْتَهِينَ تَنْظُرِينَ ‏"‏‏.‏ فَقَالَتْ نَعَمْ‏.‏ فَأَقَامَنِي وَرَاءَهُ خَدِّي عَلَى خَدِّهِ وَيَقُولُ ‏"‏ دُونَكُمْ بَنِي أَرْفِدَةَ ‏"‏‏.‏ حَتَّى إِذَا مَلِلْتُ قَالَ ‏"‏ حَسْبُكِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَاذْهَبِي ‏"‏‏.‏ قَالَ أَحْمَدُ عَنِ ابْنِ وَهْبٍ، فَلَمَّا غَفَلَ‏.‏\hadithno{2907}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) came to my house while two girls were singing beside me the songs of Bu'ath (a story about the war between the two tribes of the Ansar, i.e. Khazraj and Aus, before Islam.) The Prophet (ﷺ) reclined on the bed and turned his face to the other side. Abu Bakr came and scolded me and said protestingly, "Instrument of Satan in the presence of Allah's Messenger (ﷺ)?" Allah's Messenger (ﷺ) turned his face towards him and said, "Leave them." When Abu Bakr became inattentive, I waved the two girls to go away and they left. It was the day of `Id when negroes used to play with leather shields and spears. Either I requested Allah's Messenger (ﷺ) or he himself asked me whether I would like to see the display. I replied in the affirmative. Then he let me stand behind him and my cheek was touching his cheek and he was saying, "Carry on, O Bani Arfida (i.e. negroes)!" When I got tired, he asked me if that was enough. I replied in the affirmative and he told me to leave}}
\hadithdefcmd{bukhari}{2908}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم أَحْسَنَ النَّاسِ وَأَشْجَعَ النَّاسِ، وَلَقَدْ فَزِعَ أَهْلُ الْمَدِينَةِ لَيْلَةً فَخَرَجُوا نَحْوَ الصَّوْتِ فَاسْتَقْبَلَهُمُ النَّبِيُّ صلى الله عليه وسلم وَقَدِ اسْتَبْرَأَ الْخَبَرَ، وَهْوَ عَلَى فَرَسٍ لأَبِي طَلْحَةَ عُرْىٍ وَفِي عُنُقِهِ السَّيْفُ وَهْوَ يَقُولُ ‏"‏ لَمْ تُرَاعُوا لَمْ تُرَاعُوا ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ وَجَدْنَاهُ بَحْرًا ‏"‏‏.‏ أَوْ قَالَ ‏"‏ إِنَّهُ لَبَحْرٌ ‏"‏‏.‏\hadithno{2908}\hadithtrans{Narrated Anas:The 'Prophet was the best and the bravest amongst the people. Once the people of Medina got terrified at night, so they went in the direction of the noise (that terrified them). The Prophet (ﷺ) met them (on his way back) after he had found out the truth. He was riding an unsaddled horse belonging to Abu Talha and a sword was hanging by his neck, and he was saying, "Don't be afraid! Don't be afraid!" He further said, "I found it (i.e. the horse) very fast," or said, "This horse is very fast." (Qastala-ni)}}
\hadithdefcmd{bukhari}{2909}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الأَوْزَاعِيُّ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ حَبِيبٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ لَقَدْ فَتَحَ الْفُتُوحَ قَوْمٌ مَا كَانَتْ حِلْيَةُ سُيُوفِهِمِ الذَّهَبَ وَلاَ الْفِضَّةَ، إِنَّمَا كَانَتْ حِلْيَتُهُمُ الْعَلاَبِيَّ وَالآنُكَ وَالْحَدِيدَ‏.‏\hadithno{2909}\hadithtrans{Narrated Abu Umama:Some people conquered many countries and their swords were decorated neither with gold nor silver, but they were decorated with leather, lead and iron}}
\hadithdefcmd{bukhari}{2910}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سِنَانُ بْنُ أَبِي سِنَانٍ الدُّؤَلِيُّ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَخْبَرَ أَنَّهُ، غَزَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قِبَلَ نَجْدٍ، فَلَمَّا قَفَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَفَلَ مَعَهُ، فَأَدْرَكَتْهُمُ الْقَائِلَةُ فِي وَادٍ كَثِيرِ الْعِضَاهِ، فَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَفَرَّقَ النَّاسُ يَسْتَظِلُّونَ بِالشَّجَرِ، فَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَحْتَ سَمُرَةٍ وَعَلَّقَ بِهَا سَيْفَهُ وَنِمْنَا نَوْمَةً، فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُونَا وَإِذَا عِنْدَهُ أَعْرَابِيٌّ فَقَالَ ‏"‏ إِنَّ هَذَا اخْتَرَطَ عَلَىَّ سَيْفِي وَأَنَا نَائِمٌ، فَاسْتَيْقَظْتُ وَهْوَ فِي يَدِهِ صَلْتًا ‏"‏‏.‏ فَقَالَ مَنْ يَمْنَعُكَ مِنِّي فَقُلْتُ ‏"‏ اللَّهُ ‏"‏‏.‏ ثَلاَثًا وَلَمْ يُعَاقِبْهُ وَجَلَسَ‏.‏\hadithno{2910}\hadithtrans{Narrated Jabir bin `Abdullah:That he proceeded in the company of Allah's Messenger (ﷺ) towards Najd to participate in a Ghazwa. (Holybattle) When Allah's Messenger (ﷺ) returned, he too returned with him. Midday came upon them while they were in a valley having many thorny trees. Allah's Messenger (ﷺ) and the people dismounted and dispersed to rest in the shade of the trees. Allah's Messenger (ﷺ) rested under a tree and hung his sword on it. We all took a nap and suddenly we heard Allah's Messenger (ﷺ) calling us. (We woke up) to see a bedouin with him. The Prophet (ﷺ) said, "This bedouin took out my sword while I was sleeping and when I woke up, I found the unsheathed sword in his hand and he challenged me saying, 'Who will save you from me?' I said thrice, 'Allah.' The Prophet (ﷺ) did not punish him but sat down}}
\hadithdefcmd{bukhari}{2911}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ ـ رضى الله عنه ـ أَنَّهُ سُئِلَ عَنْ جُرْحِ النَّبِيِّ، صلى الله عليه وسلم يَوْمَ أُحُدٍ‏.‏ فَقَالَ جُرِحَ وَجْهُ النَّبِيِّ صلى الله عليه وسلم وَكُسِرَتْ رَبَاعِيَتُهُ وَهُشِمَتِ الْبَيْضَةُ عَلَى رَأْسِهِ، فَكَانَتْ فَاطِمَةُ ـ عَلَيْهَا السَّلاَمُ ـ تَغْسِلُ الدَّمَ وَعَلِيٌّ يُمْسِكُ، فَلَمَّا رَأَتْ أَنَّ الدَّمَ لاَ يَزِيدُ إِلاَّ كَثْرَةً أَخَذَتْ حَصِيرًا فَأَحْرَقَتْهُ حَتَّى صَارَ رَمَادًا ثُمَّ أَلْزَقَتْهُ، فَاسْتَمْسَكَ الدَّمُ‏.‏\hadithno{2911}\hadithtrans{Narrated Sahl:That he was asked about the wound of the Prophet (ﷺ) on the day (of the battle) of Uhud. He said, "The face of the Prophet (ﷺ) was wounded and one of his front teeth was broken and the helmet over his head was smashed. Fatima washed off the blood while `Ali held water. When she saw that the bleeding was increasing continuously, she burnt a mat (of date-palm leaves) till it turned into ashes which she put over the wound and thus the bleeding ceased}}
\hadithdefcmd{bukhari}{2912}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، قَالَ مَا تَرَكَ النَّبِيُّ صلى الله عليه وسلم إِلاَّ سِلاَحَهُ وَبَغْلَةً بَيْضَاءَ وَأَرْضًا جَعَلَهَا صَدَقَةً‏.‏\hadithno{2912}\hadithtrans{Narrated `Amr bin Al-Harith:The Prophet (ﷺ) did not leave behind him after his death, anything except his arms, his white mule, and a piece of land at Khaibar which he left to be given in charity}}
\hadithdefcmd{bukhari}{2913}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا سِنَانُ بْنُ أَبِي سِنَانٍ، وَأَبُو سَلَمَةَ أَنَّ جَابِرًا، أَخْبَرَهُ‏.‏ حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ سِنَانِ بْنِ أَبِي سِنَانٍ الدُّؤَلِيِّ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّهُ، غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم فَأَدْرَكَتْهُمُ الْقَائِلَةُ فِي وَادٍ كَثِيرِ الْعِضَاهِ، فَتَفَرَّقَ النَّاسُ فِي الْعِضَاهِ يَسْتَظِلُّونَ بِالشَّجَرِ، فَنَزَلَ النَّبِيُّ صلى الله عليه وسلم تَحْتَ شَجَرَةٍ فَعَلَّقَ بِهَا سَيْفَهُ ثُمَّ نَامَ، فَاسْتَيْقَظَ وَعِنْدَهُ رَجُلٌ وَهْوَ لاَ يَشْعُرُ بِهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ هَذَا اخْتَرَطَ سَيْفِي ‏"‏‏.‏ فَقَالَ مَنْ يَمْنَعُكَ قُلْتُ ‏"‏ اللَّهُ ‏"‏‏.‏ فَشَامَ السَّيْفَ، فَهَا هُوَ ذَا جَالِسٌ، ثُمَّ لَمْ يُعَاقِبْهُ‏.‏\hadithno{2913}\hadithtrans{Narrated Jabir:as above (Hadith No. 158). Narrated Jabir bin `Abdullah: That he participated in a Ghazwa (Holy-Battle) in the company of Allah's Messenger (ﷺ). Midday came upon them while they were in a valley having many thorny trees. The people dispersed to rest in the shade of the trees. The Prophet (ﷺ) rested under a tree, hung his sword on it, and then slept. Then he woke up to find near to him, a man whose presence he had not noticed before. The Prophet (ﷺ) said, "This (man) took my sword (out of its scabbard) and said, 'Who will save you from me.' I replied, 'Allah.' So, he put the sword back into its scabbard, and you see him sitting here." Anyhow, the Prophet (ﷺ) did not punish him. (See Hadith No)}}
\hadithdefcmd{bukhari}{2914}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ الأَنْصَارِيِّ عَنْ أَبِي قَتَادَةَ ـ رضى الله عنه ـ أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِبَعْضِ طَرِيقِ مَكَّةَ تَخَلَّفَ مَعَ أَصْحَابٍ لَهُ مُحْرِمِينَ وَهْوَ غَيْرُ مُحْرِمٍ، فَرَأَى حِمَارًا وَحْشِيًّا فَاسْتَوَى عَلَى فَرَسِهِ، فَسَأَلَ أَصْحَابَهُ أَنْ يُنَاوِلُوهُ سَوْطَهُ فَأَبَوْا، فَسَأَلَهُمْ رُمْحَهُ فَأَبَوْا، فَأَخَذَهُ ثُمَّ شَدَّ عَلَى الْحِمَارِ فَقَتَلَهُ، فَأَكَلَ مِنْهُ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم، وَأَبَى بَعْضٌ، فَلَمَّا أَدْرَكُوا رَسُولَ اللَّهِ صلى الله عليه وسلم سَأَلُوهُ عَنْ ذَلِكَ قَالَ ‏"‏ إِنَّمَا هِيَ طُعْمَةٌ أَطْعَمَكُمُوهَا اللَّهُ ‏"‏‏.‏ وَعَنْ زَيْدِ بْنِ أَسْلَمَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ أَبِي قَتَادَةَ فِي الْحِمَارِ الْوَحْشِيِّ مِثْلُ حَدِيثِ أَبِي النَّضْرِ قَالَ ‏"‏ هَلْ مَعَكُمْ مِنْ لَحْمِهِ شَىْءٌ ‏"‏‏.‏\hadithno{2914}\hadithtrans{Narrated Abu Qatada:That he was in the company of Allah's Messenger (ﷺ) and when they had covered a portion of the road to Mecca, he and some of the companions lagged behind. The latter were in a state of Ihram, while he was not. He saw an onager and rode his horse and requested his companions to give him his lash but they refused. Then he asked them to give him his spear but they refused, so he took it himself, attacked the onager, and killed it. Some of the companions of the Prophet (ﷺ) ate of it while some others refused to eat. When they caught up with Allah's Messenger (ﷺ) they asked him about that, and he said, "That was a meal Allah fed you with." (It is also said that Allah's Messenger (ﷺ) asked, "Have you got something of its meat?}}
\hadithdefcmd{bukhari}{2915}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم وَهْوَ فِي قُبَّةٍ ‏"‏ اللَّهُمَّ إِنِّي أَنْشُدُكَ عَهْدَكَ وَوَعْدَكَ، اللَّهُمَّ إِنْ شِئْتَ لَمْ تُعْبَدْ بَعْدَ الْيَوْمِ ‏"‏‏.‏ فَأَخَذَ أَبُو بَكْرٍ بِيَدِهِ فَقَالَ حَسْبُكَ يَا رَسُولَ اللَّهِ، فَقَدْ أَلْحَحْتَ عَلَى رَبِّكَ، وَهْوَ فِي الدِّرْعِ، فَخَرَجَ وَهْوَ يَقُولُ ‏\{‏سَيُهْزَمُ الْجَمْعُ وَيُوَلُّونَ الدُّبُرَ * بَلِ السَّاعَةُ مَوْعِدُهُمْ وَالسَّاعَةُ أَدْهَى وَأَمَرُّ ‏\}‏‏.‏ وَقَالَ وُهَيْبٌ حَدَّثَنَا خَالِدٌ يَوْمَ بَدْرٍ‏.‏\hadithno{2915}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) , while in a tent (on the day of the battle of Badr) said, "O Allah! I ask you the fulfillment of Your Covenant and Promise. O Allah! If You wish (to destroy the believers) You will never be worshipped after today." Abu Bakr caught him by the hand and said, "This is sufficient, O Allah's Apostle! You have asked Allah pressingly." The Prophet (ﷺ) was clad in his armor at that time. He went out, saying to me: "Their multitude will be put to flight and they will show their backs. Nay, but the Hour is their appointed time (for their full recompense) and that Hour will be more grievous and more bitter (than their worldly failure)." (54.45-46) Khalid said that was on the day of the battle of Badr}}
\hadithdefcmd{bukhari}{2916}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَدِرْعُهُ مَرْهُونَةٌ عِنْدَ يَهُودِيٍّ بِثَلاَثِينَ صَاعًا مِنْ شَعِيرٍ‏.‏ وَقَالَ يَعْلَى حَدَّثَنَا الأَعْمَشُ دِرْعٌ مِنْ حَدِيدٍ‏.‏ وَقَالَ مُعَلًّى حَدَّثَنَا عَبْدُ الْوَاحِدِ حَدَّثَنَا الأَعْمَشُ وَقَالَ رَهَنَهُ دِرْعًا مِنْ حَدِيدٍ‏.‏\hadithno{2916}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) died while his (iron) armor was mortgaged to a Jew for thirty Sas of barley}}
\hadithdefcmd{bukhari}{2917}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَثَلُ الْبَخِيلِ وَالْمُتَصَدِّقِ مَثَلُ رَجُلَيْنِ عَلَيْهِمَا جُبَّتَانِ مِنْ حَدِيدٍ، قَدِ اضْطَرَّتْ أَيْدِيَهُمَا إِلَى تَرَاقِيهِمَا، فَكُلَّمَا هَمَّ الْمُتَصَدِّقُ بِصَدَقَتِهِ اتَّسَعَتْ عَلَيْهِ حَتَّى تُعَفِّيَ أَثَرَهُ، وَكُلَّمَا هَمَّ الْبَخِيلُ بِالصَّدَقَةِ انْقَبَضَتْ كُلُّ حَلْقَةٍ إِلَى صَاحِبَتِهَا وَتَقَلَّصَتْ عَلَيْهِ وَانْضَمَّتْ يَدَاهُ إِلَى تَرَاقِيهِ ‏"‏‏.‏ فَسَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ فَيَجْتَهِدُ أَنْ يُوَسِّعَهَا فَلاَ تَتَّسِعُ ‏"‏‏.‏\hadithno{2917}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The example of a miser and the one who gives in charity, is like the example of two men wearing iron cloaks so tightly that their arms are raised forcibly towards their collar-bones. So, whenever a charitable person wants to give in charity, his cloak spreads over his body so much so that it wipes out his traces, but whenever the miser wants to give in charity, the rings (of the iron cloak) come closer to each other and press over his body, and his hands get connected to his collarbones. Abu Huraira heard the Prophet (ﷺ) saying. "The miser then tries to widen it but in vain}}
\hadithdefcmd{bukhari}{2918}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي الضُّحَى، مُسْلِمٍ ـ هُوَ ابْنُ صُبَيْحٍ ـ عَنْ مَسْرُوقٍ، قَالَ حَدَّثَنِي الْمُغِيرَةُ بْنُ شُعْبَةَ، قَالَ انْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحَاجَتِهِ ثُمَّ أَقْبَلَ، فَلَقِيتُهُ بِمَاءٍ، وَعَلَيْهِ جُبَّةٌ شَأْمِيَّةٌ، فَمَضْمَضَ وَاسْتَنْشَقَ وَغَسَلَ وَجْهَهُ، فَذَهَبَ يُخْرِجُ يَدَيْهِ مِنْ كُمَّيْهِ فَكَانَا ضَيِّقَيْنِ، فَأَخْرَجَهُمَا مِنْ تَحْتُ، فَغَسَلَهُمَا وَمَسَحَ بِرَأْسِهِ وَعَلَى خُفَّيْهِ‏.‏\hadithno{2918}\hadithtrans{Narrated Al-Mughira bin Shu`ba:Allah's Messenger (ﷺ) went out to answer the call of nature and on his return I brought some water to him. He performed the ablution while he was wearing a Sha'mi cloak. He rinsed his mouth and washed his nose by putting water in it and then blowing it out, and washed his face. Then he tried to take out his hands through his sleeves but they were tight, so he took them out from underneath, washed them and passed wet hands over his head and over his leather socks}}
\hadithdefcmd{bukhari}{2919}{حَدَّثَنَا أَحْمَدُ بْنُ الْمِقْدَامِ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسًا، حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَالزُّبَيْرِ فِي قَمِيصٍ مِنْ حَرِيرٍ، مِنْ حِكَّةٍ كَانَتْ بِهِمَا‏.‏\hadithno{2919}\hadithtrans{Narrated Anas:The Prophet (ﷺ) allowed `Abdur-Rahman bin `Auf and Az-Zubair to wear silken shirts because they had a skin disease causing itching}}
\hadithdefcmd{bukhari}{2920}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ عَبْدَ، الرَّحْمَنِ بْنَ عَوْفٍ وَالزُّبَيْرَ شَكَوَا إِلَى النَّبِيِّ صلى الله عليه وسلم ـ يَعْنِي الْقَمْلَ ـ فَأَرْخَصَ لَهُمَا فِي الْحَرِيرِ، فَرَأَيْتُهُ عَلَيْهِمَا فِي غَزَاةٍ‏.‏\hadithno{2920}\hadithtrans{Narrated Anas:As above. Narrated Anas: `Abdur Rahman bin `Auf and Az-Zubair complained to the Prophet, i.e. about the lice (that caused itching) so he allowed them to wear silken clothes. I saw them wearing such clothes in a holy battle}}
\hadithdefcmd{bukhari}{2921}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، أَخْبَرَنِي قَتَادَةُ، أَنَّ أَنَسًا، حَدَّثَهُمْ قَالَ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَالزُّبَيْرِ بْنِ الْعَوَّامِ فِي حَرِيرٍ‏.‏\hadithno{2921}\hadithtrans{Narrated Anas:The Prophet (ﷺ) allowed `Abdur-Rahman bin `Auf and Az-Zubair bin Al-`Awwam to wear silk}}
\hadithdefcmd{bukhari}{2922}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، عَنْ أَنَسٍ، رَخَّصَ أَوْ رُخِّصَ لِحِكَّةٍ بِهِمَا‏.‏\hadithno{2922}\hadithtrans{Narrated Anas:(Wearing of silk) was allowed to them (i.e. `AbdurRahman and Az-Zubair) because of the itching they suffered from}}
\hadithdefcmd{bukhari}{2923}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَأْكُلُ مِنْ كَتِفٍ يَحْتَزُّ مِنْهَا، ثُمَّ دُعِيَ إِلَى الصَّلاَةِ فَصَلَّى وَلَمْ يَتَوَضَّأْ‏.‏ حَدَّثَنَا أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ عَنِ الزُّهْرِيِّ وَزَادَ فَأَلْقَى السِّكِّينَ‏.‏\hadithno{2923}\hadithtrans{Narrated Umaiya Ad-Damri:I saw the Prophet (ﷺ) eating of a shoulder (of a sheep) by cutting from it and then he was called to prayer and he prayed without repeating his ablution. Narrated Az-Zuhri: as above (Hadith No. 173...) and added that the Prophet (ﷺ) put the knife down}}
\hadithdefcmd{bukhari}{2924}{حَدَّثَنِي إِسْحَاقُ بْنُ يَزِيدَ الدِّمَشْقِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، قَالَ حَدَّثَنِي ثَوْرُ بْنُ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، أَنَّ عُمَيْرَ بْنَ الأَسْوَدِ الْعَنْسِيَّ، حَدَّثَهُ أَنَّهُ، أَتَى عُبَادَةَ بْنَ الصَّامِتِ وَهْوَ نَازِلٌ فِي سَاحِلِ حِمْصَ، وَهْوَ فِي بِنَاءٍ لَهُ وَمَعَهُ أُمُّ حَرَامٍ، قَالَ عُمَيْرٌ فَحَدَّثَتْنَا أُمُّ حَرَامٍ أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ أَوَّلُ جَيْشٍ مِنْ أُمَّتِي يَغْزُونَ الْبَحْرَ قَدْ أَوْجَبُوا ‏"‏‏.‏ قَالَتْ أُمُّ حَرَامٍ قُلْتُ يَا رَسُولَ اللَّهِ أَنَا فِيهِمْ‏.‏ قَالَ ‏"‏ أَنْتِ فِيهِمْ ‏"‏‏.‏ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَوَّلُ جَيْشٍ مِنْ أُمَّتِي يَغْزُونَ مَدِينَةَ قَيْصَرَ مَغْفُورٌ لَهُمْ ‏"‏‏.‏ فَقُلْتُ أَنَا فِيهِمْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏\hadithno{2924}\hadithtrans{Narrated Khalid bin Madan:That 'Umair bin Al-Aswad Al-Ansi told him that he went to 'Ubada bin As-Samit while he was staying in his house at the sea-shore of Hims with (his wife) Um Haram. 'Umair said. Um Haram informed us that she heard the Prophet (ﷺ) saying, "Paradise is granted to the first batch of my followers who will undertake a naval expedition." Um Haram added, I said, 'O Allah's Messenger (ﷺ)! Will I be amongst them?' He replied, 'You are amongst them.' The Prophet (ﷺ) then said, 'The first army amongst' my followers who will invade Caesar's City will be forgiven their sins.' I asked, 'Will I be one of them, O Allah's Messenger (ﷺ)?' He replied in the negative}}
\hadithdefcmd{bukhari}{2925}{حَدَّثَنَا إِسْحَاقُ بْنُ مُحَمَّدٍ الْفَرْوِيُّ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُقَاتِلُونَ الْيَهُودَ حَتَّى يَخْتَبِيَ أَحَدُهُمْ وَرَاءَ الْحَجَرِ فَيَقُولُ يَا عَبْدَ اللَّهِ هَذَا يَهُودِيٌّ وَرَائِي فَاقْتُلْهُ ‏"‏‏.‏\hadithno{2925}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "You (i.e. Muslims) will fight with the Jews until some of them will hide behind stones. The stones will (betray them) saying, 'O `Abdullah (i.e. slave of Allah)! There is a Jew hiding behind me; so kill him}}
\hadithdefcmd{bukhari}{2926}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا الْيَهُودَ حَتَّى يَقُولَ الْحَجَرُ وَرَاءَهُ الْيَهُودِيُّ يَا مُسْلِمُ، هَذَا يَهُودِيٌّ وَرَائِي فَاقْتُلْهُ ‏"‏‏.‏\hadithno{2926}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established until you fight with the Jews, and the stone behind which a Jew will be hiding will say. "O Muslim! There is a Jew hiding behind me, so kill him}}
\hadithdefcmd{bukhari}{2927}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ سَمِعْتُ الْحَسَنَ، يَقُولُ حَدَّثَنَا عَمْرُو بْنُ تَغْلِبَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ تُقَاتِلُوا قَوْمًا يَنْتَعِلُونَ نِعَالَ الشَّعَرِ، وَإِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ تُقَاتِلُوا قَوْمًا عِرَاضَ الْوُجُوهِ، كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطَرَّقَةُ ‏"‏‏.‏\hadithno{2927}\hadithtrans{Narrated `Amr bin Taghlib:The Prophet (ﷺ) said, "One of the portents of the Hour is that you will fight with people wearing shoes made of hair; and one of the portents of the Hour is that you will fight with broad-faced people whose faces will look like shields coated with leather}}
\hadithdefcmd{bukhari}{2928}{حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ الأَعْرَجِ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا التُّرْكَ صِغَارَ الأَعْيُنِ، حُمْرَ الْوُجُوهِ، ذُلْفَ الأُنُوفِ، كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطَرَّقَةُ، وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ ‏"‏‏.‏\hadithno{2928}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established until you fight with the Turks; people with small eyes, red faces, and flat noses. Their faces will look like shields coated with leather. The Hour will not be established till you fight with people whose shoes are made of hair}}
\hadithdefcmd{bukhari}{2929}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ، وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطَرَّقَةُ ‏"‏‏.‏ قَالَ سُفْيَانُ وَزَادَ فِيهِ أَبُو الزِّنَادِ عَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ، رِوَايَةً ‏"‏ صِغَارَ الأَعْيُنِ، ذُلْفَ الأُنُوفِ، كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏‏.‏\hadithno{2929}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till you fight with people wearing shoes made of hair. And the Hour will not be established till you fight with people whose faces look like shields coated with leather. " (Abu Huraira added, "They will be) small-eyed, flat nosed, and their faces will look like shields coated with leather}}
\hadithdefcmd{bukhari}{2930}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، وَسَأَلَهُ، رَجُلٌ أَكُنْتُمْ فَرَرْتُمْ يَا أَبَا عُمَارَةَ يَوْمَ حُنَيْنٍ قَالَ لاَ، وَاللَّهِ مَا وَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم، وَلَكِنَّهُ خَرَجَ شُبَّانُ أَصْحَابِهِ وَأَخِفَّاؤُهُمْ حُسَّرًا لَيْسَ بِسِلاَحٍ، فَأَتَوْا قَوْمًا رُمَاةً، جَمْعَ هَوَازِنَ وَبَنِي نَصْرٍ، مَا يَكَادُ يَسْقُطُ لَهُمْ سَهْمٌ، فَرَشَقُوهُمْ رَشْقًا مَا يَكَادُونَ يُخْطِئُونَ، فَأَقْبَلُوا هُنَالِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ عَلَى بَغْلَتِهِ الْبَيْضَاءِ، وَابْنُ عَمِّهِ أَبُو سُفْيَانَ بْنُ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ يَقُودُ بِهِ، فَنَزَلَ وَاسْتَنْصَرَ ثُمَّ قَالَ أَنَا النَّبِيُّ لاَ كَذِبْ أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ ثُمَّ صَفَّ أَصْحَابَهُ‏.‏\hadithno{2930}\hadithtrans{Narrated Abu 'Is-haq:A man asked Al-Bara', "O Abu '`Umara! Did you all flee on the day (of the battle) of Hunain?" He replied, "No, by Allah! Allah's Messenger (ﷺ) did not flee, but his young unarmed companions passed by the archers of the tribe of Hawazin and Bani Nasr whose arrows hardly missed a target, and they threw arrows at them hardly missing a shot. So the Muslims retreated towards the Prophet (ﷺ) while he was riding his white mule which was being led by his cousin Abu Sufyan bin Al-Harith bin `Abdul Muttalib. The Prophet (ﷺ) dismounted and invoked Allah for victory; then he said, 'I am the Prophet, without a lie; I am the son of `Abdul Muttalib, and then he arranged his companions in rows}}
\hadithdefcmd{bukhari}{2931}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ لَمَّا كَانَ يَوْمُ الأَحْزَابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَلأَ اللَّهُ بُيُوتَهُمْ وَقُبُورَهُمْ نَارًا، شَغَلُونَا عَنِ الصَّلاَةِ الْوُسْطَى حِينَ غَابَتِ الشَّمْسُ ‏"‏‏.‏\hadithno{2931}\hadithtrans{Narrated `Ali:When it was the day of the battle of Al-Ahzab (i.e. the clans), Allah's Messenger (ﷺ) said, "O Allah! Fill their (i.e. the infidels') houses and graves with fire as they busied us so much that we did not perform the prayer (i.e. `Asr) till the sun set}}
\hadithdefcmd{bukhari}{2932}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ ذَكْوَانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو فِي الْقُنُوتِ ‏ "‏ اللَّهُمَّ أَنْجِ سَلَمَةَ بْنَ هِشَامٍ، اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ، اللَّهُمَّ أَنْجِ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ، اللَّهُمَّ أَنْجِ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، اللَّهُمَّ سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏\hadithno{2932}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) used to recite the following invocations during Qunut: "O Allah! Save Salama bin Hisham. O Allah! Save Al-Walid bin Al-Walid. O Allah! Save `Aiyash bin Rabi`a O Allah ! Save the weak Muslims. O Allah! Be very hard on Mudar tribe. O Allah! Afflict them with years (of famine) similar to the (famine) years of the time of Prophet Joseph}}
\hadithdefcmd{bukhari}{2933}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى ـ رضى الله عنهما ـ يَقُولُ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَحْزَابِ عَلَى الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ سَرِيعَ الْحِسَابِ، اللَّهُمَّ اهْزِمِ الأَحْزَابَ، اللَّهُمَّ اهْزِمْهُمْ وَزَلْزِلْهُمْ ‏"‏‏.‏\hadithno{2933}\hadithtrans{Narrated `Abdullah bin Abi `Aufa:Allah's Messenger (ﷺ) invoked evil upon the pagans on the ay (of the battle) of Al-Ahzab, saying, "O Allah! The Revealer of the Holy Book, the Swift-Taker of Accounts, O Allah, defeat Al-Ahzab (i.e. the clans), O Allah, defeat them and shake them}}
\hadithdefcmd{bukhari}{2934}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي فِي ظِلِّ الْكَعْبَةِ، فَقَالَ أَبُو جَهْلٍ وَنَاسٌ مِنْ قُرَيْشٍ، وَنُحِرَتْ جَزُورٌ بِنَاحِيَةِ مَكَّةَ، فَأَرْسَلُوا فَجَاءُوا مِنْ سَلاَهَا، وَطَرَحُوهُ عَلَيْهِ، فَجَاءَتْ فَاطِمَةُ فَأَلْقَتْهُ عَنْهُ، فَقَالَ ‏ "‏ اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ، اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ، اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ ‏"‏‏.‏ لأَبِي جَهْلِ بْنِ هِشَامٍ، وَعُتْبَةَ بْنِ رَبِيعَةَ، وَشَيْبَةَ بْنِ رَبِيعَةَ، وَالْوَلِيدِ بْنِ عُتْبَةَ، وَأُبَىِّ بْنِ خَلَفٍ، وَعُقْبَةَ بْنِ أَبِي مُعَيْطٍ‏.‏ قَالَ عَبْدُ اللَّهِ فَلَقَدْ رَأَيْتُهُمْ فِي قَلِيبِ بَدْرٍ قَتْلَى‏.‏ قَالَ أَبُو إِسْحَاقَ وَنَسِيتُ السَّابِعَ‏.‏ وَقَالَ يُوسُفُ بْنُ إِسْحَاقَ عَنْ أَبِي إِسْحَاقَ أُمَيَّةُ بْنُ خَلَفٍ‏.‏ وَقَالَ شُعْبَةُ أُمَيَّةُ أَوْ أُبَىٌّ‏.‏ وَالصَّحِيحُ أُمَيَّةُ‏.‏\hadithno{2934}\hadithtrans{Narrated `Abdullah:Once the Prophet (ﷺ) was offering the prayer in the shade of the Ka`ba. Abu Jahl and some Quraishi men sent somebody to bring the Abdominal contents of a she-camel which had been slaughtered somewhere in Mecca, and when he brought them, they put them over the Prophet (ﷺ) Then Fatima (i.e. the Prophet's daughter) came and threw them away from him, and he said, "O Allah! Destroy (the pagans of) Quraish; O Allah! Destroy Quraish; O Allah Destroy Quraish," naming especially Abu Jahl bin Hisham, `Utba bin Rabi`a, Shaiba bin Rabi`a, Al Walid bin `Utba, Ubai bin Khalaf and `Uqba bin Abi Muait. (The narrator, `Abdullah added, "I saw them all killed and thrown in the Badr well)}}
\hadithdefcmd{bukhari}{2935}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ الْيَهُودَ، دَخَلُوا عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا السَّامُ عَلَيْكَ‏.‏ فَلَعَنْتُهُمْ‏.‏ فَقَالَ ‏"‏ مَا لَكِ ‏"‏‏.‏ قُلْتُ أَوَلَمْ تَسْمَعْ مَا قَالُوا قَالَ ‏"‏ فَلَمْ تَسْمَعِي مَا قُلْتُ وَعَلَيْكُمْ ‏"‏‏.‏\hadithno{2935}\hadithtrans{Narrated `Aisha:Once the Jews came to the Prophet (ﷺ) and said, "Death be upon you." So I cursed them. The Prophet (ﷺ) said, "What is the matter?" I said, "Have you not heard what they said?" The Prophet (ﷺ) said, "Have you not heard what I replied (to them)? (I said), ('The same is upon you)}}
\hadithdefcmd{bukhari}{2936}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَى قَيْصَرَ، وَقَالَ ‏ "‏ فَإِنْ تَوَلَّيْتَ فَإِنَّ عَلَيْكَ إِثْمَ الأَرِيسِيِّينَ ‏"‏‏.‏\hadithno{2936}\hadithtrans{Narrated `Abdullah bin `Abbas:Allah's Messenger (ﷺ) wrote a letter to Caesar saying, "If you reject Islam, you will be responsible for the sins of the tillers (i.e. your people)}}
\hadithdefcmd{bukhari}{2937}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ عَبْدَ الرَّحْمَنِ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه قَدِمَ طُفَيْلُ بْنُ عَمْرٍو الدَّوْسِيُّ وَأَصْحَابُهُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ، إِنَّ دَوْسًا عَصَتْ وَأَبَتْ، فَادْعُ اللَّهَ عَلَيْهَا‏.‏ فَقِيلَ هَلَكَتْ دَوْسٌ‏.‏ قَالَ ‏ "‏ اللَّهُمَّ اهْدِ دَوْسًا وَائْتِ بِهِمْ ‏"‏‏.‏\hadithno{2937}\hadithtrans{Narrated Abu Huraira:Tufail bin `Amr Ad-Dausi and his companions came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! The people of the tribe of Daus disobeyed and refused to follow you; so invoke Allah against them." The people said, "The tribe of Daus is ruined." The Prophet (ﷺ) said, "O Allah! Give guidance to the people of Daus, and let them embrace Islam}}
\hadithdefcmd{bukhari}{2938}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ لَمَّا أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى الرُّومِ، قِيلَ لَهُ إِنَّهُمْ لاَ يَقْرَءُونَ كِتَابًا إِلاَّ أَنْ يَكُونَ مَخْتُومًا‏.‏ فَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ، فَكَأَنِّي أَنْظُرُ إِلَى بَيَاضِهِ فِي يَدِهِ، وَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏\hadithno{2938}\hadithtrans{Narrated Anas:When the Prophet (ﷺ) intended to write a letter to the ruler of the Byzantines, he was told that those people did not read any letter unless it was stamped with a seal. So, the Prophet (ﷺ) got a silver ring-- as if I were just looking at its white glitter on his hand ---- and stamped on it the expression "Muhammad, Apostle of Allah}}
\hadithdefcmd{bukhari}{2939}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ بِكِتَابِهِ إِلَى كِسْرَى، فَأَمَرَهُ أَنْ يَدْفَعَهُ إِلَى عَظِيمِ الْبَحْرَيْنِ، يَدْفَعُهُ عَظِيمُ الْبَحْرَيْنِ إِلَى كِسْرَى، فَلَمَّا قَرَأَهُ كِسْرَى خَرَّقَهُ، فَحَسِبْتُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ قَالَ فَدَعَا عَلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُمَزَّقُوا كُلَّ مُمَزَّقٍ‏.‏\hadithno{2939}\hadithtrans{Narrated `Abdullah bin `Abbas:Allah's Messenger (ﷺ) sent his letter to Khusrau and ordered his messenger to hand it over to the Governor of Bahrain who was to hand it over to Khusrau. So, when Khusrau read the letter he tore it. Sa`id bin Al- Musaiyab said, "The Prophet (ﷺ) then invoked Allah to disperse them with full dispersion, (destroy them (i.e. Khusrau and his followers) severely}}
\hadithdefcmd{bukhari}{2941}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَى قَيْصَرَ يَدْعُوهُ إِلَى الإِسْلاَمِ، وَبَعَثَ بِكِتَابِهِ إِلَيْهِ مَعَ دِحْيَةَ الْكَلْبِيِّ، وَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَدْفَعَهُ إِلَى عَظِيمِ بُصْرَى لِيَدْفَعَهُ إِلَى قَيْصَرَ، وَكَانَ قَيْصَرُ لَمَّا كَشَفَ اللَّهُ عَنْهُ جُنُودَ فَارِسَ مَشَى مِنْ حِمْصَ إِلَى إِيلِيَاءَ، شُكْرًا لِمَا أَبْلاَهُ اللَّهُ، فَلَمَّا جَاءَ قَيْصَرَ كِتَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ حِينَ قَرَأَهُ الْتَمِسُوا لِي هَا هُنَا أَحَدًا مِنْ قَوْمِهِ لأَسْأَلَهُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ ابْنُ عَبَّاسٍ فَأَخْبَرَنِي أَبُو سُفْيَانَ، أَنَّهُ كَانَ بِالشَّأْمِ فِي رِجَالٍ مِنْ قُرَيْشٍ، قَدِمُوا تِجَارًا فِي الْمُدَّةِ الَّتِي كَانَتْ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ كُفَّارِ قُرَيْشٍ، قَالَ أَبُو سُفْيَانَ فَوَجَدَنَا رَسُولُ قَيْصَرَ بِبَعْضِ الشَّأْمِ فَانْطَلَقَ بِي وَبِأَصْحَابِي حَتَّى قَدِمْنَا إِيلِيَاءَ، فَأُدْخِلْنَا عَلَيْهِ، فَإِذَا هُوَ جَالِسٌ فِي مَجْلِسِ مُلْكِهِ وَعَلَيْهِ التَّاجُ، وَإِذَا حَوْلَهُ عُظَمَاءُ الرُّومِ فَقَالَ لِتُرْجُمَانِهِ سَلْهُمْ أَيُّهُمْ أَقْرَبُ نَسَبًا إِلَى هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ قَالَ أَبُو سُفْيَانَ فَقُلْتُ أَنَا أَقْرَبُهُمْ نَسَبًا‏.‏ قَالَ مَا قَرَابَةُ مَا بَيْنَكَ وَبَيْنَهُ فَقُلْتُ هُوَ ابْنُ عَمِّي، وَلَيْسَ فِي الرَّكْبِ يَوْمَئِذٍ أَحَدٌ مِنْ بَنِي عَبْدِ مَنَافٍ غَيْرِي‏.‏ فَقَالَ قَيْصَرُ أَدْنُوهُ‏.‏ وَأَمَرَ بِأَصْحَابِي فَجُعِلُوا خَلْفَ ظَهْرِي عِنْدَ كَتِفِي، ثُمَّ قَالَ لِتُرْجُمَانِهِ قُلْ لأَصْحَابِهِ إِنِّي سَائِلٌ هَذَا الرَّجُلَ عَنِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ، فَإِنْ كَذَبَ فَكَذِّبُوهُ‏.‏ قَالَ أَبُو سُفْيَانَ وَاللَّهِ لَوْلاَ الْحَيَاءُ يَوْمَئِذٍ مِنْ أَنْ يَأْثُرَ أَصْحَابِي عَنِّي الْكَذِبَ لَكَذَبْتُهُ حِينَ سَأَلَنِي عَنْهُ، وَلَكِنِّي اسْتَحْيَيْتُ أَنْ يَأْثُرُوا الْكَذِبَ عَنِّي فَصَدَقْتُهُ، ثُمَّ قَالَ لِتُرْجُمَانِهِ قُلْ لَهُ كَيْفَ نَسَبُ هَذَا الرَّجُلِ فِيكُمْ قُلْتُ هُوَ فِينَا ذُو نَسَبٍ‏.‏ قَالَ فَهَلْ قَالَ هَذَا الْقَوْلَ أَحَدٌ مِنْكُمْ قَبْلَهُ قُلْتُ لاَ‏.‏ فَقَالَ كُنْتُمْ تَتَّهِمُونَهُ عَلَى الْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ قُلْتُ لاَ‏.‏ قَالَ فَهَلْ كَانَ مِنْ آبَائِهِ مِنْ مَلِكٍ قُلْتُ لاَ‏.‏ قَالَ فَأَشْرَافُ النَّاسِ يَتَّبِعُونَهُ أَمْ ضُعَفَاؤُهُمْ قُلْتُ بَلْ ضُعَفَاؤُهُمْ‏.‏ قَالَ فَيَزِيدُونَ أَوْ يَنْقُصُونَ قُلْتُ بَلْ يَزِيدُونَ‏.‏ قَالَ فَهَلْ يَرْتَدُّ أَحَدٌ سَخْطَةً لِدِينِهِ بَعْدَ أَنْ يَدْخُلَ فِيهِ قُلْتُ لاَ‏.‏ قَالَ فَهَلْ يَغْدِرُ قُلْتُ لاَ، وَنَحْنُ الآنَ مِنْهُ فِي مُدَّةٍ، نَحْنُ نَخَافُ أَنْ يَغْدِرَ‏.‏ قَالَ أَبُو سُفْيَانَ وَلَمْ يُمْكِنِّي كَلِمَةٌ أُدْخِلُ فِيهَا شَيْئًا أَنْتَقِصُهُ بِهِ لاَ أَخَافُ أَنْ تُؤْثَرَ عَنِّي غَيْرُهَا‏.‏ قَالَ فَهَلْ قَاتَلْتُمُوهُ أَوْ قَاتَلَكُمْ قُلْتُ نَعَمْ‏.‏ قَالَ فَكَيْفَ كَانَتْ حَرْبُهُ وَحَرْبُكُمْ قُلْتُ كَانَتْ دُوَلاً وَسِجَالاً، يُدَالُ عَلَيْنَا الْمَرَّةَ وَنُدَالُ عَلَيْهِ الأُخْرَى‏.‏ قَالَ فَمَاذَا يَأْمُرُكُمْ قَالَ يَأْمُرُنَا أَنْ نَعْبُدَ اللَّهَ وَحْدَهُ لاَ نُشْرِكُ بِهِ شَيْئًا، وَيَنْهَانَا عَمَّا كَانَ يَعْبُدُ آبَاؤُنَا، وَيَأْمُرُنَا بِالصَّلاَةِ وَالصَّدَقَةِ وَالْعَفَافِ وَالْوَفَاءِ بِالْعَهْدِ وَأَدَاءِ الأَمَانَةِ‏.‏ فَقَالَ لِتُرْجُمَانِهِ حِينَ قُلْتُ ذَلِكَ لَهُ قُلْ لَهُ إِنِّي سَأَلْتُكَ عَنْ نَسَبِهِ فِيكُمْ، فَزَعَمْتَ أَنَّهُ ذُو نَسَبٍ، وَكَذَلِكَ الرُّسُلُ تُبْعَثُ فِي نَسَبِ قَوْمِهَا، وَسَأَلْتُكَ هَلْ قَالَ أَحَدٌ مِنْكُمْ هَذَا الْقَوْلَ قَبْلَهُ فَزَعَمْتَ أَنْ لاَ، فَقُلْتُ لَوْ كَانَ أَحَدٌ مِنْكُمْ قَالَ هَذَا الْقَوْلَ قَبْلَهُ قُلْتُ رَجُلٌ يَأْتَمُّ بِقَوْلٍ قَدْ قِيلَ قَبْلَهُ‏.‏ وَسَأَلْتُكَ هَلْ كُنْتُمْ تَتَّهِمُونَهُ بِالْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ فَزَعَمْتَ أَنْ لاَ، فَعَرَفْتُ أَنَّهُ لَمْ يَكُنْ لِيَدَعَ الْكَذِبَ عَلَى النَّاسِ وَيَكْذِبَ عَلَى اللَّهِ، وَسَأَلْتُكَ هَلْ كَانَ مِنْ آبَائِهِ مِنْ مَلِكٍ فَزَعَمْتَ أَنْ لاَ، فَقُلْتُ لَوْ كَانَ مِنْ آبَائِهِ مَلِكٌ قُلْتُ يَطْلُبُ مُلْكَ آبَائِهِ‏.‏ وَسَأَلْتُكَ أَشْرَافُ النَّاسِ يَتَّبِعُونَهُ أَمْ ضُعَفَاؤُهُمْ فَزَعَمْتَ أَنَّ ضُعَفَاءَهُمُ اتَّبَعُوهُ، وَهُمْ أَتْبَاعُ الرُّسُلِ، وَسَأَلْتُكَ هَلْ يَزِيدُونَ أَوْ يَنْقُصُونَ فَزَعَمْتَ أَنَّهُمْ يَزِيدُونَ، وَكَذَلِكَ الإِيمَانُ حَتَّى يَتِمَّ، وَسَأَلْتُكَ هَلْ يَرْتَدُّ أَحَدٌ سَخْطَةً لِدِينِهِ بَعْدَ أَنْ يَدْخُلَ فِيهِ فَزَعَمْتَ أَنْ لاَ، فَكَذَلِكَ الإِيمَانُ حِينَ تَخْلِطُ بَشَاشَتُهُ الْقُلُوبَ لاَ يَسْخَطُهُ أَحَدٌ، وَسَأَلْتُكَ هَلْ يَغْدِرُ فَزَعَمْتَ أَنْ لاَ، وَكَذَلِكَ الرُّسُلُ لاَ يَغْدِرُونَ‏.‏ وَسَأَلْتُكَ هَلْ قَاتَلْتُمُوهُ وَقَاتَلَكُمْ فَزَعَمْتَ أَنْ قَدْ فَعَلَ، وَأَنَّ حَرْبَكُمْ وَحَرْبَهُ تَكُونُ دُوَلاً، وَيُدَالُ عَلَيْكُمُ الْمَرَّةَ وَتُدَالُونَ عَلَيْهِ الأُخْرَى، وَكَذَلِكَ الرُّسُلُ تُبْتَلَى، وَتَكُونُ لَهَا الْعَاقِبَةُ، وَسَأَلْتُكَ بِمَاذَا يَأْمُرُكُمْ فَزَعَمْتَ أَنَّهُ يَأْمُرُكُمْ أَنْ تَعْبُدُوا اللَّهَ وَلاَ تُشْرِكُوا بِهِ شَيْئًا، وَيَنْهَاكُمْ عَمَّا كَانَ يَعْبُدُ آبَاؤُكُمْ، وَيَأْمُرُكُمْ بِالصَّلاَةِ وَالصِّدْقِ وَالْعَفَافِ وَالْوَفَاءِ بِالْعَهْدِ، وَأَدَاءِ الأَمَانَةِ، قَالَ وَهَذِهِ صِفَةُ النَّبِيِّ، قَدْ كُنْتُ أَعْلَمُ أَنَّهُ خَارِجٌ، وَلَكِنْ لَمْ أَظُنَّ أَنَّهُ مِنْكُمْ، وَإِنْ يَكُ مَا قُلْتَ حَقًّا، فَيُوشِكُ أَنْ يَمْلِكَ مَوْضِعَ قَدَمَىَّ هَاتَيْنِ، وَلَوْ أَرْجُو أَنْ أَخْلُصَ إِلَيْهِ لَتَجَشَّمْتُ لُقِيَّهُ، وَلَوْ كُنْتُ عِنْدَهُ لَغَسَلْتُ قَدَمَيْهِ‏.‏ قَالَ أَبُو سُفْيَانَ ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُرِئَ فَإِذَا فِيهِ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ عَبْدِ اللَّهِ وَرَسُولِهِ، إِلَى هِرَقْلَ عَظِيمِ الرُّومِ، سَلاَمٌ عَلَى مَنِ اتَّبَعَ الْهُدَى، أَمَّا بَعْدُ فَإِنِّي أَدْعُوكَ بِدِعَايَةِ الإِسْلاَمِ، أَسْلِمْ تَسْلَمْ، وَأَسْلِمْ يُؤْتِكَ اللَّهُ أَجْرَكَ مَرَّتَيْنِ، فَإِنْ تَوَلَّيْتَ فَعَلَيْكَ إِثْمُ الأَرِيسِيِّينَ وَ‏\{‏يَا أَهْلَ الْكِتَابِ تَعَالَوْا إِلَى كَلِمَةٍ سَوَاءٍ بَيْنَنَا وَبَيْنَكُمْ أَنْ لاَ نَعْبُدَ إِلاَّ اللَّهَ وَلاَ نُشْرِكَ بِهِ شَيْئًا وَلاَ يَتَّخِذَ بَعْضُنَا بَعْضًا أَرْبَابًا مِنْ دُونِ اللَّهِ فَإِنْ تَوَلَّوْا فَقُولُوا اشْهَدُوا بِأَنَّا مُسْلِمُونَ‏\}‏‏"‏‏.‏ قَالَ أَبُو سُفْيَانَ فَلَمَّا أَنْ قَضَى مَقَالَتَهُ، عَلَتْ أَصْوَاتُ الَّذِينَ حَوْلَهُ مِنْ عُظَمَاءِ الرُّومِ، وَكَثُرَ لَغَطُهُمْ، فَلاَ أَدْرِي مَاذَا قَالُوا، وَأُمِرَ بِنَا فَأُخْرِجْنَا، فَلَمَّا أَنْ خَرَجْتُ مَعَ أَصْحَابِي وَخَلَوْتُ بِهِمْ قُلْتُ لَهُمْ لَقَدْ أَمِرَ أَمْرُ ابْنِ أَبِي كَبْشَةَ، هَذَا مَلِكُ بَنِي الأَصْفَرِ يَخَافُهُ، قَالَ أَبُو سُفْيَانَ وَاللَّهِ مَا زِلْتُ ذَلِيلاً مُسْتَيْقِنًا بِأَنَّ أَمْرَهُ سَيَظْهَرُ، حَتَّى أَدْخَلَ اللَّهُ قَلْبِي الإِسْلاَمَ وَأَنَا كَارِهٌ‏.‏\hadithno{2941}\hadithtrans{Narrated `Abdullah bin `Abbas:Allah's Messenger (ﷺ) wrote to Caesar and invited him to Islam and sent him his letter with Dihya Al-Kalbi whom Allah's Messenger (ﷺ) ordered to hand it over to the Governor of Busra who would forward it to Caesar. Caesar as a sign of gratitude to Allah, had walked from Hims to Ilya (i.e. Jerusalem) when Allah had granted Him victory over the Persian forces. So, when the letter of Allah's Messenger (ﷺ) reached Caesar, he said after reading it, 'Seek for me any one of his people! (Arabs of Quraish tribe) if present here, in order to ask him about Allah's Messenger (ﷺ). At that time Abu Sufyan bin Harb was in Sham with some men from Quraish who had come (to Sham) as merchants during the truce that had been concluded between Allah's Messenger (ﷺ); and the infidels of Quraish. Abu Sufyan said, Caesar's messenger found us somewhere in Sham so he took me and my companions to Ilya and we were admitted into Caesar's court to find him sitting in his royal court wearing a crown and surrounded by the senior dignitaries of the Byzantine. He said to his translator. 'Ask them who amongst them is a close relation to the man who claims to be a prophet." Abu Sufyan added, "I replied, 'I am the nearest relative to him.' He asked, 'What degree of relationship do you have with him?' I replied, 'He is my cousin,' and there was none of Bani Abu Manaf in the caravan except myself. Caesar said, 'Let him come nearer.' He then ordered that my companions stand behind me near my shoulder and said to his translator, 'Tell his companions that I am going to ask this man about the man who claims to be a prophet. If he tells a lie, they should contradict him immediately." Abu Sufyan added, "By Allah! Had it not been shameful that my companions label me a liar, I would not have spoken the truth about him when he asked me. But I considered it shameful to be called a liar by my companions. So I told the truth. He then said to his translator, 'Ask him what kind of family does he belong to.' I replied, 'He belongs to a noble family amongst us.' He said, 'Has anybody else amongst you ever claimed the same before him? 'I replied, 'No.' He said, 'Had you ever blamed him for telling lies before he claimed what he claimed? ' I replied, 'No.' He said, 'Was anybody amongst his ancestors a king?' I replied, 'No.' He said, "Do the noble or the poor follow him?' I replied, 'It is the poor who follow him.' He said, 'Are they increasing or decreasing (day by day)?' I replied,' They are increasing.' He said, 'Does anybody amongst those who embrace his (the Prophet's) Religion become displeased and then discard his Religion?'. I replied, 'No. ' He said, 'Does he break his promises? I replied, 'No, but we are now at truce with him and we are afraid that he may betray us." Abu Sufyan added, "Other than the last sentence, I could not say anything against him. Caesar then asked, 'Have you ever had a war with him?' I replied, 'Yes.' He said, 'What was the outcome of your battles with him?' I replied, 'The result was unstable; sometimes he was victorious and sometimes we.' He said, 'What does he order you to do?' I said, 'He tells us to worship Allah alone, and not to worship others along with Him, and to leave all that our fore-fathers used to worship. He orders us to pray, give in charity, be chaste, keep promises and return what is entrusted to us.' When I had said that, Caesar said to his translator, 'Say to him: I asked you about his lineage and your reply was that he belonged to a noble family. In fact, all the apostles came from the noblest lineage of their nations. Then I questioned you whether anybody else amongst you had claimed such a thing, and your reply was in the negative. If the answer had been in the affirmative, I would have thought that this man was following a claim that had been said before him. When I asked you whether he was ever blamed for telling lies, your reply was in the negative, so I took it for granted that a person who did not tell a lie about (others) the people could never tell a lie about Allah. Then I asked you whether any of his ancestors was a king. Your reply was in the negative, and if it had been in the affirmative, I would have thought that this man wanted to take back his ancestral kingdom. When I asked you whether the rich or the poor people followed him, you replied that it was the poor who followed him. In fact, such are the followers of the apostles. Then I asked you whether his followers were increasing or decreasing. You replied that they were increasing. In fact, this is the result of true faith till it is complete (in all respects). I asked you whether there was anybody who, after embracing his religion, became displeased and discarded his religion; your reply was in the negative. In fact, this is the sign of true faith, for when its cheerfulness enters and mixes in the hearts completely, nobody will be displeased with it. I asked you whether he had ever broken his promise. You replied in the negative. And such are the apostles; they never break their promises. When I asked you whether you fought with him and he fought with you, you replied that he did, and that sometimes he was victorious and sometimes you. Indeed, such are the apostles; they are put to trials and the final victory is always theirs. Then I asked you what he ordered you. You replied that he ordered you to worship Allah alone and not to worship others along with Him, to leave all that your fore-fathers used to worship, to offer prayers, to speak the truth, to be chaste, to keep promises, and to return what is entrusted to you. These are really the qualities of a prophet who, I knew (from the previous Scriptures) would appear, but I did not know that he would be from amongst you. If what you say should be true, he will very soon occupy the earth under my feet, and if I knew that I would reach him definitely, I would go immediately to meet Him; and were I with him, then I would certainly wash his feet.' " Abu Sufyan added, "Caesar then asked for the letter of Allah's Messenger (ﷺ) and it was read. Its contents were: "In the name of Allah, the most Beneficent, the most Merciful (This letter is) from Muhammad, the slave of Allah, and His Apostle, to Heraclius, the Ruler of the Byzantine. Peace be upon the followers of guidance. Now then, I invite you to Islam (i.e. surrender to Allah), embrace Islam and you will be safe; embrace Islam and Allah will bestow on you a double reward. But if you reject this invitation of Islam, you shall be responsible for misguiding the tillers (i.e. your nation). O people of the Scriptures! Come to a word common to you and us and you, that we worship none but Allah, and that we associate nothing in worship with Him; and that none of us shall take others as Lords besides Allah. Then if they turn away, say: Bear witness that we are (they who have surrendered (unto Him)..(3.64) Abu Sufyan added, "When Heraclius had finished his speech, there was a great hue and cry caused by the Byzantine Royalties surrounding him, and there was so much noise that I did not understand what they said. So, we were turned out of the court. When I went out with my companions and we were alone, I said to them, 'Verily, Ibn Abi Kabsha's (i.e. the Prophet's) affair has gained power. This is the King of Bani Al-Asfar fearing him." Abu Sufyan added, "By Allah, I remained low and was sure that his religion would be victorious till Allah converted me to Islam, though I disliked it}}
\hadithdefcmd{bukhari}{2942}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْد ٍ ـ رضى الله عنه ـ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ يَوْمَ خَيْبَرَ ‏"‏ لأُعْطِيَنَّ الرَّايَةَ رَجُلاً يَفْتَحُ اللَّهُ عَلَى يَدَيْهِ ‏"‏‏.‏ فَقَامُوا يَرْجُونَ لِذَلِكَ أَيُّهُمْ يُعْطَى، فَغَدَوْا وَكُلُّهُمْ يَرْجُو أَنْ يُعْطَى فَقَالَ ‏"‏ أَيْنَ عَلِيٌّ ‏"‏‏.‏ فَقِيلَ يَشْتَكِي عَيْنَيْهِ، فَأَمَرَ فَدُعِيَ لَهُ، فَبَصَقَ فِي عَيْنَيْهِ، فَبَرَأَ مَكَانَهُ حَتَّى كَأَنَّهُ لَمْ يَكُنْ بِهِ شَىْءٌ فَقَالَ نُقَاتِلُهُمْ حَتَّى يَكُونُوا مِثْلَنَا‏.‏ فَقَالَ ‏"‏ عَلَى رِسْلِكَ حَتَّى تَنْزِلَ بِسَاحَتِهِمْ، ثُمَّ ادْعُهُمْ إِلَى الإِسْلاَمِ، وَأَخْبِرْهُمْ بِمَا يَجِبُ عَلَيْهِمْ، فَوَاللَّهِ لأَنْ يُهْدَى بِكَ رَجُلٌ وَاحِدٌ خَيْرٌ لَكَ مِنْ حُمْرِ النَّعَمِ ‏"‏‏.‏\hadithno{2942}\hadithtrans{Narrated Sahl bin Sa`d:That he heard the Prophet (ﷺ) on the day (of the battle) of Khaibar saying, "I will give the flag to a person at whose hands Allah will grant victory." So, the companions of the Prophet (ﷺ) got up, wishing eagerly to see to whom the flag will be given, and everyone of them wished to be given the flag. But the Prophet asked for `Ali. Someone informed him that he was suffering from eye-trouble. So, he ordered them to bring `Ali in front of him. Then the Prophet (ﷺ) spat in his eyes and his eyes were cured immediately as if he had never any eye-trouble. `Ali said, "We will fight with them (i.e. infidels) till they become like us (i.e. Muslims)." The Prophet (ﷺ) said, "Be patient, till you face them and invite them to Islam and inform them of what Allah has enjoined upon them. By Allah! If a single person embraces Islam at your hands (i.e. through you), that will be better for you than the red camels}}
\hadithdefcmd{bukhari}{2943}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا غَزَا قَوْمًا لَمْ يُغِرْ حَتَّى يُصْبِحَ، فَإِنْ سَمِعَ أَذَانًا أَمْسَكَ، وَإِنْ لَمْ يَسْمَعْ أَذَانًا أَغَارَ بَعْدَ مَا يُصْبِحُ، فَنَزَلْنَا خَيْبَرَ لَيْلاً‏.‏\hadithno{2943}\hadithtrans{Narrated Anas:Whenever Allah's Messenger (ﷺ) attacked some people, he would never attack them till it was dawn. If he heard the Adhan (i.e. call for prayer) he would delay the fight, and if he did not hear the Adhan, he would attack them immediately after dawn. We reached Khaibar at night}}
\hadithdefcmd{bukhari}{2944}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا غَزَا بِنَا‏.‏\hadithno{2944}\hadithtrans{Narrated Anas:as Hadith No. 193 above}}
\hadithdefcmd{bukhari}{2945}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ إِلَى خَيْبَرَ فَجَاءَهَا لَيْلاً، وَكَانَ إِذَا جَاءَ قَوْمًا بِلَيْلٍ لاَ يُغِيرُ عَلَيْهِمْ حَتَّى يُصْبِحَ، فَلَمَّا أَصْبَحَ، خَرَجَتْ يَهُودُ بِمَسَاحِيهِمْ وَمَكَاتِلِهِمْ، فَلَمَّا رَأَوْهُ قَالُوا مُحَمَّدٌ وَاللَّهِ، مُحَمَّدٌ وَالْخَمِيسُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اللَّهُ أَكْبَرُ، خَرِبَتْ خَيْبَرُ، إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏‏.‏\hadithno{2945}\hadithtrans{Narrated Anas:The Prophet (ﷺ) set out for Khaibar and reached it at night. He used not to attack if he reached the people at night, till the day broke. So, when the day dawned, the Jews came out with their bags and spades. When they saw the Prophet; they said, "Muhammad and his army!" The Prophet (ﷺ) said, Allahu--Akbar! (Allah is Greater) and Khaibar is ruined, for whenever we approach a nation (i.e. enemy to fight) then it will be a miserable morning for those who have been warned}}
\hadithdefcmd{bukhari}{2946}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ، فَقَدْ عَصَمَ مِنِّي نَفْسَهُ وَمَالَهُ، إِلاَّ بِحَقِّهِ، وَحِسَابُهُ عَلَى اللَّهِ ‏"‏‏.‏ رَوَاهُ عُمَرُ وَابْنُ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2946}\hadithtrans{Narrated Abu Huraira:Allah's Apostle said, " I have been ordered to fight with the people till they say, 'None has the right to be worshipped but Allah,' and whoever says, 'None has the right to be worshipped but Allah,' his life and property will be saved by me except for Islamic law, and his accounts will be with Allah, (either to punish him or to forgive him)}}
\hadithdefcmd{bukhari}{2947}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ ـ رضى الله عنه ـ وَكَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ وَلَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يُرِيدُ غَزْوَةً إِلاَّ وَرَّى بِغَيْرِهَا‏.‏\hadithno{2947}\hadithtrans{Narrated Ka`b bin Malik:Whenever Allah's Messenger (ﷺ) intended to lead a Ghazwa, he would use an equivocation from which one would understand that he was going to a different destination}}
\hadithdefcmd{bukhari}{2948}{وَحَدَّثَنِي أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَلَّمَا يُرِيدُ غَزْوَةً يَغْزُوهَا إِلاَّ وَرَّى بِغَيْرِهَا، حَتَّى كَانَتْ غَزْوَةُ تَبُوكَ، فَغَزَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَرٍّ شَدِيدٍ، وَاسْتَقْبَلَ سَفَرًا بَعِيدًا وَمَفَازًا، وَاسْتَقْبَلَ غَزْوَ عَدُوٍّ كَثِيرٍ، فَجَلَّى لِلْمُسْلِمِينَ أَمْرَهُمْ، لِيَتَأَهَّبُوا أُهْبَةَ عَدُوِّهِمْ، وَأَخْبَرَهُمْ بِوَجْهِهِ الَّذِي يُرِيدُ‏.‏\hadithno{2948}\hadithtrans{Narrated Ka`b bin Malik:Whenever Allah's Messenger (ﷺ) intended to carry out a Ghazwa, he would use an equivocation to conceal his real destination till it was the Ghazwa of Tabuk which Allah's Messenger (ﷺ) carried out in very hot weather. As he was going to face a very long journey through a wasteland and was to meet and attack a large number of enemies. So, he made the situation clear to the Muslims so that they might prepare themselves accordingly and get ready to conquer their enemy. The Prophet (ﷺ) informed them of the destination he was heading for}}
\hadithdefcmd{bukhari}{2949}{وَعَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ كَعْبِ بْنِ مَالِكٍ، أَنَّ كَعْبَ بْنَ مَالِكٍ ـ رضى الله عنه ـ كَانَ يَقُولُ لَقَلَّمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْرُجُ إِذَا خَرَجَ فِي سَفَرٍ إِلاَّ يَوْمَ الْخَمِيسِ‏.‏\hadithno{2949}\hadithtrans{Ka`b bin Malik used to say:"Scarcely did Allah's Messenger (ﷺ) set out for a journey on a day other than Thursday}}
\hadithdefcmd{bukhari}{2950}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْخَمِيسِ فِي غَزْوَةِ تَبُوكَ، وَكَانَ يُحِبُّ أَنْ يَخْرُجَ يَوْمَ الْخَمِيسِ‏.‏\hadithno{2950}\hadithtrans{Narrated Ka`b bin Malik:The Prophet (ﷺ) set out on Thursday for the Ghazwa of Tabuk and he used to prefer to set out (i.e. travel) on Thursdays}}
\hadithdefcmd{bukhari}{2951}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِالْمَدِينَةِ الظُّهْرَ أَرْبَعًا، وَالْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ، وَسَمِعْتُهُمْ يَصْرُخُونَ بِهِمَا جَمِيعًا‏.‏\hadithno{2951}\hadithtrans{Narrated Anas:The Prophet (ﷺ) offered a four-rak`at Zuhr prayer at Medina and then offered a two rak`at `Asr prayer at Dhul-Hulaifa and I heard the companions of the Prophet (ﷺ) reciting Talbiya aloud (for Hajj and `Umra) altogether}}
\hadithdefcmd{bukhari}{2952}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا سَمِعَتْ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِخَمْسِ لَيَالٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ، وَلاَ نُرَى إِلاَّ الْحَجَّ، فَلَمَّا دَنَوْنَا مِنْ مَكَّةَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ إِذَا طَافَ بِالْبَيْتِ وَسَعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ أَنْ يَحِلَّ‏.‏ قَالَتْ عَائِشَةُ فَدُخِلَ عَلَيْنَا يَوْمَ النَّحْرِ بِلَحْمِ بَقَرٍ فَقُلْتُ مَا هَذَا فَقَالَ نَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَزْوَاجِهِ‏.‏ قَالَ يَحْيَى فَذَكَرْتُ هَذَا الْحَدِيثَ لِلْقَاسِمِ بْنِ مُحَمَّدٍ فَقَالَ أَتَتْكَ وَاللَّهِ بِالْحَدِيثِ عَلَى وَجْهِهِ‏.‏\hadithno{2952}\hadithtrans{Narrated `Aisha:We set out in the company of Allah's Messenger (ﷺ) five days before the end of Dhul Qa'da intending to perform Hajj only. When we approached Mecca Allah's Messenger (ﷺ) ordered those who did not have the Hadi (i.e. an animal for sacrifice) with them, to perform the Tawaf around the Ka`ba, and between Safa and Marwa and then finish their Ihram. Beef was brought to us on the day of Nahr (i.e. the days of slaughtering) and I asked, "What is this?" Somebody said, Allah's Messenger (ﷺ) has slaughtered (a cow) on behalf of his wives}}
\hadithdefcmd{bukhari}{2953}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فِي رَمَضَانَ، فَصَامَ حَتَّى بَلَغَ الْكَدِيدَ أَفْطَرَ‏.‏ قَالَ سُفْيَانُ قَالَ الزُّهْرِيُّ أَخْبَرَنِي عُبَيْدُ اللَّهِ عَنِ ابْنِ عَبَّاسٍ‏.‏ وَسَاقَ الْحَدِيثَ‏.‏\hadithno{2953}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet (ﷺ) set out in the month of Ramadan. He observed fasting till he reached a place called Kadid where he broke his fast}}
\hadithdefcmd{bukhari}{2954}{وَقَالَ ابْنُ وَهْبٍ أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْثٍ، وَقَالَ لَنَا ‏"‏ إِنْ لَقِيتُمْ فُلاَنًا وَفُلاَنًا ‏"‏‏.‏ ـ لِرَجُلَيْنِ مِنْ قُرَيْشٍ سَمَّاهُمَا ـ فَحَرِّقُوهُمَا بِالنَّارِ‏.‏ قَالَ ثُمَّ أَتَيْنَاهُ نُوَدِّعُهُ حِينَ أَرَدْنَا الْخُرُوجَ فَقَالَ ‏"‏ إِنِّي كُنْتُ أَمَرْتُكُمْ أَنْ تُحَرِّقُوا فُلاَنًا وَفُلاَنًا بِالنَّارِ، وَإِنَّ النَّارَ لاَ يُعَذِّبُ بِهَا إِلاَّ اللَّهُ، فَإِنْ أَخَذْتُمُوهُمَا فَاقْتُلُوهُمَا ‏"‏‏.‏\hadithno{2954}\hadithtrans{Narrated Abu Hurairah (ra):Allah's Messenger (ﷺ) sent us on a military expedition telling us, "If you find such and such persons (he named two men from Quraish), burn them with fire." Then we came to bid him farewell, when we wanted to set out, he said: "Previously I ordered you to burn so-and-so and so-and-so with fire, but as punishment with fire is done by none except Allah, if you capture them, kill them, (instead)}}
\hadithdefcmd{bukhari}{2955}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ صَبَّاحٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّمْعُ وَالطَّاعَةُ حَقٌّ، مَا لَمْ يُؤْمَرْ بِالْمَعْصِيَةِ، فَإِذَا أُمِرَ بِمَعْصِيَةٍ فَلاَ سَمْعَ وَلاَ طَاعَةَ ‏"‏‏.‏\hadithno{2955}\hadithtrans{Narrated Ibn `Umar:The Prophet said, "It is obligatory for one to listen to and obey (the ruler's orders) unless these orders involve one of disobedience (to Allah); but if an act of disobedience (to Allah) is imposed, he should not listen to or obey it}}
\hadithdefcmd{bukhari}{2957}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ الأَعْرَجَ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ ‏"‏‏.‏ وَبِهَذَا الإِسْنَادِ ‏"‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ، وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ، وَمَنْ يُطِعِ الأَمِيرَ فَقَدْ أَطَاعَنِي، وَمَنْ يَعْصِ الأَمِيرَ فَقَدْ عَصَانِي، وَإِنَّمَا الإِمَامُ جُنَّةٌ يُقَاتَلُ مِنْ وَرَائِهِ وَيُتَّقَى بِهِ، فَإِنْ أَمَرَ بِتَقْوَى اللَّهِ وَعَدَلَ، فَإِنَّ لَهُ بِذَلِكَ أَجْرًا، وَإِنْ قَالَ بِغَيْرِهِ، فَإِنَّ عَلَيْهِ مِنْهُ ‏"‏‏.‏\hadithno{2957}\hadithtrans{Narrated Abu Huraira:That he heard Allah's Messenger (ﷺ) saying, "We are the last but will be the foremost to enter Paradise)." The Prophet added, "He who obeys me, obeys Allah, and he who disobeys me, disobeys Allah. He who obeys the chief, obeys me, and he who disobeys the chief, disobeys me. The Imam is like a shelter for whose safety the Muslims should fight and where they should seek protection. If the Imam orders people with righteousness and rules justly, then he will be rewarded for that, and if he does the opposite, he will be responsible for that}}
\hadithdefcmd{bukhari}{2958}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، قَالَ قَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ رَجَعْنَا مِنَ الْعَامِ الْمُقْبِلِ فَمَا اجْتَمَعَ مِنَّا اثْنَانِ عَلَى الشَّجَرَةِ الَّتِي بَايَعْنَا تَحْتَهَا، كَانَتْ رَحْمَةً مِنَ اللَّهِ‏.‏ فَسَأَلْتُ نَافِعًا عَلَى أَىِّ شَىْءٍ بَايَعَهُمْ عَلَى الْمَوْتِ قَالَ لاَ، بَايَعَهُمْ عَلَى الصَّبْرِ‏.‏\hadithno{2958}\hadithtrans{Narrated Ibn `Umar:When we reached (Hudaibiya) in the next year (of the treaty of Hudaibiya), not even two men amongst us agreed unanimously as to which was the tree under which we had given the pledge of allegiance, and that was out of Allah's Mercy. (The sub narrator asked Naf'i, "For what did the Prophet (ﷺ) take their pledge of allegiance, was it for death?" Naf'i replied "No, but he took their pledge of allegiance for patience}}
\hadithdefcmd{bukhari}{2959}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ ـ رضى الله عنه ـ قَالَ لَمَّا كَانَ زَمَنَ الْحَرَّةِ أَتَاهُ آتٍ فَقَالَ لَهُ إِنَّ ابْنَ حَنْظَلَةَ يُبَايِعُ النَّاسَ عَلَى الْمَوْتِ‏.‏ فَقَالَ لاَ أُبَايِعُ عَلَى هَذَا أَحَدًا بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2959}\hadithtrans{Narrated `Abdullah bin Zaid:that in the time (of the battle) of Al-Harra a person came to him and said, "Ibn Hanzala is taking the pledge of allegiance from the people for death." He said, "I will never give a pledge of allegiance for such a thing to anyone after Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{2960}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ ـ رضى الله عنه ـ قَالَ بَايَعْتُ النَّبِيَّ صلى الله عليه وسلم ثُمَّ عَدَلْتُ إِلَى ظِلِّ الشَّجَرَةِ، فَلَمَّا خَفَّ النَّاسُ قَالَ ‏"‏ يَا ابْنَ الأَكْوَعِ، أَلاَ تُبَايِعُ ‏"‏‏.‏ قَالَ قُلْتُ قَدْ بَايَعْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ وَأَيْضًا ‏"‏‏.‏ فَبَايَعْتُهُ الثَّانِيَةَ،‏.‏ فَقُلْتُ لَهُ يَا أَبَا مُسْلِمٍ، عَلَى أَىِّ شَىْءٍ كُنْتُمْ تُبَايِعُونَ يَوْمَئِذٍ قَالَ عَلَى الْمَوْتِ‏.‏\hadithno{2960}\hadithtrans{Narrated Yazid bin Ubaid:Salama said, "I gave the Pledge of allegiance (Al-Ridwan) to Allah's Messenger (ﷺ) and then I moved to the shade of a tree. When the number of people around the Prophet (ﷺ) diminished, he said, 'O Ibn Al-Akwa` ! Will you not give to me the pledge of Allegiance?' I replied, 'O Allah's Messenger (ﷺ)! I have already given to you the pledge of Allegiance.' He said, 'Do it again.' So I gave the pledge of allegiance for the second time." I asked 'O Abu Muslim! For what did you give he pledge of Allegiance on that day?" He replied, "We gave the pledge of Allegiance for death}}
\hadithdefcmd{bukhari}{2961}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ كَانَتِ الأَنْصَارُ يَوْمَ الْخَنْدَقِ تَقُولُ نَحْنُ الَّذِينَ بَايَعُوا مُحَمَّدَا عَلَى الْجِهَادِ مَا حَيِينَا أَبَدَا فَأَجَابَهُمُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَهْ فَأَكْرِمِ الأَنْصَارَ وَالْمُهَاجِرَهْ\hadithno{2961}\hadithtrans{Narrated Anas:On the day (of the battle) of the Trench, the Ansar were saying, "We are those who have sworn allegiance to Muhammad for Jihad (for ever) as long as we live." The Prophet (ﷺ) replied to them, "O Allah! There is no life except the life of the Hereafter. So honor the Ansar and emigrants with Your Generosity}}
\hadithdefcmd{bukhari}{2963}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ مُحَمَّدَ بْنَ فُضَيْلٍ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ مُجَاشِعٍ ـ رضى الله عنه ـ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم أَنَا وَأَخِي فَقُلْتُ بَايِعْنَا عَلَى الْهِجْرَةِ‏.‏ فَقَالَ ‏"‏ مَضَتِ الْهِجْرَةُ لأَهْلِهَا ‏"‏‏.‏ فَقُلْتُ عَلاَمَ تُبَايِعُنَا قَالَ ‏"‏ عَلَى الإِسْلاَمِ وَالْجِهَادِ ‏"‏‏.‏\hadithno{2963}\hadithtrans{Narrated Mujashi:My brother and I came to the Prophet (ﷺ) and I requested him to take the pledge of allegiance from us for migration. He said, "Migration has passed away with its people." I asked, "For what will you take the pledge of allegiance from us then?" He said, "I will take (the pledge) for Islam and Jihad}}
\hadithdefcmd{bukhari}{2964}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ ـ رضى الله عنه ـ لَقَدْ أَتَانِي الْيَوْمَ رَجُلٌ فَسَأَلَنِي عَنْ أَمْرٍ مَا دَرَيْتُ مَا أَرُدُّ عَلَيْهِ، فَقَالَ أَرَأَيْتَ رَجُلاً مُؤْدِيًا نَشِيطًا، يَخْرُجُ مَعَ أُمَرَائِنَا فِي الْمَغَازِي، فَيَعْزِمُ عَلَيْنَا فِي أَشْيَاءَ لاَ نُحْصِيهَا‏.‏ فَقُلْتُ لَهُ وَاللَّهِ مَا أَدْرِي مَا أَقُولُ لَكَ إِلاَّ أَنَّا كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فَعَسَى أَنْ لاَ يَعْزِمَ عَلَيْنَا فِي أَمْرٍ إِلاَّ مَرَّةً حَتَّى نَفْعَلَهُ، وَإِنَّ أَحَدَكُمْ لَنْ يَزَالَ بِخَيْرٍ مَا اتَّقَى اللَّهَ، وَإِذَا شَكَّ فِي نَفْسِهِ شَىْءٌ سَأَلَ رَجُلاً فَشَفَاهُ مِنْهُ، وَأَوْشَكَ أَنْ لاَ تَجِدُوهُ، وَالَّذِي لاَ إِلَهَ إِلاَّ هُوَ مَا أَذْكُرُ مَا غَبَرَ مِنَ الدُّنْيَا إِلاَّ كَالثَّغْبِ شُرِبَ صَفْوُهُ وَبَقِيَ كَدَرُهُ‏.‏\hadithno{2964}\hadithtrans{Narrated `Abdullah:Today a man came to me and asked me a question which I did not know how to answer. He said, "Tell me, if a wealthy active man, well-equipped with arms, goes out on military expeditions with our chiefs, and orders us to do such things as we cannot do (should we obey him?)" I replied, "By Allah, I do not know what to reply to you, except that we, were in the company of the Prophet (ﷺ) and he used to order us to do a thing once only till we finished it. And no doubt, everyone among you will remain in a good state as long as he obeys Allah. If one is in doubt as to the legality of something, he should ask somebody who would satisfy him, but soon will come a time when you will not find such a man. By Him, except Whom none has the right to be worshipped. I see that the example of what has passed of this life (to what remains thereof) is like a pond whose fresh water has been used up and nothing remains but muddy water}}
\hadithdefcmd{bukhari}{2966}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ وَكَانَ كَاتِبًا لَهُ قَالَ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى ـ رضى الله عنهما ـ فَقَرَأْتُهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَيَّامِهِ الَّتِي لَقِيَ فِيهَا انْتَظَرَ حَتَّى مَالَتِ الشَّمْسُ‏.‏ ثُمَّ قَامَ فِي النَّاسِ قَالَ ‏ "‏ أَيُّهَا النَّاسُ، لاَ تَتَمَنَّوْا لِقَاءَ الْعَدُوِّ، وَسَلُوا اللَّهَ الْعَافِيَةَ، فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا، وَاعْلَمُوا أَنَّ الْجَنَّةَ تَحْتَ ظِلاَلِ السُّيُوفِ، ثُمَّ قَالَ اللَّهُمَّ مُنْزِلَ الْكِتَابِ وَمُجْرِيَ السَّحَابِ وَهَازِمَ الأَحْزَابِ، اهْزِمْهُمْ وَانْصُرْنَا عَلَيْهِمْ ‏"‏‏.‏\hadithno{2966}\hadithtrans{Narrated Salim Abu An-Nadr:The freed slave of `Umar bin 'Ubaidullah who was `Umar's clerk: `Abdullah bin Abi `Aufa wrote him (i.e. `Umar) a letter that contained the following:-- "Once Allah's Messenger (ﷺ) (during a holy battle), waited till the sun had declined and then he got up among the people and said, "O people! Do not wish to face the enemy (in a battle) and ask Allah to save you (from calamities) but if you should face the enemy, then be patient and let it be known to you that Paradise is under the shades of swords." He then said,, "O Allah! The Revealer of the (Holy) Book, the Mover of the clouds, and Defeater of Al-Ahzab (i.e. the clans of infidels), defeat them infidels and bestow victory upon us}}
\hadithdefcmd{bukhari}{2967}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَتَلاَحَقَ بِي النَّبِيُّ صلى الله عليه وسلم وَأَنَا عَلَى نَاضِحٍ لَنَا قَدْ أَعْيَا فَلاَ يَكَادُ يَسِيرُ فَقَالَ لِي ‏"‏ مَا لِبَعِيرِكَ ‏"‏‏.‏ قَالَ قُلْتُ عَيِيَ‏.‏ قَالَ فَتَخَلَّفَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَزَجَرَهُ وَدَعَا لَهُ، فَمَا زَالَ بَيْنَ يَدَىِ الإِبِلِ قُدَّامَهَا يَسِيرُ‏.‏ فَقَالَ لِي ‏"‏ كَيْفَ تَرَى بَعِيرَكَ ‏"‏‏.‏ قَالَ قُلْتُ بِخَيْرٍ قَدْ أَصَابَتْهُ بَرَكَتُكَ‏.‏ قَالَ ‏"‏ أَفَتَبِيعُنِيهِ ‏"‏‏.‏ قَالَ فَاسْتَحْيَيْتُ، وَلَمْ يَكُنْ لَنَا نَاضِحٌ غَيْرَهُ، قَالَ فَقُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَبِعْنِيهِ ‏"‏‏.‏ فَبِعْتُهُ إِيَّاهُ عَلَى أَنَّ لِي فَقَارَ ظَهْرِهِ حَتَّى أَبْلُغَ الْمَدِينَةَ‏.‏ قَالَ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي عَرُوسٌ، فَاسْتَأْذَنْتُهُ فَأَذِنَ لِي، فَتَقَدَّمْتُ النَّاسَ إِلَى الْمَدِينَةِ حَتَّى أَتَيْتُ الْمَدِينَةَ، فَلَقِيَنِي خَالِي فَسَأَلَنِي عَنِ الْبَعِيرِ، فَأَخْبَرْتُهُ بِمَا صَنَعْتُ فِيهِ فَلاَمَنِي، قَالَ وَقَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لِي حِينَ اسْتَأْذَنْتُهُ ‏"‏ هَلْ تَزَوَّجْتَ بِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ فَقُلْتُ تَزَوَّجْتُ ثَيِّبًا‏.‏ فَقَالَ ‏"‏ هَلاَّ تَزَوَّجْتَ بِكْرًا تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ تُوُفِّيَ وَالِدِي ـ أَوِ اسْتُشْهِدَ ـ وَلِي أَخَوَاتٌ صِغَارٌ، فَكَرِهْتُ أَنْ أَتَزَوَّجَ مِثْلَهُنَّ، فَلاَ تُؤَدِّبُهُنَّ، وَلاَ تَقُومُ عَلَيْهِنَّ، فَتَزَوَّجْتُ ثَيِّبًا لِتَقُومَ عَلَيْهِنَّ وَتُؤَدِّبَهُنَّ‏.‏ قَالَ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ غَدَوْتُ عَلَيْهِ بِالْبَعِيرِ، فَأَعْطَانِي ثَمَنَهُ، وَرَدَّهُ عَلَىَّ‏.‏ قَالَ الْمُغِيرَةُ هَذَا فِي قَضَائِنَا حَسَنٌ لاَ نَرَى بِهِ بَأْسًا‏.‏\hadithno{2967}\hadithtrans{Narrated Jabir bin `Abdullah:I participated in a Ghazwa along with Allah's Messenger (ﷺ) The Prophet (ﷺ) met me (on the way) while I was riding a camel of ours used for irrigation and it had got so tired that it could hardly walk. The Prophet (ﷺ) asked me, "What is wrong with the camel?" I replied, "It has got tired." So. Allah's Messenger (ﷺ) came from behind it and rebuked it and prayed for it so it started surpassing the other camels and going ahead of them. Then he asked me, "How do you find your camel (now)?" I replied, "I find it quite well, now as it has received your blessings." He said, "Will you sell it to me?" I felt shy (to refuse his offer) though it was the only camel for irrigation we had. So, I said, "Yes." He said, "Sell it to me then." I sold it to him on the condition that I should keep on riding it till I reached Medina. Then I said, "O Allah's Apostle! I am a bridegroom," and requested him to allow me to go home. He allowed me, and I set out for Medina before the people till I reached Medina, where I met my uncle, who asked me about the camel and I informed him all about it and he blamed me for that. When I took the permission of Allah's Messenger (ﷺ) he asked me whether I had married a virgin or a matron and I replied that I had married a matron. He said, "Why hadn't you married a virgin who would have played with you, and you would have played with her?" I replied, "O Allah's Messenger (ﷺ)! My father died (or was martyred) and I have some young sisters, so I felt it not proper that I should marry a young girl like them who would neither teach them manners nor serve them. So, I have married a matron so that she may serve them and teach them manners." When Allah's Messenger (ﷺ) arrived in Medina, I took the camel to him the next morning and he gave me its price and gave me the camel itself as well}}
\hadithdefcmd{bukhari}{2968}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ بِالْمَدِينَةِ فَزَعٌ، فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَسًا لأَبِي طَلْحَةَ، فَقَالَ ‏ "‏ مَا رَأَيْنَا مِنْ شَىْءٍ، وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏‏.‏\hadithno{2968}\hadithtrans{Narrated Anas bin Malik:Once there was a feeling of fright at Medina, so Allah's Messenger (ﷺ) rode a horse belonging to Abu Talha and (on his return) he said, "We have not seen anything (fearful), but we found this horse very fast}}
\hadithdefcmd{bukhari}{2969}{حَدَّثَنَا الْفَضْلُ بْنُ سَهْلٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ مُحَمَّدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ فَزِعَ النَّاسُ فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَسًا لأَبِي طَلْحَةَ بَطِيئًا، ثُمَّ خَرَجَ يَرْكُضُ وَحْدَهُ، فَرَكِبَ النَّاسُ يَرْكُضُونَ خَلْفَهُ، فَقَالَ ‏ "‏ لَمْ تُرَاعُوا، إِنَّهُ لَبَحْرٌ ‏"‏‏.‏ فَمَا سُبِقَ بَعْدَ ذَلِكَ الْيَوْمِ‏.‏\hadithno{2969}\hadithtrans{Narrated Anas bin Malik:Once the people got frightened, so Allah's Messenger (ﷺ) rode a slow horse belonging to Abu Talha, and he set out all alone, making the horse gallop. Then the people rode, making their horses gallop after him. On his return he said, "Don't be afraid (there is nothing to be afraid of) (and I have found) this horse a very fast one." That horse was never excelled in running hence forward. (Qastalani Vol)}}
\hadithdefcmd{bukhari}{2970}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ مَالِكَ بْنَ أَنَسٍ، سَأَلَ زَيْدَ بْنَ أَسْلَمَ، فَقَالَ زَيْدٌ سَمِعْتُ أَبِي يَقُولُ، قَالَ عُمَرُ بْنُ الْخَطَّابِ ـ رضى الله عنه ـ حَمَلْتُ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ، فَرَأَيْتُهُ يُبَاعُ، فَسَأَلْتُ النَّبِيَّ صلى الله عليه وسلم آشْتَرِيهِ فَقَالَ ‏ "‏ لاَ تَشْتَرِهِ، وَلاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏‏.‏\hadithno{2970}\hadithtrans{Narrated `Umar bin Al-Khattab:I gave a horse to be used in Allah's Cause, but later on I saw it being sold. I asked the Prophet (ﷺ) whether I could buy it. He said, "Don't buy it and don't take back your gift of charity}}
\hadithdefcmd{bukhari}{2971}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما أَنَّ عُمَرَ بْنَ الْخَطَّابِ، حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ، فَوَجَدَهُ يُبَاعُ، فَأَرَادَ أَنْ يَبْتَاعَهُ، فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَبْتَعْهُ، وَلاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏‏.‏\hadithno{2971}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar gave a horse to be used in Allah's Cause, but later on he found it being sold. So, he intended to buy it and asked Allah's Messenger (ﷺ) who said, "Don't buy it and don't take back your gift of charity}}
\hadithdefcmd{bukhari}{2972}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، قَالَ حَدَّثَنِي أَبُو صَالِحٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي مَا تَخَلَّفْتُ عَنْ سَرِيَّةٍ، وَلَكِنْ لاَ أَجِدُ حَمُولَةً، وَلاَ أَجِدُ مَا أَحْمِلُهُمْ عَلَيْهِ، وَيَشُقُّ عَلَىَّ أَنْ يَتَخَلَّفُوا عَنِّي، وَلَوَدِدْتُ أَنِّي قَاتَلْتُ فِي سَبِيلِ اللَّهِ فَقُتِلْتُ، ثُمَّ أُحْيِيتُ ثُمَّ قُتِلْتُ، ثُمَّ أُحْيِيتُ ‏"‏‏.‏\hadithno{2972}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Were it not for the fear that it would be difficult for my followers, I would not have remained behind any Sariya, (army-unit) but I don't have riding camels and have no other means of conveyance to carry them on, and it is hard for me that my companions should remain behind me. No doubt I wish I could fight in Allah's Cause and be martyred and come to life again to be martyred and come to life once more}}
\hadithdefcmd{bukhari}{2973}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَزْوَةَ تَبُوكَ، فَحَمَلْتُ عَلَى بَكْرٍ، فَهْوَ أَوْثَقُ أَعْمَالِي فِي نَفْسِي، فَاسْتَأْجَرْتُ أَجِيرًا، فَقَاتَلَ رَجُلاً، فَعَضَّ أَحَدُهُمَا الآخَرَ فَانْتَزَعَ يَدَهُ مِنْ فِيهِ، وَنَزَعَ ثَنِيَّتَهُ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَهْدَرَهَا فَقَالَ ‏ "‏ أَيَدْفَعُ يَدَهُ إِلَيْكَ فَتَقْضَمُهَا كَمَا يَقْضَمُ الْفَحْلُ ‏"‏‏.‏\hadithno{2973}\hadithtrans{Narrated Yali:I participated in the Ghazwa of Tabuk along with Allah's Messenger (ﷺ) and I gave a young camel to be ridden in Jihad and that was, to me, one of my best deeds. Then I employed a laborer who quarrelled with another person. One of them bit the hand of the other and the latter drew his hand from the mouth of the former pulling out his front tooth. Then the former instituted a suit against the latter before the Prophet who rejected that suit saying, "Do you expect him to put out his hand for you to snap as a male camel snaps (vegetation)?}}
\hadithdefcmd{bukhari}{2974}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ أَخْبَرَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي ثَعْلَبَةُ بْنُ أَبِي مَالِكٍ الْقُرَظِيُّ، أَنَّ قَيْسَ بْنَ سَعْدٍ الأَنْصَارِيّ َ ـ رضى الله عنه ـ وَكَانَ صَاحِبَ لِوَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرَادَ الْحَجَّ فَرَجَّلَ‏.‏\hadithno{2974}\hadithtrans{Narrated Tha`laba bin Abi Malik Al-Qurazi:When Qais bin Sa`d Al-Ansari, who used to carry the flag of the Prophet, intended to perform Hajj, he combed his hair}}
\hadithdefcmd{bukhari}{2975}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ ـ رضى الله عنه ـ قَالَ كَانَ عَلِيٌّ ـ رضى الله عنه ـ تَخَلَّفَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي خَيْبَرَ، وَكَانَ بِهِ رَمَدٌ، فَقَالَ أَنَا أَتَخَلَّفُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ عَلِيٌّ فَلَحِقَ بِالنَّبِيِّ صلى الله عليه وسلم، فَلَمَّا كَانَ مَسَاءُ اللَّيْلَةِ الَّتِي فَتَحَهَا فِي صَبَاحِهَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأُعْطِيَنَّ الرَّايَةَ ـ أَوْ قَالَ لَيَأْخُذَنَّ ـ غَدًا رَجُلٌ يُحِبُّهُ اللَّهُ وَرَسُولُهُ ـ أَوْ قَالَ يُحِبُّ اللَّهَ وَرَسُولَهُ ـ يَفْتَحُ اللَّهُ عَلَيْهِ ‏"‏‏.‏ فَإِذَا نَحْنُ بِعَلِيٍّ، وَمَا نَرْجُوهُ، فَقَالُوا هَذَا عَلِيٌّ، فَأَعْطَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم، فَفَتَحَ اللَّهُ عَلَيْهِ‏.‏\hadithno{2975}\hadithtrans{Narrated Salama bin Al-Akwa: Ali remained behind the Prophet (ﷺ) during the battle of Khaibar as he was suffering from some eye trouble but then he said, "How should I stay behind Allah's Messenger (ﷺ)?" So, he set out till he joined the Prophet. On the eve of the day of the conquest of Khaibar, Allah's Messenger (ﷺ) said, "(No doubt) I will give the flag or, tomorrow, a man whom Allah and His Apostle love or who loves Allah and His apostle will take the flag. Allah will bestow victory upon him." Suddenly 'Ali joined us though we were not expecting him. The people said, "Here is 'Ali. "So, Allah's Messenger (ﷺ) gave the flag to him and Allah bestowed victory upon him}}
\hadithdefcmd{bukhari}{2976}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، قَالَ سَمِعْتُ الْعَبَّاسَ، يَقُولُ لِلزُّبَيْرِ رضى الله عنهما هَا هُنَا أَمَرَكَ النَّبِيُّ صلى الله عليه وسلم أَنْ تَرْكُزَ الرَّايَةَ‏.‏\hadithno{2976}\hadithtrans{Narrated Nafi bin Jubair: I heard Al Abbas telling Az-Zubair, "The Prophet (ﷺ) ordered you to fix the flag here}}
\hadithdefcmd{bukhari}{2977}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ بِجَوَامِعِ الْكَلِمِ، وَنُصِرْتُ بِالرُّعْبِ، فَبَيْنَا أَنَا نَائِمٌ أُتِيتُ بِمَفَاتِيحِ خَزَائِنِ الأَرْضِ، فَوُضِعَتْ فِي يَدِي ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ وَقَدْ ذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْتُمْ تَنْتَثِلُونَهَا‏.‏\hadithno{2977}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "I have been sent with the shortest expressions bearing the widest meanings, and I have been made victorious with awe (cast in the hearts of the enemy), and while I was sleeping, the keys of the treasures of the world were brought to me and put in my hand." Abu Huraira added: Allah's Messenger (ﷺ) has left the world and now you, people, are bringing out those treasures (i.e. the Prophet (ﷺ) did not benefit by them}}
\hadithdefcmd{bukhari}{2978}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ أَبَا سُفْيَانَ أَخْبَرَهُ أَنَّ هِرَقْلَ أَرْسَلَ إِلَيْهِ وَهُمْ بِإِيلِيَاءَ، ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَلَمَّا فَرَغَ مِنْ قِرَاءَةِ الْكِتَابِ كَثُرَ عِنْدَهُ الصَّخَبُ، فَارْتَفَعَتِ الأَصْوَاتُ، وَأُخْرِجْنَا، فَقُلْتُ لأَصْحَابِي حِينَ أُخْرِجْنَا لَقَدْ أَمِرَ أَمْرُ ابْنِ أَبِي كَبْشَةَ، إِنَّهُ يَخَافُهُ مَلِكُ بَنِي الأَصْفَرِ‏.‏\hadithno{2978}\hadithtrans{Narrated Ibn `Abbas:Abu Sufyan said, "Heraclius sent for me when I was in 'Ilya' (i.e. Jerusalem). Then he asked for the letter of Allah's Messenger (ﷺ) and when he had finished its reading there was a great hue and cry around him and the voices grew louder and we were asked to quit the place. When we were turned out, I said to my companions, 'The cause of Ibn Abi Kabsha has become conspicuous as the King of Bani Al- Asfar is afraid of him}}
\hadithdefcmd{bukhari}{2979}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي وَ، حَدَّثَتْنِي أَيْضًا، فَاطِمَةُ عَنْ أَسْمَاءَ ـ رضى الله عنها ـ قَالَتْ صَنَعْتُ سُفْرَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَيْتِ أَبِي بَكْرٍ حِينَ أَرَادَ أَنْ يُهَاجِرَ إِلَى الْمَدِينَةِ، قَالَتْ فَلَمْ نَجِدْ لِسُفْرَتِهِ وَلاَ لِسِقَائِهِ مَا نَرْبِطُهُمَا بِهِ، فَقُلْتُ لأَبِي بَكْرٍ وَاللَّهِ مَا أَجِدُ شَيْئًا أَرْبِطُ بِهِ إِلاَّ نِطَاقِي‏.‏ قَالَ فَشُقِّيهِ بِاثْنَيْنِ، فَارْبِطِيهِ بِوَاحِدٍ السِّقَاءَ وَبِالآخَرِ السُّفْرَةَ‏.‏ فَفَعَلْتُ، فَلِذَلِكَ سُمِّيَتْ ذَاتَ النِّطَاقَيْنِ‏.‏\hadithno{2979}\hadithtrans{Narrated Asma:I prepared the journey-food for Allah's Messenger (ﷺ) in Abu Bakr's house when he intended to emigrate to Medina. I could not find anything to tie the food-container and the water skin with. So, I said to Abu Bakr, "By Allah, I do not find anything to tie (these things) with except my waist belt." He said, "Cut it into two pieces and tie the water-skin with one piece and the food-container with the other (The subnarrator added, "She did accordingly and that was the reason for calling her Dhatun-Nitaqain (i.e. two-belted woman)}}
\hadithdefcmd{bukhari}{2980}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ أَخْبَرَنِي عَطَاءٌ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كُنَّا نَتَزَوَّدُ لُحُومَ الأَضَاحِيِّ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم إِلَى الْمَدِينَةِ‏.‏\hadithno{2980}\hadithtrans{Narrated Jabir bin `Abdullah:During the life-time of the Prophet (ﷺ) we used to take the meat of sacrificed animals (as journey food) to Medina. (See Hadith No. 474 Vol)}}
\hadithdefcmd{bukhari}{2981}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى، قَالَ أَخْبَرَنِي بُشَيْرُ بْنُ يَسَارٍ، أَنَّ سُوَيْدَ بْنَ النُّعْمَانِ ـ رضى الله عنه ـ أَخْبَرَهُ أَنَّهُ، خَرَجَ مَعَ النَّبِيِّ صلى الله عليه وسلم عَامَ خَيْبَرَ، حَتَّى إِذَا كَانُوا بِالصَّهْبَاءِ ـ وَهْىَ مِنْ خَيْبَرَ وَهْىَ أَدْنَى خَيْبَرَ ـ فَصَلَّوُا الْعَصْرَ، فَدَعَا النَّبِيُّ صلى الله عليه وسلم بِالأَطْعِمَةِ، فَلَمْ يُؤْتَ النَّبِيُّ صلى الله عليه وسلم إِلاَّ بِسَوِيقٍ، فَلُكْنَا فَأَكَلْنَا وَشَرِبْنَا، ثُمَّ قَامَ النَّبِيُّ صلى الله عليه وسلم فَمَضْمَضَ وَمَضْمَضْنَا، وَصَلَّيْنَا‏.‏\hadithno{2981}\hadithtrans{Narrated Suwaid bin An-Nu`man:That he went out in the company of the Prophet (ﷺ) during the year of Khaibar (campaign) till they reached a place called As-Sahba', the lower part of Khaibar. They offered the `Asr prayer (there) and the Prophet asked for the food. Nothing but Sawiq was brought to the Prophet. So, they chewed it and ate it and drank water. After that the Prophet (ﷺ) got up, washed his mouth, and they too washed their mouths and then offered the prayer}}
\hadithdefcmd{bukhari}{2982}{حَدَّثَنَا بِشْرُ بْنُ مَرْحُومٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ ـ رضى الله عنه قَالَ خَفَّتْ أَزْوَادُ النَّاسِ وَأَمْلَقُوا، فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فِي نَحْرِ إِبِلِهِمْ، فَأَذِنَ لَهُمْ، فَلَقِيَهُمْ عُمَرُ فَأَخْبَرُوهُ فَقَالَ مَا بَقَاؤُكُمْ بَعْدَ إِبِلِكُمْ فَدَخَلَ عُمَرُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا بَقَاؤُهُمْ بَعْدَ إِبِلِهِمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَادِ فِي النَّاسِ يَأْتُونَ بِفَضْلِ أَزْوَادِهِمْ ‏"‏‏.‏ فَدَعَا وَبَرَّكَ عَلَيْهِ، ثُمَّ دَعَاهُمْ بِأَوْعِيَتِهِمْ، فَاحْتَثَى النَّاسُ حَتَّى فَرَغُوا، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَنِّي رَسُولُ اللَّهِ ‏"‏‏.‏\hadithno{2982}\hadithtrans{Narrated Salama:Once the journey-food of the people ran short and they were in great need. So, they came to the Prophet to take his permission for slaughtering their camels, and he permitted them. Then `Umar met them and they informed him about it. He said, "What will sustain you after your camels (are finished)?" Then `Umar went to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! What will sustain them after their camels (are finished)?" Allah's Messenger (ﷺ) said, "Make an announcement amongst the people that they should bring all their remaining food (to me)." (They brought it and) the Prophet (ﷺ) invoked Allah and asked for His Blessings for it. Then he asked them to bring their food utensils and the people started filling their food utensils with their hands till they were satisfied. Allah's Messenger (ﷺ) then said, "I testify that None has the right to be worshipped but Allah, and I am His Apostle}}
\hadithdefcmd{bukhari}{2983}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ خَرَجْنَا وَنَحْنُ ثَلاَثُمِائَةٍ نَحْمِلُ زَادَنَا عَلَى رِقَابِنَا، فَفَنِيَ زَادُنَا، حَتَّى كَانَ الرَّجُلُ مِنَّا يَأْكُلُ فِي كُلِّ يَوْمٍ تَمْرَةً‏.‏ قَالَ رَجُلٌ يَا أَبَا عَبْدِ اللَّهِ، وَأَيْنَ كَانَتِ التَّمْرَةُ تَقَعُ مِنَ الرَّجُلِ قَالَ لَقَدْ وَجَدْنَا فَقْدَهَا حِينَ فَقَدْنَاهَا، حَتَّى أَتَيْنَا الْبَحْرَ فَإِذَا حُوتٌ قَدْ قَذَفَهُ الْبَحْرُ، فَأَكَلْنَا مِنْهَا ثَمَانِيَةَ عَشَرَ يَوْمًا مَا أَحْبَبْنَا‏.‏\hadithno{2983}\hadithtrans{Narrated Wahb bin Kaisan:Jabir bin `Abdullah said, "We set out, and we were three-hundred men carrying our journey-food on our shoulders. Then we began to eat a single date each per day." A man asked (Jabir), "O Abu `Abdullah! How could a person be satisfied with a single date?" Jabir replied, "We realized the value of that one date when we could not even have that much till we reached the sea-shore, when all of a sudden we saw a huge fish cast by the sea. So, we ate of it as much as we wished for eighteen days}}
\hadithdefcmd{bukhari}{2984}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عُثْمَانُ بْنُ الأَسْوَدِ، حَدَّثَنَا ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ، يَرْجِعُ أَصْحَابُكَ بِأَجْرِ حَجٍّ وَعُمْرَةٍ، وَلَمْ أَزِدْ عَلَى الْحَجِّ‏.‏ فَقَالَ لَهَا ‏ "‏ اذْهَبِي وَلْيَرْدِفْكِ عَبْدُ الرَّحْمَنِ ‏"‏‏.‏ فَأَمَرَ عَبْدَ الرَّحْمَنِ أَنْ يُعْمِرَهَا مِنَ التَّنْعِيمِ، فَانْتَظَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَعْلَى مَكَّةَ حَتَّى جَاءَتْ‏.‏\hadithno{2984}\hadithtrans{Narrated Aisha:That she said, "O Allah's Messenger (ﷺ)! Your companions are returning with the reward of both Hajj and `Umra, while I am returning with (the reward of) Hajj only." He said to her, "Go, and let `Abdur- Rahman (i.e. your brother) make you sit behind him (on the animal)." So, he ordered `AbdurRahman to let her perform `Umra from Al-Tan`im. Then the Prophet (ﷺ) waited for her at the higher region of Mecca till she returned}}
\hadithdefcmd{bukhari}{2985}{حَدَّثَنِي عَبْدُ اللَّهِ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ ـ رضى الله عنهما ـ قَالَ أَمَرَنِي النَّبِيُّ صلى الله عليه وسلم أَنْ أُرْدِفَ عَائِشَةَ وَأُعْمِرَهَا مِنَ التَّنْعِيمِ‏.‏\hadithno{2985}\hadithtrans{Narrated `Abdur-Rahman bin Abi Bakr As-Siddiq:The Prophet (ﷺ) ordered me to let `Aisha sit behind me (on the animal) and to let her perform `Umra from at-Tan`im}}
\hadithdefcmd{bukhari}{2986}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كُنْتُ رَدِيفَ أَبِي طَلْحَةَ، وَإِنَّهُمْ لَيَصْرُخُونَ بِهِمَا جَمِيعًا الْحَجِّ وَالْعُمْرَةِ‏.‏\hadithno{2986}\hadithtrans{Narrated Anas:I was riding behind Abu Talha (on the same) riding animal and (the Prophet's companions) were reciting Talbiya aloud for both Hajj and `Umra}}
\hadithdefcmd{bukhari}{2987}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ عَلَى حِمَارٍ، عَلَى إِكَافٍ عَلَيْهِ قَطِيفَةٌ، وَأَرْدَفَ أُسَامَةَ وَرَاءَهُ‏.‏\hadithno{2987}\hadithtrans{Narrated `Urwa from Usama bin Zaid:Allah's Messenger (ﷺ) rode a donkey on which there was a saddle covered by a velvet sheet and let Usama ride behind him (on the donkey)}}
\hadithdefcmd{bukhari}{2988}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، قَالَ يُونُسُ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقْبَلَ يَوْمَ الْفَتْحِ مِنْ أَعْلَى مَكَّةَ عَلَى رَاحِلَتِهِ، مُرْدِفًا أُسَامَةَ بْنَ زَيْدٍ وَمَعَهُ بِلاَلٌ وَمَعَهُ عُثْمَانُ بْنُ طَلْحَةَ مِنَ الْحَجَبَةِ، حَتَّى أَنَاخَ فِي الْمَسْجِدِ، فَأَمَرَهُ أَنْ يَأْتِيَ بِمِفْتَاحِ الْبَيْتِ، فَفَتَحَ وَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ أُسَامَةُ وَبِلاَلٌ وَعُثْمَانُ، فَمَكَثَ فِيهَا نَهَارًا طَوِيلاً ثُمَّ خَرَجَ، فَاسْتَبَقَ النَّاسُ، وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَوَّلَ مَنْ دَخَلَ، فَوَجَدَ بِلاَلاً وَرَاءَ الْبَابِ قَائِمًا، فَسَأَلَهُ أَيْنَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَشَارَ لَهُ إِلَى الْمَكَانِ الَّذِي صَلَّى فِيهِ، قَالَ عَبْدُ اللَّهِ فَنَسِيتُ أَنْ أَسْأَلَهُ كَمْ صَلَّى مِنْ سَجْدَةٍ\hadithno{2988}\hadithtrans{Narrated Nafi` from `Abdullah:Allah's Messenger (ﷺ) came to Mecca through its higher region on the day of the Conquest (of Mecca) riding his she-camel on which Usama was riding behind him. Bilal and `Uthman bin Talha, one of the servants of the Ka`ba, were also accompanying him till he made his camel kneel in the mosque and ordered the latter to bring the key of the Ka`ba. He opened the door of the Ka`ba and Allah's Messenger (ﷺ) entered in the company of Usama, Bilal and `Uthman, and stayed in it for a long period. When he came out, the people rushed to it, and `Abdullah bin `Umar was the first to enter it and found Bilal standing behind the door. He asked Bilal, "Where did the Prophet (ﷺ) offer his prayer?" He pointed to the place where he had offered his prayer. `Abdullah said, "I forgot to ask him how many rak`at he had performed}}
\hadithdefcmd{bukhari}{2989}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ سُلاَمَى مِنَ النَّاسِ عَلَيْهِ صَدَقَةٌ كُلَّ يَوْمٍ تَطْلُعُ فِيهِ الشَّمْسُ، يَعْدِلُ بَيْنَ الاِثْنَيْنِ صَدَقَةٌ، وَيُعِينُ الرَّجُلَ عَلَى دَابَّتِهِ، فَيَحْمِلُ عَلَيْهَا، أَوْ يَرْفَعُ عَلَيْهَا مَتَاعَهُ صَدَقَةٌ، وَالْكَلِمَةُ الطَّيِّبَةُ صَدَقَةٌ، وَكُلُّ خَطْوَةٍ يَخْطُوهَا إِلَى الصَّلاَةِ صَدَقَةٌ، وَيُمِيطُ الأَذَى عَنِ الطَّرِيقِ صَدَقَةٌ ‏"‏‏.‏\hadithno{2989}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There is a (compulsory) Sadaqa (charity) to be given for every joint of the human body (as a sign of gratitude to Allah) everyday the sun rises. To judge justly between two persons is regarded as Sadaqa, and to help a man concerning his riding animal by helping him to ride it or by lifting his luggage on to it, is also regarded as Sadaqa, and (saying) a good word is also Sadaqa, and every step taken on one's way to offer the compulsory prayer (in the mosque) is also Sadaqa and to remove a harmful thing from the way is also Sadaqa}}
\hadithdefcmd{bukhari}{2990}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُسَافَرَ بِالْقُرْآنِ إِلَى أَرْضِ الْعَدُوِّ‏.‏\hadithno{2990}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) forbade the people to travel to a hostile country carrying (copies of) the Qur'an}}
\hadithdefcmd{bukhari}{2991}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ صَبَّحَ النَّبِيُّ صلى الله عليه وسلم خَيْبَرَ وَقَدْ خَرَجُوا بِالْمَسَاحِي عَلَى أَعْنَاقِهِمْ، فَلَمَّا رَأَوْهُ قَالُوا هَذَا مُحَمَّدٌ وَالْخَمِيسُ، مُحَمَّدٌ وَالْخَمِيسُ‏.‏ فَلَجَئُوا إِلَى الْحِصْنِ، فَرَفَعَ النَّبِيُّ صلى الله عليه وسلم يَدَيْهِ وَقَالَ ‏ "‏ اللَّهُ أَكْبَرُ، خَرِبَتْ خَيْبَرُ، إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏‏.‏ وَأَصَبْنَا حُمُرًا فَطَبَخْنَاهَا، فَنَادَى مُنَادِي النَّبِيِّ صلى الله عليه وسلم إِنَّ اللَّهَ وَرَسُولَهُ يَنْهَيَانِكُمْ عَنْ لُحُومِ الْحُمُرِ، فَأُكْفِئَتِ الْقُدُورُ بِمَا فِيهَا‏.‏ تَابَعَهُ عَلِيٌّ عَنْ سُفْيَانَ رَفَعَ النَّبِيُّ صلى الله عليه وسلم يَدَيْهِ‏.‏\hadithno{2991}\hadithtrans{Narrated Anas:The Prophet (ﷺ) reached Khaibar in the morning, while the people were coming out carrying their spades over their shoulders. When they saw him they said, "This is Muhammad and his army! Muhammad and his army!" So, they took refuge in the fort. The Prophet (ﷺ) raised both his hands and said, "Allahu Akbar, Khaibar is ruined, for when we approach a nation (i.e. enemy to fight) then miserable is the morning of the warned ones." Then we found some donkeys which we (killed and) cooked: The announcer of the Prophet (ﷺ) announced: "Allah and His Apostle forbid you to eat donkey's meat." So, all the pots including their contents were turned upside down}}
\hadithdefcmd{bukhari}{2992}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَكُنَّا إِذَا أَشْرَفْنَا عَلَى وَادٍ هَلَّلْنَا وَكَبَّرْنَا ارْتَفَعَتْ أَصْوَاتُنَا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَيُّهَا النَّاسُ، ارْبَعُوا عَلَى أَنْفُسِكُمْ، فَإِنَّكُمْ لاَ تَدْعُونَ أَصَمَّ وَلاَ غَائِبًا، إِنَّهُ مَعَكُمْ، إِنَّهُ سَمِيعٌ قَرِيبٌ، تَبَارَكَ اسْمُهُ وَتَعَالَى جَدُّهُ ‏"‏‏.‏\hadithno{2992}\hadithtrans{Narrated Abu Musa Al-Ash`ari:We were in the company of Allah's Messenger (ﷺ) (during Hajj). Whenever we went up a high place we used to say: "None has the right to be worshipped but Allah, and Allah is Greater," and our voices used to rise, so the Prophet (ﷺ) said, "O people! Be merciful to yourselves (i.e. don't raise your voice), for you are not calling a deaf or an absent one, but One Who is with you, no doubt He is All-Hearer, ever Near (to all things)}}
\hadithdefcmd{bukhari}{2993}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كُنَّا إِذَا صَعِدْنَا كَبَّرْنَا، وَإِذَا نَزَلْنَا سَبَّحْنَا‏.‏\hadithno{2993}\hadithtrans{Narrated Jabir bin `Abdullah:Whenever we went up a place we would say, "Allahu--Akbar (i.e. Allah is Greater)", and whenever we went down a place we would say, "Subhan Allah}}
\hadithdefcmd{bukhari}{2994}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ حُصَيْنٍ، عَنْ سَالِمٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ كُنَّا إِذَا صَعِدْنَا كَبَّرْنَا، وَإِذَا تَصَوَّبْنَا سَبَّحْنَا‏.‏\hadithno{2994}\hadithtrans{Narrated Jabir:Whenever we went up a place we would say Takbir, and whenever we went down we would say, "Subhan Allah}}
\hadithdefcmd{bukhari}{2995}{حَدَّثَنَا عَبْدُ اللَّهِ، قَالَ حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَفَلَ مِنَ الْحَجِّ أَوِ الْعُمْرَةِ ـ وَلاَ أَعْلَمُهُ إِلاَّ قَالَ الْغَزْوِ ـ يَقُولُ كُلَّمَا أَوْفَى عَلَى ثَنِيَّةٍ أَوْ فَدْفَدٍ كَبَّرَ ثَلاَثًا ثُمَّ قَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ، وَلَهُ الْحَمْدُ، وَهْوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ، آيِبُونَ تَائِبُونَ عَابِدُونَ سَاجِدُونَ لِرَبِّنَا حَامِدُونَ، صَدَقَ اللَّهُ وَعْدَهُ، وَنَصَرَ عَبْدَهُ، وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏‏.‏ قَالَ صَالِحٌ فَقُلْتُ لَهُ أَلَمْ يَقُلْ عَبْدُ اللَّهِ إِنْ شَاءَ اللَّهُ قَالَ لاَ‏.‏\hadithno{2995}\hadithtrans{Narrated `Abdullah bin `Umar:Whenever the Prophet (ﷺ) returned from the Hajj or the `Umra or a Ghazwa, he would say Takbir thrice. Whenever he came upon a mountain path or wasteland, then he would say, "None has the right to be worshipped but Allah Alone Who has no partner. All the Kingdom belongs to Him and all the praises are for Him and He is Omnipotent. We are returning with repentance, worshipping, prostrating ourselves and praising our Lord. Allah fulfilled His Promise, granted victory to His slave and He Alone defeated all the clans}}
\hadithdefcmd{bukhari}{2996}{حَدَّثَنَا مَطَرُ بْنُ الْفَضْلِ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا الْعَوَّامُ، حَدَّثَنَا إِبْرَاهِيمُ أَبُو إِسْمَاعِيلَ السَّكْسَكِيُّ، قَالَ سَمِعْتُ أَبَا بُرْدَةَ، وَاصْطَحَبَ، هُوَ وَيَزِيدُ بْنُ أَبِي كَبْشَةَ فِي سَفَرٍ، فَكَانَ يَزِيدُ يَصُومُ فِي السَّفَرِ فَقَالَ لَهُ أَبُو بُرْدَةَ سَمِعْتُ أَبَا مُوسَى مِرَارًا يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَرِضَ الْعَبْدُ أَوْ سَافَرَ، كُتِبَ لَهُ مِثْلُ مَا كَانَ يَعْمَلُ مُقِيمًا صَحِيحًا ‏"‏‏.‏\hadithno{2996}\hadithtrans{Narrated Ibrahim Abu Isma`il As-Saksaki:I heard Abu Burda who accompanied Yazid bin Abi Kabsha on a journey. Yazid used to observe fasting on journeys. Abu Burda said to him, "I heard Abu Musa several times saying that Allah's Apostle said, 'When a slave falls ill or travels, then he will get reward similar to that he gets for good deeds practiced at home when in good health}}
\hadithdefcmd{bukhari}{2997}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ نَدَبَ النَّبِيُّ صلى الله عليه وسلم النَّاسَ يَوْمَ الْخَنْدَقِ، فَانْتَدَبَ الزُّبَيْرُ، ثُمَّ نَدَبَهُمْ فَانْتَدَبَ الزُّبَيْرُ، ثُمَّ نَدَبَهُمْ فَانْتَدَبَ الزُّبَيْرُ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ لِكُلِّ نَبِيٍّ حَوَارِيًّا، وَحَوَارِيَّ الزُّبَيْرُ ‏"‏‏.‏ قَالَ سُفْيَانُ الْحَوَارِيُّ النَّاصِرُ‏.‏\hadithno{2997}\hadithtrans{Narrated Jabir bin `Abdullah:On the day of the battle of the Trench, the Prophet (ﷺ) wanted somebody from amongst the people to volunteer to be a reconnoitre. Az-Zubair volunteered. He demanded the same again and Az-Zubair volunteered again. Then he repeated the same demand (thrice) and Az-Zubair volunteered once more. The Prophet (ﷺ) then said, " Every prophet has a disciple and my disciple is Az-Zubair}}
\hadithdefcmd{bukhari}{2998}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدِ بْنِ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي الْوَحْدَةِ مَا أَعْلَمُ مَا سَارَ رَاكِبٌ بِلَيْلٍ وَحْدَهُ ‏"‏‏.‏\hadithno{2998}\hadithtrans{Narrated Ibn' `Umar:from the Prophet (ﷺ) the following Hadith (No. 242). Narrated Ibn `Umar: The Prophet (ﷺ) said, "If the people knew what I know about traveling alone, then nobody would travel alone at night}}
\hadithdefcmd{bukhari}{2999}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي قَالَ، سُئِلَ أُسَامَةُ بْنُ زَيْدٍ ـ رضى الله عنهما ـ كَانَ يَحْيَى يَقُولُ وَأَنَا أَسْمَعُ فَسَقَطَ عَنِّي ـ عَنْ مَسِيرِ النَّبِيِّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ، قَالَ فَكَانَ يَسِيرُ الْعَنَقَ، فَإِذَا وَجَدَ فَجْوَةً نَصَّ‏.‏ وَالنَّصُّ فَوْقَ الْعَنَقِ‏.‏\hadithno{2999}\hadithtrans{Narrated Hisham's father:Usama bin Zaid was asked at what pace the Prophet (ﷺ) rode during Hajjat-ul-Wada`. He said, "He rode at a medium pace, but when he came upon an open way he would go at full pace}}
\hadithdefcmd{bukhari}{3000}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي زَيْدٌ ـ هُوَ ابْنُ أَسْلَمَ ـ عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ بِطَرِيقِ مَكَّةَ، فَبَلَغَهُ عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ شِدَّةُ وَجَعٍ، فَأَسْرَعَ السَّيْرَ حَتَّى إِذَا كَانَ بَعْدَ غُرُوبِ الشَّفَقِ، ثُمَّ نَزَلَ فَصَلَّى الْمَغْرِبَ وَالْعَتَمَةَ، يَجْمَعُ بَيْنَهُمَا، وَقَالَ إِنِّي رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم إِذَا جَدَّ بِهِ السَّيْرُ أَخَّرَ الْمَغْرِبَ وَجَمَعَ بَيْنَهُمَا‏.‏\hadithno{3000}\hadithtrans{Narrated Aslam:While I was in the company of `Abdullah bin `Umar on the way to Mecca, he received the news of the severe illness of Safiya bint Abi Ubaid (i.e. his wife), so he proceeded at greater speed, and when the twilight disappeared, he dismounted and offered the Maghrib and `Isha 'prayers together and said, " I saw the Prophet (ﷺ) delaying the Maghrib prayer to offer it along with the `Isha' when he was in a hurry on a journey}}
\hadithdefcmd{bukhari}{3001}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ السَّفَرُ قِطْعَةٌ مِنَ الْعَذَابِ، يَمْنَعُ أَحَدَكُمْ نَوْمَهُ وَطَعَامَهُ وَشَرَابَهُ، فَإِذَا قَضَى أَحَدُكُمْ نَهْمَتَهُ فَلْيُعَجِّلْ إِلَى أَهْلِهِ ‏"‏‏.‏\hadithno{3001}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Journey is a piece of torture, for it disturbs one's sleep, eating and drinking. So, when you fulfill your job, you should hurry up to your family}}
\hadithdefcmd{bukhari}{3002}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما أَنَّ عُمَرَ بْنَ الْخَطَّابِ، حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ فَوَجَدَهُ يُبَاعُ، فَأَرَادَ أَنْ يَبْتَاعَهُ، فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَبْتَعْهُ، وَلاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏‏.‏\hadithno{3002}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab gave a horse to be ridden in Allah's Cause and then he found it being sold. He intended to purchase it. So, he consulted Allah's Messenger (ﷺ) who said, "Don't buy it and don't take back your gift of charity}}
\hadithdefcmd{bukhari}{3003}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ يَقُولُ حَمَلْتُ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ فَابْتَاعَهُ ـ أَوْ فَأَضَاعَهُ ـ الَّذِي كَانَ عِنْدَهُ، فَأَرَدْتُ أَنْ أَشْتَرِيَهُ، وَظَنَنْتُ أَنَّهُ بَائِعُهُ بِرُخْصٍ، فَسَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَشْتَرِهِ وَإِنْ بِدِرْهَمٍ، فَإِنَّ الْعَائِدَ فِي هِبَتِهِ كَالْكَلْبِ يَعُودُ فِي قَيْئِهِ ‏"‏‏.‏\hadithno{3003}\hadithtrans{Narrated Aslam:I heard `Umar bin Al-Khattab saying, "I gave a horse to be ridden in Allah's Cause and the person who got it intended to sell it or neglected it. So, I wanted to buy it as I thought he would sell it cheap. I consulted the Prophet (ﷺ) who said, "Do not buy it even if for one Dirham, because he who takes back his gift is like a dog swallowing its vomit}}
\hadithdefcmd{bukhari}{3004}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، قَالَ سَمِعْتُ أَبَا الْعَبَّاسِ الشَّاعِرَ ـ وَكَانَ لاَ يُتَّهَمُ فِي حَدِيثِهِ ـ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو ـ رضى الله عنهما ـ يَقُولُ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَاسْتَأْذَنَهُ فِي الْجِهَادِ فَقَالَ ‏"‏ أَحَىٌّ وَالِدَاكَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَفِيهِمَا فَجَاهِدْ ‏"‏‏.‏\hadithno{3004}\hadithtrans{Narrated `Abdullah bin `Amr:A man came to the Prophet (ﷺ) asking his permission to take part in Jihad. The Prophet (ﷺ) asked him, "Are your parents alive?" He replied in the affirmative. The Prophet (ﷺ) said to him, "Then exert yourself in their service}}
\hadithdefcmd{bukhari}{3005}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، أَنَّ أَبَا بَشِيرٍ الأَنْصَارِيّ َ ـ رضى الله عنه ـ أَخْبَرَهُ أَنَّهُ، كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ ـ قَالَ عَبْدُ اللَّهِ حَسِبْتُ أَنَّهُ قَالَ ـ وَالنَّاسُ فِي مَبِيتِهِمْ، فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَسُولاً أَنْ لاَ يَبْقَيَنَّ فِي رَقَبَةِ بَعِيرٍ قِلاَدَةٌ مِنْ وَتَرٍ أَوْ قِلاَدَةٌ إِلاَّ قُطِعَتْ‏.‏\hadithno{3005}\hadithtrans{Narrated Abu Bashir Al-Ansari:That he was in the company of Allah's Messenger (ﷺ) on some of his journeys. (The sub-narrator `Abdullah adds, "I think that Abu Bashir also said, 'And the people were at their sleeping places.") Allah's Apostle sent a messenger ordering: "There shall not remain any necklace of string or any other kind of necklace round the necks of camels except it is cut off}}
\hadithdefcmd{bukhari}{3006}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَخْلُوَنَّ رَجُلٌ بِامْرَأَةٍ، وَلاَ تُسَافِرَنَّ امْرَأَةٌ إِلاَّ وَمَعَهَا مَحْرَمٌ ‏"‏‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ، اكْتُتِبْتُ فِي غَزْوَةِ كَذَا وَكَذَا، وَخَرَجَتِ امْرَأَتِي حَاجَّةً‏.‏ قَالَ ‏"‏ اذْهَبْ فَحُجَّ مَعَ امْرَأَتِكَ ‏"‏‏.‏\hadithno{3006}\hadithtrans{Narrated Ibn `Abbas:That he heard the Prophet (ﷺ) saying, "It is not permissible for a man to be alone with a woman, and no lady should travel except with a Mahram (i.e. her husband or a person whom she cannot marry in any case for ever; e.g. her father, brother, etc.)." Then a man got up and said, "O Allah's Messenger (ﷺ)! I have enlisted in the army for such-and-such Ghazwa and my wife is proceeding for Hajj." Allah's Messenger (ﷺ) said, "Go, and perform the Hajj with your wife}}
\hadithdefcmd{bukhari}{3007}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، سَمِعْتُهُ مِنْهُ، مَرَّ��َيْنِ قَالَ أَخْبَرَنِي حَسَنُ بْنُ مُحَمَّدٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي رَافِعٍ، قَالَ سَمِعْتُ عَلِيًّا ـ رضى الله عنه ـ يَقُولُ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَا وَالزُّبَيْرَ وَالْمِقْدَادَ بْنَ الأَسْوَدِ قَالَ ‏"‏ انْطَلِقُوا حَتَّى تَأْتُوا رَوْضَةَ خَاخٍ، فَإِنَّ بِهَا ظَعِينَةً وَمَعَهَا كِتَابٌ، فَخُذُوهُ مِنْهَا ‏"‏‏.‏ فَانْطَلَقْنَا تَعَادَى بِنَا خَيْلُنَا حَتَّى انْتَهَيْنَا إِلَى الرَّوْضَةِ، فَإِذَا نَحْنُ بِالظَّعِينَةِ فَقُلْنَا أَخْرِجِي الْكِتَابَ‏.‏ فَقَالَتْ مَا مَعِي مِنْ كِتَابٍ‏.‏ فَقُلْنَا لَتُخْرِجِنَّ الْكِتَابَ أَوْ لَنُلْقِيَنَّ الثِّيَابَ‏.‏ فَأَخْرَجَتْهُ مِنْ عِقَاصِهَا، فَأَتَيْنَا بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم، فَإِذَا فِيهِ مِنْ حَاطِبِ بْنِ أَبِي بَلْتَعَةَ إِلَى أُنَاسٍ مِنَ الْمُشْرِكِينَ مِنْ أَهْلِ مَكَّةَ، يُخْبِرُهُمْ بِبَعْضِ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا حَاطِبُ، مَا هَذَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، لاَ تَعْجَلْ عَلَىَّ، إِنِّي كُنْتُ امْرَأً مُلْصَقًا فِي قُرَيْشٍ، وَلَمْ أَكُنْ مِنْ أَنْفُسِهَا، وَكَانَ مَنْ مَعَكَ مِنَ الْمُهَاجِرِينَ لَهُمْ قَرَابَاتٌ بِمَكَّةَ، يَحْمُونَ بِهَا أَهْلِيهِمْ وَأَمْوَالَهُمْ، فَأَحْبَبْتُ إِذْ فَاتَنِي ذَلِكَ مِنَ النَّسَبِ فِيهِمْ أَنْ أَتَّخِذَ عِنْدَهُمْ يَدًا يَحْمُونَ بِهَا قَرَابَتِي، وَمَا فَعَلْتُ كُفْرًا وَلاَ ارْتِدَادًا وَلاَ رِضًا بِالْكُفْرِ بَعْدَ الإِسْلاَمِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ صَدَقَكُمْ ‏"‏‏.‏ قَالَ عُمَرُ يَا رَسُولَ اللَّهِ دَعْنِي أَضْرِبْ عُنُقَ هَذَا الْمُنَافِقِ‏.‏ قَالَ ‏"‏ إِنَّهُ قَدْ شَهِدَ بَدْرًا، وَمَا يُدْرِيكَ لَعَلَّ اللَّهَ أَنْ يَكُونَ قَدِ اطَّلَعَ عَلَى أَهْلِ بَدْرٍ فَقَالَ اعْمَلُوا مَا شِئْتُمْ، فَقَدْ غَفَرْتُ لَكُمْ ‏"‏‏.‏ قَالَ سُفْيَانُ وَأَىُّ إِسْنَادٍ هَذَا‏.‏\hadithno{3007}\hadithtrans{Narrated 'Ubaidullah bin Abi Rafi`:I heard `Ali saying, "Allah's Messenger (ﷺ) sent me, Az-Zubair and Al-Miqdad somewhere saying, 'Proceed till you reach Rawdat Khakh. There you will find a lady with a letter. Take the letter from her.' " So, we set out and our horses ran at full pace till we got at Ar-Rawda where we found the lady and said (to her). "Take out the letter." She replied, "I have no letter with me." We said, "Either you take out the letter or else we will take off your clothes." So, she took it out of her braid. We brought the letter to Allah's Messenger (ﷺ) and it contained a statement from Hatib bin Abi Balta'a to some of the Meccan pagans informing them of some of the intentions of Allah's Messenger (ﷺ). Then Allah's Messenger (ﷺ) said, "O Hatib! What is this?" Hatib replied, "O Allah's Messenger (ﷺ)! Don't hasten to give your judgment about me. I was a man closely connected with the Quraish, but I did not belong to this tribe, while the other emigrants with you, had their relatives in Mecca who would protect their dependents and property . So, I wanted to recompense for my lacking blood relation to them by doing them a favor so that they might protect my dependents. I did this neither because of disbelief nor apostasy nor out of preferring Kufr (disbelief) to Islam." Allah's Messenger (ﷺ), said, "Hatib has told you the truth." `Umar said, O Allah's Apostle! Allow me to chop off the head of this hypocrite." Allah's Messenger (ﷺ) said, "Hatib participated in the battle of Badr, and who knows, perhaps Allah has already looked at the Badr warriors and said, 'Do whatever you like, for I have forgiven you}}
\hadithdefcmd{bukhari}{3008}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ لَمَّا كَانَ يَوْمَ بَدْرٍ أُتِيَ بِأُسَارَى، وَأُتِيَ بِالْعَبَّاسِ وَلَمْ يَكُنْ عَلَيْهِ ثَوْبٌ، فَنَظَرَ النَّبِيُّ صلى الله عليه وسلم لَهُ قَمِيصًا فَوَجَدُوا قَمِيصَ عَبْدِ اللَّهِ بْنِ أُبَىٍّ يَقْدُرُ عَلَيْهِ، فَكَسَاهُ النَّبِيُّ صلى الله عليه وسلم إِيَّاهُ، فَلِذَلِكَ نَزَعَ النَّبِيُّ صلى الله عليه وسلم قَمِيصَهُ الَّذِي أَلْبَسَهُ‏.‏ قَالَ ابْنُ عُيَيْنَةَ كَانَتْ لَهُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم يَدٌ فَأَحَبَّ أَنْ يُكَافِئَهُ‏.‏\hadithno{3008}\hadithtrans{Narrated Jabir bin `Abdullah:When it was the day (of the battle) of Badr, prisoners of war were brought including Al-Abbas who was undressed. The Prophet (ﷺ) looked for a shirt for him. It was found that the shirt of `Abdullah bin Ubai would do, so the Prophet (ﷺ) let him wear it. That was the reason why the Prophet (ﷺ) took off and gave his own shirt to `Abdullah. (The narrator adds, "He had done the Prophet (ﷺ) some favor for which the Prophet liked to reward him}}
\hadithdefcmd{bukhari}{3009}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدٍ الْقَارِيُّ، عَنْ أَبِي حَازِمٍ، قَالَ أَخْبَرَنِي سَهْلٌ ـ رضى الله عنه يَعْنِي ابْنَ سَعْدٍ ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ خَيْبَرَ ‏"‏ لأُعْطِيَنَّ الرَّايَةَ غَدًا رَجُلاً يُفْتَحُ عَلَى يَدَيْهِ، يُحِبُّ اللَّهَ وَرَسُولَهُ، وَيُحِبُّهُ اللَّهُ وَرَسُولُهُ ‏"‏‏.‏ فَبَاتَ النَّاسُ لَيْلَتَهُمْ أَيُّهُمْ يُعْطَى فَغَدَوْا كُلُّهُمْ يَرْجُوهُ فَقَالَ ‏"‏ أَيْنَ عَلِيٌّ ‏"‏‏.‏ فَقِيلَ يَشْتَكِي عَيْنَيْهِ، فَبَصَقَ فِي عَيْنَيْهِ وَدَعَا لَهُ، فَبَرَأَ كَأَنْ لَمْ يَكُنْ بِهِ وَجَعٌ، فَأَعْطَاهُ فَقَالَ أُقَاتِلُهُمْ حَتَّى يَكُونُوا مِثْلَنَا‏.‏ فَقَالَ ‏"‏ انْفُذْ عَلَى رِسْلِكَ حَتَّى تَنْزِلَ بِسَاحَتِهِمْ، ثُمَّ ادْعُهُمْ إِلَى الإِسْلاَمِ، وَأَخْبِرْهُمْ بِمَا يَجِبُ عَلَيْهِمْ، فَوَاللَّهِ لأَنْ يَهْدِيَ اللَّهُ بِكَ رَجُلاً خَيْرٌ لَكَ مِنْ أَنْ يَكُونَ لَكَ حُمْرُ النَّعَمِ ‏"‏‏.‏\hadithno{3009}\hadithtrans{Narrated Sahl:On the day (of the battle) of Khaibar the Prophet (ﷺ) said, "Tomorrow I will give the flag to somebody who will be given victory (by Allah) and who loves Allah and His Apostle and is loved by Allah and His Apostle." So, the people wondered all that night as to who would receive the flag and in the morning everyone hoped that he would be that person. Allah's Messenger (ﷺ) asked, "Where is `Ali?" He was told that `Ali was suffering from eye-trouble, so he applied saliva to his eyes and invoked Allah to cure him. He at once got cured as if he had no ailment. The Prophet (ﷺ) gave him the flag. `Ali said, "Should I fight them till they become like us (i.e. Muslim)?" The Prophet (ﷺ) said, "Go to them patiently and calmly till you enter the land. Then, invite them to Islam, and inform them what is enjoined upon them, for, by Allah, if Allah gives guidance to somebody through you, it is better for you than possessing red camels}}
\hadithdefcmd{bukhari}{3010}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عَجِبَ اللَّهُ مِنْ قَوْمٍ يَدْخُلُونَ الْجَنَّةَ فِي السَّلاَسِلِ ‏"‏‏.‏\hadithno{3010}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah wonders at those people who will enter Paradise in chains}}
\hadithdefcmd{bukhari}{3011}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا صَالِحُ بْنُ حَىٍّ أَبُو حَسَنٍ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يَقُولُ حَدَّثَنِي أَبُو بُرْدَةَ، أَنَّهُ سَمِعَ أَبَاهُ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ يُؤْتَوْنَ أَجْرَهُمْ مَرَّتَيْنِ الرَّجُلُ تَكُونُ لَهُ الأَمَةُ فَيُعَلِّمُهَا فَيُحْسِنُ تَعْلِيمَهَا، وَيُؤَدِّبُهَا فَيُحْسِنُ أَدَبَهَا، ثُمَّ يُعْتِقُهَا فَيَتَزَوَّجُهَا، فَلَهُ أَجْرَانِ، وَمُؤْمِنُ أَهْلِ الْكِتَابِ الَّذِي كَانَ مُؤْمِنًا، ثُمَّ آمَنَ بِالنَّبِيِّ صلى الله عليه وسلم فَلَهُ أَجْرَانِ، وَالْعَبْدُ الَّذِي يُؤَدِّي حَقَّ اللَّهِ وَيَنْصَحُ لِسَيِّدِهِ ‏"‏‏.‏ ثُمَّ قَالَ الشَّعْبِيُّ وَأَعْطَيْتُكَهَا بِغَيْرِ شَىْءٍ وَقَدْ كَانَ الرَّجُلُ يَرْحَلُ فِي أَهْوَنَ مِنْهَا إِلَى الْمَدِينَةِ‏.‏\hadithno{3011}\hadithtrans{Narrated Abu Burda's father:The Prophet (ﷺ) said, "Three persons will get their reward twice. (One is) a person who has a slave girl and he educates her properly and teaches her good manners properly (without violence) and then manumits and marries her. Such a person will get a double reward. (Another is) a believer from the people of the scriptures who has been a true believer and then he believes in the Prophet (ﷺ) (Muhammad). Such a person will get a double reward. (The third is) a slave who observes Allah's Rights and Obligations and is sincere to his master}}
\hadithdefcmd{bukhari}{3012}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ ـ رضى الله عنهم ـ قَالَ مَرَّ بِيَ النَّبِيُّ صلى الله عليه وسلم بِالأَبْوَاءِ ـ أَوْ بِوَدَّانَ ـ وَسُئِلَ عَنْ أَهْلِ الدَّارِ يُبَيَّتُونَ مِنَ الْمُشْرِكِينَ، فَيُصَابُ مِنْ نِسَائِهِمْ وَذَرَارِيِّهِمْ قَالَ ‏"‏ هُمْ مِنْهُمْ ‏"‏‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ لاَ حِمَى إِلاَّ لِلَّهِ وَلِرَسُولِهِ صلى الله عليه وسلم ‏"‏‏.‏\hadithno{3012}\hadithtrans{Narrated As-Sab bin Jaththama:The Prophet (ﷺ) passed by me at a place called Al-Abwa or Waddan, and was asked whether it was permissible to attack the pagan warriors at night with the probability of exposing their women and children to danger. The Prophet (ﷺ) replied, "They (i.e. women and children) are from them (i.e. pagans)." I also heard the Prophet (ﷺ) saying, "The institution of Hima is invalid except for Allah and His Apostle}}
\hadithdefcmd{bukhari}{3013}{وَعَنِ الزُّهْرِيِّ، أَنَّهُ سَمِعَ عُبَيْدَ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، حَدَّثَنَا الصَّعْبُ، فِي الذَّرَارِيِّ كَانَ عَمْرٌو يُحَدِّثُنَا عَنِ ابْنِ شِهَابٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فَسَمِعْنَاهُ مِنَ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ، قَالَ ‏"‏ هُمْ مِنْهُمْ ‏"‏ وَلَمْ يَقُلْ كَمَا قَالَ عَمْرٌو ‏"‏ هُمْ مِنْ آبَائِهِمْ ‏"‏‏.‏\hadithno{3013}\hadithtrans{As above (hadith)}}
\hadithdefcmd{bukhari}{3014}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ ـ رضى الله عنه ـ أَخْبَرَهُ أَنَّ امْرَأَةً وُجِدَتْ فِي بَعْضِ مَغَازِي النَّبِيِّ صلى الله عليه وسلم مَقْتُولَةً، فَأَنْكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَتْلَ النِّسَاءِ وَالصِّبْيَانِ‏.‏\hadithno{3014}\hadithtrans{Narrated `Abdullah:During some of the Ghazawat of the Prophet (ﷺ) a woman was found killed. Allah's Messenger (ﷺ) disapproved the killing of women and children}}
\hadithdefcmd{bukhari}{3015}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ قُلْتُ لأَبِي أُسَامَةَ حَدَّثَكُمْ عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ وُجِدَتِ امْرَأَةٌ مَقْتُولَةً فِي بَعْضِ مَغَازِي رَسُولِ اللَّهِ صلى الله عليه وسلم، فَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ قَتْلِ النِّسَاءِ وَالصِّبْيَانِ‏.‏\hadithno{3015}\hadithtrans{Narrated Ibn `Umar:During some of the Ghazawat of Allah's Messenger (ﷺ) a woman was found killed, so Allah's Messenger (ﷺ) forbade the killing of women and children}}
\hadithdefcmd{bukhari}{3016}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْثٍ فَقَالَ ‏"‏ إِنْ وَجَدْتُمْ فُلاَنًا وَفُلاَنًا فَأَحْرِقُوهُمَا بِالنَّارِ ‏"‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَرَدْنَا الْخُرُوجَ ‏"‏ إِنِّي أَمَرْتُكُمْ أَنْ تُحْرِقُوا فُلاَنًا وَفُلاَنًا، وَإِنَّ النَّارَ لاَ يُعَذِّبُ بِهَا إِلاَّ اللَّهُ، فَإِنْ وَجَدْتُمُوهُمَا فَاقْتُلُوهُمَا ‏"‏‏.‏\hadithno{3016}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) sent us in a mission (i.e., an army-unit) and said, "If you find so-and-so and so-and-so, burn both of them with fire." When we intended to depart, Allah's Messenger (ﷺ) said, "I have ordered you to burn so-and-so and so-and-so, and it is none but Allah Who punishes with fire, so, if you find them, kill them (i.e., don't burn them)}}
\hadithdefcmd{bukhari}{3017}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، أَنَّ عَلِيًّا ـ رضى الله عنه ـ حَرَّقَ قَوْمًا، فَبَلَغَ ابْنَ عَبَّاسٍ فَقَالَ لَوْ كُنْتُ أَنَا لَمْ أُحَرِّقْهُمْ، لأَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُعَذِّبُوا بِعَذَابِ اللَّهِ ‏"‏‏.‏ وَلَقَتَلْتُهُمْ كَمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏‏.‏\hadithno{3017}\hadithtrans{Narrated `Ikrima:`Ali burnt some people and this news reached Ibn `Abbas, who said, "Had I been in his place I would not have burnt them, as the Prophet (ﷺ) said, 'Don't punish (anybody) with Allah's Punishment.' No doubt, I would have killed them, for the Prophet (ﷺ) said, 'If somebody (a Muslim) discards his religion, kill him}}
\hadithdefcmd{bukhari}{3018}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَهْطًا، مِنْ عُكْلٍ ثَمَانِيَةً قَدِمُوا عَلَى النَّبِيِّ صلى الله عليه وسلم فَاجْتَوَوُا الْمَدِينَةَ فَقَالُوا يَا رَسُولَ اللَّهِ، ابْغِنَا رِسْلاً‏.‏ قَالَ ‏ "‏ مَا أَجِدُ لَكُمْ إِلاَّ أَنْ تَلْحَقُوا بِالذَّوْدِ ‏"‏‏.‏ فَانْطَلَقُوا فَشَرِبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا حَتَّى صَحُّوا وَسَمِنُوا، وَقَتَلُوا الرَّاعِيَ، وَاسْتَاقُوا الذَّوْدَ، وَكَفَرُوا بَعْدَ إِسْلاَمِهِمْ، فَأَتَى الصَّرِيخُ النَّبِيَّ صلى الله عليه وسلم، فَبَعَثَ الطَّلَبَ، فَمَا تَرَجَّلَ النَّهَارُ حَتَّى أُتِيَ بِهِمْ، فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ، ثُمَّ أَمَرَ بِمَسَامِيرَ فَأُحْمِيَتْ فَكَحَلَهُمْ بِهَا، وَطَرَحَهُمْ بِالْحَرَّةِ، يَسْتَسْقُونَ فَمَا يُسْقَوْنَ حَتَّى مَاتُوا‏.‏ قَالَ أَبُو قِلاَبَةَ قَتَلُوا وَسَرَقُوا وَحَارَبُوا اللَّهَ وَرَسُولَهُ صلى الله عليه وسلم وَسَعَوْا فِي الأَرْضِ فَسَادًا‏.‏\hadithno{3018}\hadithtrans{Narrated Anas bin Malik:A group of eight men from the tribe of 'Ukl came to the Prophet (ﷺ) and then they found the climate of Medina unsuitable for them. So, they said, "O Allah's Messenger (ﷺ)! Provide us with some milk." Allah's Apostle said, "I recommend that you should join the herd of camels." So they went and drank the urine and the milk of the camels (as a medicine) till they became healthy and fat. Then they killed the shepherd and drove away the camels, and they became unbelievers after they were Muslims. When the Prophet (ﷺ) was informed by a shouter for help, he sent some men in their pursuit, and before the sun rose high, they were brought, and he had their hands and feet cut off. Then he ordered for nails which were heated and passed over their eyes, and they were left in the Harra (i.e. rocky land in Medina). They asked for water, and nobody provided them with water till they died (Abu Qilaba, a sub-narrator said, "They committed murder and theft and fought against Allah and His Apostle, and spread evil in the land)}}
\hadithdefcmd{bukhari}{3019}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَرَصَتْ نَمْلَةٌ نَبِيًّا مِنَ الأَنْبِيَاءِ، فَأَمَرَ بِقَرْيَةِ النَّمْلِ فَأُحْرِقَتْ، فَأَوْحَى اللَّهُ إِلَيْهِ أَنْ قَرَصَتْكَ نَمْلَةٌ أَحْرَقْتَ أُمَّةً مِنَ الأُمَمِ تُسَبِّحُ اللَّهِ.‏"‏‏‏\hadithno{3019}\hadithtrans{Narrated Abu Hurairah (ra):I heard Allah's Messenger (ﷺ) saying, "An ant bit a Prophet amongst the Prophets, and he ordered that the place of the ants be burnt. So, Allah inspired to him, 'It is because one ant bit you that you burnt a nation amongst the nations that glorify Allah?}}
\hadithdefcmd{bukhari}{3020}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسُ بْنُ أَبِي حَازِمٍ، قَالَ قَالَ لِي جَرِيرٌ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ تُرِيحُنِي مِنْ ذِي الْخَلَصَةِ ‏"‏‏.‏ وَكَانَ بَيْتًا فِي خَثْعَمَ يُسَمَّى كَعْبَةَ الْيَمَانِيَةَ قَالَ فَانْطَلَقْتُ فِي خَمْسِينَ وَمِائَةِ فَارِسٍ مِنْ أَحْمَسَ، وَكَانُوا أَصْحَابَ خَيْلٍ ـ قَالَ ـ وَكُنْتُ لاَ أَثْبُتُ عَلَى الْخَيْلِ، فَضَرَبَ فِي صَدْرِي حَتَّى رَأَيْتُ أَثَرَ أَصَابِعِهِ فِي صَدْرِي وَقَالَ ‏"‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏‏.‏ فَانْطَلَقَ إِلَيْهَا فَكَسَرَهَا وَحَرَّقَهَا، ثُمَّ بَعَثَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يُخْبِرُهُ فَقَالَ رَسُولُ جَرِيرٍ وَالَّذِي بَعَثَكَ بِالْحَقِّ، مَا جِئْتُكَ حَتَّى تَرَكْتُهَا كَأَنَّهَا جَمَلٌ أَجْوَفُ أَوْ أَجْرَبُ‏.‏ قَالَ فَبَارَكَ فِي خَيْلِ أَحْمَسَ وَرِجَالِهَا خَمْسَ مَرَّاتٍ‏.‏\hadithno{3020}\hadithtrans{Narrated Jarir:Allah's Messenger (ﷺ) said to me, "Will you relieve me from Dhul-Khalasa? Dhul-Khalasa was a house (of an idol) belonging to the tribe of Khath'am called Al-Ka`ba Al-Yama-niya. So, I proceeded with one hundred and fifty cavalry men from the tribe of Ahmas, who were excellent knights. It happened that I could not sit firm on horses, so the Prophet (ﷺ) , stroke me over my chest till I saw his finger-marks over my chest, he said, 'O Allah! Make him firm and make him a guiding and rightly guided man.' " Jarir proceeded towards that house, and dismantled and burnt it. Then he sent a messenger to Allah's Apostle informing him of that. Jarir's messenger said, "By Him Who has sent you with the Truth, I did not come to you till I had left it like an emancipated or gabby camel (i.e. completely marred and spoilt)." Jarir added, "The Prophet (ﷺ) asked for Allah's Blessings for the horses and the men of Ahmas five times}}
\hadithdefcmd{bukhari}{3021}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ حَرَّقَ النَّبِيُّ صلى الله عليه وسلم نَخْلَ بَنِي النَّضِيرِ‏.‏\hadithno{3021}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) burnt the date-palms of Bani An-Nadir}}
\hadithdefcmd{bukhari}{3022}{حَدَّثَنَا عَلِيُّ بْنُ مُسْلِمٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَهْطًا مِنَ الأَنْصَارِ إِلَى أَبِي رَافِعٍ لِيَقْتُلُوهُ، فَانْطَلَقَ رَجُلٌ مِنْهُمْ فَدَخَلَ حِصْنَهُمْ قَالَ فَدَخَلْتُ فِي مَرْبِطِ دَوَابَّ لَهُمْ، قَالَ وَأَغْلَقُوا باب الْحِصْنِ، ثُمَّ إِنَّهُمْ فَقَدُوا حِمَارًا لَهُمْ، فَخَرَجُوا يَطْلُبُونَهُ، فَخَرَجْتُ فِيمَنْ خَرَجَ أُرِيهِمْ أَنَّنِي أَطْلُبُهُ مَعَهُمْ، فَوَجَدُوا الْحِمَارَ، فَدَخَلُوا وَدَخَلْتُ، وَأَغْلَقُوا باب الْحِصْنِ لَيْلاً، فَوَضَعُوا الْمَفَاتِيحَ فِي كَوَّةٍ حَيْثُ أَرَاهَا، فَلَمَّا نَامُوا أَخَذْتُ الْمَفَاتِيحَ، فَفَتَحْتُ باب الْحِصْنِ ثُمَّ دَخَلْتُ عَلَيْهِ فَقُلْتُ يَا أَبَا رَافِعٍ‏.‏ فَأَجَابَنِي، فَتَعَمَّدْتُ الصَّوْتَ، فَضَرَبْتُهُ فَصَاحَ، فَخَرَجْتُ ثُمَّ جِئْتُ، ثُمَّ رَجَعْتُ كَأَنِّي مُغِيثٌ فَقُلْتُ يَا أَبَا رَافِعٍ، وَغَيَّرْتُ صَوْتِي، فَقَالَ مَا لَكَ لأُمِّكَ الْوَيْلُ قُلْتُ مَا شَأْنُكَ قَالَ لاَ أَدْرِي مَنْ دَخَلَ عَلَىَّ فَضَرَبَنِي‏.‏ قَالَ فَوَضَعْتُ سَيْفِي فِي بَطْنِهِ، ثُمَّ تَحَامَلْتُ عَلَيْهِ حَتَّى قَرَعَ الْعَظْمَ، ثُمَّ خَرَجْتُ وَأَنَا دَهِشٌ، فَأَتَيْتُ سُلَّمًا لَهُمْ لأَنْزِلَ مِنْهُ فَوَقَعْتُ فَوُثِئَتْ رِجْلِي، فَخَرَجْتُ إِلَى أَصْحَابِي فَقُلْتُ مَا أَنَا بِبَارِحٍ حَتَّى أَسْمَعَ النَّاعِيَةَ، فَمَا بَرِحْتُ حَتَّى سَمِعْتُ نَعَايَا أَبِي رَافِعٍ تَاجِرِ أَهْلِ الْحِجَازِ‏.‏ قَالَ فَقُمْتُ وَمَا بِي قَلَبَةٌ حَتَّى أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرْنَاهُ‏.‏\hadithno{3022}\hadithtrans{Narrated Al-Bara bin Azib:Allah's Messenger (ﷺ) sent a group of Ansari men to kill Abu-Rafi`. One of them set out and entered their (i.e. the enemies) fort. That man said, "I hid myself in a stable for their animals. They closed the fort gate. Later they lost a donkey of theirs, so they went out in its search. I, too, went out along with them, pretending to look for it. They found the donkey and entered their fort. And I, too, entered along with them. They closed the gate of the fort at night, and kept its keys in a small window where I could see them. When those people slept, I took the keys and opened the gate of the fort and came upon Abu Rafi` and said, 'O Abu Rafi`. When he to replied me, I proceeded towards the voice and hit him. He shouted and I came out to come back, pretending to be a helper. I said, 'O Abu Rafi`,' changing the tone of my voice. He asked me, 'What do you want; woe to your mother?' I asked him, 'What has happened to you?' He said, 'I don't know who came to me and hit me.' Then I drove my sword into his belly and pushed it forcibly till it touched the bone. Then I came out, filled with puzzlement and went towards a ladder of theirs in order to get down but I fell down and sprained my foot. I came to my companions and said, 'I will not leave till I hear the wailing of the women.' So, I did not leave till I heard the women bewailing Abu Rafi`, the merchant of Hijaz. Then I got up, feeling no ailment, (and we proceeded) till we came upon the Prophet (ﷺ) and informed him}}
\hadithdefcmd{bukhari}{3023}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَهْطًا مِنَ الأَنْصَارِ إِلَى أَبِي رَافِعٍ فَدَخَلَ عَلَيْهِ عَبْدُ اللَّهِ بْنُ عَتِيكٍ بَيْتَهُ لَيْلاً، فَقَتَلَهُ وَهْوَ نَائِمٌ‏.‏\hadithno{3023}\hadithtrans{Narrated Al-Bara bin Azib:Allah's Messenger (ﷺ) sent a group of the Ansar to Abu Rafi`. `Abdullah bin Atik entered his house at night and killed him while he was sleeping}}
\hadithdefcmd{bukhari}{3025}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا عَاصِمُ بْنُ يُوسُفَ الْيَرْبُوعِيُّ، حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ مُوسَى بْنِ عُقْبَةَ، قَالَ حَدَّثَنِي سَالِمٌ أَبُو النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ كُنْتُ كَاتِبًا لَهُ قَالَ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى حِينَ خَرَجَ إِلَى الْحَرُورِيَّةِ فَقَرَأْتُهُ فَإِذَا فِيهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَيَّامِهِ الَّتِي لَقِيَ فِيهَا الْعَدُوَّ انْتَظَرَ حَتَّى مَالَتِ الشَّمْسُ‏.‏ ثُمَّ قَامَ فِي النَّاسِ فَقَالَ ‏"‏ أَيُّهَا النَّاسُ لاَ تَمَنَّوْا لِقَاءَ الْعَدُوِّ وَسَلُوا اللَّهَ الْعَافِيَةَ، فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا وَاعْلَمُوا أَنَّ الْجَنَّةَ تَحْتَ ظِلاَلِ السُّيُوفِ ـ ثُمَّ قَالَ ـ اللَّهُمَّ مُنْزِلَ الْكِتَابِ وَمُجْرِيَ السَّحَابِ وَهَازِمَ الأَحْزَابِ اهْزِمْهُمْ وَانْصُرْنَا عَلَيْهِمْ ‏"‏‏.‏ وَقَالَ مُوسَى بْنُ عُقْبَةَ حَدَّثَنِي سَالِم أَبُو النَّضْرِ كُنْتُ كَاتِبًا لِعُمَرَ بْنِ عُبَيْدِ اللَّهِ فَأَتَاهُ كِتَابُ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَمَنَّوْا لِقَاءَ الْعَدُو ‏"‏‏.‏\hadithno{3025}\hadithtrans{Narrated Salim Abu An-Nadr: (the freed slave of 'Umar bin 'Ubaidullah) I was Umar's clerk. Once Abdullah bin Abi Aufa wrote a letter to 'Umar when he proceeded to Al-Haruriya. I read in it that Allah's Messenger (ﷺ) in one of his military expeditions against the enemy, waited till the sun declined and then he got up amongst the people saying, "O people! Do not wish to meet the enemy, and ask Allah for safety, but when you face the enemy, be patient, and remember that Paradise is under the shades of swords." Then he said, "O Allah, the Revealer of the Holy Book, and the Mover of the clouds and the Defeater of the clans, defeat them, and grant us victory over them}}
\hadithdefcmd{bukhari}{3026}{وَقَالَ أَبُو عَامِرٍ حَدَّثَنَا مُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَمَنَّوْا لِقَاءَ الْعَدُوِّ، فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا ‏"‏‏.‏\hadithno{3026}\hadithtrans{Narrated Abu Huraira: The Prophet (ﷺ) said: "Do not wish to meet the enemy, but when you meet face) the enemy, be patient}}
\hadithdefcmd{bukhari}{3028}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ هَلَكَ كِسْرَى ثُمَّ لاَ يَكُونُ كِسْرَى بَعْدَهُ، وَقَيْصَرٌ لَيَهْلِكَنَّ ثُمَّ لاَ يَكُونُ قَيْصَرٌ بَعْدَهُ، وَلَتُقْسَمَنَّ كُنُوزُهَا فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ وَسَمَّى الْحَرْبَ خَدْعَةً\hadithno{3028}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Khosrau will be ruined, and there will be no Khosrau after him, and Caesar will surely be ruined and there will be no Caesar after him, and you will spend their treasures in Allah's Cause." He called, "War is deceit}}
\hadithdefcmd{bukhari}{3029}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَصْرَمَ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمَّى النَّبِيُّ صلى الله عليه وسلم الْحَرْبَ خُدْعَةً‏.‏\hadithno{3029}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) called,: "War is deceit}}
\hadithdefcmd{bukhari}{3030}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْحَرْبُ خُدْعَةٌ ‏"‏‏.‏\hadithno{3030}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "War is deceit}}
\hadithdefcmd{bukhari}{3031}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ لِكَعْبِ بْنِ الأَشْرَفِ، فَإِنَّهُ قَدْ آذَى اللَّهَ وَرَسُولَهُ ‏"‏‏.‏ قَالَ مُحَمَّدُ بْنُ مَسْلَمَةَ أَتُحِبُّ أَنْ أَقْتُلَهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ فَأَتَاهُ فَقَالَ إِنَّ هَذَا ـ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ـ قَدْ عَنَّانَا وَسَأَلَنَا الصَّدَقَةَ، قَالَ وَأَيْضًا وَاللَّهِ قَالَ فَإِنَّا قَدِ اتَّبَعْنَاهُ فَنَكْرَهُ أَنْ نَدَعَهُ حَتَّى نَنْظُرَ إِلَى مَا يَصِيرُ أَمْرُهُ قَالَ فَلَمْ يَزَلْ يُكَلِّمُهُ حَتَّى اسْتَمْكَنَ مِنْهُ فَقَتَلَهُ‏.‏\hadithno{3031}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "Who is ready to kill Ka`b bin Al-Ashraf who has really hurt Allah and His Apostle?" Muhammad bin Maslama said, "O Allah's Messenger (ﷺ)! Do you like me to kill him?" He replied in the affirmative. So, Muhammad bin Maslama went to him (i.e. Ka`b) and said, "This person (i.e. the Prophet) has put us to task and asked us for charity." Ka`b replied, "By Allah, you will get tired of him." Muhammad said to him, "We have followed him, so we dislike to leave him till we see the end of his affair." Muhammad bin Maslama went on talking to him in this way till he got the chance to kill him}}
\hadithdefcmd{bukhari}{3032}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ لِكَعْبِ بْنِ الأَشْرَفِ ‏"‏‏.‏ فَقَالَ مُحَمَّدُ بْنُ مَسْلَمَةَ أَتُحِبُّ أَنْ أَقْتُلَهُ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ فَأْذَنْ لِي فَأَقُولَ‏.‏ قَالَ ‏"‏ قَدْ فَعَلْتُ ‏"‏‏.‏\hadithno{3032}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said, "Who is ready to kill Ka`b bin Ashraf (i.e. a Jew)." Muhammad bin Maslama replied, "Do you like me to kill him?" The Prophet (ﷺ) replied in the affirmative. Muhammad bin Maslama said, "Then allow me to say what I like." The Prophet (ﷺ) replied, "I do (i.e. allow you)}}
\hadithdefcmd{bukhari}{3033}{قَالَ اللَّيْثُ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ قَالَ انْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ أُبَىُّ بْنُ كَعْبٍ قِبَلَ ابْنِ صَيَّادٍ، فَحُدِّثَ بِهِ فِي نَخْلٍ، فَلَمَّا دَخَلَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّخْلَ، طَفِقَ يَتَّقِي بِجُذُوعِ النَّخْلِ، وَابْنُ صَيَّادٍ فِي قَطِيفَةٍ لَهُ فِيهَا رَمْرَمَةٌ، فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا صَافِ، هَذَا مُحَمَّدٌ، فَوَثَبَ ابْنُ صَيَّادٍ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏‏.‏\hadithno{3033}\hadithtrans{Narrated 'Abdullah bin Umar (ra):Once, Allah's Messenger (ﷺ) accompanied by Ubai bin Ka'b set out to Ibn Saiyyad. He was informed that Ibn Saiyyad was in a garden of date palms. When Allah's Messenger (ﷺ) entered the garden of date-palms, he started hiding himself behind the trunks of the palms while Ibn Saiyyad was covered with a velvet sheet with murmurs emanating from under it. Ibn Saiyyad's mother saw Allah's Messenger (ﷺ) and said, "O Saf! This is Muhammad." So Ibn Saiyyad got up. Allah's Messenger (ﷺ) said, "If she had left him (in his state), the truth would have been clear}}
\hadithdefcmd{bukhari}{3034}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَوْمَ الْخَنْدَقِ وَهُوَ يَنْقُلُ التُّرَابَ حَتَّى وَارَى التُّرَابُ شَعَرَ صَدْرِهِ، وَكَانَ رَجُلاً كَثِيرَ الشَّعَرِ وَهْوَ يَرْتَجِزُ بِرَجَزِ عَبْدِ اللَّهِ اللَّهُمَّ لَوْلاَ أَنْتَ مَا اهْتَدَيْنَا وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا فَأَنْزِلَنْ سَكِينَةً عَلَيْنَا وَثَبِّتِ الأَقْدَامَ إِنْ لاَقَيْنَا إِنَّ الأَعْدَاءَ قَدْ بَغَوْا عَلَيْنَا إِذَا أَرَادُوا فِتْنَةً أَبَيْنَا يَرْفَعُ بِهَا صَوْتَهُ‏.‏\hadithno{3034}\hadithtrans{Narrated Al-Bara:I saw Allah's Messenger (ﷺ) on the day (of the battle) of the Trench carrying earth till the hair of his chest were covered with dust and he was a hairy man. He was reciting the following verses of `Abdullah (bin Rawaha): "O Allah, were it not for You, We would not have been guided, Nor would we have given in charity, nor prayed. So, bestow on us calmness, and when we meet the enemy. Then make our feet firm, for indeed, Yet if they want to put us in affliction, (i.e. want to fight against us) we would not (flee but withstand them)." The Prophet (ﷺ) used to raise his voice while reciting these verses. (See Hadith No. 432, Vol)}}
\hadithdefcmd{bukhari}{3036}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ ـ رضى الله عنه ـ قَالَ مَا حَجَبَنِي النَّبِيُّ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ، وَلاَ رَآنِي إِلاَّ تَبَسَّمَ فِي وَجْهِي‏.‏ وَلَقَدْ شَكَوْتُ إِلَيْهِ إِنِّي لاَ أَثْبُتُ عَلَى الْخَيْلِ‏.‏ فَضَرَبَ بِيَدِهِ فِي صَدْرِي وَقَالَ ‏ "‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏‏.‏\hadithno{3036}\hadithtrans{Narrated Jarir:Allah's Messenger (ﷺ) did not screen himself from me since my embracing Islam, and whenever he saw me he would receive me with a smile. Once I told him that I could not sit firm on horses. He stroke me on the chest with his hand and said, "O Allah! Make him firm and make him a guiding and a rightly guided man}}
\hadithdefcmd{bukhari}{3037}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو حَازِمٍ، قَالَ سَأَلُوا سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ ـ رضى الله عنه ـ بِأَىِّ شَىْءٍ دُووِيَ جُرْحُ النَّبِيِّ صلى الله عليه وسلم فَقَالَ مَا بَقِيَ مِنَ النَّاسِ أَحَدٌ أَعْلَمُ بِهِ مِنِّي، كَانَ عَلِيٌّ يَجِيءُ بِالْمَاءِ فِي تُرْسِهِ، وَكَانَتْ ـ يَعْنِي فَاطِمَةَ ـ تَغْسِلُ الدَّمَ عَنْ وَجْهِهِ، وَأُخِذَ حَصِيرٌ فَأُحْرِقَ، ثُمَّ حُشِيَ بِهِ جُرْحُ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3037}\hadithtrans{Narrated Abu Hazim:The people asked Sahl bin Sa`d As-Sa' idi "With what thing (medicine) was the wound of Allah's Apostle treated?" He replied, "There is none left (living) amongst the people who knows it better than me. `Ali used to bring water in his shield and Fatima (i.e. the Prophet's daughter) used to wash the blood off his face. Then a mat (of palm leaves) was burnt and its ash was inserted in the wound of Allah's Apostle}}
\hadithdefcmd{bukhari}{3038}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مُعَاذًا وَأَبَا مُوسَى إِلَى الْيَمَنِ قَالَ ‏ "‏ يَسِّرَا وَلاَ تُعَسِّرَا، وَبَشِّرَا وَلاَ تُنَفِّرَا، وَتَطَاوَعَا وَلاَ تَخْتَلِفَا ‏"‏‏.‏\hadithno{3038}\hadithtrans{Narrated Abu Burda:That his father said, "The Prophet (ﷺ) sent Mu`adh and Abu Musa to Yemen telling them. 'Treat the people with ease and don't be hard on them; give them glad tidings and don't fill them with aversion; and love each other, and don't differ}}
\hadithdefcmd{bukhari}{3039}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ يُحَدِّثُ قَالَ جَعَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى الرَّجَّالَةِ يَوْمَ أُحُدٍ ـ وَكَانُوا خَمْسِينَ رَجُلاً ـ عَبْدَ اللَّهِ بْنَ جُبَيْرٍ فَقَالَ ‏"‏ إِنْ رَأَيْتُمُونَا تَخْطَفُنَا الطَّيْرُ، فَلاَ تَبْرَحُوا مَكَانَكُمْ هَذَا حَتَّى أُرْسِلَ إِلَيْكُمْ، وَإِنْ رَأَيْتُمُونَا هَزَمْنَا الْقَوْمَ وَأَوْطَأْنَاهُمْ فَلاَ تَبْرَحُوا حَتَّى أُرْسِلَ إِلَيْكُمْ ‏"‏ فَهَزَمُوهُمْ‏.‏ قَالَ فَأَنَا وَاللَّهِ رَأَيْتُ النِّسَاءَ يَشْتَدِدْنَ قَدْ بَدَتْ خَلاَخِلُهُنَّ وَأَسْوُقُهُنَّ رَافِعَاتٍ ثِيَابَهُنَّ، فَقَالَ أَصْحَابُ عَبْدِ اللَّهِ بْنِ جُبَيْرٍ الْغَنِيمَةَ ـ أَىْ قَوْمِ ـ الْغَنِيمَةَ، ظَهَرَ أَصْحَابُكُمْ فَمَا تَنْتَظِرُونَ فَقَالَ عَبْدُ اللَّهِ بْنُ جُبَيْرٍ أَنَسِيتُمْ مَا قَالَ لَكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالُوا وَاللَّهِ لَنَأْتِيَنَّ النَّاسَ فَلَنُصِيبَنَّ مِنَ الْغَنِيمَةِ‏.‏ فَلَمَّا أَتَوْهُمْ صُرِفَتْ وُجُوهُهُمْ فَأَقْبَلُوا مُنْهَزِمِينَ، فَذَاكَ إِذْ يَدْعُوهُمُ الرَّسُولُ فِي أُخْرَاهُمْ، فَلَمْ يَبْقَ مَعَ النَّبِيِّ صلى الله عليه وسلم غَيْرُ اثْنَىْ عَشَرَ رَجُلاً، فَأَصَابُوا مِنَّا سَبْعِينَ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ أَصَابَ مِنَ الْمُشْرِكِينَ يَوْمَ بَدْرٍ أَرْبَعِينَ وَمِائَةً سَبْعِينَ أَسِيرًا وَسَبْعِينَ قَتِيلاً، فَقَالَ أَبُو سُفْيَانَ أَفِي الْقَوْمِ مُحَمَّدٌ ثَلاَثَ مَرَّاتٍ، فَنَهَاهُمُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُجِيبُوهُ ثُمَّ قَالَ أَفِي الْقَوْمِ ابْنُ أَبِي قُحَافَةَ ثَلاَثَ مَرَّاتٍ، ثُمَّ قَالَ أَفِي الْقَوْمِ ابْنُ الْخَطَّابِ ثَلاَثَ مَرَّاتٍ، ثُمَّ رَجَعَ إِلَى أَصْحَابِهِ فَقَالَ أَمَّا هَؤُلاَءِ فَقَدْ قُتِلُوا‏.‏ فَمَا مَلَكَ عُمَرُ نَفْسَهُ فَقَالَ كَذَبْتَ وَاللَّهِ يَا عَدُوَّ اللَّهِ، إِنَّ الَّذِينَ عَدَدْتَ لأَحْيَاءٌ كُلُّهُمْ، وَقَدْ بَقِيَ لَكَ مَا يَسُوؤُكَ‏.‏ قَالَ يَوْمٌ بِيَوْمِ بَدْرٍ، وَالْحَرْبُ سِجَالٌ، إِنَّكُمْ سَتَجِدُونَ فِي الْقَوْمِ مُثْلَةً لَمْ آمُرْ بِهَا وَلَمْ تَسُؤْنِي، ثُمَّ أَخَذَ يَرْتَجِزُ أُعْلُ هُبَلْ، أُعْلُ هُبَلْ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلاَ تُجِيبُوا لَهُ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، مَا نَقُولُ قَالَ ‏"‏ قُولُوا اللَّهُ أَعْلَى وَأَجَلُّ ‏"‏‏.‏ قَالَ إِنَّ لَنَا الْعُزَّى وَلاَ عُزَّى لَكُمْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلاَ تُجِيبُوا لَهُ ‏"‏‏.‏ قَالَ قَالُوا يَا رَسُولَ اللَّهِ، مَا نَقُولُ قَالَ ‏"‏ قُولُوا اللَّهُ مَوْلاَنَا وَلاَ مَوْلَى لَكُمْ ‏"‏‏.‏\hadithno{3039}\hadithtrans{Narrated Al-Bara bin Azib:The Prophet (ﷺ) appointed `Abdullah bin Jubair as the commander of the infantry men (archers) who were fifty on the day (of the battle) of Uhud. He instructed them, "Stick to your place, and don't leave it even if you see birds snatching us, till I send for you; and if you see that we have defeated the infidels and made them flee, even then you should not leave your place till I send for you." Then the infidels were defeated. By Allah, I saw the women fleeing lifting up their clothes revealing their leg-bangles and their legs. So, the companions of `Abdullah bin Jubair said, "The booty! O people, the booty ! Your companions have become victorious, what are you waiting for now?" `Abdullah bin Jubair said, "Have you forgotten what Allah's Messenger (ﷺ) said to you?" They replied, "By Allah! We will go to the people (i.e. the enemy) and collect our share from the war booty." But when they went to them, they were forced to turn back defeated. At that time Allah's Messenger (ﷺ) in their rear was calling them back. Only twelve men remained with the Prophet (ﷺ) and the infidels martyred seventy men from us. On the day (of the battle) of Badr, the Prophet (ﷺ) and his companions had caused the 'Pagans to lose 140 men, seventy of whom were captured and seventy were killed. Then Abu Sufyan asked thrice, "Is Muhammad present amongst these people?" The Prophet (ﷺ) ordered his companions not to answer him. Then he asked thrice, "Is the son of Abu Quhafa present amongst these people?" He asked again thrice, "Is the son of Al-Khattab present amongst these people?" He then returned to his companions and said, "As for these (men), they have been killed." `Umar could not control himself and said (to Abu Sufyan), "You told a lie, by Allah! O enemy of Allah! All those you have mentioned are alive, and the thing which will make you unhappy is still there." Abu Sufyan said, "Our victory today is a counterbalance to yours in the battle of Badr, and in war (the victory) is always undecided and is shared in turns by the belligerents, and you will find some of your (killed) men mutilated, but I did not urge my men to do so, yet I do not feel sorry for their deed" After that he started reciting cheerfully, "O Hubal, be high! (1) On that the Prophet (ﷺ) said (to his companions), "Why don't you answer him back?" They said, "O Allah's Messenger (ﷺ) What shall we say?" He said, "Say, Allah is Higher and more Sublime." (Then) Abu Sufyan said, "We have the (idol) Al `Uzza, and you have no `Uzza." The Prophet said (to his companions), "Why don't you answer him back?" They asked, "O Allah's Messenger (ﷺ)! What shall we say?" He said, "Say Allah is our Helper and you have no helper}}
\hadithdefcmd{bukhari}{3040}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْسَنَ النَّاسِ، وَأَجْوَدَ النَّاسِ، وَأَشْجَعَ النَّاسِ، قَالَ وَقَدْ فَزِعَ أَهْلُ الْمَدِينَةِ لَيْلَةً سَمِعُوا صَوْتًا، قَالَ فَتَلَقَّاهُمُ النَّبِيُّ صلى الله عليه وسلم عَلَى فَرَسٍ لأَبِي طَلْحَةَ عُرْىٍ، وَهُوَ مُتَقَلِّدٌ سَيْفَهُ فَقَالَ ‏"‏ لَمْ تُرَاعُوا، لَمْ تُرَاعُوا ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَجَدْتُهُ بَحْرًا ‏"‏‏.‏ يَعْنِي الْفَرَسَ‏.‏\hadithno{3040}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) was the (most handsome), most generous and the bravest of all the people. Once the people of Medina got frightened having heard an uproar at night. So, the Prophet (ﷺ) met the people while he was riding an unsaddled horse belonging to Abu Talha and carrying his sword (slung over his shoulder). He said (to them), "Don't get scared, don't get scared." Then he added, "I found it (i.e the horse) very fast}}
\hadithdefcmd{bukhari}{3041}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَزِيدُ بْنُ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ، أَنَّهُ أَخْبَرَهُ قَالَ خَرَجْتُ مِنَ الْمَدِينَةِ ذَاهِبًا نَحْوَ الْغَابَةِ، حَتَّى إِذَا كُنْتُ بِثَنِيَّةِ الْغَابَةِ لَقِيَنِي غُلاَمٌ لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ قُلْتُ وَيْحَكَ، مَا بِكَ قَالَ أُخِذَتْ لِقَاحُ النَّبِيِّ صلى الله عليه وسلم‏.‏ قُلْتُ مَنْ أَخَذَهَا قَالَ غَطَفَانُ وَفَزَارَةُ‏.‏ فَصَرَخْتُ ثَلاَثَ صَرَخَاتٍ أَسْمَعْتُ مَا بَيْنَ لاَبَتَيْهَا يَا صَبَاحَاهْ، يَا صَبَاحَاهْ‏.‏ ثُمَّ انْدَفَعْتُ حَتَّى أَلْقَاهُمْ وَقَدْ أَخَذُوهَا، فَجَعَلْتُ أَرْمِيهِمْ وَأَقُولُ أَنَا ابْنُ الأَكْوَعِ، وَالْيَوْمُ يَوْمُ الرُّضَّعِ، فَاسْتَنْقَذْتُهَا مِنْهُمْ قَبْلَ أَنْ يَشْرَبُوا، فَأَقْبَلْتُ بِهَا أَسُوقُهَا، فَلَقِيَنِي النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ، إِنَّ الْقَوْمَ عِطَاشٌ، وَإِنِّي أَعْجَلْتُهُمْ أَنْ يَشْرَبُوا سِقْيَهُمْ، فَابْعَثْ فِي إِثْرِهِمْ، فَقَالَ ‏ "‏ يَا ابْنَ الأَكْوَعِ، مَلَكْتَ فَأَسْجِحْ‏.‏ إِنَّ الْقَوْمَ يُقْرَوْنَ فِي قَوْمِهِمْ ‏"‏‏.‏\hadithno{3041}\hadithtrans{Narrated Salama:I went out of Medina towards Al-Ghaba. When I reached the mountain path of Al-Ghaba, a slave of `Abdur-Rahman bin `Auf met me. I said to him, "Woe to you! What brought you here?" He replied, "The she-camels of the Prophet (ﷺ) have been taken away." I said, "Who took them?" He said, "Ghatafan and Fazara." So, I sent three cries, "O Sabaha-h ! O Sabahah !" so loudly that made the people in between its (i.e. Medina's) two mountains hear me. Then I rushed till I met them after they had taken the camels away. I started throwing arrows at them saying, "I am the son of Al-Akwa`"; and today perish the mean people!" So, I saved the she-camels from them before they (i.e. the robbers) could drink water. When I returned driving the camels, the Prophet (ﷺ) met me, I said, "O Allah's Messenger (ﷺ) Those people are thirsty and I have prevented them from drinking water, so send some people to chase them." The Prophet (ﷺ) said, "O son of Al-Akwa`, you have gained power (over your enemy), so forgive (them). (Besides) those people are now being entertained by their folk}}
\hadithdefcmd{bukhari}{3042}{حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَأَلَ رَجُلٌ الْبَرَاءَ ـ رضى الله عنه ـ فَقَالَ يَا أَبَا عُمَارَةَ، أَوَلَّيْتُمْ يَوْمَ حُنَيْنٍ قَالَ الْبَرَاءُ وَأَنَا أَسْمَعُ أَمَّا رَسُولُ اللَّهِ صلى الله عليه وسلم لَمْ يُوَلِّ يَوْمَئِذٍ، كَانَ أَبُو سُفْيَانَ بْنُ الْحَارِثِ آخِذًا بِعِنَانِ بَغْلَتِهِ، فَلَمَّا غَشِيَهُ الْمُشْرِكُونَ نَزَلَ، فَجَعَلَ يَقُولُ أَنَا النَّبِيُّ لاَ كَذِبْ، أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ قَالَ فَمَا رُئِيَ مِنَ النَّاسِ يَوْمَئِذٍ أَشَدُّ مِنْهُ‏.‏\hadithno{3042}\hadithtrans{Narrated Abu 'Is-haq:A man asked Al-Bara "O Abu '`Umara! Did you flee on the day (of the battle) of Hunain?" Al-Bara replied while I was listening, "As for Allah's Messenger (ﷺ) he did not flee on that day. Abu Sufyan bin Al- Harith was holding the reins of his mule and when the pagans attacked him, he dismounted and started saying, 'I am the Prophet, and there is no lie about it; I am the son of `Abdul Muttalib.' On that day nobody was seen braver than the Prophet}}
\hadithdefcmd{bukhari}{3043}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي أُمَامَةَ ـ هُوَ ابْنُ سَهْلِ بْنِ حُنَيْفٍ ـ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ بَنُو قُرَيْظَةَ عَلَى حُكْمِ سَعْدٍ ـ هُوَ ابْنُ مُعَاذٍ ـ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم، وَكَانَ قَرِيبًا مِنْهُ، فَجَاءَ عَلَى حِمَارٍ، فَلَمَّا دَنَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُومُوا إِلَى سَيِّدِكُمْ ‏"‏‏.‏ فَجَاءَ فَجَلَسَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ ‏"‏ إِنَّ هَؤُلاَءِ نَزَلُوا عَلَى حُكْمِكَ ‏"‏‏.‏ قَالَ فَإِنِّي أَحْكُمُ أَنْ تُقْتَلَ الْمُقَاتِلَةُ، وَأَنْ تُسْبَى الذُّرِّيَّةُ‏.‏ قَالَ ‏"‏ لَقَدْ حَكَمْتَ فِيهِمْ بِحُكْمِ الْمَلِكِ ‏"‏‏.‏\hadithno{3043}\hadithtrans{Narrated Abu Sa`id Al-Khudri:When the tribe of Bani Quraiza was ready to accept Sa`d's judgment, Allah's Messenger (ﷺ) sent for Sa`d who was near to him. Sa`d came, riding a donkey and when he came near, Allah's Messenger (ﷺ) said (to the Ansar), "Stand up for your leader." Then Sa`d came and sat beside Allah's Messenger (ﷺ) who said to him. "These people are ready to accept your judgment." Sa`d said, "I give the judgment that their warriors should be killed and their children and women should be taken as prisoners." The Prophet (ﷺ) then remarked, "O Sa`d! You have judged amongst them with (or similar to) the judgment of the King Allah}}
\hadithdefcmd{bukhari}{3044}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَامَ الْفَتْحِ وَعَلَى رَأْسِهِ الْمِغْفَرُ، فَلَمَّا نَزَعَهُ جَاءَ رَجُلٌ فَقَالَ إِنَّ ابْنَ خَطَلٍ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ، فَقَالَ ‏ "‏ اقْتُلُوهُ ‏"‏‏.‏\hadithno{3044}\hadithtrans{Narrated Anas bin Malik (ra):Allah's Messenger (ﷺ) entered (Makkah) in the year of the Conquest (of Makkah) wearing a helmet over his head. After he took it off, a man came and said, "Ibn Khatal is clinging to the curtains of the Ka'bah." The Prophet (ﷺ) said, "Kill him}}
\hadithdefcmd{bukhari}{3045}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ أَبِي سُفْيَانَ بْنِ أَسِيدِ بْنِ جَارِيَةَ الثَّقَفِيُّ ـ وَهْوَ حَلِيفٌ لِبَنِي زُهْرَةَ وَكَانَ مِنْ أَصْحَابِ أَبِي هُرَيْرَةَ ـ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشَرَةَ رَهْطٍ سَرِيَّةً عَيْنًا، وَأَمَّرَ عَلَيْهِمْ عَاصِمَ بْنَ ثَابِتٍ الأَنْصَارِيَّ جَدَّ عَاصِمِ بْنِ عُمَرَ، فَانْطَلَقُوا حَتَّى إِذَا كَانُوا بِالْهَدَأَةِ وَهْوَ بَيْنَ عُسْفَانَ وَمَكَّةَ ذُكِرُوا لِحَىٍّ مِنْ هُذَيْلٍ يُقَالُ لَهُمْ بَنُو لِحْيَانَ، فَنَفَرُوا لَهُمْ قَرِيبًا مِنْ مِائَتَىْ رَجُلٍ، كُلُّهُمْ رَامٍ، فَاقْتَصُّوا آثَارَهُمْ حَتَّى وَجَدُوا مَأْكَلَهُمْ تَمْرًا تَزَوَّدُوهُ مِنَ الْمَدِينَةِ فَقَالُوا هَذَا تَمْرُ يَثْرِبَ‏.‏ فَاقْتَصُّوا آثَارَهُمْ، فَلَمَّا رَآهُمْ عَاصِمٌ وَأَصْحَابُهُ لَجَئُوا إِلَى فَدْفَدٍ، وَأَحَاطَ بِهِمُ الْقَوْمُ فَقَالُوا لَهُمُ انْزِلُوا وَأَعْطُونَا بِأَيْدِيكُمْ، وَلَكُمُ الْعَهْدُ وَالْمِيثَاقُ، وَلاَ نَقْتُلُ مِنْكُمْ أَحَدًا‏.‏ قَالَ عَاصِمُ بْنُ ثَابِتٍ أَمِيرُ السَّرِيَّةِ أَمَّا أَنَا فَوَاللَّهِ لاَ أَنْزِلُ الْيَوْمَ فِي ذِمَّةِ كَافِرٍ، اللَّهُمَّ أَخْبِرْ عَنَّا نَبِيَّكَ‏.‏ فَرَمَوْهُمْ بِالنَّبْلِ، فَقَتَلُوا عَاصِمًا فِي سَبْعَةٍ، فَنَزَلَ إِلَيْهِمْ ثَلاَثَةُ رَهْطٍ بِالْعَهْدِ وَالْمِيثَاقِ، مِنْهُمْ خُبَيْبٌ الأَنْصَارِيُّ وَابْنُ دَثِنَةَ وَرَجُلٌ آخَرُ، فَلَمَّا اسْتَمْكَنُوا مِنْهُمْ أَطْلَقُوا أَوْتَارَ قِسِيِّهِمْ فَأَوْثَقُوهُمْ فَقَالَ الرَّجُلُ الثَّالِثُ هَذَا أَوَّلُ الْغَدْرِ، وَاللَّهِ لاَ أَصْحَبُكُمْ، إِنَّ فِي هَؤُلاَءِ لأُسْوَةً‏.‏ يُرِيدُ الْقَتْلَى، فَجَرَّرُوهُ وَعَالَجُوهُ عَلَى أَنْ يَصْحَبَهُمْ فَأَبَى فَقَتَلُوهُ، فَانْطَلَقُوا بِخُبَيْبٍ وَابْنِ دَثِنَةَ حَتَّى بَاعُوهُمَا بِمَكَّةَ بَعْدَ وَقْعَةِ بَدْرٍ، فَابْتَاعَ خُبَيْبًا بَنُو الْحَارِثِ بْنِ عَامِرِ بْنِ نَوْفَلِ بْنِ عَبْدِ مَنَافٍ، وَكَانَ خُبَيْبٌ هُوَ قَتَلَ الْحَارِثَ بْنَ عَامِرٍ يَوْمَ بَدْرٍ، فَلَبِثَ خُبَيْبٌ عِنْدَهُمْ أَسِيرًا، فَأَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عِيَاضٍ أَنَّ بِنْتَ الْحَارِثِ أَخْبَرَتْهُ أَنَّهُمْ حِينَ اجْتَمَعُوا اسْتَعَارَ مِنْهَا مُوسَى يَسْتَحِدُّ بِهَا فَأَعَارَتْهُ، فَأَخَذَ ابْنًا لِي وَأَنَا غَافِلَةٌ حِينَ أَتَاهُ قَالَتْ فَوَجَدْتُهُ مُجْلِسَهُ عَلَى فَخِذِهِ وَالْمُوسَى بِيَدِهِ، فَفَزِعْتُ فَزْعَةً عَرَفَهَا خُبَيْبٌ فِي وَجْهِي فَقَالَ تَخْشَيْنَ أَنْ أَقْتُلَهُ مَا كُنْتُ لأَفْعَلَ ذَلِكَ‏.‏ وَاللَّهِ مَا رَأَيْتُ أَسِيرًا قَطُّ خَيْرًا مِنْ خُبَيْبٍ، وَاللَّهِ لَقَدْ وَجَدْتُهُ يَوْمًا يَأْكُلُ مِنْ قِطْفِ عِنَبٍ فِي يَدِهِ، وَإِنَّهُ لَمُوثَقٌ فِي الْحَدِيدِ، وَمَا بِمَكَّةَ مِنْ ثَمَرٍ وَكَانَتْ تَقُولُ إِنَّهُ لَرِزْقٌ مِنَ اللَّهِ رَزَقَهُ خُبَيْبًا، فَلَمَّا خَرَجُوا مِنَ الْحَرَمِ لِيَقْتُلُوهُ فِي الْحِلِّ، قَالَ لَهُمْ خُبَيْبٌ ذَرُونِي أَرْكَعْ رَكْعَتَيْنِ‏.‏ فَتَرَكُوهُ، فَرَكَعَ رَكْعَتَيْنِ ثُمَّ قَالَ لَوْلاَ أَنْ تَظُنُّوا أَنَّ مَا بِي جَزَعٌ لَطَوَّلْتُهَا اللَّهُمَّ أَحْصِهِمْ عَدَدًا‏.‏ وَلَسْتُ أُبَالِي حِينَ أُقْتَلُ مُسْلِمًا عَلَى أَىِّ شِقٍّ كَانَ لِلَّهِ مَصْرَعِي وَذَلِكَ فِي ذَاتِ الإِلَهِ وَإِنْ يَشَأْ يُبَارِكْ عَلَى أَوْصَالِ شِلْوٍ مُمَزَّعِ فَقَتَلَهُ ابْنُ الْحَارِثِ، فَكَانَ خُبَيْبٌ هُوَ سَنَّ الرَّكْعَتَيْنِ لِكُلِّ امْرِئٍ مُسْلِمٍ قُتِلَ صَبْرًا، فَاسْتَجَابَ اللَّهُ لِعَاصِمِ بْنِ ثَابِتٍ يَوْمَ أُصِيبَ، فَأَخْبَرَ النَّبِيُّ صلى الله عليه وسلم أَصْحَابَهُ خَبَرَهُمْ وَمَا أُصِيبُوا، وَبَعَثَ نَاسٌ مِنْ كُفَّارِ قُرَيْشٍ إِلَى عَاصِمٍ حِينَ حُدِّثُوا أَنَّهُ قُتِلَ لِيُؤْتَوْا بِشَىْءٍ مِنْهُ يُعْرَفُ، وَكَانَ قَدْ قَتَلَ رَجُلاً مِنْ عُظَمَائِهِمْ يَوْمَ بَدْرٍ، فَبُعِثَ عَلَى عَاصِمٍ مِثْلُ الظُّلَّةِ مِنَ الدَّبْرِ، فَحَمَتْهُ مِنْ رَسُولِهِمْ، فَلَمْ يَقْدِرُوا عَلَى أَنْ يَقْطَعَ مِنْ لَحْمِهِ شَيْئًا‏.‏\hadithno{3045}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) sent a Sariya of ten men as spies under the leadership of `Asim bin Thabit al-Ansari, the grandfather of `Asim bin `Umar bin Al-Khattab. They proceeded till they reached Hadaa, a place between 'Usfan, and Mecca, and their news reached a branch of the tribe of Hudhail called Bani Lihyan. About two-hundred men, who were all archers, hurried to follow their tracks till they found the place where they had eaten dates they had brought with them from Medina. They said, "These are the dates of Yathrib (i.e. Medina), "and continued following their tracks When `Asim and his companions saw their pursuers, they went up a high place and the infidels circled them. The infidels said to them, "Come down and surrender, and we promise and guarantee you that we will not kill any one of you" `Asim bin Thabit; the leader of the Sariya said, "By Allah! I will not come down to be under the protection of infidels. O Allah! Convey our news to Your Prophet. Then the infidels threw arrows at them till they martyred `Asim along with six other men, and three men came down accepting their promise and convention, and they were Khubaib-al-Ansari and Ibn Dathina and another man So, when the infidels captured them, they undid the strings of their bows and tied them. Then the third (of the captives) said, "This is the first betrayal. By Allah! I will not go with you. No doubt these, namely the martyred, have set a good example to us." So, they dragged him and tried to compel him to accompany them, but as he refused, they killed him. They took Khubaid and Ibn Dathina with them and sold them (as slaves) in Mecca (and all that took place) after the battle of Badr. Khubaib was bought by the sons of Al-Harith bin 'Amir bin Naufal bin `Abd Manaf. It was Khubaib who had killed Al-Harith bin 'Amir on the day (of the battle of) Badr. So, Khubaib remained a prisoner with those people. Narrated Az-Zuhri: 'Ubaidullah bin 'Iyyad said that the daughter of Al-Harith had told him, "When those people gathered (to kill Khubaib) he borrowed a razor from me to shave his pubes and I gave it to him. Then he took a son of mine while I was unaware when he came upon him. I saw him placing my son on his thigh and the razor was in his hand. I got scared so much that Khubaib noticed the agitation on my face and said, 'Are you afraid that I will kill him? No, I will never do so.' By Allah, I never saw a prisoner better than Khubaib. By Allah, one day I saw him eating of a bunch of grapes in his hand while he was chained in irons, and there was no fruit at that time in Mecca." The daughter of Al-Harith used to say, "It was a boon Allah bestowed upon Khubaib." When they took him out of the Sanctuary (of Mecca) to kill him outside its boundaries, Khubaib requested them to let him offer two rak`at (prayer). They allowed him and he offered Two rak`at and then said, "Hadn't I been afraid that you would think that I was afraid (of being killed), I would have prolonged the prayer. O Allah, kill them all with no exception." (He then recited the poetic verse):-- "I being martyred as a Muslim, Do not mind how I am killed in Allah's Cause, For my killing is for Allah's Sake, And if Allah wishes, He will bless the amputated parts of a torn body" Then the son of Al Harith killed him. So, it was Khubaib who set the tradition for any Muslim sentenced to death in captivity, to offer a two-rak`at prayer (before being killed). Allah fulfilled the invocation of `Asim bin Thabit on that very day on which he was martyred. The Prophet (ﷺ) informed his companions of their news and what had happened to them. Later on when some infidels from Quraish were informed that `Asim had been killed, they sent some people to fetch a part of his body (i.e. his head) by which he would be recognized. (That was because) `Asim had killed one of their chiefs on the day (of the battle) of Badr. So, a swarm of wasps, resembling a shady cloud, were sent to hover over `Asim and protect him from their messenger and thus they could not cut off anything from his flesh}}
\hadithdefcmd{bukhari}{3046}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فُكُّوا الْعَانِيَ ـ يَعْنِي الأَسِيرَ ـ وَأَطْعِمُوا الْجَائِعَ وَعُودُوا الْمَرِيضَ ‏"‏‏.‏\hadithno{3046}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "Free the captives, feed the hungry and pay a visit to the sick}}
\hadithdefcmd{bukhari}{3047}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُطَرِّفٌ، أَنَّ عَامِرًا، حَدَّثَهُمْ عَنْ أَبِي جُحَيْفَةَ ـ رضى الله عنه ـ قَالَ قُلْتُ لِعَلِيٍّ ـ رضى الله عنه هَلْ عِنْدَكُمْ شَىْءٌ مِنَ الْوَحْىِ إِلاَّ مَا فِي كِتَابِ اللَّهِ قَالَ وَالَّذِي فَلَقَ الْحَبَّةَ وَبَرَأَ النَّسَمَةَ مَا أَعْلَمُهُ إِلاَّ فَهْمًا يُعْطِيهِ اللَّهُ رَجُلاً فِي الْقُرْآنِ، وَمَا فِي هَذِهِ الصَّحِيفَةِ‏.‏ قُلْتُ وَمَا فِي الصَّحِيفَةِ قَالَ الْعَقْلُ وَفَكَاكُ الأَسِيرِ، وَأَنْ لاَ يُقْتَلَ مُسْلِمٌ بِكَافِرٍ‏.‏\hadithno{3047}\hadithtrans{Narrated Abu Juhaifa:I asked `Ali, "Do you have the knowledge of any Divine Inspiration besides what is in Allah's Book?" `Ali replied, "No, by Him Who splits the grain of corn and creates the soul. I don't think we have such knowledge, but we have the ability of understanding which Allah may endow a person with, so that he may understand the Qur'an, and we have what is written in this paper as well." I asked, "What is written in this paper?" He replied, "(The regulations of) blood-money, the freeing of captives, and the judgment that no Muslim should be killed for killing an infidel}}
\hadithdefcmd{bukhari}{3048}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رِجَالاً، مِنَ الأَنْصَارِ اسْتَأْذَنُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ ائْذَنْ فَلْنَتْرُكْ لاِبْنِ أُخْتِنَا عَبَّاسٍ فِدَاءَهُ‏.‏ فَقَالَ ‏ "‏ لاَ تَدَعُونَ مِنْهَا دِرْهَمًا ‏"‏‏.‏\hadithno{3048}\hadithtrans{Narrated Anas bin Malik:Some Ansari men asked permission from Allah's Messenger (ﷺ) saying, "O Allah's Messenger (ﷺ)! Allow us not to take the ransom of our nephew Al `Abbas. The Prophet (ﷺ) replied, "Do not leave a single Dirham thereof}}
\hadithdefcmd{bukhari}{3049}{وَقَالَ إِبْرَاهِيمُ عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِمَالٍ مِنَ الْبَحْرَيْنِ، فَجَاءَهُ الْعَبَّاسُ فَقَالَ يَا رَسُولَ اللَّهِ، أَعْطِنِي فَإِنِّي فَادَيْتُ نَفْسِي، وَفَادَيْتُ عَقِيلاً‏.‏ فَقَالَ ‏ "‏ خُذْ ‏"‏‏.‏ فَأَعْطَاهُ فِي ثَوْبِهِ‏.‏\hadithno{3049}\hadithtrans{(In another narration) Anas said:"Some wealth was brought to the Prophet (ﷺ) from Bahrain. Al `Abbas came to him and said, 'O Allah's Messenger (ﷺ)! Give me (some of it), as I have paid my and `Aqil's ransom.' The Prophet (ﷺ) said, 'Take,' and gave him in his garment}}
\hadithdefcmd{bukhari}{3050}{حَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ ـ وَكَانَ جَاءَ فِي أُسَارَى بَدْرٍ ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْمَغْرِبِ بِالطُّورِ‏.‏\hadithno{3050}\hadithtrans{Narrated Jubair:(who was among the captives of the Battle of Badr) I heard the Prophet (ﷺ) reciting 'Surat-at-Tur' in the Maghrib prayer}}
\hadithdefcmd{bukhari}{3051}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَبُو الْعُمَيْسِ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم عَيْنٌ مِنَ الْمُشْرِكِينَ وَهْوَ فِي سَفَرٍ، فَجَلَسَ عِنْدَ أَصْحَابِهِ يَتَحَدَّثُ ثُمَّ انْفَتَلَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اطْلُبُوهُ وَاقْتُلُوهُ ‏"‏‏.‏ فَقَتَلَهُ فَنَفَّلَهُ سَلَبَهُ‏.‏\hadithno{3051}\hadithtrans{Narrated Salama bin Al-Akwa`:"An infidel spy came to the Prophet (ﷺ) while he was on a journey. The spy sat with the companions of the Prophet (ﷺ) and started talking and then went away. The Prophet (ﷺ) said (to his companions), 'Chase and kill him.' So, I killed him." The Prophet (ﷺ) then gave him the belongings of the killed spy (in addition to his share of the war booty)}}
\hadithdefcmd{bukhari}{3052}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عُمَرَ ـ رضى الله عنه ـ قَالَ وَأُوصِيهِ بِذِمَّةِ اللَّهِ وَذِمَّةِ رَسُولِهِ صلى الله عليه وسلم أَنْ يُوفَى لَهُمْ بِعَهْدِهِمْ، وَأَنْ يُقَاتَلَ مِنْ وَرَائِهِمْ، وَلاَ يُكَلَّفُوا إِلاَّ طَاقَتَهُمْ‏.‏\hadithno{3052}\hadithtrans{Narrated `Amr bin Maimun:`Umar (after he was stabbed), instructed (his would-be-successor) saying, "I urge him (i.e. the new Caliph) to take care of those non-Muslims who are under the protection of Allah and His Apostle in that he should observe the convention agreed upon with them, and fight on their behalf (to secure their safety) and he should not over-tax them beyond their capability}}
\hadithdefcmd{bukhari}{3053}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ قَالَ يَوْمُ الْخَمِيسِ، وَمَا يَوْمُ الْخَمِيسِ ثُمَّ بَكَى حَتَّى خَضَبَ دَمْعُهُ الْحَصْبَاءَ فَقَالَ اشْتَدَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَجَعُهُ يَوْمَ الْخَمِيسِ فَقَالَ ‏"‏ ائْتُونِي بِكِتَابٍ أَكْتُبْ لَكُمْ كِتَابًا لَنْ تَضِلُّوا بَعْدَهُ أَبَدًا ‏"‏‏.‏ فَتَنَازَعُوا وَلاَ يَنْبَغِي عِنْدَ نَبِيٍّ تَنَازُعٌ فَقَالُوا هَجَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ ‏"‏ دَعُونِي فَالَّذِي أَنَا فِيهِ خَيْرٌ مِمَّا تَدْعُونِي إِلَيْهِ ‏"‏‏.‏ وَأَوْصَى عِنْدَ مَوْتِهِ بِثَلاَثٍ ‏"‏ أَخْرِجُوا الْمُشْرِكِينَ مِنْ جَزِيرَةِ الْعَرَبِ، وَأَجِيزُوا الْوَفْدَ بِنَحْوِ مَا كُنْتُ أُجِيزُهُمْ ‏"‏‏.‏ وَنَسِيتُ الثَّالِثَةَ‏.‏ وَقَالَ يَعْقُوبُ بْنُ مُحَمَّدٍ سَأَلْتُ الْمُغِيرَةَ بْنَ عَبْدِ الرَّحْمَنِ عَنْ جَزِيرَةِ الْعَرَبِ‏.‏ فَقَالَ مَكَّةُ وَالْمَدِينَةُ وَالْيَمَامَةُ وَالْيَمَنُ‏.‏ وَقَالَ يَعْقُوبُ وَالْعَرْجُ أَوَّلُ تِهَامَةَ‏.‏\hadithno{3053}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Abbas said, "Thursday! What (great thing) took place on Thursday!" Then he started weeping till his tears wetted the gravels of the ground . Then he said, "On Thursday the illness of Allah's Messenger (ﷺ) was aggravated and he said, "Fetch me writing materials so that I may have something written to you after which you will never go astray." The people (present there) differed in this matter and people should not differ before a prophet. They said, "Allah's Messenger (ﷺ) is seriously sick.' The Prophet (ﷺ) said, "Let me alone, as the state in which I am now, is better than what you are calling me for." The Prophet (ﷺ) on his death-bed, gave three orders saying, "Expel the pagans from the Arabian Peninsula, respect and give gifts to the foreign delegates as you have seen me dealing with them." I forgot the third (order)" (Ya'qub bin Muhammad said, "I asked Al-Mughira bin `Abdur-Rahman about the Arabian Peninsula and he said, 'It comprises Mecca, Medina, Al-Yama-ma and Yemen." Ya'qub added, "And Al-Arj, the beginning of Tihama)}}
\hadithdefcmd{bukhari}{3054}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ وَجَدَ عُمَرُ حُلَّةَ إِسْتَبْرَقٍ تُبَاعُ فِي السُّوقِ فَأَتَى بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، ابْتَعْ هَذِهِ الْحُلَّةَ فَتَجَمَّلْ بِهَا لِلْعِيدِ وَلِلْوُفُودِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ، أَوْ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ ‏"‏‏.‏ فَلَبِثَ مَا شَاءَ اللَّهُ ثُمَّ أَرْسَلَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم بِجُبَّةِ دِيبَاجٍ، فَأَقْبَلَ بِهَا عُمَرُ حَتَّى أَتَى بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، قُلْتَ ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ أَوْ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لا خَلاَقَ لَهُ ‏"‏‏.‏ ثُمَّ أَرْسَلْتَ إِلَىَّ بِهَذِهِ فَقَالَ ‏"‏ تَبِيعُهَا، أَوْ تُصِيبُ بِهَا بَعْضَ حَاجَتِكَ ‏"‏‏.‏\hadithno{3054}\hadithtrans{Narrated Ibn `Umar:`Umar saw a silken cloak being sold in the market and he brought it to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Buy this cloak and adorn yourself with it on the `Id festivals and on meeting the delegations." Allah's Messenger (ﷺ) replied, "This is the dress for the one who will have no share in the Hereafter (or, this is worn by one who will have no share in the Hereafter)." After sometime had passed, Allah's Messenger (ﷺ) sent a silken cloak to `Umar. `Umar took it and brought it to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! You have said that this is the dress of that who will have no share in the Hereafter (or, this is worn by one who will have no share in the Hereafter), yet you have sent me this!" The Prophet (ﷺ) said," I have sent it) so that you may sell it or fulfill with it some of your needs}}
\hadithdefcmd{bukhari}{3055}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ أَخْبَرَهُ أَنَّ عُمَرَ انْطَلَقَ فِي رَهْطٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مَعَ النَّبِيِّ صلى الله عليه وسلم قِبَلَ ابْنِ صَيَّادٍ حَتَّى وَجَدُوهُ يَلْعَبُ مَعَ الْغِلْمَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ، وَقَدْ قَارَبَ يَوْمَئِذٍ ابْنُ صَيَّادٍ يَحْتَلِمُ، فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ النَّبِيُّ صلى الله عليه وسلم ظَهْرَهُ بِيَدِهِ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏‏.‏ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ‏.‏ فَقَالَ ابْنُ صَيَّادٍ لِلنَّبِيِّ صلى الله عليه وسلم أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ‏.‏ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ آمَنْتُ بِاللَّهِ وَرُسُلِهِ ‏"‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَاذَا تَرَى ‏"‏‏.‏ قَالَ ابْنُ صَيَّادٍ يَأْتِينِي صَادِقٌ وَكَاذِبٌ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُلِطَ عَلَيْكَ الأَمْرُ ‏"‏‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ خَبَأْتُ لَكَ خَبِيئًا ‏"‏‏.‏ قَالَ ابْنُ صَيَّادٍ هُوَ الدُّخُّ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏‏.‏ قَالَ عُمَرُ يَا رَسُولَ اللَّهِ، ائْذَنْ لِي فِيهِ أَضْرِبْ عُنُقَهُ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْهُ فَلَنْ تُسَلَّطَ عَلَيْهِ، وَإِنْ لَمْ يَكُنْهُ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏‏.‏\hadithno{3055}\hadithtrans{Narrated Ibn 'Umar: Umar and a group of the companions of the Prophet (ﷺ) set out with the Prophet to Ibn Saiyad. He found him playing with some boys near the hillocks of Bani Maghala. Ibn Saiyad at that time was nearing his puberty. He did not notice (the Prophet's presence) till the Prophet (ﷺ) stroked him on the back with his hand and said, "Ibn Saiyad! Do you testify that I am Allah's Messenger (ﷺ)?" Ibn Saiyad looked at him and said, "I testify that you are the Apostle of the illiterates." Then Ibn Saiyad asked the Prophet. "Do you testify that I am the apostle of Allah?" The Prophet (ﷺ) said to him, "I believe in Allah and His Apostles." Then the Prophet (ﷺ) said (to Ibn Saiyad). "What do you see?" Ibn Saiyad replied, "True people and false ones visit me." The Prophet said, "Your mind is confused as to this matter." The Prophet (ﷺ) added, " I have kept something (in my mind) for you." Ibn Saiyad said, "It is Ad-Dukh." The Prophet (ﷺ) said (to him), "Shame be on you! You cannot cross your limits." On that 'Umar said, "O Allah's Messenger (ﷺ)! Allow me to chop his head off." The Prophet (ﷺ) said, "If he should be him (i.e. Ad-Dajjal) then you cannot overpower him, and should he not be him, then you are not going to benefit by murdering him}}
\hadithdefcmd{bukhari}{3057}{قَالَ ابْنُ عُمَرَ انْطَلَقَ النَّبِيُّ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ يَأْتِيَانِ النَّخْلَ الَّذِي فِيهِ ابْنُ صَيَّادٍ، حَتَّى إِذَا دَخَلَ النَّخْلَ طَفِقَ النَّبِيُّ صلى الله عليه وسلم يَتَّقِي بِجُذُوعِ النَّخْلِ وَهْوَ يَخْتِلُ ابْنَ صَيَّادٍ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ، وَابْنُ صَيَّادٍ مُضْطَجِعٌ عَلَى فِرَاشِهِ فِي قَطِيفَةٍ لَهُ فِيهَا رَمْزَةٌ، فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ النَّبِيَّ صلى الله عليه وسلم وَهْوَ يَتَّقِي بِجُذُوعِ النَّخْلِ، فَقَالَتْ لاِبْنِ صَيَّادٍ أَىْ صَافِ ـ وَهْوَ اسْمُهُ ـ فَثَارَ ابْنُ صَيَّادٍ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏‏.‏ وَقَالَ سَالِمٌ قَالَ ابْنُ عُمَرَ ثُمَّ قَامَ النَّبِيُّ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏"‏ إِنِّي أُنْذِرُكُمُوهُ، وَمَا مِنْ نَبِيٍّ إِلاَّ قَدْ أَنْذَرَهُ قَوْمَهُ، لَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ، وَلَكِنْ سَأَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ، تَعْلَمُونَ أَنَّهُ أَعْوَرُ وَأَنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ‏"‏‏.‏\hadithno{3057}\hadithtrans{Narrated Ibn Umar: (Later on) Allah's Messenger (ﷺ) (once again) went along with Ubai bin Ka'b to the garden of date-palms where Ibn Saiyad was staying. When the Prophet entered the garden, he started hiding himself behind the trunks of the date-palms as he wanted to hear something from Ibn Saiyad before the latter could see him. Ibn Saiyad was lying in his bed, covered with a velvet sheet from where his murmurs were heard. Ibn Saiyad's mother saw the Prophet (ﷺ) while he was hiding himself behind the trunks of the date-palms. She addressed Ibn Saiyad, "O Saf!" (And this was his name). Ibn Saiyad got up. The Prophet (ﷺ) said, "Had this woman let him to himself, he would have revealed the reality of his case." Then the Prophet (ﷺ) got up amongst the people, glorifying Allah as He deserves, he mentioned Ad-Dajjal, saying, "I warn you about him (i.e. Ad-Dajjal) and there is no prophet who did not warn his nation about him, and Noah warned his nation about him, but I tell you a statement which no prophet informed his nation of. You should understand that he is a one-eyed man and Allah is not one-eyed}}
\hadithdefcmd{bukhari}{3058}{حَدَّثَنَا مَحْمُودٌ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ بْنِ عَفَّانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ، أَيْنَ تَنْزِلُ غَدًا فِي حَجَّتِهِ‏.‏ قَالَ ‏"‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مَنْزِلاً ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏نَحْنُ نَازِلُونَ غَدًا بِخَيْفِ بَنِي كِنَانَةَ الْمُحَصَّبِ، حَيْثُ قَاسَمَتْ قُرَيْشٌ عَلَى الْكُفْرِ ‏"‏‏.‏ وَذَلِكَ أَنَّ بَنِي كِنَانَةَ حَالَفَتْ قُرَيْشًا عَلَى بَنِي هَاشِمٍ أَنْ لاَ يُبَايِعُوهُمْ وَلاَ يُئْوُوهُمْ‏.‏ قَالَ الزُّهْرِيُّ وَالْخَيْفُ الْوَادِي‏.‏\hadithno{3058}\hadithtrans{Narrated Usama bin Zaid:I asked the Prophet (ﷺ) during his Hajj, "O Allah's Messenger (ﷺ)! Where will you stay tomorrow?" He said, "Has `Aqil left for us any house?" He then added, "Tomorrow we will stay at Khaif Bani Kinana, i.e. Al-Muhassab, where (the Pagans of) Quraish took an oath of Kufr (i.e. to be loyal to heathenism) in that Bani Kinana got allied with Quraish against Bani Hashim on the terms that they would not deal with the members of this tribe or give them shelter." (Az-Zuhri said, "Khaif means valley.") (See Hadith No. 659, Vol)}}
\hadithdefcmd{bukhari}{3059}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ اسْتَعْمَلَ مَوْلًى لَهُ يُدْعَى هُنَيًّا عَلَى الْحِمَى فَقَالَ يَا هُنَىُّ، اضْمُمْ جَنَاحَكَ عَنِ الْمُسْلِمِينَ، وَاتَّقِ دَعْوَةَ الْمَظْلُومِ، فَإِنَّ دَعْوَةَ الْمَظْلُومِ مُسْتَجَابَةٌ، وَأَدْخِلْ رَبَّ الصُّرَيْمَةِ وَرَبَّ الْغُنَيْمَةِ، وَإِيَّاىَ وَنَعَمَ ابْنِ عَوْفٍ، وَنَعَمَ ابْنِ عَفَّانَ، فَإِنَّهُمَا إِنْ تَهْلِكْ مَاشِيَتُهُمَا يَرْجِعَا إِلَى نَخْلٍ وَزَرْعٍ، وَإِنَّ رَبَّ الصُّرَيْمَةِ وَرَبَّ الْغُنَيْمَةِ إِنْ تَهْلِكْ مَاشِيَتُهُمَا يَأْتِنِي بِبَنِيهِ فَيَقُولُ يَا أَمِيرَ الْمُؤْمِنِينَ‏.‏ أَفَتَارِكُهُمْ أَنَا لاَ أَبَا لَكَ فَالْمَاءُ وَالْكَلأُ أَيْسَرُ عَلَىَّ مِنَ الذَّهَبِ وَالْوَرِقِ، وَايْمُ اللَّهِ، إِنَّهُمْ لَيَرَوْنَ أَنِّي قَدْ ظَلَمْتُهُمْ، إِنَّهَا لَبِلاَدُهُمْ فَقَاتَلُوا عَلَيْهَا فِي الْجَاهِلِيَّةِ، وَأَسْلَمُوا عَلَيْهَا فِي الإِسْلاَمِ، وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ الْمَالُ الَّذِي أَحْمِلُ عَلَيْهِ فِي سَبِيلِ اللَّهِ مَا حَمَيْتُ عَلَيْهِمْ مِنْ بِلاَدِهِمْ شِبْرًا‏.‏\hadithno{3059}\hadithtrans{Narrated Aslam:`Umar bin Al-Khattab appointed a freed slave of his, called Hunai, manager of the Hima (i.e. a pasture devoted for grazing the animals of the Zakat or other specified animals). He said to him, "O Hunai! Don't oppress the Muslims and ward off their curse (invocations against you) for the invocation of the oppressed is responded to (by Allah); and allow the shepherd having a few camels and those having a few sheep (to graze their animals), and take care not to allow the livestock of `Abdur-Rahman bin `Auf and the livestock of (`Uthman) bin `Affan, for if their livestock should perish, then they have their farms and gardens, while those who own a few camels and those who own a few sheep, if their livestock should perish, would bring their dependents to me and appeal for help saying, 'O chief of the believers! O chief of the believers!' Would I then neglect them? (No, of course not). So, I find it easier to let them have water and grass rather than to give them gold and silver (from the Muslims' treasury). By Allah, these people think that I have been unjust to them. This is their land, and during the pre-Islamic period, they fought for it and they embraced Islam (willingly) while it was in their possession. By Him in Whose Hand my life is! Were it not for the animals (in my custody) which I give to be ridden for striving in Allah's Cause, I would not have turned even a span of their land into a Hima}}
\hadithdefcmd{bukhari}{3060}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اكْتُبُوا لِي مَنْ تَلَفَّظَ بِالإِسْلاَمِ مِنَ النَّاسِ ‏"‏‏.‏ فَكَتَبْنَا لَهُ أَلْفًا وَخَمْسَمِائَةِ رَجُلٍ، فَقُلْنَا نَخَافُ وَنَحْنُ أَلْفٌ وَخَمْسُمِائَةٍ فَلَقَدْ رَأَيْتُنَا ابْتُلِينَا حَتَّى إِنَّ الرَّجُلَ لَيُصَلِّي وَحْدَهُ وَهْوَ خَائِفٌ‏.‏ حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، فَوَجَدْنَاهُمْ خَمْسَمِائَةٍ‏.‏ قَالَ أَبُو مُعَاوِيَةَ مَا بَيْنَ سِتِّمِائَةٍ إِلَى سَبْعِمِائَةٍ‏.‏\hadithno{3060}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) said (to us), " List the names of those people who have announced that they are Muslims." So, we listed one thousand and five hundred men. Then we wondered, "Should we be afraid (of infidels) although we are one thousand and five hundred in number?" No doubt, we witnessed ourselves being afflicted with such bad trials that one would have to offer the prayer alone in fear. Narrated Al-A`mash: "We (listed the Muslims and) found them five hundred." And Abu Muawiya said, "Between six hundred to seven hundred}}
\hadithdefcmd{bukhari}{3061}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، إِنِّي كُتِبْتُ فِي غَزْوَةِ كَذَا وَكَذَا، وَامْرَأَتِي حَاجَّةٌ‏.‏ قَالَ ‏ "‏ ارْجِعْ فَحُجَّ مَعَ امْرَأَتِكَ ‏"‏‏.‏\hadithno{3061}\hadithtrans{Narrated Ibn `Abbas:A man came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! I have enlisted in the army for such-andsuch Ghazwa, and my wife is leaving for Hajj." Allah's Messenger (ﷺ) said, "Go back and perform Hajj with your wife}}
\hadithdefcmd{bukhari}{3062}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنِي مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ شَهِدْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لِرَجُلٍ مِمَّنْ يَدَّعِي الإِسْلاَمَ ‏"‏ هَذَا مِنْ أَهْلِ النَّارِ ‏"‏‏.‏ فَلَمَّا حَضَرَ الْقِتَالُ قَاتَلَ الرَّجُلُ قِتَالاً شَدِيدًا، فَأَصَابَتْهُ جِرَاحَةٌ فَقِيلَ يَا رَسُولَ اللَّهِ، الَّذِي قُلْتَ إِنَّهُ مِنْ أَهْلِ النَّارِ فَإِنَّهُ قَدْ قَاتَلَ الْيَوْمَ قِتَالاً شَدِيدًا وَقَدْ مَاتَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِلَى النَّارِ ‏"‏‏.‏ قَالَ فَكَادَ بَعْضُ النَّاسِ أَنْ يَرْتَابَ، فَبَيْنَمَا هُمْ عَلَى ذَلِكَ إِذْ قِيلَ إِنَّهُ لَمْ يَمُتْ، وَلَكِنَّ بِهِ جِرَاحًا شَدِيدًا‏.‏ فَلَمَّا كَانَ مِنَ اللَّيْلِ لَمْ يَصْبِرْ عَلَى الْجِرَاحِ، فَقَتَلَ نَفْسَهُ، فَأُخْبِرَ النَّبِيُّ صلى الله عليه وسلم بِذَلِكَ فَقَالَ ‏"‏ اللَّهُ أَكْبَرُ، أَشْهَدُ أَنِّي عَبْدُ اللَّهِ وَرَسُولُهُ ‏"‏‏.‏ ثُمَّ أَمَرَ بِلاَلاً فَنَادَى بِالنَّاسِ ‏"‏ إِنَّهُ لاَ يَدْخُلُ الْجَنَّةَ إِلاَّ نَفْسٌ مُسْلِمَةٌ، وَإِنَّ اللَّهَ لَيُؤَيِّدُ هَذَا الدِّينَ بِالرَّجُلِ الْفَاجِرِ ‏"‏‏.‏\hadithno{3062}\hadithtrans{Narrated Az-Zuhri:as follows in Hadith 297. Narrated Abu Huraira: We were in the company of Allah's Messenger (ﷺ) in a Ghazwa, and he remarked about a man who claimed to be a Muslim, saying, "This (man) is from the people of the (Hell) Fire." When the battle started, the man fought violently till he got wounded. Somebody said, "O Allah's Messenger (ﷺ)! The man whom you described as being from the people of the (Hell) Fire fought violently today and died." The Prophet (ﷺ) said, "He will go to the (Hell) Fire." Some people were on the point of doubting (the truth of what the Prophet had said) while they were in this state, suddenly someone said that he was still alive but severely wounded. When night fell, he lost patience and committed suicide. The Prophet (ﷺ) was informed of that, and he said, "Allah is Greater! I testify that I am Allah's Slave and His Apostle." Then he ordered Bilal to announce amongst the people: 'None will enter Paradise but a Muslim, and Allah may support this religion (i.e. Islam) even with a disobedient man}}
\hadithdefcmd{bukhari}{3063}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَخَذَ الرَّايَةَ زَيْدٌ فَأُصِيبَ، ثُمَّ أَخَذَهَا جَعْفَرٌ فَأُصِيبَ، ثُمَّ أَخَذَهَا عَبْدُ اللَّهِ بْنُ رَوَاحَةَ فَأُصِيبَ، ثُمَّ أَخَذَهَا خَالِدُ بْنُ الْوَلِيدِ عَنْ غَيْرِ إِمْرَةٍ فَفُتِحَ عَلَيْهِ، وَمَا يَسُرُّنِي ـ أَوْ قَالَ مَا يَسُرُّهُمْ ـ أَنَّهُمْ عِنْدَنَا ‏"‏‏.‏ وَقَالَ وَإِنَّ عَيْنَيْهِ لَتَذْرِفَانِ‏.‏\hadithno{3063}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) delivered a sermon and said, "Zaid received the flag and was martyred, then Ja`far took it and was martyred, then `Abdullah bin Rawaha took it and was martyred, and then Khalid bin Al-Walid took it without being appointed, and Allah gave him victory." The Prophet (ﷺ) added, "I am not pleased (or they will not be pleased) that they should remain (alive) with us," while his eyes were shedding tears}}
\hadithdefcmd{bukhari}{3064}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَسَهْلُ بْنُ يُوسُفَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم أَتَاهُ رِعْلٌ وَذَكْوَانُ وَعُصَيَّةُ وَبَنُو لِحْيَانَ، فَزَعَمُوا أَنَّهُمْ قَدْ أَسْلَمُوا، وَاسْتَمَدُّوهُ عَلَى قَوْمِهِمْ، فَأَمَدَّهُمُ النَّبِيُّ صلى الله عليه وسلم بِسَبْعِينَ مِنَ الأَنْصَارِ قَالَ أَنَسٌ كُنَّا نُسَمِّيهِمُ الْقُرَّاءَ، يَحْطِبُونَ بِالنَّهَارِ وَيُصَلُّونَ بِاللَّيْلِ، فَانْطَلَقُوا بِهِمْ حَتَّى بَلَغُوا بِئْرَ مَعُونَةَ غَدَرُوا بِهِمْ وَقَتَلُوهُمْ، فَقَنَتَ شَهْرًا يَدْعُو عَلَى رِعْلٍ وَذَكْوَانَ وَبَنِي لِحْيَانَ‏.‏ قَالَ قَتَادَةُ وَحَدَّثَنَا أَنَسٌ أَنَّهُمْ قَرَءُوا بِهِمْ قُرْآنًا أَلاَ بَلِّغُوا عَنَّا قَوْمَنَا بِأَنَّا قَدْ لَقِينَا رَبَّنَا فَرَضِيَ عَنَّا وَأَرْضَانَا‏.‏ ثُمَّ رُفِعَ ذَلِكَ بَعْدُ‏.‏\hadithno{3064}\hadithtrans{Narrated Anas: The people of the tribes of Ril, Dhakwan, 'Usaiya and Bani Lihyan came to the Prophet (ﷺ) and claimed that they had embraced Islam, and they requested him to support them with some men to fight their own people. The Prophet (ﷺ) supported them with seventy men from the Ansar whom we used to call Al-Qurra'(i.e. Scholars) who (out of piety) used to cut wood during the day and pray all the night. So, those people took the (seventy) men till they reached a place called Bi'r-Ma'una where they betrayed and martyred them. So, the Prophet (ﷺ) invoked evil on the tribe of Ril, Dhakwan and Bani Lihyan for one month in the prayer. Narrated Qatada: Anas told us that they (i.e. Muslims) used to recite a Quranic Verse concerning those martyrs which was:-- "O Allah! Let our people be informed on our behalf that we have met our Lord Who has got pleased with us and made us pleased." Then the Verse was cancelled}}
\hadithdefcmd{bukhari}{3065}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، قَالَ ذَكَرَ لَنَا أَنَسُ بْنُ مَالِكٍ عَنْ أَبِي طَلْحَةَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ إِذَا ظَهَرَ عَلَى قَوْمٍ أَقَامَ بِالْعَرْصَةِ ثَلاَثَ لَيَالٍ‏.‏ تَابَعَهُ مُعَاذٌ وَعَبْدُ الأَعْلَى حَدَّثَنَا سَعِيدٌ عَنْ قَتَادَةَ عَنْ أَنَسٍ عَنْ أَبِي طَلْحَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3065}\hadithtrans{Narrated Abu Talha:Whenever the Prophet (ﷺ) conquered some people, he would stay in their town for three days}}
\hadithdefcmd{bukhari}{3066}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسًا، أَخْبَرَهُ قَالَ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْجِعْرَانَةِ، حَيْثُ قَسَمَ غَنَائِمَ حُنَيْنٍ‏.‏\hadithno{3066}\hadithtrans{Narrated Anas:The Prophet (ﷺ) performed `Umra, setting out from Al-Ji'rana where he distributed the war booty of Hunain}}
\hadithdefcmd{bukhari}{3067}{قَالَ ابْنُ نُمَيْرٍ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ ذَهَبَ فَرَسٌ لَهُ، فَأَخَذَهُ الْعَدُوُّ، فَظَهَرَ عَلَيْهِ الْمُسْلِمُونَ فَرُدَّ عَلَيْهِ فِي زَمَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَأَبَقَ عَبْدٌ لَهُ فَلَحِقَ بِالرُّومِ، فَظَهَرَ عَلَيْهِمُ الْمُسْلِمُونَ، فَرَدَّهُ عَلَيْهِ خَالِدُ بْنُ الْوَلِيدِ بَعْدَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3067}\hadithtrans{Narrated Nafi' (ra):A horse of Ibn 'Umar fled and the enemy took it. Then the Muslims conquered the enemy and the horse was returned to him during the lifetime of Allah's Messenger (ﷺ). And also, once a slave of Ibn 'Umar (ra) fled and joined the Byzantines, and when the Muslims conquered them, Khalid bin Al-Walid returned the slave to him after the death of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{3068}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، أَنَّ عَبْدًا، لاِبْنِ عُمَرَ أَبَقَ فَلَحِقَ بِالرُّومِ، فَظَهَرَ عَلَيْهِ خَالِدُ بْنُ الْوَلِيدِ، فَرَدَّهُ عَلَى عَبْدِ اللَّهِ، وَأَنَّ فَرَسًا لاِبْنِ عُمَرَ عَارَ فَلَحِقَ بِالرُّومِ، فَظَهَرَ عَلَيْهِ فَرَدُّوهُ عَلَى عَبْدِ اللَّهِ‏.‏ قَالَ أَبُو عَبْد اللَّهِ عَارَ مُشْتَقٌّ مِنْ الْعَيْرِ وَهُوَ حِمَارُ وَحْشٍ أَيْ هَرَبَ\hadithno{3068}\hadithtrans{Narrated Nafi`:Once a slave of Ibn `Umar fled and joined the Byzantine. Khalid bin Al-Walid got him back and returned him to `Abdullah (bin `Umar). Once a horse of Ibn `Umar also ran away and followed the Byzantines, and he (i.e. Khalid) got it back and returned it to `Abdullah}}
\hadithdefcmd{bukhari}{3069}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما أَنَّهُ كَانَ عَلَى فَرَسٍ يَوْمَ لَقِيَ الْمُسْلِمُونَ، وَأَمِيرُ الْمُسْلِمِينَ يَوْمَئِذٍ خَالِدُ بْنُ الْوَلِيدِ، بَعَثَهُ أَبُو بَكْرٍ، فَأَخَذَهُ الْعَدُوُّ، فَلَمَّا هُزِمَ الْعَدُوُّ رَدَّ خَالِدٌ فَرَسَهُ‏.‏\hadithno{3069}\hadithtrans{Narrated Ibn `Umar:That he was riding a horse on the day, the Muslims fought (against the Byzantines), and the commander of the Muslim army was Khalid bin Al-Walid who had been appointed by Abu Bakr. The enemy took the horse away, and when the enemy was defeated, Khalid returned the horse to him}}
\hadithdefcmd{bukhari}{3070}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ، أَخْبَرَنَا سَعِيدُ بْنُ مِينَاءَ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ، ذَبَحْنَا بُهَيْمَةً لَنَا، وَطَحَنْتُ صَاعًا مِنْ شَعِيرٍ، فَتَعَالَ أَنْتَ وَنَفَرٌ، فَصَاحَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا أَهْلَ الْخَنْدَقِ، إِنَّ جَابِرًا قَدْ صَنَعَ سُؤْرًا، فَحَىَّ هَلاً بِكُمْ ‏"‏‏.‏\hadithno{3070}\hadithtrans{Narrated Jabir bin `Abdullah:I said, "O Allah's Messenger (ﷺ)! We have slaughtered a young sheep of ours and have ground one Sa of barley. So, I invite you along with some persons." So, the Prophet (ﷺ) said in a loud voice, "O the people of the Trench! Jabir has prepared "Sur" so come along}}
\hadithdefcmd{bukhari}{3071}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ خَالِدِ بْنِ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أُمِّ خَالِدٍ بِنْتِ خَالِدِ بْنِ سَعِيدٍ، قَالَتْ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مَعَ أَبِي وَعَلَىَّ قَمِيصٌ أَصْفَرُ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَنَهْ سَنَهْ ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ وَهْىَ بِالْحَبَشِيَّةِ حَسَنَةٌ‏.‏ قَالَتْ فَذَهَبْتُ أَلْعَبُ بِخَاتَمِ النُّبُوَّةِ، فَزَبَرَنِي أَبِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعْهَا ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ ‏"‏ أَبْلِي وَأَخْلِفِي، ثُمَّ أَبْلِي وَأَخْلِفِي، ثُمَّ أَبْلِي وَأَخْلِفِي ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ فَبَقِيَتْ حَتَّى ذَكَرَ‏.‏\hadithno{3071}\hadithtrans{Narrated Um Khalid:(the daughter of Khalid bin Sa`id) I went to Allah's Messenger (ﷺ) with my father and I was wearing a yellow shirt. Allah's Messenger (ﷺ) said, "Sanah, Sanah!" (`Abdullah, the narrator, said that 'Sanah' meant 'good' in the Ethiopian language). I then started playing with the seal of Prophethood (in between the Prophet's shoulders) and my father rebuked me harshly for that. Allah's Messenger (ﷺ) said, "Leave her," and then Allah's Messenger (ﷺ) (invoked Allah to grant me a long life) by saying (thrice), "Wear this dress till it is worn out and then wear it till it is worn out, and then wear it till it is worn out." (The narrator adds, "It is said that she lived for a long period, wearing that (yellow) dress till its color became dark because of long wear}}
\hadithdefcmd{bukhari}{3072}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه أَنَّ الْحَسَنَ بْنَ عَلِيٍّ، أَخَذَ تَمْرَةً مِنْ تَمْرِ الصَّدَقَةِ، فَجَعَلَهَا فِي فِيهِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم بِالْفَارِسِيَّةِ ‏ "‏ كَخٍ كَخٍ، أَمَا تَعْرِفُ أَنَّا لاَ نَأْكُلُ الصَّدَقَةَ ‏"‏‏.‏\hadithno{3072}\hadithtrans{Narrated Abu Huraira:Al-Hasan bin 'Ali took a date from the dates of the Sadaqa and put it in his mouth. The Prophet (ﷺ) said (to him) in Persian, "Kakh, kakh! (i.e. Don't you know that we do not eat the Sadaqa (i.e. what is given in charity) (charity is the dirt of the people)}}
\hadithdefcmd{bukhari}{3073}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي حَيَّانَ، قَالَ حَدَّثَنِي أَبُو زُرْعَةَ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَامَ فِينَا النَّبِيُّ صلى الله عليه وسلم فَذَكَرَ الْغُلُولَ فَعَظَّمَهُ وَعَظَّمَ أَمْرَهُ قَالَ ‏ "‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ يَوْمَ الْقِيَامَةِ عَلَى رَقَبَتِهِ شَاةٌ لَهَا ثُغَاءٌ عَلَى رَقَبَتِهِ فَرَسٌ لَهُ حَمْحَمَةٌ يَقُولُ يَا رَسُولَ اللَّهِ، أَغِثْنِي‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا، قَدْ أَبْلَغْتُكَ‏.‏ وَعَلَى رَقَبَتِهِ بَعِيرٌ لَهُ رُغَاءٌ، يَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا، قَدْ أَبْلَغْتُكَ‏.‏ وَعَلَى رَقَبَتِهِ صَامِتٌ، فَيَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا، قَدْ أَبْلَغْتُكَ‏.‏ أَوْ عَلَى رَقَبَتِهِ رِقَاعٌ تَخْفِقُ، فَيَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا، قَدْ أَبْلَغْتُكَ ‏"‏‏.‏ وَقَالَ أَيُّوبُ عَنْ أَبِي حَيَّانَ فَرَسٌ لَهُ حَمْحَمَةٌ‏.‏\hadithno{3073}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) got up amongst us and mentioned Al Ghulul, emphasized its magnitude and declared that it was a great sin saying, "Don't commit Ghulul for I should not like to see anyone amongst you on the Day of Resurrection, carrying over his neck a sheep that will be bleating, or carrying over his neck a horse that will be neighing. Such a man will be saying: 'O Allah's Messenger (ﷺ)! Intercede with Allah for me,' and I will reply, 'I can't help you, for I have conveyed Allah's Message to you Nor should I like to see a man carrying over his neck, a camel that will be grunting. Such a man will say, 'O Allah's Apostle! Intercede with Allah for me, and I will say, 'I can't help you for I have conveyed Allah's Message to you,' or one carrying over his neck gold and silver and saying, 'O Allah's Messenger (ﷺ)! Intercede with Allah for me,' and I will say, 'I can't help you for I have conveyed Allah's Message to you,' or one carrying clothes that will be fluttering, and the man will say, 'O Allah's Messenger (ﷺ)! Intercede with Allah for me.' And I will say, 'I can't help you, for I have conveyed Allah's Message to you}}
\hadithdefcmd{bukhari}{3074}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كَانَ عَلَى ثَقَلِ النَّبِيِّ صلى الله عليه وسلم رَجُلٌ يُقَالُ لَهُ كِرْكِرَةُ فَمَاتَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ فِي النَّارِ ‏"‏‏.‏ فَذَهَبُوا يَنْظُرُونَ إِلَيْهِ فَوَجَدُوا عَبَاءَةً قَدْ غَلَّهَا‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ ابْنُ سَلاَمٍ كَرْكَرَةُ، يَعْنِي بِفَتْحِ الْكَافِ، وَهْوَ مَضْبُوطٌ كَذَا‏.‏\hadithno{3074}\hadithtrans{Narrated `Abdullah bin `Amr:There was a man who looked after the family and the belongings of the Prophet (ﷺ) and he was called Karkara. The man died and Allah's Messenger (ﷺ) said, "He is in the '(Hell) Fire." The people then went to look at him and found in his place, a cloak he had stolen from the war booty}}
\hadithdefcmd{bukhari}{3075}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعٍ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ، فَأَصَابَ النَّاسَ جُوعٌ وَأَصَبْنَا إِبِلاً وَغَنَمًا، وَكَانَ النَّبِيُّ صلى الله عليه وسلم فِي أُخْرَيَاتِ النَّاسِ، فَعَجِلُوا فَنَصَبُوا الْقُدُورَ، فَأَمَرَ بِالْقُدُورِ فَأُكْفِئَتْ، ثُمَّ قَسَمَ فَعَدَلَ عَشَرَةً مِنَ الْغَنَمِ بِبَعِيرٍ، فَنَدَّ مِنْهَا بَعِيرٌ، وَفِي الْقَوْمِ خَيْلٌ يَسِيرٌ فَطَلَبُوهُ فَأَعْيَاهُمْ، فَأَهْوَى إِلَيْهِ رَجُلٌ بِسَهْمٍ، فَحَبَسَهُ اللَّهُ فَقَالَ ‏"‏ هَذِهِ الْبَهَائِمُ لَهَا أَوَابِدُ كَأَوَابِدِ الْوَحْشِ، فَمَا نَدَّ عَلَيْكُمْ فَاصْنَعُوا بِهِ هَكَذَا ‏"‏‏.‏ فَقَالَ جَدِّي إِنَّا نَرْجُو ـ أَوْ نَخَافُ ـ أَنْ نَلْقَى الْعَدُوَّ غَدًا وَلَيْسَ مَعَنَا مُدًى، أَفَنَذْبَحُ بِالْقَصَبِ فَقَالَ ‏"‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ فَكُلْ، لَيْسَ السِّنَّ وَالظُّفُرَ، وَسَأُحَدِّثُكُمْ عَنْ ذَلِكَ، أَمَّا السِّنُّ فَعَظْمٌ، وَأَمَّا الظُّفُرُ فَمُدَى الْحَبَشَةِ ‏"‏‏.‏\hadithno{3075}\hadithtrans{Narrated Abaya bin Rifaa:My grandfather, Rafi` said, "We were in the company of the Prophet (ﷺ) at DhulHulaifa, and the people suffered from hunger. We got some camels and sheep (as booty) and the Prophet (ﷺ) was still behind the people. They hurried and put the cooking pots on the fire. (When he came) he ordered that the cooking pots should be upset and then he distributed the booty (amongst the people) regarding ten sheep as equal to one camel. Then a camel fled and the people chased it till they got tired, as they had a few horses (for chasing it). So a man threw an arrow at it and caused it to stop (with Allah's Permission). On that the Prophet (ﷺ) said, 'Some of these animals behave like wild beasts, so, if any animal flees from you, deal with it in the same way." My grandfather asked (the Prophet (ﷺ) ), "We hope (or are afraid) that we may meet the enemy tomorrow and we have no knives. Can we slaughter our animals with canes?" Allah's Messenger (ﷺ) replied, "If the instrument used for killing causes the animal to bleed profusely and if Allah's Name is mentioned on killing it, then eat its meat (i.e. it is lawful) but don't use a tooth or a nail and I am telling you the reason: A tooth is a bone (and slaughtering with a bone is forbidden ), and a nail is the slaughtering instrument of the Ethiopians}}
\hadithdefcmd{bukhari}{3076}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي قَيْسٌ، قَالَ قَالَ لِي جَرِيرُ بْنُ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ تُرِيحُنِي مِنْ ذِي الْخَلَصَةِ ‏"‏‏.‏ وَكَانَ بَيْتًا فِيهِ خَثْعَمُ يُسَمَّى كَعْبَةَ الْيَمَانِيَةَ، فَانْطَلَقْتُ فِي خَمْسِينَ وَمِائَةٍ مِنْ أَحْمَسَ، وَكَانُوا أَصْحَابَ خَيْلٍ، فَأَخْبَرْتُ النَّبِيَّ صلى الله عليه وسلم أَنِّي لاَ أَثْبُتُ عَلَى الْخَيْلِ، فَضَرَبَ فِي صَدْرِي حَتَّى رَأَيْتُ أَثَرَ أَصَابِعِهِ فِي صَدْرِي فَقَالَ ‏"‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏‏.‏ فَانْطَلَقَ إِلَيْهَا فَكَسَرَهَا وَحَرَّقَهَا، فَأَرْسَلَ إِلَى النَّبِيِّ صلى الله عليه وسلم يُبَشِّرُهُ فَقَالَ رَسُولُ جَرِيرٍ يَا رَسُولَ اللَّهِ، وَالَّذِي بَعَثَكَ بِالْحَقِّ، مَا جِئْتُكَ حَتَّى تَرَكْتُهَا كَأَنَّهَا جَمَلٌ أَجْرَبُ، فَبَارَكَ عَلَى خَيْلِ أَحْمَسَ وَرِجَالِهَا خَمْسَ مَرَّاتٍ‏.‏ قَالَ مُسَدَّدٌ بَيْتٌ فِي خَثْعَمَ‏.‏\hadithno{3076}\hadithtrans{Narrated Qais:Jarir bin `Abdullah said to me, "Allah's Messenger (ﷺ) said to me, 'Won't you relieve me from Dhul- Khalasa?' Dhul-Khalasa was a house where the tribe of Khatham used to stay, and it used to be called Ka`bat-ul Yamaniya. So I proceeded with one hundred-and-fifty (men) from the tribe of Ahmas who were good cavalry. I informed the Prophet (ﷺ) that I could not sit firm on horses, so he stroke me on the chest with his hand and I noticed his finger marks on my chest. He invoked, 'O Allah! Make him firm and a guiding and rightly-guided man." Jarir set out towards that place, dismantled and burnt it, and then sent the good news to Allah's Messenger (ﷺ) . The messenger of Jarir said to Allah's Messenger (ﷺ). "O Allah's Apostle! By Him Who has sent you with the Truth, I did not come to you till it (i.e. the house) had been turned (black) like a scabby camel (covered with tar)." So the Prophet (ﷺ) invoked Allah to Bless the horses of the men of Ahmas five times}}
\hadithdefcmd{bukhari}{3077}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ ‏ "‏ لاَ هِجْرَةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ، وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏‏.‏\hadithno{3077}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, on the day of the Conquest of Mecca, "There is no migration (after the Conquest), but Jihad and good intentions, and when you are called for Jihad, you should immediately respond to the call}}
\hadithdefcmd{bukhari}{3079}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ مُجَاشِعِ بْنِ مَسْعُودٍ، قَالَ جَاءَ مُجَاشِعٌ بِأَخِيهِ مُجَالِدِ بْنِ مَسْعُودٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ هَذَا مُجَالِدٌ يُبَايِعُكَ عَلَى الْهِجْرَةِ‏.‏ فَقَالَ ‏ "‏ لاَ هِجْرَةَ بَعْدَ فَتْحِ مَكَّةَ، وَلَكِنْ أُبَايِعُهُ عَلَى الإِسْلاَمِ ‏"‏‏.‏\hadithno{3079}\hadithtrans{Narrated Abu `Uthman An-Nahdi:Mujashi (bin Mas`ud) took his brother Mujalid bin Mas`ud to the Prophet (ﷺ) and said, "This is Mujalid and he will give a pledge of allegiance to you for migration." The Prophet (ﷺ) said, "There is no migration after the Conquest of Mecca, but I will take his pledge of allegiance for Islam}}
\hadithdefcmd{bukhari}{3080}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو وَابْنُ جُرَيْجٍ سَمِعْتُ عَطَاءً، يَقُولُ ذَهَبْتُ مَعَ عُبَيْدِ بْنِ عُمَيْرٍ إِلَى عَائِشَةَ ـ رضى الله عنها ـ وَهْىَ مُجَاوِرَةٌ بِثَبِيرٍ فَقَالَتْ لَنَا انْقَطَعَتِ الْهِجْرَةُ مُنْذُ فَتَحَ اللَّهُ عَلَى نَبِيِّهِ صلى الله عليه وسلم مَكَّةَ‏.‏\hadithno{3080}\hadithtrans{Narrated `Ata':I and 'Ubai bin `Umar went to `Aisha while she was staying near Thabir (i.e. a mountain). She said, "There is no Migration after Allah gave His Prophet victory over Mecca}}
\hadithdefcmd{bukhari}{3081}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ الطَّائِفِيُّ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُصَيْنٌ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، وَكَانَ، عُثْمَانِيًّا فَقَالَ لاِبْنِ عَطِيَّةَ وَكَانَ عَلَوِيًّا إِنِّي لأَعْلَمُ مَا الَّذِي جَرَّأَ صَاحِبَكَ عَلَى الدِّمَاءِ سَمِعْتُهُ يَقُولُ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم وَالزُّبَيْرَ، فَقَالَ ‏"‏ ائْتُوا رَوْضَةَ كَذَا، وَتَجِدُونَ بِهَا امْرَأَةً أَعْطَاهَا حَاطِبٌ كِتَابًا ‏"‏‏.‏ فَأَتَيْنَا الرَّوْضَةَ فَقُلْنَا الْكِتَابَ‏.‏ قَالَتْ لَمْ يُعْطِنِي‏.‏ فَقُلْنَا لَتُخْرِجِنَّ أَوْ لأُجَرِّدَنَّكِ‏.‏ فَأَخْرَجَتْ مِنْ حُجْزَتِهَا، فَأَرْسَلَ إِلَى حَاطِبٍ فَقَالَ لاَ تَعْجَلْ، وَاللَّهِ مَا كَفَرْتُ وَلاَ ازْدَدْتُ لِلإِسْلاَمِ إِلاَّ حُبًّا، وَلَمْ يَكُنْ أَحَدٌ مِنْ أَصْحَابِكَ إِلاَّ وَلَهُ بِمَكَّةَ مَنْ يَدْفَعُ اللَّهُ بِهِ عَنْ أَهْلِهِ وَمَالِهِ، وَلَمْ يَكُنْ لِي أَحَدٌ، فَأَحْبَبْتُ أَنْ أَتَّخِذَ عِنْدَهُمْ يَدًا‏.‏ فَصَدَّقَهُ النَّبِيُّ صلى الله عليه وسلم‏.‏ قَالَ عُمَرُ دَعْنِي أَضْرِبْ عُنُقَهُ، فَإِنَّهُ قَدْ نَافَقَ‏.‏ فَقَالَ ‏"‏ مَا يُدْرِيكَ لَعَلَّ اللَّهَ اطَّلَعَ عَلَى أَهْلِ بَدْرٍ، فَقَالَ اعْمَلُوا مَا شِئْتُمْ ‏"‏‏.‏ فَهَذَا الَّذِي جَرَّأَهُ‏.‏\hadithno{3081}\hadithtrans{Narrated Sa`d bin 'Ubaida:Abu `Abdur-Rahman who was one of the supporters of `Uthman said to Abu Talha who was one of the supporters of `Ali, "I perfectly know what encouraged your leader (i.e. `Ali) to shed blood. I heard him saying: Once the Prophet (ﷺ) sent me and Az-Zubair saying, 'Proceed to such-and-such Ar-Roudah (place) where you will find a lady whom Hatib has given a letter. So when we arrived at Ar-Roudah, we requested the lady to hand over the letter to us. She said, 'Hatib has not given me any letter.' We said to her. 'Take out the letter or else we will strip off your clothes.' So she took it out of her braid. So the Prophet (ﷺ) sent for Hatib, (who came) and said, 'Don't hurry in judging me, for, by Allah, I have not become a disbeliever, and my love to Islam is increasing. (The reason for writing this letter was) that there is none of your companions but has relatives in Mecca who look after their families and property, while I have nobody there, so I wanted to do them some favor (so that they might look after my family and property).' The Prophet (ﷺ) believed him. `Umar said, 'Allow me to chop off his (i.e. Hatib's) neck as he has done hypocrisy.' The Prophet (ﷺ) said, (to `Umar), 'Who knows, perhaps Allah has looked at the warriors of Badr and said (to them), 'Do whatever you like, for I have forgiven you.' " Abu `Abdur-Rahman added, "So this is what encouraged him (i.e. `Ali)}}
\hadithdefcmd{bukhari}{3082}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، وَحُمَيْدُ بْنُ الأَسْوَدِ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ ابْنُ الزُّبَيْرِ لاِبْنِ جَعْفَرٍ ـ رضى الله عنهم أَتَذْكُرُ إِذْ تَلَقَّيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَا وَأَنْتَ وَابْنُ عَبَّاسٍ قَالَ نَعَمْ، فَحَمَلَنَا وَتَرَكَكَ‏.‏\hadithno{3082}\hadithtrans{Narrated Ibn Abi Mulaika:Ibn Az-Zubair said to Ibn Ja`far "Do you remember when I, you and Ibn `Abbas went out to receive Allah's Messenger (ﷺ)?" Ibn Ja`far replied in the affirmative. Ibn Az-Zubair added, "And Allah's Messenger (ﷺ) made us (i.e. I and Ibn `Abbas) ride along with him and left you}}
\hadithdefcmd{bukhari}{3083}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، قَالَ قَالَ السَّائِبُ بْنُ يَزِيدَ ـ رضى الله عنه ذَهَبْنَا نَتَلَقَّى رَسُولَ اللَّهِ صلى الله عليه وسلم مَعَ الصِّبْيَانِ إِلَى ثَنِيَّةِ الْوَدَاعِ‏.‏\hadithno{3083}\hadithtrans{Narrated As-Sa'ib bin Yazid:I along with some boys went out to receive Allah's Messenger (ﷺ) at Thaniyatal-Wada}}
\hadithdefcmd{bukhari}{3084}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَفَلَ كَبَّرَ ثَلاَثًا قَالَ ‏ "‏ آيِبُونَ إِنْ شَاءَ اللَّهُ تَائِبُونَ عَابِدُونَ حَامِدُونَ لِرَبِّنَا سَاجِدُونَ، صَدَقَ اللَّهُ وَعْدَهُ، وَنَصَرَ عَبْدَهُ، وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏‏.‏\hadithno{3084}\hadithtrans{Narrated `Abdullah:When the Prophet (ﷺ) returned (from Jihad), he would say Takbir thrice and add, "We are returning, if Allah wishes, with repentance and worshipping and praising (our Lord) and prostrating ourselves before our Lord. Allah fulfilled His Promise and helped His Slave, and He Alone defeated the (infidel) clans}}
\hadithdefcmd{bukhari}{3085}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم مَقْفَلَهُ مِنْ عُسْفَانَ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ، وَقَدْ أَرْدَفَ صَفِيَّةَ بِنْتَ حُيَىٍّ، فَعَثَرَتْ نَاقَتُهُ فَصُرِعَا جَمِيعًا، فَاقْتَحَمَ أَبُو طَلْحَةَ فَقَالَ يَا رَسُولَ اللَّهِ، جَعَلَنِي اللَّهُ فِدَاءَكَ‏.‏ قَالَ ‏"‏ عَلَيْكَ الْمَرْأَةَ ‏"‏‏.‏ فَقَلَبَ ثَوْبًا عَلَى وَجْهِهِ وَأَتَاهَا، فَأَلْقَاهَا عَلَيْهَا وَأَصْلَحَ لَهُمَا مَرْكَبَهُمَا فَرَكِبَا، وَاكْتَنَفْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم، فَلَمَّا أَشْرَفْنَا عَلَى الْمَدِينَةِ قَالَ ‏"‏ آيِبُونَ تَائِبُونَ عَابِدُونَ لِرَبِّنَا حَامِدُونَ ‏"‏‏.‏ فَلَمْ يَزَلْ يَقُولُ ذَلِكَ حَتَّى دَخَلَ الْمَدِينَةَ‏.‏\hadithno{3085}\hadithtrans{Narrated Anas bin Malik:We were in the company of the Prophet (ﷺ) while returning from 'Usfan, and Allah's Messenger (ﷺ) was riding his she-camel keeping Safiya bint Huyay riding behind him. His she-camel slipped and both of them fell down. Abu Talha jumped from his camel and said, "O Allah's Messenger (ﷺ)! May Allah sacrifice me for you." The Prophet (ﷺ) said, "Take care of the lady." So, Abu Talha covered his face with a garment and went to Safiya and covered her with it, and then he set right the condition of their she-camel so that both of them rode, and we were encircling Allah's Messenger (ﷺ) like a cover. When we approached Medina, the Prophet (ﷺ) said, "We are returning with repentance and worshipping and praising our Lord." He kept on saying this till he entered Medina}}
\hadithdefcmd{bukhari}{3086}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه أَنَّهُ أَقْبَلَ هُوَ وَأَبُو طَلْحَةَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَمَعَ النَّبِيِّ صلى الله عليه وسلم صَفِيَّةُ مُرْدِفَهَا عَلَى رَاحِلَتِهِ، فَلَمَّا كَانُوا بِبَعْضِ الطَّرِيقِ عَثَرَتِ النَّاقَةُ، فَصُرِعَ النَّبِيُّ صلى الله عليه وسلم وَالْمَرْأَةُ، وَإِنَّ أَبَا طَلْحَةَ ـ قَالَ أَحْسِبُ قَالَ ـ اقْتَحَمَ عَنْ بَعِيرِهِ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ جَعَلَنِي اللَّهُ فِدَاءَكَ، هَلْ أَصَابَكَ مِنْ شَىْءٍ قَالَ ‏"‏ لاَ، وَلَكِنْ عَلَيْكَ بِالْمَرْأَةِ ‏"‏‏.‏ فَأَلْقَى أَبُو طَلْحَةَ ثَوْبَهُ عَلَى وَجْهِهِ، فَقَصَدَ قَصْدَهَا فَأَلْقَى ثَوْبَهُ عَلَيْهَا، فَقَامَتِ الْمَرْأَةُ، فَشَدَّ لَهُمَا عَلَى رَاحِلَتِهِمَا فَرَكِبَا، فَسَارُوا حَتَّى إِذَا كَانُوا بِظَهْرِ الْمَدِينَةِ ـ أَوْ قَالَ أَشْرَفُوا عَلَى الْمَدِينَةِ ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ آيِبُونَ تَائِبُونَ عَابِدُونَ لِرَبِّنَا حَامِدُونَ ‏"‏‏.‏ فَلَمْ يَزَلْ يَقُولُهَا حَتَّى دَخَلَ الْمَدِينَةَ‏.‏\hadithno{3086}\hadithtrans{Narrated Anas bin Malik:That he and Abu Talha came in the company of the Prophet (ﷺ) and Safiya was accompanying the Prophet, who let her ride behind him on his she-camel. During the journey, the she-camel slipped and both the Prophet (ﷺ) and (his) wife fell down. Abu Talha (the sub-narrator thinks that Anas said that Abu Talha jumped from his camel quickly) said, "O Allah's Messenger (ﷺ)! May Allah sacrifice me for your sake! Did you get hurt?" The Prophet (ﷺ) replied,"No, but take care of the lady." Abu Talha covered his face with his garment and proceeded towards her and covered her with his garment, and she got up. He then set right the condition of their she-camel and both of them (i.e. the Prophet (ﷺ) and his wife) rode and proceeded till they approached Medina. The Prophet (ﷺ) said, "We are returning with repentance and worshipping and praising our Lord." The Prophet (ﷺ) kept on saying this statement till he entered Medina}}
\hadithdefcmd{bukhari}{3087}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، رضى الله عنهما قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَلَمَّا قَدِمْنَا الْمَدِينَةَ قَالَ لِي ‏ "‏ ادْخُلِ الْمَسْجِدَ فَصَلِّ رَكْعَتَيْنِ ‏"‏‏.‏\hadithno{3087}\hadithtrans{Narrated Jabir bin `Abdullah:I was on a journey in the company of the Prophet (ﷺ) and when we reached Medina, he said to me, "Enter the Mosque and offer two rak`at}}
\hadithdefcmd{bukhari}{3088}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ أَبِيهِ، وَعَمِّهِ، عُبَيْدِ اللَّهِ بْنِ كَعْبٍ عَنْ كَعْبٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَدِمَ مِنْ سَفَرٍ ضُحًى دَخَلَ الْمَسْجِدَ، فَصَلَّى رَكْعَتَيْنِ قَبْلَ أَنْ يَجْلِسَ‏.‏\hadithno{3088}\hadithtrans{Narrated Ka`b:Whenever the Prophet (ﷺ) returned from a journey in the forenoon, he would enter the Mosque and offer two rak`at before sitting}}
\hadithdefcmd{bukhari}{3089}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا قَدِمَ الْمَدِينَةَ نَحَرَ جَزُورًا أَوْ بَقَرَةً‏.‏ زَادَ مُعَاذ عَنْ شُعْبَةَ عَنْ مُحَارِبٍ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ اشْتَرَى مِنى النَّبِيُّ صلى الله عليه وسلم بَعِيرًا بِوَقِيَّتَيْنِ وَدِرْهَمٍ أَوْ دِرْهَمَيْنِ، فَلَمَّا قَدِمَ صِرَارًا أَمَرَ بِبَقَرَةٍ فَذُبِحَتْ فَأَكَلُوا مِنْهَا، فَلَمَّا قَدِمَ الْمَدِينَةَ أَمَرَنِي أَنْ آتِيَ الْمَسْجِدَ فَأُصَلىَ رَكْعَتَيْنِ، وَوَزَنَ لِي ثَمَنَ الْبَعِيرِ‏.‏\hadithno{3089}\hadithtrans{Narrated Muharib bin Dithar:Jabir bin `Abdullah said, "When Allah's Messenger (ﷺ) arrived at Medina, he slaughtered a camel or a cow." Jabir added, "The Prophet (ﷺ) bought a camel from me for two Uqiyas (of gold) and one or two Dirhams. When he reached Sirar, he ordered that a cow be slaughtered and they ate its meat. When he arrived at Medina, he ordered me to go to the Mosque and offer two rak`at, and weighed (and gave) me the price of the camel}}
\hadithdefcmd{bukhari}{3090}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، قَالَ قَدِمْتُ مِنْ سَفَرٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ صَلِّ رَكْعَتَيْنِ ‏"‏‏.‏ صِرَارٌ مَوْضِعٌ نَاحِيَةً بِالْمَدِينَةِ‏.‏\hadithno{3090}\hadithtrans{Narrated Jabir:Once I returned from a journey and the Prophet (ﷺ) said (to me) "Offer two rak`at." (Sirar is a place near Medina)}}
