% Auto-generated chapter 44 for muslim
% Hadiths in this chapter: 324

\hadithdefcmd{muslim}{6169}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، قَالَ عَبْدُ اللَّهِ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا ثَابِتٌ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ، حَدَّثَهُ قَالَ نَظَرْتُ إِلَى أَقْدَامِ الْمُشْرِكِينَ عَلَى رُءُوسِنَا وَنَحْنُ فِي الْغَارِ فَقُلْتُ يَا رَسُولَ اللَّهِ لَوْ أَنَّ أَحَدَهُمْ نَظَرَ إِلَى قَدَمَيْهِ أَبْصَرَنَا تَحْتَ قَدَمَيْهِ فَقَالَ ‏ "‏ يَا أَبَا بَكْرٍ مَا ظَنُّكَ بِاثْنَيْنِ اللَّهُ ثَالِثُهُمَا ‏"‏ ‏.‏\hadithno{6169}\hadithtrans{Anas b. Malik reported that Abu Bakr Siddiq reported him thus:I saw the feet of the polytheists very close to us as we were in the cave. I said: Allah's Messenger, if one amongst them were to see at his feet he would have surely seen us. Thereupon he said: Abu Bakr, what can befall two who have Allah as the third One with them}}
\hadithdefcmd{muslim}{6170}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرِ بْنِ يَحْيَى بْنِ خَالِدٍ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي، النَّضْرِ عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَلَسَ عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ عَبْدٌ خَيَّرَهُ اللَّهُ بَيْنَ أَنْ يُؤْتِيَهُ زَهْرَةَ الدُّنْيَا وَبَيْنَ مَا عِنْدَهُ فَاخْتَارَ مَا عِنْدَهُ ‏"‏ ‏.‏ فَبَكَى أَبُو بَكْرٍ وَبَكَى فَقَالَ فَدَيْنَاكَ بِآبَائِنَا وَأُمَّهَاتِنَا ‏.‏ قَالَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ الْمُخَيَّرُ وَكَانَ أَبُو بَكْرٍ أَعْلَمَنَا بِهِ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَمَنَّ النَّاسِ عَلَىَّ فِي مَالِهِ وَصُحْبَتِهِ أَبُو بَكْرٍ وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ خَلِيلاً وَلَكِنْ أُخُوَّةُ الإِسْلاَمِ لاَ تُبْقَيَنَّ فِي الْمَسْجِدِ خَوْخَةٌ إِلاَّ خَوْخَةَ أَبِي بَكْرٍ ‏"‏ ‏.‏\hadithno{6170}\hadithtrans{Abu Sa'id reported that Allah's Messenger (ﷺ) sat on the pulpit and said:Allah gave a choice to His servant that he may opt the beauties of the world or that which is with Him and the servant chose that which was with Him. Thereupon Abu Bakr wept and he wept bitterly and said: Let our fathers and our mothers be taken as ransom for you. It was Allah's Messenger (ﷺ) who had been given the choice and Abu Bakr knew it better than us, and Allah's Messenger (ﷺ) is reported to have said: Behold, of all people the most generous toward me in regard to his companionship and his property was Abu Bakr and were I to choose anyone as my bosom friend, I would have chosen Abu Bakr as my dear friend, but (for him) I cherish Islamic brotherliness and love. There shall be left open no window in the mosque except Abu Bakr's window}}
\hadithdefcmd{muslim}{6171}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ عُبَيْدِ، بْنِ حُنَيْنٍ وَبُسْرِ بْنِ سَعِيدٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ يَوْمًا ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ ‏.‏\hadithno{6171}\hadithtrans{This hadith has been narrated on the authority of Abu Sa'id Khudri through another chain of transmitters}}
\hadithdefcmd{muslim}{6172}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ الْعَبْدِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ إِسْمَاعِيلَ، بْنِ رَجَاءٍ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي الْهُذَيْلِ، يُحَدِّثُ عَنْ أَبِي الأَحْوَصِ، قَالَ سَمِعْتُ عَبْدَ، اللَّهِ بْنَ مَسْعُودٍ يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ خَلِيلاً وَلَكِنَّهُ أَخِي وَصَاحِبِي وَقَدِ اتَّخَذَ اللَّهُ عَزَّ وَجَلَّ صَاحِبَكُمْ خَلِيلاً ‏"‏ ‏.‏\hadithno{6172}\hadithtrans{Abdullah b. Mas'ud reported Allah's Messenger (ﷺ) as saying:If I were to choose a bosom friend I would have definitely chosen Abu Bakr as my bosom friend, but he is my brother and my companion and Allah, the Exalted and Gliorious. has taken your brother and companion (meaning Prophet himself) as a friend}}
\hadithdefcmd{muslim}{6173}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لَوْ كُنْتُ مُتَّخِذًا مِنْ أُمَّتِي أَحَدًا خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ ‏"‏ ‏.‏\hadithno{6173}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:If I were to choose from my Umma anyone as my bosom friend, I would have chosen Abu Bakr}}
\hadithdefcmd{muslim}{6174}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنِي سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا جَعْفَرُ بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عُمَيْسٍ، عَنِ ابْنِ أَبِي، مُلَيْكَةَ عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ ابْنَ أَبِي قُحَافَةَ خَلِيلاً ‏"‏ ‏.‏\hadithno{6174}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:If I were to choose as my bosom friend I would have chosen the son of Abu Quhafa (Abu Bakr) as my bosom friend}}
\hadithdefcmd{muslim}{6175}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنْ وَاصِلِ بْنِ حَيَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي، الْهُذَيْلِ عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ كُنْتُ مُتَّخِذًا مِنْ أَهْلِ الأَرْضِ خَلِيلاً لاَتَّخَذْتُ ابْنَ أَبِي قُحَافَةَ خَلِيلاً وَلَكِنْ صَاحِبُكُمْ خَلِيلُ اللَّهِ ‏"‏ ‏.‏\hadithno{6175}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:If I were to choose amongst the people of earth someone as my bosom friend, I would have chosen the son of Abu Quhafa as my friends but God has taken your companion as a friend}}
\hadithdefcmd{muslim}{6176}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ، إِبْرَاهِيمَ أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو سَعِيدٍ الأَشَجُّ - وَاللَّفْظُ لَهُمَا - قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ إِنِّي أَبْرَأُ إِلَى كُلِّ خِلٍّ مِنْ خِلِّهِ وَلَوْ كُنْتُ مُتَّخِذًا خَلِيلاً لاَتَّخَذْتُ أَبَا بَكْرٍ خَلِيلاً إِنَّ صَاحِبَكُمْ خَلِيلُ اللَّهِ ‏"‏ ‏.‏\hadithno{6176}\hadithtrans{This hadith has been narrated through another chain of transmitters and the one narrated on the authority of Abdullah (the words are):" Allah's Messenger (ﷺ) is reported to have said: Behold I am free from the dependence of all bosom friends and if I were to choose anyone as bosom friend I would have taken Abu Bakr as my bosom friend. Allah has taken your companion as a friend}}
\hadithdefcmd{muslim}{6177}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ أَبِي عُثْمَانَ، أَخْبَرَنِي عَمْرُو بْنُ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَهُ عَلَى جَيْشِ ذَاتِ السَّلاَسِلِ فَأَتَيْتُهُ فَقُلْتُ أَىُّ النَّاسِ أَحَبُّ إِلَيْكَ قَالَ ‏"‏ عَائِشَةُ ‏"‏ ‏.‏ قُلْتُ مِنَ الرِّجَالِ قَالَ ‏"‏ أَبُوهَا ‏"‏ ‏.‏ قُلْتُ ثُمَّ مَنْ قَالَ ‏"‏ عُمَرُ ‏"‏ ‏.‏ فَعَدَّ رِجَالاً ‏.‏\hadithno{6177}\hadithtrans{Amr b. al-'As reported that Allah's Messenger (ﷺ) sent him in command of the army despatched to Dhat-as-Salasil. When 'Amr b. al-'As came back to the Prophet (ﷺ) he said:Who amongst people are dearest to you? He said: A'isha. He then said: Who amongst men? He said: Her father, and I said: And who next? He said: Umar. He then enumerated some other men}}
\hadithdefcmd{muslim}{6178}{وَحَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، عَنْ أَبِي عُمَيْسٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا جَعْفَرُ بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عُمَيْسٍ، عَنِ ابْنِ، أَبِي مُلَيْكَةَ سَمِعْتُ عَائِشَةَ، وَسُئِلَتْ، مَنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُسْتَخْلِفًا لَوِ اسْتَخْلَفَهُ قَالَتْ أَبُو بَكْرٍ ‏.‏ فَقِيلَ لَهَا ثُمَّ مَنْ بَعْدَ أَبِي بَكْرٍ قَالَتْ عُمَرُ ‏.‏ ثُمَّ قِيلَ لَهَا مَنْ بَعْدَ عُمَرَ قَالَتْ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏.‏ ثُمَّ انْتَهَتْ إِلَى هَذَا ‏.‏\hadithno{6178}\hadithtrans{Ibn Abu Mulaika reported:I heard `A'isha as saying and she was asked as to whom Allah's Messenger (ﷺ) would have nominated as his successor if he had to nominate one at all. She said: Abu Bakr. It was said to her: Then whom after Abu Bakr? She said: `Umar. It was said to her. Then whom after `Umar? She said: Abu `Ubaida b. al-Jarrah, and then she kept quiet at this}}
\hadithdefcmd{muslim}{6181}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا صَالِحُ بْنُ كَيْسَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ ‏ "‏ ادْعِي لِي أَبَا بَكْرٍ وَأَخَاكِ حَتَّى أَكْتُبَ كِتَابًا فَإِنِّي أَخَافُ أَنْ يَتَمَنَّى مُتَمَنٍّ وَيَقُولَ قَائِلٌ أَنَا أَوْلَى ‏.‏ وَيَأْبَى اللَّهُ وَالْمُؤْمِنُونَ إِلاَّ أَبَا بَكْرٍ ‏"‏ ‏.‏\hadithno{6181}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) in his (last) illness asked me to call Abu Bakr, her father, and her brother too, so that he might write a document, for he feared that someone else might be desirous (of succeeding him) and that some claimant may say:I have better claim to it, whereas Allah and the Faithful do not substantiate the claim of anyone but that of Abu Bakr}}
\hadithdefcmd{muslim}{6182}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ كَيْسَانَ - عَنْ أَبِي حَازِمٍ الأَشْجَعِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَصْبَحَ مِنْكُمُ الْيَوْمَ صَائِمًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ أَنَا ‏.‏ قَالَ ‏"‏ فَمَنْ تَبِعَ مِنْكُمُ الْيَوْمَ جَنَازَةً ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ أَنَا ‏.‏ قَالَ ‏"‏ فَمَنْ أَطْعَمَ مِنْكُمُ الْيَوْمَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ أَنَا ‏.‏ قَالَ ‏"‏ فَمَنْ عَادَ مِنْكُمُ الْيَوْمَ مَرِيضًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ أَنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا اجْتَمَعْنَ فِي امْرِئٍ إِلاَّ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{6182}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:Who amongst you is fasting today? Abu Bakr said: I am. He (again) said: Who amongst you followed a funeral procession today? Abu Bakr said: I did. He (the Prophet) again said: Who amongst you served food to the needy? Abu Bakr said: I did. He (again) said: Who amongst you has today visited the sick? Abu Bakr said: I did. Thereupon Allah's Messenger (ﷺ) said: Anyone in whom (these good deeds) are combined will certainly enter paradise}}
\hadithdefcmd{muslim}{6183}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ وَحَرْمَلَةُ بْنُ يَحْيَى قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَيْنَمَا رَجُلٌ يَسُوقُ بَقَرَةً لَهُ قَدْ حَمَلَ عَلَيْهَا الْتَفَتَتْ إِلَيْهِ الْبَقَرَةُ فَقَالَتْ إِنِّي لَمْ أُخْلَقْ لِهَذَا وَلَكِنِّي إِنَّمَا خُلِقْتُ لِلْحَرْثِ ‏"‏ ‏.‏ فَقَالَ النَّاسُ سُبْحَانَ اللَّهِ ‏.‏ تَعَجُّبًا وَفَزَعًا ‏.‏ أَبَقَرَةٌ تَكَلَّمُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنِّي أُومِنُ بِهِ وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَيْنَا رَاعٍ فِي غَنَمِهِ عَدَا عَلَيْهِ الذِّئْبُ فَأَخَذَ مِنْهَا شَاةً فَطَلَبَهُ الرَّاعِي حَتَّى اسْتَنْقَذَهَا مِنْهُ فَالْتَفَتَ إِلَيْهِ الذِّئْبُ فَقَالَ لَهُ مَنْ لَهَا يَوْمَ السَّبُعِ يَوْمَ لَيْسَ لَهَا رَاعٍ غَيْرِي ‏"‏ ‏.‏ فَقَالَ النَّاسُ سُبْحَانَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنِّي أُومِنُ بِذَلِكَ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏\hadithno{6183}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A person had been driving an ox loaded with luggage. The ox looked towards him and said: I have not been created for this but for lands (i. e. for ploughing the land and for drawing out water from the wells for the purpose of irrigating the lands). The people said with surprise and awe: Hallowed be Allah, does the ox speak? Allah's Messenger (ﷺ) said: I believe it and so do Abu Bakr and 'Umar. Abu Huraira reported Allah's Messenger (ﷺ) as saying: A shepherd was tendirig the flock when a wolf came there and took away one goat. Tile shepherd pursued it (the wolf) and rescued it (the goat) from that (wolf). The wolf looked towards him and said: Who would save it on the day when there will be no shepherd except me? Thereupon people said: Hallowed be Allah I Thereupon Allah's Messenger (ﷺ) said: I believe in it and so do Abu Bakr and Umar believe}}
\hadithdefcmd{muslim}{6184}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ قِصَّةَ الشَّاةِ وَالذِّئْبِ وَلَمْ يَذْكُرْ قِصَّةَ الْبَقَرَةِ ‏.‏\hadithno{6184}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters, but there is no mention of the story pertaining to the ox}}
\hadithdefcmd{muslim}{6185}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، كِلاَهُمَا عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي، هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمَعْنَى حَدِيثِ يُونُسَ عَنِ الزُّهْرِيِّ وَفِي حَدِيثِهِمَا ذِكْرُ الْبَقَرَةِ وَالشَّاةِ مَعًا وَقَالاَ فِي حَدِيثِهِمَا ‏ "‏ فَإِنِّي أُومِنُ بِهِ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏ وَمَا هُمَا ثَمَّ ‏.‏\hadithno{6185}\hadithtrans{This hadith has been transmitted on the authority of Zuhri, and there is a clear mention of the stories of ox and goat (and the words are):I believe in it and so do Abu Bakr and Umar, but they were not at that time present there}}
\hadithdefcmd{muslim}{6186}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مِسْعَرٍ، كِلاَهُمَا عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{6186}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transrritters}}
\hadithdefcmd{muslim}{6187}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَأَبُو الرَّبِيعِ الْعَتَكِيُّ، وَأَبُو كُرَيْبٍ مُحَمَّدُ بْنُ الْعَلاَءِ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ وُضِعَ عُمَرُ بْنُ الْخَطَّابِ عَلَى سَرِيرِهِ فَتَكَنَّفَهُ النَّاسُ يَدْعُونَ وَيُثْنُونَ وَيُصَلُّونَ عَلَيْهِ قَبْلَ أَنْ يُرْفَعَ وَأَنَا فِيهِمْ - قَالَ - فَلَمْ يَرُعْنِي إِلاَّ بِرَجُلٍ قَدْ أَخَذَ بِمَنْكِبِي مِنْ وَرَائِي فَالْتَفَتُّ إِلَيْهِ فَإِذَا هُوَ عَلِيُّ فَتَرَحَّمَ عَلَى عُمَرَ وَقَالَ مَا خَلَّفْتَ أَحَدًا أَحَبَّ إِلَىَّ أَنْ أَلْقَى اللَّهَ بِمِثْلِ عَمَلِهِ مِنْكَ وَايْمُ اللَّهِ إِنْ كُنْتُ لأَظُنُّ أَنْ يَجْعَلَكَ اللَّهُ مَعَ صَاحِبَيْكَ وَذَاكَ أَنِّي كُنْتُ أُكَثِّرُ أَسْمَعُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ جِئْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ وَدَخَلْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ وَخَرَجْتُ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏ ‏.‏ فَإِنْ كُنْتُ لأَرْجُو أَوْ لأَظُنُّ أَنْ يَجْعَلَكَ اللَّهُ مَعَهُمَا ‏.‏\hadithno{6187}\hadithtrans{Ibn Abu Mulaika reported:I heard Ibn 'Abbas as saying: When 'Umar b. Khattab was placed in the coffin the people gathered around him. They praised him and supplicated for him before the bier was lifted up, and I was one amongst them. Nothing attracted my attention but a person who gripped my shoulder from behind. I saw towards him and found that he was 'Ali. He invoked Allah's mercy upon 'Umar and said: You have left none behind you (whose) deeds (are so enviable) that I love to meet Allah with them. By Allah, I hoped that Allah would keep you and your two associates together. I had often heard Allah's Messenger (ﷺ) as saying: I came and there came too Abu Bakr and 'Umar; I entered and there entered too Abu Bakr and 'Umar; I went out and there went out too Abu Bakr and 'Umar, and I hope and think that Allah will keep you along with them}}
\hadithdefcmd{muslim}{6188}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُمَرَ بْنِ سَعِيدٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{6188}\hadithtrans{This hadith has been narrated on the authority of 'Umar b. Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{6189}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لَهُمْ - قَالُوا حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو أُمَامَةَ، بْنُ سَهْلٍ أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُ النَّاسَ يُعْرَضُونَ وَعَلَيْهِمْ قُمُصٌ مِنْهَا مَا يَبْلُغُ الثُّدِيَّ وَمِنْهَا مَا يَبْلُغُ دُونَ ذَلِكَ وَمَرَّ عُمَرُ بْنُ الْخَطَّابِ وَعَلَيْهِ قَمِيصٌ يَجُرُّهُ ‏"‏ ‏.‏ قَالُوا مَاذَا أَوَّلْتَ ذَلِكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الدِّينَ ‏"‏ ‏.‏\hadithno{6189}\hadithtrans{Abu Sa'id Khudri reported Allah's Messenger (ﷺ) as say ing:While I was asleep I saw people being presented to me (in a dream) and they wore shirts and some of these reached up to the breasts and some even beyond them. Then there happened to pass 'Umar b. Khattab and his shirt had been trailing. They said: Allah's Messeneer, how do you interpret the dream? He said: (As strength of) faith}}
\hadithdefcmd{muslim}{6190}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَنَا نَائِمٌ إِذْ رَأَيْتُ قَدَحًا أُتِيتُ بِهِ فِيهِ لَبَنٌ فَشَرِبْتُ مِنْهُ حَتَّى إِنِّي لأَرَى الرِّيَّ يَجْرِي فِي أَظْفَارِي ثُمَّ أَعْطَيْتُ فَضْلِي عُمَرَ بْنَ الْخَطَّابِ ‏"‏ ‏.‏ قَالُوا فَمَا أَوَّلْتَ ذَلِكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْعِلْمَ ‏"‏ ‏.‏\hadithno{6190}\hadithtrans{Hamza b. Abdullah b. 'Umar b. Khattab reported on the authority of his father that Allah's Messenger (ﷺ) said:While I was asleep I saw (in a dream) a cup containing milk being presented to me. I took out of that until I perceived freshness being reflected through my nails. Then I presented the leftover to 'Umar b. Khattab. They said: Allah's Messenger: How do you interpret it? He said: This implies knowledge}}
\hadithdefcmd{muslim}{6191}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، ح وَحَدَّثَنَا الْحُلْوَانِيُّ، وَعَبْدُ بْنُ، حُمَيْدٍ كِلاَهُمَا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، بِإِسْنَادِ يُونُسَ نَحْوَ حَدِيثِهِ ‏.‏\hadithno{6191}\hadithtrans{This hadith has been narrated on the authority of Yunus with the same chain of transmitters}}
\hadithdefcmd{muslim}{6192}{حَدَّثَنَا حَرْمَلَةُ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعِيدَ بْنَ، الْمُسَيَّبِ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُنِي عَلَى قَلِيبٍ عَلَيْهَا دَلْوٌ فَنَزَعْتُ مِنْهَا مَا شَاءَ اللَّهُ ثُمَّ أَخَذَهَا ابْنُ أَبِي قُحَافَةَ فَنَزَعَ بِهَا ذَنُوبًا أَوْ ذَنُوبَيْنِ وَفِي نَزْعِهِ وَاللَّهُ يَغْفِرُ لَهُ ضَعْفٌ ثُمَّ اسْتَحَالَتْ غَرْبًا فَأَخَذَهَا ابْنُ الْخَطَّابِ فَلَمْ أَرَ عَبْقَرِيًّا مِنَ النَّاسِ يَنْزِعُ نَزْعَ عُمَرَ بْنِ الْخَطَّابِ حَتَّى ضَرَبَ النَّاسُ بِعَطَنٍ ‏"‏ ‏.‏\hadithno{6192}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:While I was asleep I saw myself on a well with a leathern bucket on a pulley. I drew (water) out of that as Allah wished me (to draw). Then the son of Abu Quhafa (Abu Bakr) drew from it one bucketful or two and there was some weakness in drawing that (may Allah forgive him). Then that bucket (changed into a large bucket) and Ibn Khattab drew it. I did not see any strongest man drawing it like 'Umar b. Khattab. He brought out so much water that the camels of the people had enough to drink and then laid down (for rest)}}
\hadithdefcmd{muslim}{6193}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَالْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، بِإِسْنَادِ يُونُسَ نَحْوَ حَدِيثِهِ ‏.‏\hadithno{6193}\hadithtrans{This hadith has been narrated on the authority of Yunus through another chain of transmitters}}
\hadithdefcmd{muslim}{6194}{حَدَّثَنَا الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، قَالَ قَالَ الأَعْرَجُ وَغَيْرُهُ إِنَّ أَبَا هُرَيْرَةَ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رَأَيْتُ ابْنَ أَبِي قُحَافَةَ يَنْزِعُ ‏"‏ ‏.‏ بِنَحْوِ حَدِيثِ الزُّهْرِيِّ ‏.‏\hadithno{6194}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:I saw Ibn Abu Quhafa drawing (water) ; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6195}{حَدَّثَنِي أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ وَهْبٍ، حَدَّثَنَا عَمِّي عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا يُونُسَ، مَوْلَى أَبِي هُرَيْرَةَ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَا أَنَا نَائِمٌ أُرِيتُ أَنِّي أَنْزِعُ عَلَى حَوْضِي أَسْقِي النَّاسَ فَجَاءَنِي أَبُو بَكْرٍ فَأَخَذَ الدَّلْوَ مِنْ يَدِي لِيُرَوِّحَنِي فَنَزَعَ دَلْوَيْنِ وَفِي نَزْعِهِ ضُعْفٌ وَاللَّهُ يَغْفِرُ لَهُ فَجَاءَ ابْنُ الْخَطَّابِ فَأَخَذَ مِنْهُ فَلَمْ أَرَ نَزْعَ رَجُلٍ قَطُّ أَقْوَى مِنْهُ حَتَّى تَوَلَّى النَّاسُ وَالْحَوْضُ مَلآنُ يَتَفَجَّرُ ‏"‏ ‏.‏\hadithno{6195}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:While I was asleep I saw myself drawing water from my tank in order to quench the thirst of the people that there came to me Abu Bakr. He took hold of the leathern bucket from my hand so that he should serve water to the people. He drew two bucketfuls and there was some weakness in his drawing (Allah may forgive him). Then there came Ibn Khattab and he took hold of that, and I did not see a person stronger than he (drawing water) until the people went away with their thirst quenched and the tank filled with water}}
\hadithdefcmd{muslim}{6196}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنِي أَبُو بَكْرِ بْنُ سَالِمٍ، عَنْ سَالِمِ، بْنِ عَبْدِ اللَّهِ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُرِيتُ كَأَنِّي أَنْزِعُ بِدَلْوِ بَكْرَةٍ عَلَى قَلِيبٍ فَجَاءَ أَبُو بَكْرٍ فَنَزَعَ ذَنُوبًا أَوْ ذَنُوبَيْنِ فَنَزَعَ نَزْعًا ضَعِيفًا وَاللَّهُ تَبَارَكَ وَتَعَالَى يَغْفِرُ لَهُ ثُمَّ جَاءَ عُمَرُ فَاسْتَقَى فَاسْتَحَالَتْ غَرْبًا فَلَمْ أَرَ عَبْقَرِيًّا مِنَ النَّاسِ يَفْرِي فَرْيَهُ حَتَّى رَوِيَ النَّاسُ وَضَرَبُوا الْعَطَنَ ‏"‏ ‏.‏\hadithno{6196}\hadithtrans{Abdullah b. 'Umar reported Allah's Messenger (ﷺ) as saying:I saw (in a dream) as if I was drawing water with a leathern bucket on a wooden pulley. There came Abu Bakr and he drew out a bucketful or two and as he drew out, some weakness (was perceived in it) (may Allah, the Exalted and Glorious, forgive him). Then Umar came in order to serve water -and the bucket was changed into a large leather bucket and I did not see such a wonderful man amongst persons (drawing water) and he went on serving water to the people until they were fully satisfied and then went to their resting places}}
\hadithdefcmd{muslim}{6197}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ رُؤْيَا، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي أَبِي بَكْرٍ وَعُمَرَ بْنِ الْخَطَّابِ رضى الله عنهما بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{6197}\hadithtrans{Salim b. 'Abdullah reported on the authority of his father some of the dreams of Allah's Messenger (ﷺ) pertaining to Abu Bakr and Umar b. Khattab (Allah be pleased with them) and a hadith like this}}
\hadithdefcmd{muslim}{6198}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، وَابْنِ الْمُنْكَدِرِ، سَمِعَا جَابِرًا، يُخْبِرُ عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ الْمُنْكَدِرِ، وَعَمْرٍو، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ دَخَلْتُ الْجَنَّةَ فَرَأَيْتُ فِيهَا دَارًا أَوْ قَصْرًا فَقُلْتُ لِمَنْ هَذَا فَقَالُوا لِعُمَرَ بْنِ الْخَطَّابِ ‏.‏ فَأَرَدْتُ أَنْ أَدْخُلَ ‏.‏ فَذَكَرْتُ غَيْرَتَكَ ‏"‏ ‏.‏ فَبَكَى عُمَرُ وَقَالَ أَىْ رَسُولَ اللَّهِ أَوَعَلَيْكَ يُغَارُ\hadithno{6198}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:I entered Paradise and saw in it a house or a palace. I said: For whom is it resersred? They (the Angels) said: It is for 'Umar b. Khattab. (The Prophet said to 'Umar b. Khattab): I intenied to get into it but I thought of your feelings. Thereupon 'Umar wept and said: Apostle of Allah, could I feel any jealousy in your case?}}
\hadithdefcmd{muslim}{6199}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، وَابْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرًا، ح وَحَدَّثَنَاهُ عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، سَمِعْتُ جَابِرًا، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ وَزُهَيْرٍ ‏.‏\hadithno{6199}\hadithtrans{This hadith has been narrated on the authority of Jabir through another chain of transmitters}}
\hadithdefcmd{muslim}{6202}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا إِبْرَاهِيمُ يَعْنِي ابْنَ سَعْدٍ، ح وَحَدَّثَنَا حَسَنٌ، الْحُلْوَانِيُّ وَعَبْدُ بْنُ حُمَيْدٍ قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ، حَسَنٌ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ الْحَمِيدِ بْنُ عَبْدِ الرَّحْمَنِ، بْنِ زَيْدٍ أَنَّ مُحَمَّدَ بْنَ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَخْبَرَهُ أَنَّ أَبَاهُ سَعْدًا قَالَ اسْتَأْذَنَ عُمَرُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ نِسَاءٌ مِنْ قُرَيْشٍ يُكَلِّمْنَهُ وَيَسْتَكْثِرْنَهُ عَالِيَةً أَصْوَاتُهُنَّ فَلَمَّا اسْتَأْذَنَ عُمَرُ قُمْنَ يَبْتَدِرْنَ الْحِجَابَ فَأَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَضْحَكُ فَقَالَ عُمَرُ أَضْحَكَ اللَّهُ سِنَّكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَجِبْتُ مِنْ هَؤُلاَءِ اللاَّتِي كُنَّ عِنْدِي فَلَمَّا سَمِعْنَ صَوْتَكَ ابْتَدَرْنَ الْحِجَابَ ‏"‏ ‏.‏ قَالَ عُمَرُ فَأَنْتَ يَا رَسُولَ اللَّهِ أَحَقُّ أَنْ يَهَبْنَ ‏.‏ ثُمَّ قَالَ عُمَرُ أَىْ عَدُوَّاتِ أَنْفُسِهِنَّ أَتَهَبْنَنِي وَلاَ تَهَبْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْنَ نَعَمْ أَنْتَ أَغْلَظُ وَأَفَظُّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ مَا لَقِيَكَ الشَّيْطَانُ قَطُّ سَالِكًا فَجًّا إِلاَّ سَلَكَ فَجًّا غَيْرَ فَجِّكَ ‏"‏ ‏.‏\hadithno{6202}\hadithtrans{Sa'd b. Waqqas reported that Umar sought permission from Allah's Messenger (ﷺ) to visit him when some women of the Quraish were busy in talking with him and raising their voices above his Voiee. When'Umar sought permission they stood up and went hurriedly behind the curtain. Allah's Messenger (ﷺ) gave him permission smilingly. Thereupon 'Umar said:Allah's Messenger, may Allah keep you happy all your life. Then Allah's Messenger (ﷺ) said: I wonder at these women who were with me and no sooner did they hear your voice, they immediately went behind the curtain. Thereupon 'Umar said: Allah's Messenger, you have more right that they should fear you. Then Umar (addressing the women) said: O ye enemies of yourselves, do you fear me and fear not the Messenger of Allah (ﷺ)? They said: Yes, you are harsh and strict as compared to the Messenger of Allah (ﷺ). Thereupon, Allah's Messenger (maypeace be upon him) said: By Him in Whose Hand is my life, if satan would encounter you in the way he would certainly take a different way from that of yours}}
\hadithdefcmd{muslim}{6203}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا بِهِ عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، أَخْبَرَنِي سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ نِسْوَةٌ قَدْ رَفَعْنَ أَصْوَاتَهُنَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا اسْتَأْذَنَ عُمَرُ ابْتَدَرْنَ الْحِجَابَ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ الزُّهْرِيِّ ‏.‏\hadithno{6203}\hadithtrans{Abu Huraira reported that Umar b. Khattab came to Allah's Messenger (ﷺ) while there were some women with him and they were raising their voices above the voice of Allah's Messenger (ﷺ) and when Umar sought permission to get into the house they went behind the curtain hurriedly. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6204}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ إِبْرَاهِيمَ، بْنِ سَعْدٍ عَنْ أَبِيهِ، سَعْدِ بْنِ إِبْرَاهِيمَ عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ قَدْ كَانَ يَكُونُ فِي الأُمَمِ قَبْلَكُمْ مُحَدَّثُونَ فَإِنْ يَكُنْ فِي أُمَّتِي مِنْهُمْ أَحَدٌ فَإِنَّ عُمَرَ بْنَ الْخَطَّابِ مِنْهُمْ ‏"‏ ‏.‏ قَالَ ابْنُ وَهْبٍ تَفْسِيرُ مُحَدَّثُونَ مُلْهَمُونَ ‏.‏\hadithno{6204}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:There had been among the people before you inspired persons and if there were any such among my Umma Umar b. Khattab would be one of them. Ibn Wahb explained the word Muhaddathun as those who receive hint from the High (Mulhamun)}}
\hadithdefcmd{muslim}{6205}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، كِلاَهُمَا عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6205}\hadithtrans{This hadith has been narrated on the authority of Sa'd b. Ibrahim with the same chain of transmitters}}
\hadithdefcmd{muslim}{6206}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، قَالَ جُوَيْرِيَةُ بْنُ أَسْمَاءَ أَخْبَرَنَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ عُمَرُ وَافَقْتُ رَبِّي فِي ثَلاَثٍ فِي مَقَامِ إِبْرَاهِيمَ وَفِي الْحِجَابِ وَفِي أُسَارَى بَدْرٍ ‏.‏\hadithno{6206}\hadithtrans{Ibn Umar reported Umar as saying:My lord concorded with (my judgments) on three occasions. In case of the Station of Ibrahim, in case of the observance of veil and in case of the prisoners of Badr}}
\hadithdefcmd{muslim}{6207}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا تُوُفِّيَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ جَاءَ ابْنُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ أَنْ يُعْطِيَهُ قَمِيصَهُ أَنْ يُكَفِّنَ فِيهِ أَبَاهُ فَأَعْطَاهُ ثُمَّ سَأَلَهُ أَنْ يُصَلِّيَ عَلَيْهِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ عَلَيْهِ فَقَامَ عُمَرُ فَأَخَذَ بِثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَتُصَلِّي عَلَيْهِ وَقَدْ نَهَاكَ اللَّهُ أَنْ تُصَلِّيَ عَلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا خَيَّرَنِيَ اللَّهُ فَقَالَ ‏\{‏ اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ إِنْ تَسْتَغْفِرْ لَهُمْ سَبْعِينَ مَرَّةً‏\}‏ وَسَأَزِيدُ عَلَى سَبْعِينَ ‏"‏ ‏.‏ قَالَ إِنَّهُ مُنَافِقٌ ‏.‏ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ‏\}‏ ‏.‏\hadithno{6207}\hadithtrans{Ibn Umar reported that when 'Abdullah b. Ubayy b. Salul (the hypocrite) died, his son Abdullah b. Abdullah came to Allah's Messenger (may peace be upon -him) and asked him to give his shirt which should be used for the coffin of his father. He gave that to him. Allah's Messenger (ﷺ) stood up to say prayer over him Thereupon I Umar caught hold of the clothe of Allah's Messenger (ﷺ) and said:Allah's Messenger, are you going to offer prayer, whereas Allah has forbidden to offer prayer for him, whereupon Allah's Messenger (ﷺ) said: Allah has given me a choice saying: Ask forgiveness for them or you may not ask for them; even if you ask for them seventy times, I will make an addition to the seventy. He was a hypocrite and Allah's Messenger (ﷺ) said prayer over him that Allah, the Exalted and Glorious, revealed the verse:" And never pray over any one of them that has died and never should you stand by his grave" (ix)}}
\hadithdefcmd{muslim}{6208}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ فِي مَعْنَى حَدِيثِ أَبِي أُسَامَةَ وَزَادَ قَالَ فَتَرَكَ الصَّلاَةَ عَلَيْهِمْ ‏.‏\hadithno{6208}\hadithtrans{This hadith has been narrated on the authority of 'Ubaidullah with the same chain of transmitter but with the addition of the words:" He abandoned saying prayer over the hypocrites who had died}}
\hadithdefcmd{muslim}{6209}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنْ مُحَمَّدِ بْنِ أَبِي حَرْمَلَةَ، عَنْ عَطَاءٍ، وَسُلَيْمَانَ، ابْنَىْ يَسَارٍ وَأَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُضْطَجِعًا فِي بَيْتِي كَاشِفًا عَنْ فَخِذَيْهِ أَوْ سَاقَيْهِ فَاسْتَأْذَنَ أَبُو بَكْرٍ فَأَذِنَ لَهُ وَهُوَ عَلَى تِلْكَ الْحَالِ فَتَحَدَّثَ ثُمَّ اسْتَأْذَنَ عُمَرُ فَأَذِنَ لَهُ وَهُوَ كَذَلِكَ فَتَحَدَّثَ ثُمَّ اسْتَأْذَنَ عُثْمَانُ فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَوَّى ثِيَابَهُ - قَالَ مُحَمَّدٌ وَلاَ أَقُولُ ذَلِكَ فِي يَوْمٍ وَاحِدٍ - فَدَخَلَ فَتَحَدَّثَ فَلَمَّا خَرَجَ قَالَتْ عَائِشَةُ دَخَلَ أَبُو بَكْرٍ فَلَمْ تَهْتَشَّ لَهُ وَلَمْ تُبَالِهِ ثُمَّ دَخَلَ عُمَرُ فَلَمْ تَهْتَشَّ لَهُ وَلَمْ تُبَالِهِ ثُمَّ دَخَلَ عُثْمَانُ فَجَلَسْتَ وَسَوَّيْتَ ثِيَابَكَ فَقَالَ ‏ "‏ أَلاَ أَسْتَحِي مِنْ رَجُلٍ تَسْتَحِي مِنْهُ الْمَلاَئِكَةُ ‏"‏ ‏.‏\hadithno{6209}\hadithtrans{Aisha reported:Allah's Messenger (ﷺ) was lying in the bed in my apartment with his thigh uncovered and Abu Bakr sought permission to enter. It was given to him and he conversed in the same very state (the Prophet's thigh or shank uncovered). Then `Umar sought permission for entering and it was given to him and he conversed in that very state. Then `Uthman sought permission to enter; Allah's Messenger (ﷺ) sat down and he set right his clothes. Muhammad (one of the narrators) said: I do not say that it happened on the same day. He (`Uthman) then entered and conversed and as he went out, `Aisha said: Abu Bakr entered and you did not stir and did not observe much care (in arranging your clothes), then `Umar entered and you did not stir and did not arrange your clothes, then `Uthman entered and you got up and set your clothes right, so he (ﷺ) said: Should I not show modesty to one whom even the Angels show modesty}}
\hadithdefcmd{muslim}{6210}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ، بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ يَحْيَى بْنِ سَعِيدِ بْنِ الْعَاصِ، أَنَّ سَعِيدَ بْنَ الْعَاصِ، أَخْبَرَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم وَعُثْمَانَ حَدَّثَاهُ أَنَّ أَبَا بَكْرٍ اسْتَأْذَنَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ عَلَى فِرَاشِهِ لاَبِسٌ مِرْطَ عَائِشَةَ فَأَذِنَ لأَبِي بَكْرٍ وَهُوَ كَذَلِكَ فَقَضَى إِلَيْهِ حَاجَتَهُ ثُمَّ انْصَرَفَ ثُمَّ اسْتَأْذَنَ عُمَرُ فَأَذِنَ لَهُ وَهُوَ عَلَى تِلْكَ الْحَالِ فَقَضَى إِلَيْهِ حَاجَتَهُ ثُمَّ انْصَرَفَ ‏.‏ قَالَ عُثْمَانُ ثُمَّ اسْتَأْذَنْتُ عَلَيْهِ فَجَلَسَ وَقَالَ لِعَائِشَةَ ‏"‏ اجْمَعِي عَلَيْكِ ثِيَابَكِ ‏"‏ ‏.‏ فَقَضَيْتُ إِلَيْهِ حَاجَتِي ثُمَّ انْصَرَفْتُ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ مَا لِي لَمْ أَرَكَ فَزِعْتَ لأَبِي بَكْرٍ وَعُمَرَ رَضِيَ اللَّهُ عَنْهُمَا كَمَا فَزِعْتَ لِعُثْمَانَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ عُثْمَانَ رَجُلٌ حَيِيٌّ وَإِنِّي خَشِيتُ إِنْ أَذِنْتُ لَهُ عَلَى تِلْكَ الْحَالِ أَنْ لاَ يَبْلُغَ إِلَىَّ فِي حَاجَتِهِ ‏"‏ ‏.‏\hadithno{6210}\hadithtrans{A'isha, the wife of Allah's Apostle (mav peace be upon him), and Uthman both reported that Abu Bakr sought permission from Allah's Messenger (ﷺ) for entrance (in his apartment) as he had been lying on his bed covered with the bed-sheet of A'isha, and he gave permission to Abu Bakr in that very state and he, having his need fulfilled, went back. Then Umar sought permission and it was given to him in that very state and, after having his need fulfilled, he went back. And 'Uthman reported:Then I sought permission from him and he got up and raid to A'isha: Wrap yourself well with your cloth, then I got my need fulfilled and came back. And A'isha said: Allah's Messenger, why is it that I did not see you feeling any anxiety in case of dressing properly in the presence of Abu Bakr and 'Umar (Allah be pleased with them) as you showed in case of 'Uthman. Thereupon Allah's Messenger (ﷺ) said: Verily Uthman is a person who is very modest and I was afraid that if I permitted him to enter in this very state he would not inform me of his need}}
\hadithdefcmd{muslim}{6211}{حَدَّثَنَاهُ عَمْرٌو النَّاقِدُ، وَالْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، كُلُّهُمْ عَنْ يَعْقُوبَ، بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي يَحْيَى، بْنُ سَعِيدِ بْنِ الْعَاصِ أَنَّ سَعِيدَ بْنَ الْعَاصِ، أَخْبَرَهُ أَنَّ عُثْمَانَ وَعَائِشَةَ حَدَّثَاهُ أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ اسْتَأْذَنَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ عُقَيْلٍ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{6211}\hadithtrans{This hadith has been transmitted on the authority of Uthman and A'isha with the same wording}}
\hadithdefcmd{muslim}{6212}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ عُثْمَانَ بْنِ غِيَاثٍ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَائِطٍ مِنْ حَائِطِ الْمَدِينَةِ وَهُوَ مُتَّكِئٌ يَرْكُزُ بِعُودٍ مَعَهُ بَيْنَ الْمَاءِ وَالطِّينِ إِذَا اسْتَفْتَحَ رَجُلٌ فَقَالَ ‏"‏ افْتَحْ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏ ‏.‏ قَالَ فَإِذَا أَبُو بَكْرٍ فَفَتَحْتُ لَهُ وَبَشَّرْتُهُ بِالْجَنَّةِ - قَالَ - ثُمَّ اسْتَفْتَحَ رَجُلٌ آخَرُ فَقَالَ ‏"‏ افْتَحْ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏ ‏.‏ قَالَ فَذَهَبْتُ فَإِذَا هُوَ عُمَرُ فَفَتَحْتُ لَهُ وَبَشَّرْتُهُ بِالْجَنَّةِ ثُمَّ اسْتَفْتَحَ رَجُلٌ آخَرُ - قَالَ - فَجَلَسَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ افْتَحْ وَبَشِّرْهُ بِالْجَنَّةِ عَلَى بَلْوَى تَكُونُ ‏"‏ ‏.‏ قَالَ فَذَهَبْتُ فَإِذَا هُوَ عُثْمَانُ بْنُ عَفَّانَ - قَالَ - فَفَتَحْتُ وَبَشَّرْتُهُ بِالْجَنَّةِ - قَالَ - وَقُلْتُ الَّذِي قَالَ فَقَالَ اللَّهُمَّ صَبْرًا أَوِ اللَّهُ الْمُسْتَعَانُ ‏.‏\hadithno{6212}\hadithtrans{Abu Musa al-Ash'ari reported that while Allah's Messenger (ﷺ) was in one of the gardens of Medina, reclining against a pillow and fixing a stick in a mud, that a person came asking for the gate to be opened, whereupon he said:Open it for him and give him glad tidings of Paradise and, lo, it was Abu Bakr. I opened (the gate) for him and gave him the glad tidings of Paradise. Then another person asked for the door to be opened, whereupon he said: Open it and give him the glad tidings of Piradise. He said: I went away and, lo, it was 'Umar. I opened it for him and gave him the glad tidings of Paradise. Then still another man asked for the door to be opened, and thereupon Allah's Apostle (ﷺ) said: Open it and give him the glad tidings of Paradise after a trial would afflict him. I went and, lo, it was 'Uthman b. 'Affan. 1 opened the door and gave him the glad tidings of Paradise and informed him (what the Prophet had said). Thereupon he said: O Allah, grant me steadfastness. Allah is one Whose help is to be sought}}
\hadithdefcmd{muslim}{6213}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ حَائِطًا وَأَمَرَنِي أَنْ أَحْفَظَ الْبَابَ ‏.‏ بِمَعْنَى حَدِيثِ عُثْمَانَ بْنِ غِيَاثٍ ‏.‏\hadithno{6213}\hadithtrans{This hadith has been transmitted on the authority of Abu Musa al-Ash'ari with a slight variation of wording}}
\hadithdefcmd{muslim}{6214}{حَدَّثَنَا مُحَمَّدُ بْنُ مِسْكِينٍ الْيَمَامِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا سُلَيْمَانُ، - وَهُوَ ابْنُ بِلاَلٍ - عَنْ شَرِيكِ بْنِ أَبِي نَمِرٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَخْبَرَنِي أَبُو مُوسَى الأَشْعَرِيُّ، أَنَّهُ تَوَضَّأَ فِي بَيْتِهِ ثُمَّ خَرَجَ فَقَالَ لأَلْزَمَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَلأَكُونَنَّ مَعَهُ يَوْمِي هَذَا ‏.‏ قَالَ فَجَاءَ الْمَسْجِدَ فَسَأَلَ عَنِ النَّبِيِّ صلى الله عليه وسلم فَقَالُوا خَرَجَ ‏.‏ وَجَّهَ هَا هُنَا - قَالَ - فَخَرَجْتُ عَلَى أَثَرِهِ أَسْأَلُ عَنْهُ حَتَّى دَخَلَ بِئْرَ أَرِيسٍ - قَالَ - فَجَلَسْتُ عِنْدَ الْبَابِ وَبَابُهَا مِنْ جَرِيدٍ حَتَّى قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم حَاجَتَهُ وَتَوَضَّأَ فَقُمْتُ إِلَيْهِ فَإِذَا هُوَ قَدْ جَلَسَ عَلَى بِئْرِ أَرِيسٍ وَتَوَسَّطَ قُفَّهَا وَكَشَفَ عَنْ سَاقَيْهِ وَدَلاَّهُمَا فِي الْبِئْرِ - قَالَ - فَسَلَّمْتُ عَلَيْهِ ثُمَّ انْصَرَفْتُ فَجَلَسْتُ عِنْدَ الْبَابِ فَقُلْتُ لأَكُونَنَّ بَوَّابَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْيَوْمَ ‏.‏ فَجَاءَ أَبُو بَكْرٍ فَدَفَعَ الْبَابَ فَقُلْتُ مَنْ هَذَا فَقَالَ أَبُو بَكْرٍ ‏.‏ فَقُلْتُ عَلَى رِسْلِكَ - قَالَ - ثُمَّ ذَهَبْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا أَبُو بَكْرٍ يَسْتَأْذِنُ فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏ ‏.‏ قَالَ فَأَقْبَلْتُ حَتَّى قُلْتُ لأَبِي بَكْرٍ ادْخُلْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُبَشِّرُكَ بِالْجَنَّةِ - قَالَ - فَدَخَلَ أَبُو بَكْرٍ فَجَلَسَ عَنْ يَمِينِ رَسُولِ اللَّهِ صلى الله عليه وسلم مَعَهُ فِي الْقُفِّ وَدَلَّى رِجْلَيْهِ فِي الْبِئْرِ كَمَا صَنَعَ النَّبِيُّ صلى الله عليه وسلم وَكَشَفَ عَنْ سَاقَيْهِ ثُمَّ رَجَعْتُ فَجَلَسْتُ وَقَدْ تَرَكْتُ أَخِي يَتَوَضَّأُ وَيَلْحَقُنِي فَقُلْتُ إِنْ يُرِدِ اللَّهُ بِفُلاَنٍ - يُرِيدُ أَخَاهُ - خَيْرًا يَأْتِ بِهِ ‏.‏ فَإِذَا إِنْسَانٌ يُحَرِّكُ الْبَابَ فَقُلْتُ مَنْ هَذَا فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ‏.‏ فَقُلْتُ عَلَى رِسْلِكَ ‏.‏ ثُمَّ جِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ وَقُلْتُ هَذَا عُمَرُ يَسْتَأْذِنُ فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏ ‏.‏ فَجِئْتُ عُمَرَ فَقُلْتُ أَذِنَ وَيُبَشِّرُكَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْجَنَّةِ - قَالَ - فَدَخَلَ فَجَلَسَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْقُفِّ عَنْ يَسَارِهِ وَدَلَّى رِجْلَيْهِ فِي الْبِئْرِ ثُمَّ رَجَعْتُ فَجَلَسْتُ فَقُلْتُ إِنْ يُرِدِ اللَّهُ بِفُلاَنٍ خَيْرًا - يَعْنِي أَخَاهُ - يَأْتِ بِهِ فَجَاءَ إِنْسَانٌ فَحَرَّكَ الْبَابَ فَقُلْتُ مَنْ هَذَا فَقَالَ عُثْمَانُ بْنُ عَفَّانَ ‏.‏ فَقُلْتُ عَلَى رِسْلِكَ - قَالَ - وَجِئْتُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏"‏ ائْذَنْ لَهُ وَبَشِّرْهُ بِالْجَنَّةِ مَعَ بَلْوَى تُصِيبُهُ ‏"‏ ‏.‏ قَالَ فَجِئْتُ فَقُلْتُ ادْخُلْ وَيُبَشِّرُكَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْجَنَّةِ مَعَ بَلْوَى تُصِيبُكَ - قَالَ - فَدَخَلَ فَوَجَدَ الْقُفَّ قَدْ مُلِئَ فَجَلَسَ وُجَاهَهُمْ مِنَ الشِّقِّ الآخَرِ ‏.‏ قَالَ شَرِيكٌ فَقَالَ سَعِيدُ بْنُ الْمُسَيَّبِ فَأَوَّلْتُهَا قُبُورَهُمْ ‏.‏\hadithno{6214}\hadithtrans{Abu Musa Ash'ari reported that he performed ablution in his house and then came out saying:I would remain with Allah's Messenger (ﷺ) the whole day long. He came to the mosque, and asked about Allah's Apostle (ﷺ). They (his Companions) said: He has gone in this direction. He (Abu Musa Ash'ari) said: I followed his steps asking about him until I came to Bi'r Aris (it is a well in the suburb of Medina). I sat by its wooden door until Allah's Messenger (ﷺ) had relieved himself and then performed ablution. I went to him and he was sitting with his shanks uncovered hp to the knees and his legs dangl- ing in that well. I offered him salutations. I then came back and sat at the door as if I had been a chamberlain at the door of Allah's Messenger (ﷺ) that day. There came Abu Bakr and knocked the door and I said: Who is it? He said: This is Abu Bakr. I said: Wait, please. I went and said: Allah's Messenger, here is Abu Bakr seeking permission. Thereupon he said: Admit him and give him glad tidings of Paradise. I came and I said to Abu Bakr to get in (and also told him) that Allah's Messenger (ﷺ) was giving him the glad tidings of Paradise. Abu Bakr got in and sat on the right side of Allah's Messenger (ﷺ) and dangled his feet in the well as Allah's Messenger (ﷺ) had done, and he uncovered his shanks. I then returned and sat there and I had left my brother as he had been performing ablution and he was to meet me and I said: If Allah would intend goodness for such and such he would intend goodness for his brother and He would bring him. I was thinking this that a person stirred the door. I said: Who is it. He said: This is Umar b., Khattab. I said: Wait. Then I came to Allah's Messenger (ﷺ), greeted him and said: Here is 'Umar seeking your. permission to get in. Thereupon he said: Let him come in and give him glad tid- ings of Paradise. I came to Umar and said: There is permission for you and glad tidings for you from Allah's Messenger (ﷺ) for Paradise. He got in and sat on the left side of Allah's Messenger (ﷺ) with his feet dangling in the well. I then returned and sat and said: If Allah would intend goodness for such and such (that is for his brother), He would bring him. And I was contemplat- ing over it that a man stirred the door and I said: Who is it? He said: This is Uthman b. Affan. I said: Wait, please. I then came to Allah's Messenger (ﷺ) and informed him. and he said: Admit him and give him glad tidings (and inform) him of the turmoil which he shall have to face. I came and said: Get in, Allah's Messenger (ﷺ) gives you the glad tidings of Paradise along with the trial which you shall have to face. He got in and saw the elevated plan round the well fully occupied. He sat on the other side. Sharik said that Sa'id b. al-Musayyib reported: I drew a conclusion from it that their groves would be (in this very state, the graves of Hadrat Abu Bakr, 'Umar Faruq by the tide of the Prophet [may peace be upon him] and the grave of Hadrat 'Uthman away from their graves}}
\hadithdefcmd{muslim}{6215}{حَدَّثَنِيهِ أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي شَرِيكُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ حَدَّثَنِي أَبُو مُوسَى الأَشْعَرِيُّ، هَا هُنَا - وَأَشَارَ لِي سُلَيْمَانُ إِلَى مَجْلِسِ سَعِيدٍ نَاحِيَةَ الْمَقْصُورَةِ - قَالَ أَبُو مُوسَى خَرَجْتُ أُرِيدُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَوَجَدْتُهُ قَدْ سَلَكَ فِي الأَمْوَالِ فَتَبِعْتُهُ فَوَجَدْتُهُ قَدْ دَخَلَ مَالاً فَجَلَسَ فِي الْقُفِّ وَكَشَفَ عَنْ سَاقَيْهِ وَدَلاَّهُمَا فِي الْبِئْرِ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ يَحْيَى بْنِ حَسَّانَ وَلَمْ يَذْكُرْ قَوْلَ سَعِيدٍ فَأَوَّلْتُهَا قُبُورَهُمْ ‏.‏\hadithno{6215}\hadithtrans{Abu Musa. reported:I set out with the intention (of meeting) Allah's Messenger (ﷺ) and came to know that he had gone to the gardens (in the suburb of Medina). I followed him and found him in a garden sitting upon an elevated place round the well with his shanks uncovered which had been dangling in the well. The rest of the hadith is the same but with this variation that there is no mention of the words of Sa'id: all drew a conclusion from it pertaining to their graves}}
\hadithdefcmd{muslim}{6216}{حَدَّثَنَا حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالاَ حَدَّثَنَا سَعِيدُ بْنُ أَبِي، مَرْيَمَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرِ بْنِ أَبِي كَثِيرٍ، أَخْبَرَنِي شَرِيكُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ سَعِيدِ، بْنِ الْمُسَيَّبِ عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا إِلَى حَائِطٍ بِالْمَدِينَةِ لِحَاجَتِهِ فَخَرَجْتُ فِي إِثْرِهِ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمَعْنَى حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ وَذَكَرَ فِي الْحَدِيثِ قَالَ ابْنُ الْمُسَيَّبِ ‏.‏ فَتَأَوَّلْتُ ذَلِكَ قُبُورَهُمُ اجْتَمَعَتْ هَا هُنَا وَانْفَرَدَ عُثْمَانُ ‏.‏\hadithno{6216}\hadithtrans{Sa'id b. al-Musayyib reported Abu Musa Ash'ari having said that Allah's Messenger (ﷺ) set out one day to the suburbs of Medina for reliev- ing himself. I followed his steps. The rest of the hadith is the same. Ibn Musayyib said:I concluded (from the manner of their sitting) the (order) of their graves. (The three) would be together (the graves of the Holy Prophet, Hadrat Abu Bakr and Hadrat Umar) and that of 'Uthman would be separate (from them)}}
\hadithdefcmd{muslim}{6217}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو جَعْفَرٍ مُحَمَّدُ بْنُ الصَّبَّاحِ وَعُبَيْدُ اللَّهِ الْقَوَارِيرِيُّ وَسُرَيْجُ بْنُ يُونُسَ كُلُّهُمْ عَنْ يُوسُفَ الْمَاجِشُونِ، - وَاللَّفْظُ لاِبْنِ الصَّبَّاحِ - حَدَّثَنَا يُوسُفُ، أَبُو سَلَمَةَ الْمَاجِشُونُ حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَامِرِ بْنِ سَعْدِ، بْنِ أَبِي وَقَّاصٍ عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَلِيٍّ ‏ "‏ أَنْتَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى إِلاَّ أَنَّهُ لاَ نَبِيَّ بَعْدِي ‏"‏ ‏.‏ قَالَ سَعِيدٌ فَأَحْبَبْتُ أَنْ أُشَافِهَ بِهَا سَعْدًا فَلَقِيتُ سَعْدًا فَحَدَّثْتُهُ بِمَا حَدَّثَنِي عَامِرٌ فَقَالَ أَنَا سَمِعْتُهُ ‏.‏ فَقُلْتُ آنْتَ سَمِعْتَهُ فَوَضَعَ إِصْبَعَيْهِ عَلَى أُذُنَيْهِ فَقَالَ نَعَمْ وَإِلاَّ فَاسْتَكَّتَا ‏.‏\hadithno{6217}\hadithtrans{Amir b Sa'd b. Abi Waqqas reported (on the authority of his father that Allah's Messenger (ﷺ) addressing 'Ali said:You are in the same position with relation to me as Aaron (Harun) was in relation to Moses but with (this explicit difference) that there is no prophet after me. Sa'd said: I had an earnest desire to hear it directly from Sa'd, so I met him and narrated to him what (his son) Amir had narrated to me, whereupon he said: Yes, I did hear it. I said: Did you hear it yourself? Thereupon he placed his fingers upon his ears and said: Yes, and if not, let both my ears become deaf}}
\hadithdefcmd{muslim}{6218}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُصْعَبِ بْنِ سَعْدِ بْنِ، أَبِي وَقَّاصٍ عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ خَلَّفَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ فِي غَزْوَةِ تَبُوكَ فَقَالَ يَا رَسُولَ اللَّهِ تُخَلِّفُنِي فِي النِّسَاءِ وَالْصِّبْيَانِ فَقَالَ ‏ "‏ أَمَا تَرْضَى أَنْ تَكُونَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى غَيْرَ أَنَّهُ لاَ نَبِيَّ بَعْدِي ‏"‏ ‏.‏\hadithno{6218}\hadithtrans{Sa'd b. Abi Waqqas reported that Allah's Messenger (ﷺ) left 'Ali b. Abi Talib behind him (as he proceeded) to the expedition of Tabuk, whereupon he ('Ali) said:Allah's Messenger, are you leaving me behind amongst women and children? Thereupon he (the Holy Prophet) said: Aren't you satisfied with being unto me what Aaron was unto Moses but with this exception that there would be no prophet after me?}}
\hadithdefcmd{muslim}{6219}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{6219}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6220}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عَبَّادٍ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنْ بُكَيْرِ بْنِ مِسْمَارٍ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ أَمَرَ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ سَعْدًا فَقَالَ مَا مَنَعَكَ أَنْ تَسُبَّ أَبَا التُّرَابِ فَقَالَ أَمَّا مَا ذَكَرْتُ ثَلاَثًا قَالَهُنَّ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَنْ أَسُبَّهُ لأَنْ تَكُونَ لِي وَاحِدَةٌ مِنْهُنَّ أَحَبُّ إِلَىَّ مِنْ حُمْرِ النَّعَمِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لَهُ خَلَّفَهُ فِي بَعْضِ مَغَازِيهِ فَقَالَ لَهُ عَلِيٌّ يَا رَسُولَ اللَّهِ خَلَّفْتَنِي مَعَ النِّسَاءِ وَالصِّبْيَانِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا تَرْضَى أَنْ تَكُونَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى إِلاَّ أَنَّهُ لاَ نُبُوَّةَ بَعْدِي ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ يَوْمَ خَيْبَرَ ‏"‏ لأُعْطِيَنَّ الرَّايَةَ رَجُلاً يُحِبُّ اللَّهَ وَرَسُولَهُ وَيُحِبُّهُ اللَّهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ فَتَطَاوَلْنَا لَهَا فَقَالَ ‏"‏ ادْعُوا لِي عَلِيًّا ‏"‏ ‏.‏ فَأُتِيَ بِهِ أَرْمَدَ فَبَصَقَ فِي عَيْنِهِ وَدَفَعَ الرَّايَةَ إِلَيْهِ فَفَتَحَ اللَّهُ عَلَيْهِ وَلَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ فَقُلْ تَعَالَوْا نَدْعُ أَبْنَاءَنَا وَأَبْنَاءَكُمْ‏\}‏ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيًّا وَفَاطِمَةَ وَحَسَنًا وَحُسَيْنًا فَقَالَ ‏"‏ اللَّهُمَّ هَؤُلاَءِ أَهْلِي ‏"‏ ‏.‏\hadithno{6220}\hadithtrans{Amir b. Sa'd b. Abi Waqqas reported on the authority of his father that Muawiya b. Abi Sufyan appointed Sa'd as the Governor and said:What prevents you from rebuking Abu Turab (Hadrat 'Ali), whereupon be said: It is because of three things which I remember Allah's Messenger (ﷺ) having said about him that I would not rebuke him and even if I find one of those three things for me, it would be more dear to me than the red camels. I heard Allah's Messenger (ﷺ) say about 'Ali as he left him behind in one of his campaigns (that was Tabuk). 'Ali said to him: Allah's Messenger, you leave me behind along with women and children. Thereupon Allah's Messenger (ﷺ) said to him: Aren't you satisfied with being unto me what Aaron was unto Moses but with this exception that there is no prophethood after me. And I (also) heard him say on the Day of Khaibar: I would certainly give this standard to a person who loves Allah and his Messenger, and Allah and his Messenger love him too. He (the narrator) said: We had been anxiously waiting for it, when he (the Holy Prophet) said: Call 'Ali. He was called and his eyes were inflamed. He applied saliva to his eyes and handed over the standard to him, and Allah gave him victory. (The third occasion is this) when the (following) verse was revealed: "Let us summon our children and your children." Allah's Messenger (ﷺ) called 'Ali, Fatima, Hasan and Husain and said: O Allah, they are my family}}
\hadithdefcmd{muslim}{6221}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، سَمِعْتُ إِبْرَاهِيمَ، بْنَ سَعْدٍ عَنْ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ لِعَلِيٍّ ‏ "‏ أَمَا تَرْضَى أَنْ تَكُونَ مِنِّي بِمَنْزِلَةِ هَارُونَ مِنْ مُوسَى ‏"‏ ‏.‏\hadithno{6221}\hadithtrans{Sa'd reported Allah's Apostle (ﷺ) as saying to 'Ali:Aren't you satisfied with being unto me what Aaron was unto Moses?}}
\hadithdefcmd{muslim}{6222}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَوْمَ خَيْبَرَ ‏"‏ لأُعْطِيَنَّ هَذِهِ الرَّايَةَ رَجُلاً يُحِبُّ اللَّهَ وَرَسُولَهُ يَفْتَحُ اللَّهُ عَلَى يَدَيْهِ ‏"‏ ‏.‏ قَالَ عُمَرُ بْنُ الْخَطَّابِ مَا أَحْبَبْتُ الإِمَارَةَ إِلاَّ يَوْمَئِذٍ - قَالَ - فَتَسَاوَرْتُ لَهَا رَجَاءَ أَنْ أُدْعَى لَهَا - قَالَ - فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ فَأَعْطَاهُ إِيَّاهَا وَقَالَ ‏"‏ امْشِ وَلاَ تَلْتَفِتْ حَتَّى يَفْتَحَ اللَّهُ عَلَيْكَ ‏"‏ ‏.‏ قَالَ فَسَارَ عَلِيٌّ شَيْئًا ثُمَّ وَقَفَ وَلَمْ يَلْتَفِتْ فَصَرَخَ يَا رَسُولَ اللَّهِ عَلَى مَاذَا أُقَاتِلُ النَّاسَ قَالَ ‏"‏ قَاتِلْهُمْ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ فَإِذَا فَعَلُوا ذَلِكَ فَقَدْ مَنَعُوا مِنْكَ دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{6222}\hadithtrans{Suhail reported on the authority of Abu Huraira that Allah's Messenger (ﷺ) said on the Day of Khaibar:I shall certainly give this standard in the hand of one who loves Allah and his Messenger and Allah will grant victory at his hand. Umar b. Khattab said: Never did I cherish for leadership but on that day. I came before him with the hope that I may be called for this, but Allah's Messenger (ﷺ) called 'Ali b. Abu Talib and he conferred (this honour) upon him and said: Proceed on and do not look about until Allah grants you victory, and 'Ali went a bit and then halted and did not look about and then said in a loud voice: Allah's Messenger, on what issue should I fight with the people? Thereupon he (the Prophet) said: Fight with them until they bear testimony to the fact that there is no god but Allah and Muhammad is his Messenger, and when they do that then their blood and their riches are inviolable from your hands but what is justified by law and their reckoning is with Allah}}
\hadithdefcmd{muslim}{6223}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ أَبِي حَازِمٍ - عَنْ أَبِي، حَازِمٍ عَنْ سَهْلٍ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، - وَاللَّفْظُ هَذَا - حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ أَبِي حَازِمٍ، أَخْبَرَنِي سَهْلُ بْنُ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَوْمَ خَيْبَرَ ‏"‏ لأُعْطِيَنَّ هَذِهِ الرَّايَةَ رَجُلاً يَفْتَحُ اللَّهُ عَلَى يَدَيْهِ يُحِبُّ اللَّهَ وَرَسُولَهُ وَيُحِبُّهُ اللَّهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ فَبَاتَ النَّاسُ يَدُوكُونَ لَيْلَتَهُمْ أَيُّهُمْ يُعْطَاهَا - قَالَ - فَلَمَّا أَصْبَحَ النَّاسُ غَدَوْا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كُلُّهُمْ يَرْجُونَ أَنْ يُعْطَاهَا فَقَالَ ‏"‏ أَيْنَ عَلِيُّ بْنُ أَبِي طَالِبٍ ‏"‏ ‏.‏ فَقَالُوا هُوَ يَا رَسُولَ اللَّهِ يَشْتَكِي عَيْنَيْهِ - قَالَ - فَأَرْسَلُوا إِلَيْهِ فَأُتِيَ بِهِ فَبَصَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي عَيْنَيْهِ وَدَعَا لَهُ فَبَرَأَ حَتَّى كَأَنْ لَمْ يَكُنْ بِهِ وَجَعٌ فَأَعْطَاهُ الرَّايَةَ فَقَالَ عَلِيٌّ يَا رَسُولَ اللَّهِ أُقَاتِلُهُمْ حَتَّى يَكُونُوا مِثْلَنَا ‏.‏ فَقَالَ ‏"‏ انْفُذْ عَلَى رِسْلِكَ حَتَّى تَنْزِلَ بِسَاحَتِهِمْ ثُمَّ ادْعُهُمْ إِلَى الإِسْلاَمِ وَأَخْبِرْهُمْ بِمَا يَجِبُ عَلَيْهِمْ مِنْ حَقِّ اللَّهِ فِيهِ فَوَاللَّهِ لأَنْ يَهْدِيَ اللَّهُ بِكَ رَجُلاً وَاحِدًا خَيْرٌ لَكَ مِنْ أَنْ يَكُونَ لَكَ حُمْرُ النَّعَمِ ‏"‏ ‏.‏\hadithno{6223}\hadithtrans{Sahl b. Sa'd reported that Allah's Messenger (ﷺ) said on the Day of Khaibar:I would certainly give this standard to a person at whose hand Allah would grant victory and who loves Allah and His Messenger and Allah and His Messenger love him also. The people spent the night thinking as to whom it would be given. When it was morning the people hastened to Allah's Messenger (ﷺ) all of them hoping that that would be given to him. He (the Holy Prophet) said: Where is 'Ali b. Abu Talib? They said: Allah's Messenger, his eyes are sore. He then sent for him and he was brought and Allah's Messenger (ﷺ) applied saliva to his eyes and invoked blessings and he was all right, as if he had no ailment at all, and conferred upon him the standard. 'Ali said: Allah's Messenger, I will fight them until they are like us. Thereupon he (the Holy Prophet) said: Advance cautiously until you reach their open places, thereafter invite them to Islam and inform them what is obligatory for them from the rights of Allah, for, by Allah, if Allah guides aright even one person through you that is better for you than to possess the most valuable of the camels}}
\hadithdefcmd{muslim}{6224}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي، عُبَيْدٍ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ كَانَ عَلِيٌّ قَدْ تَخَلَّفَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي خَيْبَرَ وَكَانَ رَمِدًا فَقَالَ أَنَا أَتَخَلَّفُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَخَرَجَ عَلِيٌّ فَلَحِقَ بِالنَّبِيِّ صلى الله عليه وسلم فَلَمَّا كَانَ مَسَاءُ اللَّيْلَةِ الَّتِي فَتَحَهَا اللَّهُ فِي صَبَاحِهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأُعْطِيَنَّ الرَّايَةَ - أَوْ لَيَأْخُذَنَّ بِالرَّايَةِ - غَدًا رَجُلٌ يُحِبُّهُ اللَّهُ وَرَسُولُهُ أَوْ قَالَ يُحِبُّ اللَّهَ وَرَسُولَهُ يَفْتَحُ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏ فَإِذَا نَحْنُ بِعَلِيٍّ وَمَا نَرْجُوهُ فَقَالُوا هَذَا عَلِيٌّ ‏.‏ فَأَعْطَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّايَةَ فَفَتَحَ اللَّهُ عَلَيْهِ ‏.‏\hadithno{6224}\hadithtrans{Salama b. Akwa' reported that it was 'Ali whom Allah's Apostle (ﷺ) left behind him (in the charge of his family and the Islamic State) on the occasion of the campaign of Khaibar, and his eyes were inflamed and he said:Is it for me to remain behind Allah's Messenger (ﷺ)? So he went forth and rejoined Allah's Apostle (ﷺ) and on the evening of that night (after which) next morning Allah granted victory. Allah's Messenger (ﷺ) said: I will certainly give this standard to a man whom Allah and His Messenger love. or he said: Who loves Allah or His Messenger and Allah will grant him victory through him, and, lo, we saw 'Ali whom we least expected (to be present on that occasion). They (the Companions) said: Here is 'Ali. Thereupon Allah's Messenger (may peace be upon hin) gave him the standard. Allah granted victory at his hand}}
\hadithdefcmd{muslim}{6225}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَشُجَاعُ بْنُ مَخْلَدٍ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، قَالَ زُهَيْرٌ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي أَبُو حَيَّانَ، حَدَّثَنِي يَزِيدُ بْنُ حَيَّانَ، قَالَ انْطَلَقْتُ أَنَا وَحُصَيْنُ، بْنُ سَبْرَةَ وَعُمَرُ بْنُ مُسْلِمٍ إِلَى زَيْدِ بْنِ أَرْقَمَ فَلَمَّا جَلَسْنَا إِلَيْهِ قَالَ لَهُ حُصَيْنٌ لَقَدْ لَقِيتَ يَا زَيْدُ خَيْرًا كَثِيرًا رَأَيْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَمِعْتَ حَدِيثَهُ وَغَزَوْتَ مَعَهُ وَصَلَّيْتَ خَلْفَهُ لَقَدْ لَقِيتَ يَا زَيْدُ خَيْرًا كَثِيرًا حَدِّثْنَا يَا زَيْدُ مَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - يَا ابْنَ أَخِي وَاللَّهِ لَقَدْ كَبِرَتْ سِنِّي وَقَدُمَ عَهْدِي وَنَسِيتُ بَعْضَ الَّذِي كُنْتُ أَعِي مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَا حَدَّثْتُكُمْ فَاقْبَلُوا وَمَا لاَ فَلاَ تُكَلِّفُونِيهِ ‏.‏ ثُمَّ قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فِينَا خَطِيبًا بِمَاءٍ يُدْعَى خُمًّا بَيْنَ مَكَّةَ وَالْمَدِينَةِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَوَعَظَ وَذَكَّرَ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ أَلاَ أَيُّهَا النَّاسُ فَإِنَّمَا أَنَا بَشَرٌ يُوشِكُ أَنْ يَأْتِيَ رَسُولُ رَبِّي فَأُجِيبَ وَأَنَا تَارِكٌ فِيكُمْ ثَقَلَيْنِ أَوَّلُهُمَا كِتَابُ اللَّهِ فِيهِ الْهُدَى وَالنُّورُ فَخُذُوا بِكِتَابِ اللَّهِ وَاسْتَمْسِكُوا بِهِ ‏"‏ ‏.‏ فَحَثَّ عَلَى كِتَابِ اللَّهِ وَرَغَّبَ فِيهِ ثُمَّ قَالَ ‏"‏ وَأَهْلُ بَيْتِي أُذَكِّرُكُمُ اللَّهَ فِي أَهْلِ بَيْتِي أُذَكِّرُكُمُ اللَّهَ فِي أَهْلِ بَيْتِي أُذَكِّرُكُمُ اللَّهَ فِي أَهْلِ بَيْتِي ‏"‏ ‏.‏ فَقَالَ لَهُ حُصَيْنٌ وَمَنْ أَهْلُ بَيْتِهِ يَا زَيْدُ أَلَيْسَ نِسَاؤُهُ مِنْ أَهْلِ بَيْتِهِ قَالَ نِسَاؤُهُ مِنْ أَهْلِ بَيْتِهِ وَلَكِنْ أَهْلُ بَيْتِهِ مَنْ حُرِمَ الصَّدَقَةَ بَعْدَهُ ‏.‏ قَالَ وَمَنْ هُمْ قَالَ هُمْ آلُ عَلِيٍّ وَآلُ عَقِيلٍ وَآلُ جَعْفَرٍ وَآلُ عَبَّاسٍ ‏.‏ قَالَ كُلُّ هَؤُلاَءِ حُرِمَ الصَّدَقَةَ قَالَ نَعَمْ ‏.‏\hadithno{6225}\hadithtrans{Yazid b. Hayyan reported, I went along with Husain b. Sabra and 'Umar b. Muslim to Zaid b. Arqam and, as we sat by his side, Husain said to him:Zaid. you have been able to acquire a great virtue that you saw Allah's Messenger (ﷺ) listened to his talk, fought by his side in (different) battles, offered prayer behind me. Zaid, you have in fact earned a great virtue. Zaid, narrate to us what you heard from Allah's Messenger (ﷺ). He said: I have grown old and have almost spent my age and I have forgotten some of the things which I remembered in connection with Allah's Messenger (ﷺ), so accept whatever I narrate to you, and which I do not narrate do not compel me to do that. He then said: One day Allah's Messenger (ﷺ) stood up to deliver sermon at a watering place known as Khumm situated between Mecca and Medina. He praised Allah, extolled Him and delivered the sermon and. exhorted (us) and said: Now to our purpose. O people, I am a human being. I am about to receive a messenger (the angel of death) from my Lord and I, in response to Allah's call, (would bid good-bye to you), but I am leaving among you two weighty things: the one being the Book of Allah in which there is right guidance and light, so hold fast to the Book of Allah and adhere to it. He exhorted (us) (to hold fast) to the Book of Allah and then said: The second are the members of my household I remind you (of your duties) to the members of my family. He (Husain) said to Zaid: Who are the members of his household? Aren't his wives the members of his family? Thereupon he said: His wives are the members of his family (but here) the members of his family are those for whom acceptance of Zakat is forbidden. And he said: Who are they? Thereupon he said: 'Ali and the offspring of 'Ali, 'Aqil and the offspring of 'Aqil and the offspring of Ja'far and the offspring of 'Abbas. Husain said: These are those for whom the acceptance of Zakat is forbidden. Zaid said: Yes}}
\hadithdefcmd{muslim}{6226}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ الرَّيَّانِ، حَدَّثَنَا حَسَّانُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ يَزِيدَ بْنِ حَيَّانَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِهِ بِمَعْنَى حَدِيثِ زُهَيْرٍ ‏.‏\hadithno{6226}\hadithtrans{This hadith has been narrated on the authority of Zaid b. Arqam through another chain of transmitters}}
\hadithdefcmd{muslim}{6227}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، كِلاَهُمَا عَنْ أَبِي حَيَّانَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ إِسْمَاعِيلَ وَزَادَ فِي حَدِيثِ جَرِيرٍ ‏ "‏ كِتَابُ اللَّهِ فِيهِ الْهُدَى وَالنُّورُ مَنِ اسْتَمْسَكَ بِهِ وَأَخَذَ بِهِ كَانَ عَلَى الْهُدَى وَمَنْ أَخْطَأَهُ ضَلَّ ‏"‏ ‏.‏\hadithno{6227}\hadithtrans{This hadith has been transmitted on the authority of Abu Hayyan but with this addition:" The Book of Allah contains right guidance, the light, and whoever adheres to it and holds it fast, he is upon right guidance and whosoever deviates from it goes astray}}
\hadithdefcmd{muslim}{6228}{حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ الرَّيَّانِ، حَدَّثَنَا حَسَّانُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - عَنْ سَعِيدٍ، - وَهُوَ ابْنُ مَسْرُوقٍ - عَنْ يَزِيدَ بْنِ حَيَّانَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ دَخَلْنَا عَلَيْهِ فَقُلْنَا لَهُ لَقَدْ رَأَيْتَ خَيْرًا ‏.‏ لَقَدْ صَاحَبْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَصَلَّيْتَ خَلْفَهُ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ أَبِي حَيَّانَ غَيْرَ أَنَّهُ قَالَ ‏ "‏ أَلاَ وَإِنِّي تَارِكٌ فِيكُمْ ثَقَلَيْنِ أَحَدُهُمَا كِتَابُ اللَّهِ عَزَّ وَجَلَّ هُوَ حَبْلُ اللَّهِ مَنِ اتَّبَعَهُ كَانَ عَلَى الْهُدَى وَمَنْ تَرَكَهُ كَانَ عَلَى ضَلاَلَةٍ ‏"‏ ‏.‏ وَفِيهِ فَقُلْنَا مَنْ أَهْلُ بَيْتِهِ نِسَاؤُهُ قَالَ لاَ وَايْمُ اللَّهِ إِنَّ الْمَرْأَةَ تَكُونُ مَعَ الرَّجُلِ الْعَصْرَ مِنَ الدَّهْرِ ثُمَّ يُطَلِّقُهَا فَتَرْجِعُ إِلَى أَبِيهَا وَقَوْمِهَا أَهْلُ بَيْتِهِ أَصْلُهُ وَعَصَبَتُهُ الَّذِينَ حُرِمُوا الصَّدَقَةَ بَعْدَهُ ‏.‏\hadithno{6228}\hadithtrans{Yazid b. Hayyan reported:We went to him (Zaid b. Arqam) and said to him. You have found goodness (for you had the honour) to live in the company of Allah's Messenger (ﷺ) and offered prayer behind him, and the rest of the hadith is the same but with this variation of wording that lie said: Behold, for I am leaving amongst you two weighty things, one of which is the Book of Allah, the Exalted and Glorious, and that is the rope of Allah. He who holds it fast would be on right guidance and he who abandons it would be in error, and in this (hadith) these words are also found: We said: Who are amongst the members of the household? Aren't the wives (of the Holy Prophet) included amongst the members of his house hold? Thereupon he said: No, by Allah, a woman lives with a man (as his wife) for a certain period; he then divorces her and she goes back to her parents and to her people; the members of his household include his ownself and his kith and kin (who are related to him by blood) and for him the acceptance of Zakat is prohibited}}
\hadithdefcmd{muslim}{6229}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ أَبِي حَازِمٍ - عَنْ أَبِي، حَازِمٍ عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ اسْتُعْمِلَ عَلَى الْمَدِينَةِ رَجُلٌ مِنْ آلِ مَرْوَانَ - قَالَ - فَدَعَا سَهْلَ بْنَ سَعْدٍ فَأَمَرَهُ أَنْ يَشْتِمَ عَلِيًّا - قَالَ - فَأَبَى سَهْلٌ فَقَالَ لَهُ أَمَّا إِذْ أَبَيْتَ فَقُلْ لَعَنَ اللَّهُ أَبَا التُّرَابِ ‏.‏ فَقَالَ سَهْلٌ مَا كَانَ لِعَلِيٍّ اسْمٌ أَحَبَّ إِلَيْهِ مِنْ أَبِي التُّرَابِ وَإِنْ كَانَ لَيَفْرَحُ إِذَا دُعِيَ بِهَا ‏.‏ فَقَالَ لَهُ أَخْبِرْنَا عَنْ قِصَّتِهِ لِمَ سُمِّيَ أَبَا تُرَابٍ قَالَ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْتَ فَاطِمَةَ فَلَمْ يَجِدْ عَلِيًّا فِي الْبَيْتِ فَقَالَ ‏"‏ أَيْنَ ابْنُ عَمِّكِ ‏"‏ ‏.‏ فَقَالَتْ كَانَ بَيْنِي وَبَيْنَهُ شَىْءٌ فَغَاضَبَنِي فَخَرَجَ فَلَمْ يَقِلْ عِنْدِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لإِنْسَانٍ ‏"‏ انْظُرْ أَيْنَ هُوَ ‏"‏ ‏.‏ فَجَاءَ فَقَالَ يَا رَسُولَ اللَّهِ هُوَ فِي الْمَسْجِدِ رَاقِدٌ ‏.‏ فَجَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ قَدْ سَقَطَ رِدَاؤُهُ عَنْ شِقِّهِ فَأَصَابَهُ تُرَابٌ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْسَحُهُ عَنْهُ وَيَقُولُ ‏"‏ قُمْ أَبَا التُّرَابِ قُمْ أَبَا التُّرَابِ ‏"‏ ‏.‏\hadithno{6229}\hadithtrans{Sahl b. Sa`d reported that a person from the offspring of Marwan was appointed as the governor of Medina. He called Sahl b. Sa`d and ordered him to abuse `Ali. Sahl refused to do that. He (the governor) said to him:If you do not agree to it (at least) say: May Allah curse Abu Turab. Sahl said: There was no name dearer to `Ali than Abu Turab (for it was given to him by the Prophet himself) and he felt delighted when he was called by this name. He (the governor) said to him: Narrate to us the story of his being named as Abu Turab. He said: Allah's Messenger (ﷺ) came to the house of Fatima and he did not find `Ali in the house; whereupon he said: Where is your uncle's son? She said: (There cropped up something) between me and him which had annoyed him with me. He went out and did not rest here. Allah's Messenger (ﷺ) asked a person to find out where he was. He came and said: Allah's Messenger, he is sleeping in the mosque. Allah's Messenger (ﷺ) came to him and found him lying in the mosque and saw that his mantle had slipped from his back and his back was covered with dust and Allah's Messenger (ﷺ) began to wipe it away from him (from the body of Hadrat `Ali) saying: Get up, covered with dust (Abu Turab); get up, covered with dust}}
\hadithdefcmd{muslim}{6230}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ عَائِشَةَ، قَالَتْ أَرِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَقَالَ لَيْتَ رَجُلاً صَالِحًا مِنْ أَصْحَابِي يَحْرُسُنِي اللَّيْلَةَ ‏.‏ قَالَتْ وَسَمِعْنَا صَوْتَ السِّلاَحِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ هَذَا ‏"‏ ‏.‏ قَالَ سَعْدُ بْنُ أَبِي وَقَّاصٍ يَا رَسُولَ اللَّهِ جِئْتُ أَحْرُسُكَ ‏.‏ قَالَتْ عَائِشَةُ فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى سَمِعْتُ غَطِيطَهُ ‏.‏\hadithno{6230}\hadithtrans{A'isha reported that Allah's Messenger (may peace he upon him) lay on bed during one night and said:Were there a pious person from amongst my companions who should keep a watch for me during the nightt? She said: We heard the noise of arms, whereupon Allah's Messenger (ﷺ) said: Who is it? And Sa'd b. Abi Waqqas said: Allah's MesseDger. I have come to serve as your sentinel. 'A'isha said: Allah' s Messenger (ﷺ) slept (such a sound sleep) that I heard the noise of his snoring}}
\hadithdefcmd{muslim}{6231}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، أَنَّ عَائِشَةَ، قَالَتْ سَهِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَقْدَمَهُ الْمَدِينَةَ لَيْلَةً فَقَالَ ‏"‏ لَيْتَ رَجُلاً صَالِحًا مِنْ أَصْحَابِي يَحْرُسُنِي اللَّيْلَةَ ‏"‏ ‏.‏ قَالَتْ فَبَيْنَا نَحْنُ كَذَلِكَ سَمِعْنَا خَشْخَشَةَ سِلاَحٍ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ قَالَ سَعْدُ بْنُ أَبِي وَقَّاصٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا جَاءَ بِكَ ‏"‏ ‏.‏ قَالَ وَقَعَ فِي نَفْسِي خَوْفٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَجِئْتُ أَحْرُسُهُ ‏.‏ فَدَعَا لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ نَامَ ‏.‏ وَفِي رِوَايَةِ ابْنِ رُمْحٍ فَقُلْنَا مَنْ هَذَا\hadithno{6231}\hadithtrans{A'isha reported that Allah's Messenger (may peace he upon him) laid down on bed during one night on his arrival at Medina and said:Were there a pious person from amongst my Companions who should keep a watch for me durin. the night? She (A'isha) reported: We were in this state that we heard the clanging noise of arms. lie (the Holy Prophet) said: Who is it? He said: This is Sa'd b. Abi Waqqas. Allah's Messenger (ﷺ) said to him: What brings you here? Thereupon he said: I harboured fear (lest any harm should come to) Allah's Messenger (ﷺ), so I came to serve as your sentinel. Allah's Messenger (ﷺ) invoked blessings upon him. He then slept. This hadith has been transmitted on the authority of Ibn Rumh with a slight variation of wording}}
\hadithdefcmd{muslim}{6232}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ، يَقُولُ قَالَتْ عَائِشَةُ أَرِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ ‏.‏ بِمِثْلِ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ ‏.‏\hadithno{6232}\hadithtrans{Abdullah b. 'Amir b. Rabi reported A'isha as saying:Allah's Messenger (ﷺ) went to bed one night; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6233}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ مَا جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ لأَحَدٍ غَيْرَ سَعْدِ بْنِ مَالِكٍ فَإِنَّهُ جَعَلَ يَقُولُ لَهُ يَوْمَ أُحُدٍ ‏ "‏ ارْمِ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏\hadithno{6233}\hadithtrans{Abdullah b. Shaddad reported that he heard `Ali saying:Allah's Messenger (ﷺ) did not gather his parents except in case of Sa`d b. Malik that he said to him on the Day of Uhud: Shoot an arrow, may my father and mother be taken as ransom for you}}
\hadithdefcmd{muslim}{6234}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، ح حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَإِسْحَاقُ الْحَنْظَلِيُّ، عَنْ مُحَمَّدِ بْنِ بِشْرٍ، عَنْ مِسْعَرٍ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، كُلُّهُمْ عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6234}\hadithtrans{This hadith has been narrated on the authority of 'Ali through another chain of transmitters}}
\hadithdefcmd{muslim}{6235}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ سَعِيدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ لَقَدْ جَمَعَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ يَوْمَ أُحُدٍ ‏.‏\hadithno{6235}\hadithtrans{Sa'd b Abi Waqqqs said:Allah's Messenger (may peace he upon him) gathered his parents for me on the Day of Uhud}}
\hadithdefcmd{muslim}{6236}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، كِلاَهُمَا عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6236}\hadithtrans{This hadith has been narrated on the authority of Yabyl b. Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{6237}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ بُكَيْرِ بْنِ مِسْمَارٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَمَعَ لَهُ أَبَوَيْهِ يَوْمَ أُحُدٍ ‏.‏ قَالَ كَانَ رَجُلٌ مِنَ الْمُشْرِكِينَ قَدْ أَحْرَقَ الْمُسْلِمِينَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ارْمِ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏ قَالَ فَنَزَعْتُ لَهُ بِسَهْمٍ لَيْسَ فِيهِ نَصْلٌ فَأَصَبْتُ جَنْبَهُ فَسَقَطَ فَانْكَشَفَتْ عَوْرَتُهُ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى نَظَرْتُ إِلَى نَوَاجِذِهِ ‏.‏\hadithno{6237}\hadithtrans{Amir b. Sa'd reported oLi the authority of his father that Allah's Apostle (ﷺ) gathered for him on the Day of Uhud his parents when a polytheist had set fire to (i. e. attacked fiercely) the Muslims. Thereupon Allah's Apostle (ﷺ) said to him:(Sa'd), shoot an arrow, (Sa'd), may my mother and father be taken as ransom for you. I drew an arrow and I shot a featherless arrow at him aiming his side that lie fell down and his private parts were exposed. Allah's Messenger (ﷺ) laughed that I saw his front teeth}}
\hadithdefcmd{muslim}{6238}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، حَدَّثَنِي مُصْعَبُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، أَنَّهُ نَزَلَتْ فِيهِ آيَاتٌ مِنَ الْقُرْآنِ - قَالَ - حَلَفَتْ أُمُّ سَعْدٍ أَنْ لاَ تُكَلِّمَهُ أَبَدًا حَتَّى يَكْفُرَ بِدِينِهِ وَلاَ تَأْكُلَ وَلاَ تَشْرَبَ ‏.‏ قَالَتْ زَعَمْتَ أَنَّ اللَّهَ وَصَّاكَ بِوَالِدَيْكَ وَأَنَا أُمُّكَ وَأَنَا آمُرُكَ بِهَذَا ‏.‏ قَالَ مَكَثَتْ ثَلاَثًا حَتَّى غُشِيَ عَلَيْهَا مِنَ الْجَهْدِ فَقَامَ ابْنٌ لَهَا يُقَالُ لَهُ عُمَارَةُ فَسَقَاهَا فَجَعَلَتْ تَدْعُو عَلَى سَعْدٍ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي الْقُرْآنِ هَذِهِ الآيَةَ ‏\{‏ وَوَصَّيْنَا الإِنْسَانَ بِوَالِدَيْهِ حُسْنًا‏\}‏ ‏\{‏ وَإِنْ جَاهَدَاكَ عَلَى أَنْ تُشْرِكَ بِي‏\}‏ وَفِيهَا ‏\{‏ وَصَاحِبْهُمَا فِي الدُّنْيَا مَعْرُوفًا‏\}‏ قَالَ وَأَصَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَنِيمَةً عَظِيمَةً فَإِذَا فِيهَا سَيْفٌ فَأَخَذْتُهُ فَأَتَيْتُ بِهِ الرَّسُولَ صلى الله عليه وسلم فَقُلْتُ نَفِّلْنِي هَذَا السَّيْفَ فَأَنَا مَنْ قَدْ عَلِمْتَ حَالَهُ ‏.‏ فَقَالَ ‏"‏ رُدُّهُ مِنْ حَيْثُ أَخَذْتَهُ ‏"‏ ‏.‏ فَانْطَلَقْتُ حَتَّى إِذَا أَرَدْتُ أَنْ أُلْقِيَهُ فِي الْقَبَضِ لاَمَتْنِي نَفْسِي فَرَجَعْتُ إِلَيْهِ فَقُلْتُ أَعْطِنِيهِ ‏.‏ قَالَ فَشَدَّ لِي صَوْتَهُ ‏"‏ رُدُّهُ مِنْ حَيْثُ أَخَذْتَهُ ‏"‏ ‏.‏ قَالَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَسْأَلُونَكَ عَنِ الأَنْفَالِ‏\}‏ قَالَ وَمَرِضْتُ فَأَرْسَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَتَانِي فَقُلْتُ دَعْنِي أَقْسِمْ مَالِي حَيْثُ شِئْتُ ‏.‏ قَالَ فَأَبَى ‏.‏ قُلْتُ فَالنِّصْفَ ‏.‏ قَالَ فَأَبَى ‏.‏ قُلْتُ فَالثُّلُثَ ‏.‏ قَالَ فَسَكَتَ فَكَانَ بَعْدُ الثُّلُثُ جَائِزًا ‏.‏ قَالَ وَأَتَيْتُ عَلَى نَفَرٍ مِنَ الأَنْصَارِ وَالْمُهَاجِرِينَ فَقَالُوا تَعَالَ نُطْعِمْكَ وَنَسْقِيكَ خَمْرًا ‏.‏ وَذَلِكَ قَبْلَ أَنْ تُحَرَّمَ الْخَمْرُ - قَالَ - فَأَتَيْتُهُمْ فِي حَشٍّ - وَالْحَشُّ الْبُسْتَانُ - فَإِذَا رَأْسُ جَزُورٍ مَشْوِيٌّ عِنْدَهُمْ وَزِقٌّ مِنْ خَمْرٍ - قَالَ - فَأَكَلْتُ وَشَرِبْتُ مَعَهُمْ - قَالَ - فَذُكِرَتِ الأَنْصَارُ وَالْمُهَاجِرُونَ عِنْدَهُمْ فَقُلْتُ الْمُهَاجِرُونَ خَيْرٌ مِنَ الأَنْصَارِ - قَالَ - فَأَخَذَ رَجُلٌ أَحَدَ لَحْيَىِ الرَّأْسِ فَضَرَبَنِي بِهِ فَجَرَحَ بِأَنْفِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِيَّ - يَعْنِي نَفْسَهُ - شَأْنَ الْخَمْرِ ‏\{‏ إِنَّمَا الْخَمْرُ وَالْمَيْسِرُ وَالأَنْصَابُ وَالأَزْلاَمُ رِجْسٌ مِنْ عَمَلِ الشَّيْطَانِ‏\}‏\hadithno{6238}\hadithtrans{Mus'ab b. Sa'd reported on the authority of his father that many verses of the Qur'an had been revealed in connection with him. His mother Umm Sa'd had taken oath that she would never talk with him until he abandoned his faith and she neither ate nor drank and said:Allah has commanded you to treat well your parents and I am your mother and I command you to do this. She passed three days in this state until she fainted because of extreme hunger and at that time her son whose name was Umara stood up and served her drink and she began to curse Sa'd that Allah, the Exalted and Glorions, revealed these verses of the Holy Qur'an:" And We have enjoined upon a person goodness to his parents but if they contend with thee to associate (others) with Me of which you have no knowledge, then obey them not" (xxix. 8) ; Treat thein with customary good in this world" (xxxi. 15). He also reported that there fell to the lot of Allah's Messenger (ﷺ) huge spoils of war and there was one sword in them. I picked that up and came to Allah's Messenger (ﷺ) and said: Bestow this sword upon me (as my share in the spoils of war) and you know my state. Thereupon he said: Return it to the place from where you picked it up. I went back until I decided to throw it in a store but my soul repulsed me so I came back and asked him to give that sword to me. He said in a loud voice to return it to the place from where I had picked it up. It was on this occasion that this verse was revealed:" They asked about the spoils of war" (viii. 1). He further said: I once fell ill and sent a message to Allah's Apostle (ﷺ). He visited me and I said to him: Permit me to distribute (in charity) my property as much as I like. He did not agree. I said: (Permit me to distribute) half of it. He did not agree. I said: (Permit me to distribute) the third part, whereupon he kept quiet and it was after this (that the distribution of one's property in charity) to the extent of one-third was held valid. He further said: I came to a group of persons of the Ansir and Muhajirin and they said: Come, so that we may serve you wine, and it was before the use of wine had been prohibited. I went to them in a garden and there had been with them the roasted head of a camel and a small water-skin containing wine. I ate and drank along with them and there came under discussion the Ansr (Helpers) and Muhajirin (immigrants). I said: The immigrants are better than the Ansar, that a person picked up a portion of the head (of the camel and struck me with it that my nose was injured. I came to Allah's Messenger (ﷺ) and informed him of the situation that Aliah, the Exalted and Glorious, revealed verses pertaining to wine:" Intoxicants and the games of chance and (sacrificing to) stones set up and (divining by) arrows are only an uncleanliness, the devil's work" (v)}}
\hadithdefcmd{muslim}{6239}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ أُنْزِلَتْ فِيَّ أَرْبَعُ آيَاتٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ زُهَيْرٍ عَنْ سِمَاكٍ وَزَادَ فِي حَدِيثِ شُعْبَةَ قَالَ فَكَانُوا إِذَا أَرَادُوا أَنْ يُطْعِمُوهَا شَجَرُوا فَاهَا بِعَصًا ثُمَّ أَوْجَرُوهَا ‏.‏ وَفِي حَدِيثِهِ أَيْضًا فَضَرَبَ بِهِ أَنْفَ سَعْدٍ فَفَزَرَهُ وَكَانَ أَنْفُ سَعْدٍ مَفْزُورًا ‏.‏\hadithno{6239}\hadithtrans{This hadith has been transmitted on the authority of Simak and the hadith transmitted on the authority of Shu'ba (the words are):When they intended to feed her (Sa'd'. s mother), they opened her mouth with the help of a stick and then put the feed in her mouth, and in the same hadith the words are: He struck the nose of Sa'd and it was injured and Sa'd had (the mark) of wound on his nose}}
\hadithdefcmd{muslim}{6240}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، فِيَّ نَزَلَتْ ‏\{‏ وَلاَ تَطْرُدِ الَّذِينَ يَدْعُونَ رَبَّهُمْ بِالْغَدَاةِ وَالْعَشِيِّ‏\}‏ قَالَ نَزَلَتْ فِي سِتَّةٍ أَنَا وَابْنُ مَسْعُودٍ مِنْهُمْ وَكَانَ الْمُشْرِكُونَ قَالُوا لَهُ تُدْنِي هَؤُلاَءِ ‏.‏\hadithno{6240}\hadithtrans{Sa'd reported:This verse was revealed in relation to six persons and I and Ibn Mas'ud were amongst them. The polytheists said to him (the Holy Prophet): Do not keep such persons near you. It was upon this that (this verse was revealed):" Drive not away those who call upon their Lord morning and evening desiring only His pleasure" (vi)}}
\hadithdefcmd{muslim}{6241}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَسَدِيُّ، عَنْ إِسْرَائِيلَ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم سِتَّةَ نَفَرٍ فَقَالَ الْمُشْرِكُونَ لِلنَّبِيِّ صلى الله عليه وسلم اطْرُدْ هَؤُلاَءِ لاَ يَجْتَرِئُونَ عَلَيْنَا ‏.‏ قَالَ وَكُنْتُ أَنَا وَابْنُ مَسْعُودٍ وَرَجُلٌ مِنْ هُذَيْلٍ وَبِلاَلٌ وَرَجُلاَنِ لَسْتُ أُسَمِّيهِمَا فَوَقَعَ فِي نَفْسِ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ أَنْ يَقَعَ فَحَدَّثَ نَفْسَهُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَطْرُدِ الَّذِينَ يَدْعُونَ رَبَّهُمْ بِالْغَدَاةِ وَالْعَشِيِّ يُرِيدُونَ وَجْهَهُ‏\}‏\hadithno{6241}\hadithtrans{Sa'd reported:We were six men in the company of Allah's Messenger (, nay peace be upon him) that the polytheists said to Allah's Apostle (ﷺ): Drive them away so that they may not be overbold upon us. He said: I, Ibn Mas'ud and a person from the tribe of Hudhail, Bilal and two other persons, whose names I do not know (were amongst such persons). And there occurred to Allah's Messenger (ﷺ) what. Allah wished and he talked with himself that Allah, the Exalted and Glorious, revealed:" Do not drive away those who call their Lord morning and evening desiring to seek His pleasure}}
\hadithdefcmd{muslim}{6242}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، وَحَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالُوا حَدَّثَنَا الْمُعْتَمِرُ، - وَهُوَ ابْنُ سُلَيْمَانَ - قَالَ سَمِعْتُ أَبِي، عَنْ أَبِي عُثْمَانَ، قَالَ لَمْ يَبْقَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ تِلْكَ الأَيَّامِ الَّتِي قَاتَلَ فِيهِنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم غَيْرُ طَلْحَةَ وَسَعْدٍ ‏.‏ عَنْ حَدِيثِهِمَا ‏.‏\hadithno{6242}\hadithtrans{Abu 'Uthman reported on one of the days when Allah's Messenger (ﷺ) was fighting and none remained with him save Talha and Sa'd}}
\hadithdefcmd{muslim}{6243}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ، بْنِ عَبْدِ اللَّهِ قَالَ سَمِعْتُهُ يَقُولُ نَدَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ يَوْمَ الْخَنْدَقِ فَانْتَدَبَ الزُّبَيْرُ ثُمَّ نَدَبَهُمْ فَانْتَدَبَ الزُّبَيْرُ ثُمَّ نَدَبَهُمْ فَانْتَدَبَ الزُّبَيْرُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لِكُلِّ نَبِيٍّ حَوَارِيٌّ وَحَوَارِيَّ الزُّبَيْرُ ‏"‏ ‏.‏\hadithno{6243}\hadithtrans{Jabir b. Abdullah reported:I heard Allah's Messenger (ﷺ) exhorting people on the Day of the Battle of the Ditch to fight. Zubair said: I am ready (to participate). He then again exhorted and he again said: I am ready to participate. Thereupon Allah's Messenger (ﷺ) said: Behold. for every Prophet there is a helper and my helper is Zubair}}
\hadithdefcmd{muslim}{6244}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ وَكِيعٍ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{6244}\hadithtrans{Jabir reported this hadith through another chain of transmitters}}
\hadithdefcmd{muslim}{6245}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ الْخَلِيلِ، وَسُوَيْدُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنِ ابْنِ مُسْهِرٍ، قَالَ إِسْمَاعِيلُ أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ كُنْتُ أَنَا وَعُمَرُ بْنُ أَبِي سَلَمَةَ، يَوْمَ الْخَنْدَقِ مَعَ النِّسْوَةِ فِي أُطُمِ حَسَّانٍ فَكَانَ يُطَأْطِئُ لِي مَرَّةً فَأَنْظُرُ وَأُطَأْطِئُ لَهُ مَرَّةً فَيَنْظُرُ فَكُنْتُ أَعْرِفُ أَبِي إِذَا مَرَّ عَلَى فَرَسِهِ فِي السِّلاَحِ إِلَى بَنِي قُرَيْظَةَ ‏.‏ قَالَ وَأَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُرْوَةَ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ قَالَ فَذَكَرْتُ ذَلِكَ لأَبِي فَقَالَ وَرَأَيْتَنِي يَا بُنَىَّ قُلْتُ نَعَمْ ‏.‏ قَالَ أَمَا وَاللَّهِ لَقَدْ جَمَعَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ أَبَوَيْهِ فَقَالَ ‏ "‏ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏\hadithno{6245}\hadithtrans{Abdullah b. Zubair reported on the Day of the Battle of the Trench:I and Umar b. Abu Salama were with women folk in the fort of Hassan (b. Thabit). He at one time leaned for me and I cast a glance and at anothertime I leaned for him and he would see and I recognised my father as he rode on his horse with his arms towards the tribe of Quraizah. 'Abdullah b. 'Urwa reported from Abdullah b. Zubair: I made a mention of that to my father, whereupon he said: My son, did you see me (on that occasion)? He said: Yes. Thereupon he said: By Allah, Allah's Messenger (ﷺ) addressed me saying: I would sacrifice for thee my father and my mother}}
\hadithdefcmd{muslim}{6246}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ لَمَّا كَانَ يَوْمُ الْخَنْدَقِ كُنْتُ أَنَا وَعُمَرُ بْنُ أَبِي سَلَمَةَ فِي الأُطُمِ الَّذِي فِيهِ النِّسْوَةُ يَعْنِي نِسْوَةَ النَّبِيِّ صلى الله عليه وسلم وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ ابْنِ مُسْهِرٍ فِي هَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ عَبْدَ اللَّهِ بْنَ عُرْوَةَ فِي الْحَدِيثِ وَلَكِنْ أَدْرَجَ الْقِصَّةَ فِي حَدِيثِ هِشَامٍ عَنْ أَبِيهِ عَنِ ابْنِ الزُّبَيْرِ ‏.‏\hadithno{6246}\hadithtrans{Abdullah b. Zubair reported:When it was the Day of the Battle of the Ditch I and 'Umar b. Salama were in the fort in which there were women, i. e. the wives of Allah's Apostle (ﷺ) ; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6247}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَلَى حِرَاءٍ هُوَ وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَطَلْحَةُ وَالزُّبَيْرُ فَتَحَرَّكَتِ الصَّخْرَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اهْدَأْ فَمَا عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدٌ ‏"‏ ‏.‏\hadithno{6247}\hadithtrans{Abu Huraira reported:Allah's Messenger (ﷺ) was upon the mountain of Hira, ' and there were along with him Abu Bakr, Umar, Uthman. 'Ali, Talha, 'Zubair, that the mountain stirred; thereupon Allah's Messenger (ﷺ) said: Be calm, there is none upon you but a Prophet, a Fiddle (the testifier of truth) and a Martyr}}
\hadithdefcmd{muslim}{6248}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ يَزِيدَ بْنِ خُنَيْسٍ، وَأَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُهَيْلِ، بْنِ أَبِي صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَلَى جَبَلِ حِرَاءٍ فَتَحَرَّكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْكُنْ حِرَاءُ فَمَا عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدٌ ‏"‏ ‏.‏ وَعَلَيْهِ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَعَلِيٌّ وَطَلْحَةُ وَالزُّبَيْرُ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ رضى الله عنهم ‏.‏\hadithno{6248}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) was on the mountain of Hira' that it stirred; thereupon Allah's Messenger (ﷺ) said:Hira! be calm, for there is none upon you but a Prophet, a Siddiq, a Shahid, and there were upon it Allah's Prophet (ﷺ), Abu Bakr, 'Umar, Uthman, 'Ali, Talha, Zubair, Sa'd b. Abi Waqqas (Allah be pleased witli them)}}
\hadithdefcmd{muslim}{6249}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَعَبْدَةُ، قَالاَ حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، قَالَ قَالَتْ لِي عَائِشَةُ أَبَوَاكَ وَاللَّهِ مِنَ الَّذِينَ اسْتَجَابُوا لِلَّهِ وَالرَّسُولِ مِنْ بَعْدِ مَا أَصَابَهُمُ الْقَرْحُ ‏.‏\hadithno{6249}\hadithtrans{Hisham reported on the authority of his father ('Urwa b. Zubair) that A'isha said:BY Allah, both fathers of yours are amongst those who have been men. tioned in this verse:" Those who responded to the call of Allah and the Messenger after the misfortune had fallen upon thein}}
\hadithdefcmd{muslim}{6250}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ وَزَادَ تَعْنِي أَبَا بَكْرٍ وَالزُّبَيْرَ ‏.‏\hadithno{6250}\hadithtrans{This hadith has been narrated on the authority of Hishan through the same chain of transmitters but with this addition (that by both fathers of yours) he meant Abu Bakr and Zubair}}
\hadithdefcmd{muslim}{6251}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنِ الْبَهِيِّ، عَنْ عُرْوَةَ، قَالَ قَالَتْ لِي عَائِشَةُ كَانَ أَبَوَاكَ مِنَ الَّذِينَ اسْتَجَابُوا لِلَّهِ وَالرَّسُولِ مِنْ بَعْدِ مَا أَصَابَهُمُ الْقَرْحُ ‏.‏\hadithno{6251}\hadithtrans{Urwa reported:'Aisha said to me: Your fathers (Zubair and Abu Bakr) were amongst those about whom (it has been revealed):" Those who responded to the call of Allah and His Messenger after the misfortune had fallen upon them}}
\hadithdefcmd{muslim}{6252}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ خَالِدٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، قَالَ قَالَ أَنَسٌ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِكُلِّ أُمَّةٍ أَمِينًا وَإِنَّ أَمِينَنَا أَيَّتُهَا الأُمَّةُ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ ‏"‏ ‏.‏\hadithno{6252}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:For every Umma there is a man of trust and the man of trust of this Umma is Abu 'Ubaida b. Jarrah}}
\hadithdefcmd{muslim}{6253}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ سَلَمَةَ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ أَهْلَ الْيَمَنِ، قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا ابْعَثْ مَعَنَا رَجُلاً يُعَلِّمْنَا السُّنَّةَ وَالإِسْلاَمَ ‏.‏ قَالَ فَأَخَذَ بِيَدِ أَبِي عُبَيْدَةَ فَقَالَ ‏ "‏ هَذَا أَمِينُ هَذِهِ الأُمَّةِ ‏"‏ ‏.‏\hadithno{6253}\hadithtrans{Anas reported that the people of Yemen came to Allah's Messenger (ﷺ) and said:Send with us a person who should teach us Sunnah and al-Islam, whereupon he (the Holy Prophet) caught hold of the hand of Ubaida and said: He is a man of trust of this Umma}}
\hadithdefcmd{muslim}{6254}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، قَالَ جَاءَ أَهْلُ نَجْرَانَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ ابْعَثْ إِلَيْنَا رَجُلاً أَمِينًا ‏.‏ فَقَالَ ‏ "‏ لأَبْعَثَنَّ إِلَيْكُمْ رَجُلاً أَمِينًا حَقَّ أَمِينٍ حَقَّ أَمِينٍ ‏"‏ ‏.‏ قَالَ فَاسْتَشْرَفَ لَهَا النَّاسُ - قَالَ - فَبَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ ‏.‏\hadithno{6254}\hadithtrans{Hudhaifa reported that the people of Najran came to Allah's Messenger (ﷺ) and said:Allah's Messenger, send along with us a man of trust; whereupon he said: I would definitely send to you a man of trust, a man of trust in the true sense of the term. Thereupon his Companions looked up eagerly and he sent Abu Ubaida b. Jarrah}}
\hadithdefcmd{muslim}{6255}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6255}\hadithtrans{This hadith has been reported on the authority of Abu Ishaq with the same chain of transmitters}}
\hadithdefcmd{muslim}{6256}{حَدَّثَنِي أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ لِحَسَنٍ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُ فَأَحِبَّهُ وَأَحْبِبْ مَنْ يُحِبُّهُ ‏"‏ ‏.‏\hadithno{6256}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying to Hasan:O Allah, behold, I love him. Thou too love him and love one who loves him}}
\hadithdefcmd{muslim}{6257}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ نَافِعِ بْنِ جُبَيْرِ، بْنِ مُطْعِمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي طَائِفَةٍ مِنَ النَّهَارِ لاَ يُكَلِّمُنِي وَلاَ أُكَلِّمُهُ حَتَّى جَاءَ سُوقَ بَنِي قَيْنُقَاعَ ثُمَّ انْصَرَفَ حَتَّى أَتَى خِبَاءَ فَاطِمَةَ فَقَالَ ‏"‏ أَثَمَّ لُكَعُ أَثَمَّ لُكَعُ ‏"‏ ‏.‏ يَعْنِي حَسَنًا فَظَنَنَّا أَنَّهُ إِنَّمَا تَحْبِسُهُ أُمُّهُ لأَنْ تُغَسِّلَهُ وَتُلْبِسَهُ سِخَابًا فَلَمْ يَلْبَثْ أَنْ جَاءَ يَسْعَى حَتَّى اعْتَنَقَ كُلُّ وَاحِدٍ مِنْهُمَا صَاحِبَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ إِنِّي أُحِبُّهُ فَأَحِبَّهُ وَأَحْبِبْ مَنْ يُحِبُّهُ ‏"‏ ‏.‏\hadithno{6257}\hadithtrans{Abu Huraira reported:I went along with Allah's Messenger (ﷺ) at a time during the day but he did not talk to me and I did not talk to him until he reached the market of Bani Qainuqa`. He came back to the tent of Fatima and said: Is the little chap (meaning Hasan) there? We were under the impression that his mother had detained him in order to bathe him and dress him and garland him with a sweet garland. Not much time had passed that he (Hasan) came running until both of them embraced each other, thereupon Allah's Messenger (ﷺ) said: O Allah, I love him; love him Thou and love one who loves him (Hasan)}}
\hadithdefcmd{muslim}{6258}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - حَدَّثَنَا الْبَرَاءُ بْنُ عَازِبٍ، قَالَ رَأَيْتُ الْحَسَنَ بْنَ عَلِيٍّ عَلَى عَاتِقِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُ فَأَحِبَّهُ ‏"‏ ‏.‏\hadithno{6258}\hadithtrans{Al-Bara' b. Azib reported:I saw Hasan b. 'Ali upon the shoulders of Allah's Apostle (ﷺ) and he was saying: O Allah, I love him, and love him Thou}}
\hadithdefcmd{muslim}{6259}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالَ ابْنُ نَافِعٍ حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - عَنِ الْبَرَاءِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَاضِعًا الْحَسَنَ بْنَ عَلِيٍّ عَلَى عَاتِقِهِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أُحِبُّهُ فَأَحِبَّهُ ‏"‏ ‏.‏\hadithno{6259}\hadithtrans{Al-Bara' b. Azib reported:I saw the Messenger of Allah (ﷺ) with Al-Hasan b. 'Ali placed upon his shoulders and he was saying: O Allah, I love him, and love him Thou}}
\hadithdefcmd{muslim}{6260}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الرُّومِيِّ الْيَمَامِيُّ، وَعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالاَ حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - حَدَّثَنَا إِيَاسٌ، عَنْ أَبِيهِ، قَالَ لَقَدْ قُدْتُ بِنَبِيِّ اللَّهِ صلى الله عليه وسلم وَالْحَسَنِ وَالْحُسَيْنِ بَغْلَتَهُ الشَّهْبَاءَ حَتَّى أَدْخَلْتُهُمْ حُجْرَةَ النَّبِيِّ صلى الله عليه وسلم هَذَا قُدَّامَهُ وَهَذَا خَلْفَهُ ‏.‏\hadithno{6260}\hadithtrans{Iyas reported on the authority of his father:I (had the honour of) leading the white mule on which rode Allah's Apostle (ﷺ) and with him were Hasan and Husain, till it reached the apartment of Allah's Apostle (ﷺ). The one amongst them was seated before him and the other one was seated behind him}}
\hadithdefcmd{muslim}{6261}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ زَكَرِيَّاءَ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، قَالَتْ قَالَتْ عَائِشَةُ خَرَجَ النَّبِيُّ صلى الله عليه وسلم غَدَاةً وَعَلَيْهِ مِرْطٌ مُرَحَّلٌ مِنْ شَعْرٍ أَسْوَدَ فَجَاءَ الْحَسَنُ بْنُ عَلِيٍّ فَأَدْخَلَهُ ثُمَّ جَاءَ الْحُسَيْنُ فَدَخَلَ مَعَهُ ثُمَّ جَاءَتْ فَاطِمَةُ فَأَدْخَلَهَا ثُمَّ جَاءَ عَلِيٌّ فَأَدْخَلَهُ ثُمَّ قَالَ ‏\{‏ إِنَّمَا يُرِيدُ اللَّهُ لِيُذْهِبَ عَنْكُمُ الرِّجْسَ أَهْلَ الْبَيْتِ وَيُطَهِّرَكُمْ تَطْهِيرًا‏\}‏\hadithno{6261}\hadithtrans{A'isha reported that Allah's Apostle (ﷺ) went out one norning wearing a striped cloak of the black camel's hair that there came Hasan b. 'Ali. He wrapped hitn under it, then came Husain and he wrapped him under it along with the other one (Hasan). Then came Fatima and he took her under it, then came 'Ali and he also took him under it and then said:Allah only desires to take away any uncleanliness from you, O people of the household, and purify you (thorough purifying)}}
\hadithdefcmd{muslim}{6262}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ مَا كُنَّا نَدْعُو زَيْدَ بْنَ حَارِثَةَ إِلاَّ زَيْدَ بْنَ مُحَمَّدٍ حَتَّى نَزَلَ الْقُرْآنُ ‏\{‏ ادْعُوهُمْ لآبَائِهِمْ هُوَ أَقْسَطُ عِنْدَ اللَّهِ‏\}‏ قَالَ الشَّيْخُ أَبُو أَحْمَدَ مُحَمَّدُ بْنُ عِيسَى أَخْبَرَنَا أَبُو الْعَبَّاسِ السَّرَّاجُ وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يُوسُفَ الدُّوَيْرِيُّ قَالاَ حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{6262}\hadithtrans{Salim b. 'Abdullah reported on the authority of his father:We were in the habit of calling Zaid b. Harith as Zaid b. Muhammad until it was revealed in the Qur'an:" Call them by the names of their fathers. This is more equitable with Allah" (This hadith has been transmitted on the authority of Qutaiba b. Sa'd)}}
\hadithdefcmd{muslim}{6263}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، حَدَّثَنِي سَالِمٌ، عَنْ عَبْدِ اللَّهِ، بِمِثْلِهِ ‏.‏\hadithno{6263}\hadithtrans{This hadith has been narrated on the authority 'Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{6264}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا - إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْثًا وَأَمَّرَ عَلَيْهِمْ أُسَامَةَ بْنَ زَيْدٍ فَطَعَنَ النَّاسُ فِي إِمْرَتِهِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنْ تَطْعَنُوا فِي إِمْرَتِهِ فَقَدْ كُنْتُمْ تَطْعَنُونَ فِي إِمْرَةِ أَبِيهِ مِنْ قَبْلُ وَايْمُ اللَّهِ إِنْ كَانَ لَخَلِيقًا لِلإِمْرَةِ وَإِنْ كَانَ لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ وَإِنَّ هَذَا لَمِنْ أَحَبِّ النَّاسِ إِلَىَّ بَعْدَهُ ‏"‏ ‏.‏\hadithno{6264}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) sent an expedition and appointed Usama b. Zaid as its chief. The people objected to his command, whereupon Allah's Messenger (ﷺ) stood up and said:You object to his command and before this you objected to the command of his father (Zaid). By Allah, he was fit as the commander and he was one of the dearest of persons to me and after him, behold! this one (Usama) is one of the dearest of persons to me}}
\hadithdefcmd{muslim}{6265}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُمَرَ، - يَعْنِي ابْنَ حَمْزَةَ - عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ عَلَى الْمِنْبَرِ ‏ "‏ إِنْ تَطْعَنُوا فِي إِمَارَتِهِ - يُرِيدُ أُسَامَةَ بْنَ زَيْدٍ - فَقَدْ طَعَنْتُمْ فِي إِمَارَةِ أَبِيهِ مِنْ قَبْلِهِ وَايْمُ اللَّهِ إِنْ كَانَ لَخَلِيقًا لَهَا ‏.‏ وَايْمُ اللَّهِ إِنْ كَانَ لأَحَبَّ النَّاسِ إِلَىَّ ‏.‏ وَايْمُ اللَّهِ إِنَّ هَذَا لَهَا لَخَلِيقٌ - يُرِيدُ أُسَامَةَ بْنَ زَيْدٍ - وَايْمُ اللَّهِ إِنْ كَانَ لأَحَبَّهُمْ إِلَىَّ مِنْ بَعْدِهِ فَأُوصِيكُمْ بِهِ فَإِنَّهُ مِنْ صَالِحِيكُمْ ‏"‏ ‏.‏\hadithno{6265}\hadithtrans{Salim reported on the authority of his father that Allah's Messenger (ﷺ) said on the pulpit:You object to the command of Usima b. Zaid as you had objected before to the command of his father (Zaid). By Allah, he was most competent for it and, by Allah, he was dearest to me amongst people and, by Allah, the same is the case with Usama b. Zaid. He is most dear to me after him and I advise you to treat him well for he is pious amongst you}}
\hadithdefcmd{muslim}{6266}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ عَبْدِ اللَّهِ بْنِ مُلَيْكَةَ، قَالَ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ لاِبْنِ الزُّبَيْرِ أَتَذْكُرُ إِذْ تَلَقَّيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَا وَأَنْتَ وَابْنُ عَبَّاسٍ قَالَ نَعَمْ فَحَمَلَنَا وَتَرَكَكَ ‏.‏\hadithno{6266}\hadithtrans{Abdullah b. Abu Mulaika reported that Abdullah b. Jafar said to Ibn Zubair:Do you remember (the occasion) when we three (i. e. I, you and lbn 'Abbas) met Allah's Messenger (ﷺ) and he mounted us (on his camel) but left you? He said: Yes}}
\hadithdefcmd{muslim}{6267}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو أُسَامَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، بِمِثْلِ حَدِيثِ ابْنِ عُلَيَّةَ وَإِسْنَادِهِ ‏.‏\hadithno{6267}\hadithtrans{This hadith has been transmitted on the authority of Habib b. Ash-Shahid}}
\hadithdefcmd{muslim}{6268}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لِيَحْيَى - قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَقَالَ، يَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ مُوَرِّقٍ الْعِجْلِيِّ، عَنْ عَبْدِ، اللَّهِ بْنِ جَعْفَرٍ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَدِمَ مِنْ سَفَرٍ تُلُقِّيَ بِصِبْيَانِ أَهْلِ بَيْتِهِ - قَالَ - وَإِنَّهُ قَدِمَ مِنْ سَفَرٍ فَسُبِقَ بِي إِلَيْهِ فَحَمَلَنِي بَيْنَ يَدَيْهِ ثُمَّ جِيءَ بِأَحَدِ ابْنَىْ فَاطِمَةَ فَأَرْدَفَهُ خَلْفَهُ - قَالَ - فَأُدْخِلْنَا الْمَدِينَةَ ثَلاَثَةً عَلَى دَابَّةٍ ‏.‏\hadithno{6268}\hadithtrans{Abdullah b. Ja'far reported that when Allah's Messenger (may peace be, upon him) came back from a journey, the children of his family used to accord him welcome. It was in this way that once he came back from a journey and I went to him first of all. He mounted me before him. Then there came one of the two sons of Fatima and he mounted him behind him and this is how we three entered Medina riding on a beast}}
\hadithdefcmd{muslim}{6269}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ عَاصِمٍ، حَدَّثَنِي مُوَرِّقٌ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَدِمَ مِنْ سَفَرٍ تُلُقِّيَ بِنَا - قَالَ - فَتُلُقِّيَ بِي وَبِالْحَسَنِ أَوْ بِالْحُسَيْنِ - قَالَ - فَحَمَلَ أَحَدَنَا بَيْنَ يَدَيْهِ وَالآخَرَ خَلْفَهُ حَتَّى دَخَلْنَا الْمَدِينَةَ ‏.‏\hadithno{6269}\hadithtrans{Abdullah b. Ja'a'far reported that when Allah's Messenger (ﷺ) came back from a journey he met us. Once he met me, Hasan or Husain, and he mounted one of us before him and the other one behind him until we entered Medina}}
\hadithdefcmd{muslim}{6270}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ، أَبِي يَعْقُوبَ عَنِ الْحَسَنِ بْنِ سَعْدٍ، مَوْلَى الْحَسَنِ بْنِ عَلِيٍّ عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ خَلْفَهُ فَأَسَرَّ إِلَىَّ ��َدِيثًا لاَ أُحَدِّثُ بِهِ أَحَدًا مِنَ النَّاسِ ‏.‏\hadithno{6270}\hadithtrans{Abdullah b. Ja'far reported that one day Allah's Messenger (ﷺ) mounted me behind him and narrated to me something in secret which I would narrate to none amongst people}}
\hadithdefcmd{muslim}{6271}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، نُمَيْرٍ وَوَكِيعٌ وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، وَاللَّفْظُ، حَدِيثُ أَبِي أُسَامَةَ ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ جَعْفَرٍ، يَقُولُ سَمِعْتُ عَلِيًّا، بِالْكُوفَةِ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ نِسَائِهَا مَرْيَمُ بِنْتُ عِمْرَانَ وَخَيْرُ نِسَائِهَا خَدِيجَةُ بِنْتُ خُوَيْلِدٍ ‏"‏ ‏.‏ قَالَ أَبُو كُرَيْبٍ وَأَشَارَ وَكِيعٌ إِلَى السَّمَاءِ وَالأَرْضِ ‏.‏\hadithno{6271}\hadithtrans{Abdullah b. Ja`far reported that he heard `Ali say in Kufa that Allah's Messenger (ﷺ) said:The best of the women of her time was Mary, daughter of `Imran, and the best of the women of her time was Khadija, daughter of Khuwailid. Abu Kuraib said that Waki` pointed towards the sky and the earth}}
\hadithdefcmd{muslim}{6272}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ الْمُثَنَّى وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، جَمِيعًا عَنْ شُعْبَةَ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ، بْنُ مُعَاذٍ الْعَنْبَرِيُّ - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ مُرَّةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَمَلَ مِنَ الرِّجَالِ كَثِيرٌ وَلَمْ يَكْمُلْ مِنَ النِّسَاءِ غَيْرُ مَرْيَمَ بِنْتِ عِمْرَانَ وَآسِيَةَ امْرَأَةِ فِرْعَوْنَ وَإِنَّ فَضْلَ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏ ‏.‏\hadithno{6272}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:There are many persons amongst men who are quite perfect but there are none perfect amongst women except Mary, daughter of 'Imran, Asiya wife of Pharaoh, and the excellence of 'A'isha as compared to women is that of Tharid over all other foods}}
\hadithdefcmd{muslim}{6273}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَابْنُ نُمَيْرٍ قَالُوا حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ أَتَى جِبْرِيلُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ هَذِهِ خَدِيجَةُ قَدْ أَتَتْكَ مَعَهَا إِنَاءٌ فِيهِ إِدَامٌ أَوْ طَعَامٌ أَوْ شَرَابٌ فَإِذَا هِيَ أَتَتْكَ فَاقْرَأْ عَلَيْهَا السَّلاَمَ مِنْ رَبِّهَا عَزَّ وَجَلَّ وَمِنِّي وَبَشِّرْهَا بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ ‏.‏ قَالَ أَبُو بَكْرٍ فِي رِوَايَتِهِ عَنْ أَبِي هُرَيْرَةَ وَلَمْ يَقُلْ سَمِعْتُ ‏.‏ وَلَمْ يَقُلْ فِي الْحَدِيثِ وَمِنِّي ‏.‏\hadithno{6273}\hadithtrans{Abu Huraira reported that Gabriel came to Allah's Apostle (ﷺ) and said:Allah's Messenger, lo. Khadija is coming to you with a vessel of seasoned food or drink. When she comes to you, offer her greetings from her Lord, the Exalted and Glorious, and on my behalf and give her glad tidings of a palace of jewels in Paradise wherein there is no noise and no toil. This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters with a slight variation of wording}}
\hadithdefcmd{muslim}{6274}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، عَنْ إِسْمَاعِيلَ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَشَّرَ خَدِيجَةَ بِبَيْتٍ فِي الْجَنَّةِ قَالَ نَعَمْ بَشَّرَهَا بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ ‏.‏\hadithno{6274}\hadithtrans{Ismail reported:I said to 'Abdullah b. Abi Aufa: Did Allah's Messenger (ﷺ) give glad tidings of Paradise to Khadija? He said: Yes. He did give glad tidings to her of a palace of jewels in Paradise wherein there would be no noise and no toil}}
\hadithdefcmd{muslim}{6275}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، وَجَرِيرٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ ابْنِ أَبِي أَوْفَى، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6275}\hadithtrans{This hadith has been narrated on the a tliority of Ibn Abi Aufa through other chains of transmitters}}
\hadithdefcmd{muslim}{6276}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ بَشَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَدِيجَةَ بِنْتَ خُوَيْلِدٍ بِبَيْتٍ فِي الْجَنَّةِ ‏.‏\hadithno{6276}\hadithtrans{A'isha reported that Allah's Messenger (may peace he upon him) gave glad tidings to Khadija bint Khuwailid of a palace in Paradise}}
\hadithdefcmd{muslim}{6277}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا غِرْتُ عَلَى امْرَأَةٍ مَا غِرْتُ عَلَى خَدِيجَةَ وَلَقَدْ هَلَكَتْ قَبْلَ أَنْ يَتَزَوَّجَنِي بِثَلاَثِ سِنِينَ لِمَا كُنْتُ أَسْمَعُهُ يَذْكُرُهَا وَلَقَدْ أَمَرَهُ رَبُّهُ عَزَّ وَجَلَّ أَنْ يُبَشِّرَهَا بِبَيْتٍ مِنْ قَصَبٍ فِي الْجَنَّةِ وَإِنْ كَانَ لَيَذْبَحُ الشَّاةَ ثُمَّ يُهْدِيهَا إِلَى خَلاَئِلِهَا ‏.‏\hadithno{6277}\hadithtrans{A'isha reported:Never did I feel jealous of any woman as I was jealous of Khadija. She had died three years before he (the Holy Prophet) married me. I often heard him praise her, and his lord, the Exalted and Glorious, had commanded him to give her the glad tidings of a palace of jewels in Paradise: and whenever he slaughtered a sheep he presented (its meat) to her female companions}}
\hadithdefcmd{muslim}{6278}{حَدَّثَنَا سَهْلُ بْنُ عُثْمَانَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا غِرْتُ عَلَى نِسَاءِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ عَلَى خَدِيجَةَ وَإِنِّي لَمْ أُدْرِكْهَا ‏.‏ قَالَتْ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَبَحَ الشَّاةَ فَيَقُولُ ‏"‏ أَرْسِلُوا بِهَا إِلَى أَصْدِقَاءِ خَدِيجَةَ ‏"‏ ‏.‏ قَالَتْ فَأَغْضَبْتُهُ يَوْمًا فَقُلْتُ خَدِيجَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ رُزِقْتُ حُبَّهَا ‏"‏ ‏.‏\hadithno{6278}\hadithtrans{A'isha reported:Never did I feel jealous of the wives of Allah's Apostle (ﷺ) but in case of Khadija, although I did no, (have the privilege to) see her. She further added that whenever Allah's Messenger (ﷺ) slaughtered a sheep, he said: Send it to the companions of Khadija I annoyed him one day and said: (It is) Khadija only who always prevails upon your mind. Thereupon Allah's Messenger (ﷺ) said: Her love had been nurtured in my heart by Allah Himself}}
\hadithdefcmd{muslim}{6279}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ أَبِي أُسَامَةَ إِلَى قِصَّةِ الشَّاةِ وَلَمْ يَذْكُرِ الزِّيَادَةَ بَعْدَهَا ‏.‏\hadithno{6279}\hadithtrans{This hadith has been transmitted on the authority of Abu Usama up to the slaughtering of a sheep, but he. did not make mention of the subsequent words}}
\hadithdefcmd{muslim}{6280}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ مَا غِرْتُ لِلنَّبِيِّ صلى الله عليه وسلم عَلَى امْرَأَةٍ مِنْ نِسَائِهِ مَا غِرْتُ عَلَى خَدِيجَةَ لِكَثْرَةِ ذِكْرِهِ إِيَّاهَا وَمَا رَأَيْتُهَا قَطُّ ‏.‏\hadithno{6280}\hadithtrans{A'isha reported:Never did I feel jealous of any wife amongst the wives of Allah's Apostle (ﷺ) as I feel in case of Khadija (though I had never seen her), for he praised her very often}}
\hadithdefcmd{muslim}{6281}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمْ يَتَزَوَّجِ النَّبِيُّ صلى الله عليه وسلم عَلَى خَدِيجَةَ حَتَّى مَاتَتْ ‏.‏\hadithno{6281}\hadithtrans{A'isha reported that Allah's Apostle (ﷺ) did not marry any other woman till her (Khadija's) death}}
\hadithdefcmd{muslim}{6282}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتِ اسْتَأْذَنَتْ هَالَةُ بِنْتُ خُوَيْلِدٍ أُخْتُ خَدِيجَةَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَرَفَ اسْتِئْذَانَ خَدِيجَةَ فَارْتَاحَ لِذَلِكَ فَقَالَ ‏ "‏ اللَّهُمَّ هَالَةُ بِنْتُ خُوَيْلِدٍ ‏"‏ ‏.‏ فَغِرْتُ فَقُلْتُ وَمَا تَذْكُرُ مِنْ عَجُوزٍ مِنْ عَجَائِزِ قُرَيْشٍ حَمْرَاءِ الشِّدْقَيْنِ هَلَكَتْ فِي الدَّهْرِ فَأَبْدَلَكَ اللَّهُ خَيْرًا مِنْهَا ‏.‏\hadithno{6282}\hadithtrans{A'isha reported that Hala b. Khuwailid (sister of Khadija) sought permission from Allah's Messenger (ﷺ) to see him and he was reminded of Khadija's (manner of) asking leave to enter and (was overwhelmed) with emotions thereby and said:O Allah, it is Hala, daughter of Khuwailid, and I felt jealous and said: Why do you remember one of those old women of the Quraish with gums red and who is long dead-while Allah has given you a better one in her stead?}}
\hadithdefcmd{muslim}{6283}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ، جَمِيعًا عَنْ حَمَّادِ بْنِ زَيْدٍ، - وَاللَّفْظُ لأَبِي الرَّبِيعِ - حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُرِيتُكِ فِي الْمَنَامِ ثَلاَثَ لَيَالٍ جَاءَنِي بِكِ الْمَلَكُ فِي سَرَقَةٍ مِنْ حَرِيرٍ فَيَقُولُ هَذِهِ امْرَأَتُكَ ‏.‏ فَأَكْشِفُ عَنْ وَجْهِكِ فَإِذَا أَنْتِ هِيَ فَأَقُولُ إِنْ يَكُ هَذَا مِنْ عِنْدِ اللَّهِ يُمْضِهِ ‏"‏ ‏.‏\hadithno{6283}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) having said:I saw you in a dream for three nights when an angel brought you to me in a silk cloth and he said: Here is your wife, and when I removed (the cloth) from your face, lo, it was yourself, so I said: If this is from Allah, let Him carry it out}}
\hadithdefcmd{muslim}{6284}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، جَمِيعًا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6284}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{6285}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ وَجَدْتُ فِي كِتَابِي عَنْ أَبِي أُسَامَةَ، حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لأَعْلَمُ إِذَا كُنْتِ عَنِّي رَاضِيَةً وَإِذَا كُنْتِ عَلَىَّ غَضْبَى ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ وَمِنْ أَيْنَ تَعْرِفُ ذَلِكَ قَالَ ‏"‏ أَمَّا إِذَا كُنْتِ عَنِّي رَاضِيَةً فَإِنَّكِ تَقُولِينَ لاَ وَرَبِّ مُحَمَّدٍ وَإِذَا كُنْتِ غَضْبَى قُلْتِ لاَ وَرَبِّ إِبْرَاهِيمَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ أَجَلْ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا أَهْجُرُ إِلاَّ اسْمَكَ ‏.‏\hadithno{6285}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) said to me: I can well discern when you are pleased with me and when you are annoyed with me. I said: How do you discern it? Thereupon be said: When you are pleased with me you say;" No, by the Lord of Muhammad," and when you are annoyed with me, you say:" No, by the Lord of Ibrahim." I said: Allah's Messenger, by Allah, I in fact leave your name (when I am annoyed with you)}}
\hadithdefcmd{muslim}{6286}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ لاَ وَرَبِّ إِبْرَاهِيمَ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{6286}\hadithtrans{This hadith has been reported on the authority of Hishim b. 'Urwa with the same chain of transmitters up to the words:" No, by the Lord of Ibrahim," and he did not make mention of what follows subsequently}}
\hadithdefcmd{muslim}{6287}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تَلْعَبُ بِالْبَنَاتِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ وَكَانَتْ تَأْتِينِي صَوَاحِبِي فَكُنَّ يَنْقَمِعْنَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَرِّبُهُنَّ إِلَىَّ ‏.‏\hadithno{6287}\hadithtrans{A'isha reported that she used to play with dolls in the presence of Allah's Messenger (ﷺ) and when her playmates came to her they left (the house) because they felt shy of Allah's Messenger (ﷺ), whereas Allah's Messenger (ﷺ) sent them to her}}
\hadithdefcmd{muslim}{6288}{حَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَقَالَ فِي حَدِيثِ جَرِيرٍ كُنْتُ أَلْعَبُ بِالْبَنَاتِ فِي بَيْتِهِ وَهُنَّ اللُّعَبُ ‏.‏\hadithno{6288}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters with a slight variation of wording}}
\hadithdefcmd{muslim}{6289}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّاسَ، كَانُوا يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ يَبْتَغُونَ بِذَلِكَ مَرْضَاةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6289}\hadithtrans{A'isha reported that people sent their gifts when it was the turn of 'A'isha seeking thereby the pleasure of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6290}{حَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَأَبُو بَكْرِ بْنُ النَّضْرِ وَعَبْدُ بْنُ حُمَيْدٍ قَالَ عَبْدٌ حَدَّثَنِي وَقَالَ الآخَرَانِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ، شِهَابٍ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ أَرْسَلَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم فَاطِمَةَ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَأْذَنَتْ عَلَيْهِ وَهُوَ مُضْطَجِعٌ مَعِي فِي مِرْطِي فَأَذِنَ لَهَا فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَزْوَاجَكَ أَرْسَلْنَنِي إِلَيْكَ يَسْأَلْنَكَ الْعَدْلَ فِي ابْنَةِ أَبِي قُحَافَةَ وَأَنَا سَاكِتَةٌ - قَالَتْ - فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَىْ بُنَيَّةُ أَلَسْتِ تُحِبِّينَ مَا أُحِبُّ ‏"‏ ‏.‏ فَقَالَتْ بَلَى ‏.‏ قَالَ ‏"‏ فَأَحِبِّي هَذِهِ ‏"‏ ‏.‏ قَالَتْ فَقَامَتْ فَاطِمَةُ حِينَ سَمِعَتْ ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَجَعَتْ إِلَى أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَتْهُنَّ بِالَّذِي قَالَتْ وَبِالَّذِي قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْنَ لَهَا مَا نُرَاكِ أَغْنَيْتِ عَنَّا مِنْ شَىْءٍ فَارْجِعِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُولِي لَهُ إِنَّ أَزْوَاجَكَ يَنْشُدْنَكَ الْعَدْلَ فِي ابْنَةِ أَبِي قُحَافَةَ ‏.‏ فَقَالَتْ فَاطِمَةُ وَاللَّهِ لاَ أُكَلِّمُهُ فِيهَا أَبَدًا ‏.‏ قَالَتْ عَائِشَةُ فَأَرْسَلَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم زَيْنَبَ بِنْتَ جَحْشٍ زَوْجَ النَّبِيِّ صلى الله عليه وسلم وَهِيَ الَّتِي كَانَتْ تُسَامِينِي مِنْهُنَّ فِي الْمَنْزِلَةِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ أَرَ امْرَأَةً قَطُّ خَيْرًا فِي الدِّينِ مِنْ زَيْنَبَ وَأَتْقَى لِلَّهِ وَأَصْدَقَ حَدِيثًا وَأَوْصَلَ لِلرَّحِمِ وَأَعْظَمَ صَدَقَةً وَأَشَدَّ ابْتِذَالاً لِنَفْسِهَا فِي الْعَمَلِ الَّذِي تَصَدَّقُ بِهِ وَتَقَرَّبُ بِهِ إِلَى اللَّهِ تَعَالَى مَا عَدَا سَوْرَةً مِنْ حَدٍّ كَانَتْ فِيهَا تُسْرِعُ مِنْهَا الْفَيْئَةَ قَالَتْ فَاسْتَأْذَنَتْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ عَائِشَةَ فِي مِرْطِهَا عَلَى الْحَالَةِ الَّتِي دَخَلَتْ فَاطِمَةُ عَلَيْهَا وَهُوَ بِهَا فَأَذِنَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَزْوَاجَكَ أَرْسَلْنَنِي إِلَيْكَ يَسْأَلْنَكَ الْعَدْلَ فِي ابْنَةِ أَبِي قُحَافَةَ ‏.‏ قَالَتْ ثُمَّ وَقَعَتْ بِي فَاسْتَطَالَتْ عَلَىَّ وَأَنَا أَرْقُبُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَرْقُبُ طَرْفَهُ هَلْ يَأْذَنُ لِي فِيهَا - قَالَتْ - فَلَمْ تَبْرَحْ زَيْنَبُ حَتَّى عَرَفْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لاَ يَكْرَهُ أَنْ أَنْتَصِرَ - قَالَتْ - فَلَمَّا وَقَعْتُ بِهَا لَمْ أَنْشَبْهَا حِينَ أَنْحَيْتُ عَلَيْهَا - قَالَتْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَبَسَّمَ ‏"‏ إِنَّهَا ابْنَةُ أَبِي بَكْرٍ ‏"‏ ‏.‏\hadithno{6290}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), said:The wives of Allah's Apostle (ﷺ) sent Fatima, the daughter of Allah's Messenger (ﷺ), to Allah's Apostle (ﷺ). She sought permission to get in as he had been lying with me in my mantle. He gave her permission and she said: Allah's Messenger, verily, your wives have sent me to you in order to ask you to observe equity in case of the daughter of Abu Quhafa. She (`A'isha) said: I kept quiet. Thereupon Allah's Messenger (ﷺ) said to her (Fatima): O daughter, don't you love whom I love? She said: Yes, (I do). Thereupon he said: I love this one. Fatima then stood up as she heard this from Allah's Messenger (ﷺ) and went to the wives of Allah's Apostle (ﷺ) and informed them of what she had said to him and what Allah's messenger (ﷺ) had said to her. Thereupon they said to her: We think that you have been of no avail to us. You may again go to Allah's Messenger (ﷺ) and tell him that his wives seek equity in case of the daughter of Abu Quhafa. Fatima said: By Allah, I will never talk to him about this matter. `A'isha (further) reported: The wives of Allah's Apostle (ﷺ) then sent Zainab b. Jahsh, the wife of Allah's Apostle (ﷺ), and she was one who was somewhat equal in rank with me in the eyes of Allah's Messenger (ﷺ) and I have never seen a woman more advanced in religious piety than Zainab, more God-conscious, more truthful, more alive to the ties of blood, more generous and having more sense of self-sacrifice in practical life and having more charitable disposition and thus more close to God, the Exalted, than her. She, however, lost temper very soon but was soon calm. Allah's Messenger (ﷺ) permitted her to enter as she (`A'isha) was along with Allah's Messenger (ﷺ) in her mantle, in the same very state when Fatima had entered. She said: Allah's Messenger, your wives have sent me to you seeking equity in case of the daughter of Abu Quhafa. She then came to me and showed harshness to me and I was seeing the eyes of Allah's Messenger (ﷺ) whether he would permit me. Zainab went on until I came to know that Allah's Messenger (ﷺ) would not disapprove if I retorted. Then I exchanged hot words until I made her quiet. Thereupon Allah's Messenger (ﷺ) smiled and said: She is the daughter of Abu Bakr}}
\hadithdefcmd{muslim}{6291}{حَدَّثَنِيهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ قُهْزَاذَ، قَالَ عَبْدُ اللَّهِ بْنُ عُثْمَانَ حَدَّثَنِيهِ عَنْ عَبْدِ، اللَّهِ بْنِ الْمُبَارَكِ عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ فِي الْمَعْنَى غَيْرَ أَنَّهُ قَالَ فَلَمَّا وَقَعْتُ بِهَا لَمْ أَنْشَبْهَا أَنْ أَثْخَنْتُهَا غَلَبَةً ‏.‏\hadithno{6291}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters, but with a slight variation of wording}}
\hadithdefcmd{muslim}{6292}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ وَجَدْتُ فِي كِتَابِي عَنْ أَبِي أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيَتَفَقَّدُ يَقُولُ ‏ "‏ أَيْنَ أَنَا الْيَوْمَ أَيْنَ أَنَا غَدًا ‏"‏ ‏.‏ اسْتِبْطَاءً لِيَوْمِ عَائِشَةَ ‏.‏ قَالَتْ فَلَمَّا كَانَ يَوْمِي قَبَضَهُ اللَّهُ بَيْنَ سَحْرِي وَنَحْرِي ‏.‏\hadithno{6292}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) during his last illness) inquired:Where I would be tomorrow, where I would be tomorrow (thinking, that the turn of 'A'isha was not very near) and when it was my turn, Allah called him to his Heavenly Home and his head was between my neck and chest}}
\hadithdefcmd{muslim}{6293}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ قَبْلَ أَنْ يَمُوتَ وَهُوَ مُسْنِدٌ إِلَى صَدْرِهَا وَأَصْغَتْ إِلَيْهِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَأَلْحِقْنِي بِالرَّفِيقِ ‏"‏ ‏.‏\hadithno{6293}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) at the time of breathing his last was reclining against her chest and she was leaning over him and listening to him as he was saying:O Allah, grant me pardon, show mercy to me, enjoin me to companions (on High)}}
\hadithdefcmd{muslim}{6294}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6294}\hadithtrans{This hadith has been narrated on the authority of Hisham through another chain of transmitters}}
\hadithdefcmd{muslim}{6295}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَسْمَعُ أَنَّهُ لَنْ يَمُوتَ نَبِيٌّ حَتَّى يُخَيَّرَ بَيْنَ الدُّنْيَا وَالآخِرَةِ - قَالَتْ - فَسَمِعْتُ النَّبِيَّ صلى الله عليه وسلم فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ وَأَخَذَتْهُ بُحَّةٌ يَقُولُ ‏\{‏ مَعَ الَّذِينَ أَنْعَمَ اللَّهُ عَلَيْهِمْ مِنَ النَّبِيِّينَ وَالصِّدِّيقِينَ وَالشُّهَدَاءِ وَالصَّالِحِينَ وَحَسُنَ أُولَئِكَ رَفِيقًا‏\}‏ قَالَتْ فَظَنَنْتُهُ خُيِّرَ حِينَئِذٍ ‏.‏\hadithno{6295}\hadithtrans{A'isha reported:I heard that never a prophet dies until he is given an option to opt the life of (this) world or that of the Hereafter. She further said: I heard Allah's Messenger (ﷺ) say in his last illness in which he' died. I heard him saying in gruffness of the voice: Along with those persons upon whom Allah bestowed favours from amongst the Apostles, the testifiers of truth, the martyrs, the pious and goodly company are they (iv. 69). (It was on bearing these words) that I thought that he had been given choice (and he opted to live with these pious persons in the Paradise)}}
\hadithdefcmd{muslim}{6296}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي قَالاَ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6296}\hadithtrans{This hadith has been narrated on the authority of Sa'd with the same chain of transmitters}}
\hadithdefcmd{muslim}{6297}{حَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، قَالَ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَعُرْوَةُ بْنُ الزُّبَيْرِ، فِي رِجَالٍ مِنْ أَهْلِ الْعِلْمِ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهُوَ صَحِيحٌ ‏"‏ إِنَّهُ لَمْ يُقْبَضْ نَبِيٌّ قَطُّ حَتَّى يَرَى مَقْعَدَهُ فِي الْجَنَّةِ ثُمَّ يُخَيَّرُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَلَمَّا نَزَلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَرَأْسُهُ عَلَى فَخِذِي غُشِيَ عَلَيْهِ سَاعَةً ثُمَّ أَفَاقَ فَأَشْخَصَ بَصَرَهُ إِلَى السَّقْفِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ الرَّفِيقَ الأَعْلَى ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ قُلْتُ إِذًا لاَ يَخْتَارُنَا ‏.‏ قَالَتْ عَائِشَةُ وَعَرَفْتُ الْحَدِيثَ الَّذِي كَانَ يُحَدِّثُنَا بِهِ وَهُوَ صَحِيحٌ فِي قَوْلِهِ ‏"‏ إِنَّهُ لَمْ يُقْبَضْ نَبِيٌّ قَطُّ حَتَّى يَرَى مَقْعَدَهُ مِنَ الْجَنَّةِ ثُمَّ يُخَيَّرُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَكَانَتْ تِلْكَ آخِرُ كَلِمَةٍ تَكَلَّمَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَوْلَهُ ‏"‏ اللَّهُمَّ الرَّفِيقَ الأَعْلَى ‏"‏ ‏.‏\hadithno{6297}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported that he used to say:Never a prophet dies in a state that he is not made to see his abode in Paradise, and then given a choice. 'A'isha said that when Allah's Messenger (ﷺ) was about to leave the world, his head was over her thigh and he had fallen into swoon three times. When he felt relief his eyes were fixed at the ceiling. He then said: O Allah, along with the high companions (i. e. along with the Apostles who live in the most elevated place of the Paradise). (On hearing these words), I then said (to myself) He is not going to opt us and I remembered a hadith which he had narrated to us as he was healthy and in which he said: No prophet dies until he sees his abode in Paradise, he is then given a choice. 'A'isha said: These were the last words which Allah's Messenger (ﷺ) spoke (the words are): O Allah, with companions on High}}
\hadithdefcmd{muslim}{6298}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، كِلاَهُمَا عَنْ أَبِي نُعَيْمٍ، قَالَ عَبْدٌ حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ، حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ، بْنِ مُحَمَّدٍ عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا خَرَجَ أَقْرَعَ بَيْنَ نِسَائِهِ فَطَارَتِ الْقُرْعَةُ عَلَى عَائِشَةَ وَحَفْصَةَ فَخَرَجَتَا مَعَهُ جَمِيعًا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ بِاللَّيْلِ سَارَ مَعَ عَائِشَةَ يَتَحَدَّثُ مَعَهَا فَقَالَتْ حَفْصَةُ لِعَائِشَةَ أَلاَ تَرْكَبِينَ اللَّيْلَةَ بَعِيرِي وَأَرْكَبُ بَعِيرَكِ فَتَنْظُرِينَ وَأَنْظُرُ قَالَتْ بَلَى ‏.‏ فَرَكِبَتْ عَائِشَةُ عَلَى بَعِيرِ حَفْصَةَ وَرَكِبَتْ حَفْصَةُ عَلَى بَعِيرِ عَائِشَةَ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى جَمَلِ عَائِشَةَ وَعَلَيْهِ حَفْصَةُ فَسَلَّمَ ثُمَّ صَارَ مَعَهَا حَتَّى نَزَلُوا فَافْتَقَدَتْهُ عَائِشَةُ فَغَارَتْ فَلَمَّا نَزَلُوا جَعَلَتْ تَجْعَلُ رِجْلَهَا بَيْنَ الإِذْخِرِ وَتَقُولُ يَا رَبِّ سَلِّطْ عَلَىَّ عَقْرَبًا أَوْ حَيَّةً تَلْدَغُنِي رَسُولُكَ وَلاَ أَسْتَطِيعُ أَنْ أَقُولَ لَهُ شَيْئًا ‏.‏\hadithno{6298}\hadithtrans{A'isha reported that when Allah's Messenger (ﷺ) set ont on a journey, he used to cast lots amongst his wives. Once this lot came out in my favour and that of Hafsa. They (Hafsi, and 'A'isha) both went along with him and Allah's Messenger (ﷺ) used to travel (on camel) when it was night along with 'A'isha and talked with her. Hafsa said to 'A'isha:Would you like to ride upon my camel tonight and allow me to ride upon your camel and you would see (what you do not generally see) and I would see (what I do not see) generally? She said: Yes. So 'A'isha rode upon the camel of Hafsa and Hafsa rode upon the camel of 'A'isha and Allah's Messenger (ﷺ) came near the camel of 'A'isha. (whereas) Hafsa had been riding over that. He greeted her and then rode with her until they came down. She ('A'isha) thus missed (the company of the Holy Prophet) and when they sat down, 'A'isha felt jealous. She put her foot in the grass and said: O Allah, let the scorpion sting me or the serpent bite me. And so far as thy Messenger is concerned, I cannot say anything about him}}
\hadithdefcmd{muslim}{6299}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ فَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏ ‏.‏\hadithno{6299}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:The excellence of 'A'isha over women is like the excellence of Tharid over all other foods}}
\hadithdefcmd{muslim}{6300}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، يَعْنُونَ ابْنَ جَعْفَرٍ ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - كِلاَهُمَا عَنْ عَبْدِ اللَّهِ بْنِ، عَبْدِ الرَّحْمَنِ عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ وَلَيْسَ فِي حَدِيثِهِمَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَفِي حَدِيثِ إِسْمَاعِيلَ أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ‏.‏\hadithno{6300}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through other chains of transmitters}}
\hadithdefcmd{muslim}{6301}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، وَيَعْلَى بْنُ عُبَيْدٍ، عَنْ زَكَرِيَّاءَ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّهَا حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ إِنَّ جِبْرِيلَ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ ‏.‏\hadithno{6301}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) said to her:Gabriel offered you greetings and I said: So there should be peace and mercy of Allah upon him}}
\hadithdefcmd{muslim}{6302}{حَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمُلاَئِيُّ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ أَبِي زَائِدَةَ، قَالَ سَمِعْتُ عَامِرًا، يَقُولُ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهَا ‏.‏ بِمِثْلِ حَدِيثِهِمَا ‏.‏\hadithno{6302}\hadithtrans{This hadith has been narrated on the authority of 'A'isha through another chain of transmitters}}
\hadithdefcmd{muslim}{6303}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، عَنْ زَكَرِيَّاءَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6303}\hadithtrans{This hadith has been narrated on the authority of Zakriyya' through another chain of transmitters}}
\hadithdefcmd{muslim}{6304}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَائِشُ هَذَا جِبْرِيلُ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ ‏.‏ قَالَتْ وَهُوَ يَرَى مَا لاَ أَرَى ‏.‏\hadithno{6304}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported that Allah's Messenger (ﷺ) said:'A'isha, here is Gabriel offering you greetings. She said: 1 made a reply: Let there be peace and blessings of Allah upon him, and added: He sees what I do not see}}
\hadithdefcmd{muslim}{6305}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَأَحْمَدُ بْنُ جَنَابٍ، كِلاَهُمَا عَنْ عِيسَى، - وَاللَّفْظُ لاِبْنِ حُجْرٍ - حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَخِيهِ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ جَلَسَ إِحْدَى عَشْرَةَ امْرَأَةً فَتَعَاهَدْنَ وَتَعَاقَدْنَ أَنْ لاَ يَكْتُمْنَ مِنْ أَخْبَارِ أَزْوَاجِهِنَّ شَيْئًا قَالَتِ الأُولَى زَوْجِي لَحْمُ جَمَلٍ غَثٌّ عَلَى رَأْسِ جَبَلٍ وَعْرٍ لاَ سَهْلٌ فَيُرْتَقَى وَلاَ سَمِينٌ فَيُنْتَقَلَ ‏.‏ قَالَتِ الثَّانِيَةُ زَوْجِي لاَ أَبُثُّ خَبَرَهُ إِنِّي أَخَافُ أَنْ لاَ أَذَرَهُ إِنْ أَذْكُرْهُ أَذْكُرْ عُجَرَهُ وَبُجَرَهُ ‏.‏ قَالَتِ الثَّالِثَةُ زَوْجِي الْعَشَنَّقُ إِنْ أَنْطِقْ أُطَلَّقْ وَإِنْ أَسْكُتْ أُعَلَّقْ ‏.‏ قَالَتِ الرَّابِعَةُ زَوْجِي كَلَيْلِ تِهَامَةَ لاَ حَرٌّ وَلاَ قُرٌّ وَلاَ مَخَافَةَ وَلاَ سَآمَةَ ‏.‏ قَالَتِ الْخَامِسَةُ زَوْجِي إِنْ دَخَلَ فَهِدَ وَإِنْ خَرَجَ أَسِدَ وَلاَ يَسْأَلُ عَمَّا عَهِدَ ‏.‏ قَالَتِ السَّادِسَةُ زَوْجِي إِنْ أَكَلَ لَفَّ وَإِنْ شَرِبَ اشْتَفَّ وَإِنِ اضْطَجَعَ الْتَفَّ وَلاَ يُولِجُ الْكَفَّ لِيَعْلَمَ الْبَثَّ ‏.‏ قَالَتِ السَّابِعَةُ زَوْجِي غَيَايَاءُ أَوْ عَيَايَاءُ طَبَاقَاءُ كُلُّ دَاءٍ لَهُ دَاءٌ شَجَّكِ أَوْ فَلَّكِ أَوْ جَمَعَ كُلاًّ لَكِ ‏.‏ قَالَتِ الثَّامِنَةُ زَوْجِي الرِّيحُ رِيحُ زَرْنَبٍ وَالْمَسُّ مَسُّ أَرْنَبٍ ‏.‏ قَالَتِ التَّاسِعَةُ زَوْجِي رَفِيعُ الْعِمَادِ طَوِيلُ النِّجَادِ عَظِيمُ الرَّمَادِ قَرِيبُ الْبَيْتِ مِنَ النَّادِي ‏.‏ قَالَتِ الْعَاشِرَةُ زَوْجِي مَالِكٌ وَمَا مَالِكٌ مَالِكٌ خَيْرٌ مِنْ ذَلِكِ لَهُ إِبِلٌ كَثِيرَاتُ الْمَبَارِكِ قَلِيلاَتُ الْمَسَارِحِ إِذَا سَمِعْنَ صَوْتَ الْمِزْهَرِ أَيْقَنَّ أَنَّهُنَّ هَوَالِكُ ‏.‏ قَالَتِ الْحَادِيَةَ عَشْرَةَ زَوْجِي أَبُو زَرْعٍ فَمَا أَبُو زَرْعٍ أَنَاسَ مِنْ حُلِيٍّ أُذُنَىَّ وَمَلأَ مِنْ شَحْمٍ عَضُدَىَّ وَبَجَّحَنِي فَبَجِحَتْ إِلَىَّ نَفْسِي وَجَدَنِي فِي أَهْلِ غُنَيْمَةٍ بِشَقٍّ فَجَعَلَنِي فِي أَهْلِ صَهِيلٍ وَأَطِيطٍ وَدَائِسٍ وَمُنَقٍّ فَعِنْدَهُ أَقُولُ فَلاَ أُقَبَّحُ وَأَرْقُدُ فَأَتَصَبَّحُ وَأَشْرَبُ فَأَتَقَنَّحُ ‏.‏ أُمُّ أَبِي زَرْعٍ فَمَا أُمُّ أَبِي زَرْعٍ عُكُومُهَا رَدَاحٌ وَبَيْتُهَا فَسَاحٌ ‏.‏ ابْنُ أَبِي زَرْعٍ فَمَا ابْنُ أَبِي زَرْعٍ مَضْجِعُهُ كَمَسَلِّ شَطْبَةٍ وَيُشْبِعُهُ ذِرَاعُ الْجَفْرَةِ ‏.‏ بِنْتُ أَبِي زَرْعٍ فَمَا بِنْتُ أَبِي زَرْعٍ طَوْعُ أَبِيهَا وَطَوْعُ أُمِّهَا وَمِلْءُ كِسَائِهَا وَغَيْظُ جَارَتِهَا ‏.‏ جَارِيَةُ أَبِي زَرْعٍ فَمَا جَارِيَةُ أَبِي زَرْعٍ لاَ تَبُثُّ حَدِيثَنَا تَبْثِيثًا وَلاَ تُنَقِّثُ مِيرَتَنَا تَنْقِيثًا وَلاَ تَمْلأُ بَيْتَنَا تَعْشِيشًا ‏.‏ قَالَتْ خَرَجَ أَبُو زَرْعٍ وَالأَوْطَابُ تُمْخَضُ فَلَقِيَ امْرَأَةً مَعَهَا وَلَدَانِ لَهَا كَالْفَهْدَيْنِ يَلْعَبَانِ مِنْ تَحْتِ خَصْرِهَا بِرُمَّانَتَيْنِ فَطَلَّقَنِي وَنَكَحَهَا فَنَكَحْتُ بَعْدَهُ رَجُلاً سَرِيًّا رَكِبَ شَرِيًّا وَأَخَذَ خَطِّيًّا وَأَرَاحَ عَلَىَّ نَعَمًا ثَرِيًّا وَأَعْطَانِي مِنْ كُلِّ رَائِحَةٍ زَوْجًا ‏.‏ قَالَ كُلِي أُمَّ زَرْعٍ وَمِيرِي أَهْلَكِ فَلَوْ جَمَعْتُ كُلَّ شَىْءٍ أَعْطَانِي مَا بَلَغَ أَصْغَرَ آنِيَةِ أَبِي زَرْعٍ ‏.‏ قَالَتْ عَائِشَةُ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُنْتُ لَكِ كَأَبِي زَرْعٍ لأُمِّ زَرْعٍ ‏"‏ ‏.‏\hadithno{6305}\hadithtrans{A'isha reported that (one day) there sat together eleven women making an explicit promise amongst themselves that they would conceal nothing about their spouses. The first one said:My husband is a sort of the meat of a lean camel placed at the top of a hill, which it is difficult to climb up, nor (the meat) is good enough that one finds in oneself the urge to take it away (from the top of that mountain). The second one said: My husband (is so bad) that I am afraid I would not be able to describe his faults-both visible and invisible completely. The third one said: My husband is a long-statured fellow (i. e. he lacks intelligence). If I give vent to my feelings about him, he would divorce me, and if I keep quiet I would be made to live in a state of suspense (neither completely abandoned by him nor entertained as wife). The fourth one said: My husband is like the night of Tihama (the night of Hijaz and Mecca), neither too cold nor hot, neither there is any fear of him nor grief. The fifth one said: My husband is (like) a leopard as he enters the house, and behaves like a lion when he gets out, and he does not ask about that which he leaves in the house. The sixth one said: So far as my husband is concerned, he eats so much that nothing is left back and when he drinks he drinks that no drop is left behind. And when he lies down he wraps his body and does not touch me so that he may know my grief. The seventh one said: My husband is heavy in spirit, having no brightness in him, impotent, suffering from all kinds of conceivable diseases, heaving such rough manners that he may break my head or wound my body, or may do both. The eighth one said: My husband is as sweet as the sweet-smelling plant, and as soft as the softness of the hare. The ninth one said: My husband is the master of a lofty building, long-statured, having heaps of ashes (at his door) and his house is near the meeting place and the inn. The tenth one said: My husband is Malik, and how fine Malik is, much above appreciation and praise (of mine). He has many folds of his camel, more in number than the pastures for them. When they (the camels) hear the sound of music they become sure that they are going to be slaughtered. The eleventh one said: My husband is Abu Zara'. How fine Abu Zara' is! He has suspended in my ears heavy ornaments and (fed me liberally) that my sinews and bones are covered with fat. So he made me happy. He found me among the shepherds living in the side of the mountain, and he made me the owner of the horses, camels and lands and heaps of grain and he finds no fault with me. I sleep and get up in the morning (at my own sweet will) and drink to my heart's content. The mother of Abu Zara', how fine is the mother of Abu Zara'! Her bundles are heavily packed (or receptacles in her house are filled to the brim) and the house quite spacious. So far as the son of Abu Zara' is concerned, his bed is as soft as a green palm-stick drawn forth from its bark, or like a sword drawn forth from its scabbard, and whom just an arm of a lamb is enough to satiate. So far as the daughter of Abu Zara' is concerned, how fine is the daughter of Abu Zara', obedient to her father, obedient to her mother, wearing sufficient flesh and a source of jealousy for her co-wife. As for the slave-girl of Abu Zara', how fine is she; she does not disclose our affairs to others (outside the four walls of the house). She does not remove our wheat, or provision, or take it forth, or squander it, but she preserves it faithfully (as a sacred trust). And she does not let the house fill with rubbish. One day Abu Zara' went out (of his house) when the milk was churned in the vessels, that he met a woman, having two children like leopards playing with her pomegranates (chest) under her vest. He divorced me (Umm Zara') and married that woman (whom Abu Zara') met on the way. I (Umm Zara') later on married another person, a chief, who was an expert rider, and a fine archer: he bestowed upon me many gifts and gave me one pair of every kind of animal and said: Umm Zara', make use of everything (you need) and send forth to your parents (but the fact) is that even if I combine all the gifts that he bestowed upon me, they stand no comparison to the least gift of Abu Zara'. 'A'isha reported that Allah's Messenger (ﷺ) said to me: I am for you as Abu Zara' was for Umm Zara}}
\hadithdefcmd{muslim}{6306}{وَحَدَّثَنِيهِ الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سَعِيدُ، بْنُ سَلَمَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ عَيَايَاءُ طَبَاقَاءُ ‏.‏ وَلَمْ يَشُكَّ وَقَالَ قَلِيلاَتُ الْمَسَارِحِ ‏.‏ وَقَالَ وَصِفْرُ رِدَائِهَا وَخَيْرُ نِسَائِهَا وَعَقْرُ جَارَتِهَا ‏.‏ وَقَالَ وَلاَ تَنْقُثُ مِيرَتَنَا تَنْقِيثًا ‏.‏ وَقَالَ وَأَعْطَانِي مِنْ كُلِّ ذَابِحَةٍ زَوْجًا ‏.‏\hadithno{6306}\hadithtrans{This hadith has been transmitted on the authority of Hisham b. 'Urwa but with a slight variation of wording}}
\hadithdefcmd{muslim}{6307}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنِ اللَّيْثِ بْنِ سَعْدٍ، قَالَ ابْنُ يُونُسَ حَدَّثَنَا لَيْثٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ الْقُرَشِيُّ التَّيْمِيُّ، أَنَّحَدَّثَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَهُوَ يَقُولُ ‏ "‏ إِنَّ بَنِي هِشَامِ بْنِ الْمُغِيرَةِ اسْتَأْذَنُونِي أَنْ يُنْكِحُوا ابْنَتَهُمْ عَلِيَّ بْنَ أَبِي طَالِبٍ فَلاَ آذَنُ لَهُمْ ثُمَّ لاَ آذَنُ لَهُمْ ثُمَّ لاَ آذَنُ لَهُمْ إِلاَّ أَنْ يُحِبَّ ابْنُ أَبِي طَالِبٍ أَنْ يُطَلِّقَ ابْنَتِي وَيَنْكِحَ ابْنَتَهُمْ فَإِنَّمَا ابْنَتِي بَضْعَةٌ مِنِّي يَرِيبُنِي مَا رَابَهَا وَيُؤْذِينِي مَا آذَاهَا ‏"‏ ‏.‏\hadithno{6307}\hadithtrans{Miswar b. Makhramali reported that he heard Allah's Messenger (ﷺ) say, as he sat on the pulpit:The sons of Hisham b. Mughira have asked my permission to marry their daughter with 'Ali b. Abi Talib (that refers to the daughter of Abu Jahl for whom 'All had sent a proposal for marriage). But I would not allow them, I would not allow them, I would not allow them (and the only alternative possible is) that 'Ali should divorce my daughter (and then marry their daughter), for my daughter is part of me. He who disturbs her in fact disturbs me and he who offends her offends me}}
\hadithdefcmd{muslim}{6308}{حَدَّثَنِي أَبُو مَعْمَرٍ، إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الْهُذَلِيُّ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا فَاطِمَةُ بَضْعَةٌ مِنِّي يُؤْذِينِي مَا آذَاهَا ‏"‏ ‏.‏\hadithno{6308}\hadithtrans{Miswar b. Makhramah reported Allah's Messenger (ﷺ) as saying:Fatima is a part of me. He in fact tortures me who tortures her}}
\hadithdefcmd{muslim}{6309}{حَدَّثَنِي أَحْمَدُ بْنُ حَنْبَلٍ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ حَلْحَلَةَ الدُّؤَلِيُّ، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ أَنَّ عَلِيَّ بْنَ الْحُسَيْنِ حَدَّثَهُ أَنَّهُمْ، حِينَ قَدِمُوا الْمَدِينَةَ مِنْ عِنْدِ يَزِيدَ بْنِ مُعَاوِيَةَ مَقْتَلَ الْحُسَيْنِ بْنِ عَلِيٍّ رضى الله عنهما لَقِيَهُ الْمِسْوَرُ بْنُ مَخْرَمَةَ فَقَالَ لَهُ هَلْ لَكَ إِلَىَّ مِنْ حَاجَةٍ تَأْمُرُنِي بِهَا قَالَ فَقُلْتُ لَهُ لاَ ‏.‏ قَالَ لَهُ هَلْ أَنْتَ مُعْطِيَّ سَيْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنِّي أَخَافُ أَنْ يَغْلِبَكَ الْقَوْمُ عَلَيْهِ وَايْمُ اللَّهِ لَئِنْ أَعْطَيْتَنِيهِ لاَ يُخْلَصُ إِلَيْهِ أَبَدًا حَتَّى تَبْلُغَ نَفْسِي إِنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ خَطَبَ بِنْتَ أَبِي جَهْلٍ عَلَى فَاطِمَةَ فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَخْطُبُ النَّاسَ فِي ذَلِكَ عَلَى مِنْبَرِهِ هَذَا وَأَنَا يَوْمَئِذٍ مُحْتَلِمٌ فَقَالَ ‏"‏ إِنَّ فَاطِمَةَ مِنِّي وَإِنِّي أَتَخَوَّفُ أَنْ تُفْتَنَ فِي دِينِهَا ‏"‏ ‏.‏ قَالَ ثُمَّ ذَكَرَ صِهْرًا لَهُ مِنْ بَنِي عَبْدِ شَمْسٍ فَأَثْنَى عَلَيْهِ فِي مُصَاهَرَتِهِ إِيَّاهُ فَأَحْسَنَ قَالَ ‏"‏ حَدَّثَنِي فَصَدَقَنِي وَوَعَدَنِي فَأَوْفَى لِي وَإِنِّي لَسْتُ أُحَرِّمُ حَلاَلاً وَلاَ أُحِلُّ حَرَامًا وَلَكِنْ وَاللَّهِ لاَ تَجْتَمِعُ بِنْتُ رَسُولِ اللَّهِ وَبِنْتُ عَدُوِّ اللَّهِ مَكَانًا وَاحِدًا أَبَدًا ‏"‏ ‏.‏\hadithno{6309}\hadithtrans{(Imam Zain-ul-'Abidin) 'Ali b. Husain reported that when they came to Medina from Yazid b. Mu'awiya after the martyrdom of Husain b. 'Ali (Allah be pleased with him) Miswar b. Makhramah met him and said to him:Is there any work for me which you ask me to do? I said to him: No. He again said to me: Would you not give me the sword of Allah's Messenger (ﷺ) for I fear that the people may snatch it from you? By Allah, if you give that to me, no one would be able to take it away, so long as there is life in me. Verily 'Ali b. Abi Talib sent a proposal of marriage to the daughter of Abu Jahl in spite of (the fact that his wife) Fatima (had been living in his house). Thereupon I heard Allah's Messenger (ﷺ) say while addressing the people on the pulpit. I was adolescing in those days. He said: Fatima is a part of me and I fear that she may be put to trial in regard to religion. He then made a mention of his son-in law who had been from the tribe of 'Abd Shams and praised his behaviour as a son-in-law and said: Whatever he said to me he told the truth and whatever he promised he fulfilled it for me. I am not going to declare forbidden what is lawful and make lawful what is forbidden, but, by Allah, the daaghter of Allah's Messenger and the daughter of the enemy of Allah can never be combined at one place}}
\hadithdefcmd{muslim}{6310}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ خَطَبَ بِنْتَ أَبِي جَهْلٍ وَعِنْدَهُ فَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا سَمِعَتْ بِذَلِكَ فَاطِمَةُ أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ لَهُ إِنَّ قَوْمَكَ يَتَحَدَّثُونَ أَنَّكَ لاَ تَغْضَبُ لِبَنَاتِكَ وَهَذَا عَلِيٌّ نَاكِحًا ابْنَةَ أَبِي جَهْلٍ ‏.‏ قَالَ الْمِسْوَرُ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَسَمِعْتُهُ حِينَ تَشَهَّدَ ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ فَإِنِّي أَنْكَحْتُ أَبَا الْعَاصِ بْنَ الرَّبِيعِ فَحَدَّثَنِي فَصَدَقَنِي وَإِنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ مُضْغَةٌ مِنِّي وَإِنَّمَا أَكْرَهُ أَنْ يَفْتِنُوهَا وَإِنَّهَا وَاللَّهِ لاَ تَجْتَمِعُ بِنْتُ رَسُولِ اللَّهِ وَبِنْتُ عَدُوِّ اللَّهِ عِنْدَ رَجُلٍ وَاحِدٍ أَبَدًا ‏"‏ ‏.‏ قَالَ فَتَرَكَ عَلِيٌّ الْخِطْبَةَ ‏.‏\hadithno{6310}\hadithtrans{Ali b. Husain reported that Miswar b. Makhramah informed him that 'Ali b. Abi Talib sent the proposal of marriage to the daughter of Abu Jahl as he had Fatima, the daughter of Allah's Messenger (ﷺ), (as his wife). When Fatima heard about it, she came to Allah's Apostle (ﷺ) and said:The people say that you never feel angry on account of your daughters and now 'Ali is going to marry the daughter of Abu Jahl. Makhramah said: Thereupon Allah's Messenger (ﷺ) rose up and I heard him reciting Tashahhud and say: Now to the point. I gave a daughter of mine (Zainab) to Abu'l-'As b. Rabi, and he spoke to me and spoke the truth. Verily Fatima, the daughter of Muhammad, is a part of me and I do not approve that she may be put to any trial and by Allah, the daughter of Allah's Messenger cannot be combined with the daughter of God's enemy (as the co-wives) of one person. Thereupon 'Ali gave up (the idea of his intended) marriage}}
\hadithdefcmd{muslim}{6311}{وَحَدَّثَنِيهِ أَبُو مَعْنٍ الرَّقَاشِيُّ، حَدَّثَنَا وَهْبٌ، - يَعْنِي ابْنَ جَرِيرٍ - عَنْ أَبِيهِ، قَالَ سَمِعْتُ النُّعْمَانَ، - يَعْنِي ابْنَ رَاشِدٍ - يُحَدِّثُ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6311}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{6312}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ عَائِشَةَ حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَعَا فَاطِمَةَ ابْنَتَهُ فَسَارَّهَا فَبَكَتْ ثُمَّ سَارَّهَا فَضَحِكَتْ فَقَالَتْ عَائِشَةُ فَقُلْتُ لِفَاطِمَةَ مَا هَذَا الَّذِي سَارَّكِ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَبَكَيْتِ ثُمَّ سَارَّكِ فَضَحِكْتِ قَالَتْ سَارَّنِي فَأَخْبَرَنِي بِمَوْتِهِ فَبَكَيْتُ ثُمَّ سَارَّنِي فَأَخْبَرَنِي أَنِّي أَوَّلُ مَنْ يَتْبَعُهُ مِنْ أَهْلِهِ فَضَحِكْتُ ‏.‏\hadithno{6312}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) called his daughter Fatima (during his last illness). He said. to her something secretly and she wept. He again said to her something secretly and she laughed. 'A'isha further reported that she said to Fatima:What is that which Allah's Messenger (ﷺ) said to you secretly and you wept and then said to you something secretly and you laughed? Thereupon she said: He informed me secretly of his death and so I wept. He then again informed me secretly that I would be the first amongst the members of his family to follow him and so I laughed}}
\hadithdefcmd{muslim}{6313}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كُنَّ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم عِنْدَهُ لَمْ يُغَادِرْ مِنْهُنَّ وَاحِدَةً فَأَقْبَلَتْ فَاطِمَةُ تَمْشِي مَا تُخْطِئُ مِشْيَتُهَا مِنْ مِشْيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم شَيْئًا فَلَمَّا رَآهَا رَحَّبَ بِهَا فَقَالَ ‏"‏ مَرْحَبًا بِابْنَتِي ‏"‏ ‏.‏ ثُمَّ أَجْلَسَهَا عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ ثُمَّ سَارَّهَا فَبَكَتْ بُكَاءً شَدِيدًا فَلَمَّا رَأَى جَزَعَهَا سَارَّهَا الثَّانِيَةَ فَضَحِكَتْ ‏.‏ فَقُلْتُ لَهَا خَصَّكِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ بَيْنِ نِسَائِهِ بِالسِّرَارِ ثُمَّ أَنْتِ تَبْكِينَ فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَأَلْتُهَا مَا قَالَ لَكِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ مَا كُنْتُ أُفْشِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سِرَّهُ ‏.‏ قَالَتْ فَلَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ عَزَمْتُ عَلَيْكِ بِمَا لِي عَلَيْكِ مِنَ الْحَقِّ لَمَا حَدَّثْتِنِي مَا قَالَ لَكِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ أَمَّا الآنَ فَنَعَمْ أَمَّا حِينَ سَارَّنِي فِي الْمَرَّةِ الأُولَى فَأَخْبَرَنِي ‏"‏ أَنَّ جِبْرِيلَ كَانَ يُعَارِضُهُ الْقُرْآنَ فِي كُلِّ سَنَةٍ مَرَّةً أَوْ مَرَّتَيْنِ وَإِنَّهُ عَارَضَهُ الآنَ مَرَّتَيْنِ وَإِنِّي لاَ أُرَى الأَجَلَ إِلاَّ قَدِ اقْتَرَبَ فَاتَّقِي اللَّهَ وَاصْبِرِي فَإِنَّهُ نِعْمَ السَّلَفُ أَنَا لَكِ ‏"‏ ‏.‏ قَالَتْ فَبَكَيْتُ بُكَائِي الَّذِي رَأَيْتِ فَلَمَّا رَأَى جَزَعِي سَارَّنِي الثَّانِيَةَ فَقَالَ ‏"‏ يَا فَاطِمَةُ أَمَا تَرْضَىْ أَنْ تَكُونِي سَيِّدَةَ نِسَاءِ الْمُؤْمِنِينَ أَوْ سَيِّدَةَ نِسَاءِ هَذِهِ الأُمَّةِ ‏"‏ ‏.‏ قَالَتْ فَضَحِكْتُ ضَحِكِي الَّذِي رَأَيْتِ ‏.‏\hadithno{6313}\hadithtrans{A'isha reported:We, the wives of Allah's Apostle (ﷺ), were with him (during his last illness) and none was absent therefrom that Fatima, who walked after the style of Allah's Messenger (ﷺ), came there, and when he saw her he welcomed her saying: You are welcome, my daughter. He their made her sit on his right side or on his left side. Then he said something secretly to her and she wept bitterly and when he found her (plunged) in grief he said to her something secretly for the second time and she laughed. I ('A'isha) said to her: Allah's Messenger has singled you amongst the women (of the family) for talking (to you something secretly) and you wept. When Allah's Messenger (ﷺ) recovered from illness, I said to her. What did Allah's Messenger (ﷺ) say to you? Thereupon she said: I am not going to disclose the secret of Allah's Messenger (ﷺ). When Allah's Messenger (ﷺ) died, I said to her: I adjure you by the right that I have upon you that you should narrate to me what Allah's Messenger (ﷺ) said to you. She said: Yes, now I can do that (so listen to it). When he talked to me secretly for the first time he informed me that Gabirel was in the habit of reciting the Qur'an along with him once or twice every year, but this year it had been twice and so he perceived his death quite near, so fear Allah and be patient (and he told me) that he would be a befitting forerunner for me and so I wept as you saw me. And when he saw me in grief he talked to me secretly for the second time and said: Fatima, are you not pleased that you should be at the head of the believing women or the head of this Umma? I laughed and it was that laughter which you saw}}
\hadithdefcmd{muslim}{6314}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ زَكَرِيَّاءَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتِ اجْتَمَعَ نِسَاءُ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يُغَادِرْ مِنْهُنَّ امْرَأَةً فَجَاءَتْ فَاطِمَةُ تَمْشِي كَأَنَّ مِشْيَتَهَا مِشْيَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَرْحَبًا بِابْنَتِي ‏"‏ ‏.‏ فَأَجْلَسَهَا عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ ثُمَّ إِنَّهُ أَسَرَّ إِلَيْهَا حَدِيثًا فَبَكَتْ فَاطِمَةُ ثُمَّ إِنَّهُ سَارَّهَا فَضَحِكَتْ أَيْضًا فَقُلْتُ لَهَا مَا يُبْكِيكِ فَقَالَتْ مَا كُنْتُ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقُلْتُ مَا رَأَيْتُ كَالْيَوْمِ فَرَحًا أَقْرَبَ مِنْ حُزْنٍ ‏.‏ فَقُلْتُ لَهَا حِينَ بَكَتْ أَخَصَّكِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِحَدِيثِهِ دُونَنَا ثُمَّ تَبْكِينَ وَسَأَلْتُهَا عَمَّا قَالَ فَقَالَتْ مَا كُنْتُ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ حَتَّى إِذَا قُبِضَ سَأَلْتُهَا فَقَالَتْ إِنَّهُ كَانَ حَدَّثَنِي ‏"‏ أَنَّ جِبْرِيلَ كَانَ يُعَارِضُهُ بِالْقُرْآنِ كُلَّ عَامٍ مَرَّةً وَإِنَّهُ عَارَضَهُ بِهِ فِي الْعَامِ مَرَّتَيْنِ وَلاَ أُرَانِي إِلاَّ قَدْ حَضَرَ أَجَلِي وَإِنَّكِ أَوَّلُ أَهْلِي لُحُوقًا بِي وَنِعْمَ السَّلَفُ أَنَا لَكِ ‏"‏ ‏.‏ فَبَكَيْتُ لِذَلِكِ ثُمَّ إِنَّهُ سَارَّنِي فَقَالَ ‏"‏ أَلاَ تَرْضَيْنَ أَنْ تَكُونِي سَيِّدَةَ نِسَاءِ الْمُؤْمِنِينَ أَوْ سَيِّدَةَ نِسَاءِ هَذِهِ الأُمَّةِ ‏"‏ ‏.‏ فَضَحِكْتُ لِذَلِكِ ‏.‏\hadithno{6314}\hadithtrans{A'isha reported that all the wives of Allah's Apostle (ﷺ) had gathered (in her apartment) during the days of his (Prophet's) last illness and no woman was left behind that Fatima, who walked after the style of Allah's Messenger (ﷺ), came there. He welcomed her by saying:You are welcome, my daughter, and made her sit on his right side or on his left side, and then talked something secretly to her and Fatima wept. Then he talked something secretly to her and she laughed. I said to her: What makes you weep? She said: I am not going to divulge the secret of Allah's Messenger (ﷺ). I (`A'isha) said: I have not seen (anything happening) like today, the happiness being more close to grief (as I see today) when she wept. I said to her: Has Allah's Messenger (ﷺ) singled you out for saying something leaving us aside? She then wept and I asked her what he said, and she said: I am not going to divulge the secrets of Allah's Messenger (ﷺ). And when he died I again asked her and she said that he (the Holy Prophet) told her: Gabriel used to recite the Qur'an to me once a year and for this year it was twice and so I perceived that my death had drawn near, and that I (Fatima) would be the first amongst the members of his family who would meet him (in the Hereafter). He shall be my good forerunner and it made me weep. He again talked to me secretly (saying): Aren't you pleased that you should be the sovereign amongst the believing women or the head of women of this Ummah? And this made me laugh}}
\hadithdefcmd{muslim}{6315}{حَدَّثَنِي عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الْقَيْسِيُّ، كِلاَهُمَا عَنِ الْمُعْتَمِرِ، - قَالَ ابْنُ حَمَّادٍ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، - قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ سَلْمَانَ، قَالَ لاَ تَكُونَنَّ إِنِ اسْتَطَعْتَ أَوَّلَ مَنْ يَدْخُلُ السُّوقَ وَلاَ آخِرَ مَنْ يَخْرُجُ مِنْهَا فَإِنَّهَا مَعْرَكَةُ الشَّيْطَانِ وَبِهَا يَنْصِبُ رَايَتَهُ ‏.‏ قَالَ وَأُنْبِئْتُ أَنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ أَتَى نَبِيَّ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ أُمُّ سَلَمَةَ - قَالَ - فَجَعَلَ يَتَحَدَّثُ ثُمَّ قَامَ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم لأُمِّ سَلَمَةَ ‏ "‏ مَنْ هَذَا ‏"‏ ‏.‏ أَوْ كَمَا قَالَ قَالَتْ هَذَا دِحْيَةُ - قَالَ - فَقَالَتْ أُمُّ سَلَمَةَ ايْمُ اللَّهِ مَا حَسِبْتُهُ إِلاَّ إِيَّاهُ حَتَّى سَمِعْتُ خُطْبَةَ نَبِيِّ اللَّهِ صلى الله عليه وسلم يُخْبِرُ خَبَرَنَا أَوْ كَمَا قَالَ قَالَ فَقُلْتُ لأَبِي عُثْمَانَ مِمَّنْ سَمِعْتَ هَذَا قَالَ مِنْ أُسَامَةَ بْنِ زَيْدٍ ‏.‏\hadithno{6315}\hadithtrans{Salman reported:In case it lies in your power don't be one to enter the bazar first and the last to get out of that because there is a bustle and the standard of Satan is set there. He said: I was informed that Gabriel (Allah be pleased with him) came to Allah's Apostle (ﷺ) and there was with him Umin Salama and he began to talk with him. He then stood up, whereupon Allah's Apostle (ﷺ) said to Umm Salama: (Do you know) who was he and what did he say? She said: He was Dihya (Kalbi). He reported Umm Salama having said: By Allah, I did not deem him but only he (Dihya) until I heard the address of Allah's Apostle (ﷺ) informing him about us. He (the narrator) said: I said to Uthman: From whom did you hear it? He said: From Usima b. Zaid}}
\hadithdefcmd{muslim}{6316}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ أَبُو أَحْمَدَ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى السِّيْنَانِيُّ، أَخْبَرَنَا طَلْحَةُ بْنُ يَحْيَى بْنِ طَلْحَةَ، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَسْرَعُكُنَّ لَحَاقًا بِي أَطْوَلُكُنَّ يَدًا ‏"‏ ‏.‏ قَالَتْ فَكُنَّ يَتَطَاوَلْنَ أَيَّتُهُنَّ أَطْوَلُ يَدًا ‏.‏ قَالَتْ فَكَانَتْ أَطْوَلَنَا يَدًا زَيْنَبُ لأَنَّهَا كَانَتْ تَعْمَلُ بِيَدِهَا وَتَصَدَّقُ ‏.‏\hadithno{6316}\hadithtrans{A'isha, the Mother of the Faithful, reported that Allah's Messenger (ﷺ) said:One who has the longest hands amongst you would meet me most immediately. She farther said: They (the wives of Allah's Apostle) used to measure the hands as to whose hand was the longest and it was the hand of Zainab that was the longest amongst them, as she used to work with her hand and Spend (that income) on charity}}
\hadithdefcmd{muslim}{6317}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ انْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أُمِّ أَيْمَنَ فَانْطَلَقْتُ مَعَهُ فَنَاوَلَتْهُ إِنَاءً فِيهِ شَرَابٌ - قَالَ - فَلاَ أَدْرِي أَصَادَفَتْهُ صَائِمًا أَوْ لَمْ يُرِدْهُ فَجَعَلَتْ تَصْخَبُ عَلَيْهِ وَتَذَمَّرُ عَلَيْهِ ‏.‏\hadithno{6317}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) went to Umm Aiman and I went along with him and she served him a drink in a vessel and he reported that the narrator said:I do not know whether it was because of the fasting (or for any other reason) that he (the Holy Prophet) refused to accept that. She raised her voice and showed annoyance to him}}
\hadithdefcmd{muslim}{6318}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، أَخْبَرَنِي عَمْرُو بْنُ عَاصِمٍ الْكِلاَبِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ أَبُو بَكْرٍ رضى الله عنه بَعْدَ وَفَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم لِعُمَرَ انْطَلِقْ بِنَا إِلَى أُمِّ أَيْمَنَ نَزُورُهَا كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَزُورُهَا ‏.‏ فَلَمَّا انْتَهَيْنَا إِلَيْهَا بَكَتْ فَقَالاَ لَهَا مَا يُبْكِيكِ مَا عِنْدَ اللَّهِ خَيْرٌ لِرَسُولِهِ صلى الله عليه وسلم ‏.‏ فَقَالَتْ مَا أَبْكِي أَنْ لاَ أَكُونَ أَعْلَمُ أَنَّ مَا عِنْدَ اللَّهِ خَيْرٌ لِرَسُولِهِ صلى الله عليه وسلم وَلَكِنْ أَبْكِي أَنَّ الْوَحْىَ قَدِ انْقَطَعَ مِنَ السَّمَاءِ ‏.‏ فَهَيَّجَتْهُمَا عَلَى الْبُكَاءِ فَجَعَلاَ يَبْكِيَانِ مَعَهَا ‏.‏\hadithno{6318}\hadithtrans{Anas reported that after the death of Allah's Messenger (ﷺ) Abu Bakr said to 'Umar:Let us visit Umm Aiman as Allah's Messenger (ﷺ) used to visit her. As we came to her, she wept. They (Abu Bakr and Umar) said to her: What makes you weep? What is in store (in the next world) for Allah's-Messenger (ﷺ) is better than (this worldly life). She said: I weep not because I am ignorant of the fact that what is in store for Allah's Messenger (ﷺ) (in the next world) is better than (this world), but I weep because the revelation which came from the Heaven has ceased to come. This moved both of them to tears and they began to weep along with her}}
\hadithdefcmd{muslim}{6319}{حَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ، اللَّهِ عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَدْخُلُ عَلَى أَحَدٍ مِنَ النِّسَاءِ إِلاَّ عَلَى أَزْوَاجِهِ إِلاَّ أُمِّ سُلَيْمٍ فَإِنَّهُ كَانَ يَدْخُلُ عَلَيْهَا فَقِيلَ لَهُ فِي ذَلِكَ فَقَالَ ‏ "‏ إِنِّي أَرْحَمُهَا قُتِلَ أَخُوهَا مَعِي ‏"‏ ‏.‏\hadithno{6319}\hadithtrans{Anas reported that Allah's Apostle (ﷺ) did not enter the house of any woman except that of his wives and that of Umm Sulaim. He used to visit her. It was said to him why it was so, whereupon he said:I feel great compassion for her. Her brother was killed while he was with me}}
\hadithdefcmd{muslim}{6320}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ السَّرِيِّ - حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ دَخَلْتُ الْجَنَّةَ فَسَمِعْتُ خَشْفَةً فَقُلْتُ مَنْ هَذَا قَالُوا هَذِهِ الْغُمَيْصَاءُ بِنْتُ مِلْحَانَ أُمُّ أَنَسِ بْنِ مَالِكٍ ‏"‏ ‏.‏\hadithno{6320}\hadithtrans{Anas reported that Allah's Apostle (ﷺ) said:I entered Paradise and heard the noise of steps. I said: Who is it? They said: She is Ghumaisa, daughter of Milhan, the mother of Anas b. Malik}}
\hadithdefcmd{muslim}{6321}{حَدَّثَنِي أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الْفَرَجِ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، أَخْبَرَنِي عَبْدُ الْعَزِيزِ، بْنُ أَبِي سَلَمَةَ أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُرِيتُ الْجَنَّةَ فَرَأَيْتُ امْرَأَةَ أَبِي طَلْحَةَ ثُمَّ سَمِعْتُ خَشْخَشَةً أَمَامِي فَإِذَا بِلاَلٌ ‏"‏ ‏.‏\hadithno{6321}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messenger (ﷺ) said:I was shown Paradise and I saw the wife of Abu Talha (i.e. Umm Sulaim) and I heard the noise of steps before me and, lo, it was that of Bilal}}
\hadithdefcmd{muslim}{6322}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ مَاتَ ابْنٌ لأَبِي طَلْحَةَ مِنْ أُمِّ سُلَيْمٍ فَقَالَتْ لأَهْلِهَا لاَ تُحَدِّثُوا أَبَا طَلْحَةَ بِابْنِهِ حَتَّى أَكُونَ أَنَا أُحَدِّثُهُ - قَالَ - فَجَاءَ فَقَرَّبَتْ إِلَيْهِ عَشَاءً فَأَكَلَ وَشَرِبَ - فَقَالَ - ثُمَّ تَصَنَّعَتْ لَهُ أَحْسَنَ مَا كَانَ تَصَنَّعُ قَبْلَ ذَلِكَ فَوَقَعَ بِهَا فَلَمَّا رَأَتْ أَنَّهُ قَدْ شَبِعَ وَأَصَابَ مِنْهَا قَالَتْ يَا أَبَا طَلْحَةَ أَرَأَيْتَ لَوْ أَنَّ قَوْمًا أَعَارُوا عَارِيَتَهُمْ أَهْلَ بَيْتٍ فَطَلَبُوا عَارِيَتَهُمْ أَلَهُمْ أَنْ يَمْنَعُوهُمْ قَالَ لاَ ‏.‏ قَالَتْ فَاحْتَسِبِ ابْنَكَ ‏.‏ قَالَ فَغَضِبَ وَقَالَ تَرَكْتِنِي حَتَّى تَلَطَّخْتُ ثُمَّ أَخْبَرْتِنِي بِابْنِي ‏.‏ فَانْطَلَقَ حَتَّى أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِمَا كَانَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَارَكَ اللَّهُ لَكُمَا فِي غَابِرِ لَيْلَتِكُمَا ‏"‏ ‏.‏ قَالَ فَحَمَلَتْ - قَالَ - فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ وَهِيَ مَعَهُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَى الْمَدِينَةَ مِنْ سَفَرٍ لاَ يَطْرُقُهَا طُرُوقًا فَدَنَوْا مِنَ الْمَدِينَةِ فَضَرَبَهَا الْمَخَاضُ فَاحْتُبِسَ عَلَيْهَا أَبُو طَلْحَةَ وَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - يَقُولُ أَبُو طَلْحَةَ إِنَّكَ لَتَعْلَمُ يَا رَبِّ إِنَّهُ يُعْجِبُنِي أَنْ أَخْرُجَ مَعَ رَسُولِكَ إِذَا خَرَجَ وَأَدْخُلَ مَعَهُ إِذَا دَخَلَ وَقَدِ احْتُبِسْتُ بِمَا تَرَى - قَالَ - تَقُولُ أُمُّ سُلَيْمٍ يَا أَبَا طَلْحَةَ مَا أَجِدُ الَّذِي كُنْتُ أَجِدُ انْطَلِقْ ‏.‏ فَانْطَلَقْنَا - قَالَ - وَضَرَبَهَا الْمَخَاضُ حِينَ قَدِمَا فَوَلَدَتْ غُلاَمًا فَقَالَتْ لِي أُمِّي يَا أَنَسُ لاَ يُرْضِعُهُ أَحَدٌ حَتَّى تَغْدُوَ بِهِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَلَمَّا أَصْبَحَ احْتَمَلْتُهُ فَانْطَلَقْتُ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - فَصَادَفْتُهُ وَمَعَهُ مِيسَمٌ فَلَمَّا رَآنِي قَالَ ‏"‏ لَعَلَّ أُمَّ سُلَيْمٍ وَلَدَتْ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَوَضَعَ الْمِيسَمَ - قَالَ - وَجِئْتُ بِهِ فَوَضَعْتُهُ فِي حَجْرِهِ وَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَجْوَةٍ مِنْ عَجْوَةِ الْمَدِينَةِ فَلاَكَهَا فِي فِيهِ حَتَّى ذَابَتْ ثُمَّ قَذَفَهَا فِي فِي الصَّبِيِّ فَجَعَلَ الصَّبِيُّ يَتَلَمَّظُهَا - قَالَ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْظُرُوا إِلَى حُبِّ الأَنْصَارِ التَّمْرَ ‏"‏ ‏.‏ قَالَ فَمَسَحَ وَجْهَهُ وَسَمَّاهُ عَبْدَ اللَّهِ ‏.‏\hadithno{6322}\hadithtrans{Anas reported that the son of Abu Talba who was born of Umm Sulaim died. She (Umm Sulaim) said to the members of her family:Do not narrate to Abu Talha about his son until I narrate it to him. Abu Talha came (home) ; she presented to him the supper. He took it and drank water. She then embellished herself which she did not do before. He (Abu Talha) had a sexual intercourse with her and when she saw that he was satisfied after sexual intercourse with her, she said: Abu Talha, if some people borrow something from another family and then (the members of the family) ask for its return, would they resist its return? He said: No. She said: I inform you about the death of your son. He was annoyed, and said: You did not inform me until I had a sexual intercourse with you and you later on gave me information about my son. He went to Allah's Messenger (ﷺ) and informed him what had happened. Thereupon Allah's Messenger (ﷺ) said: May Allah bless both of you in the night spent by you! He (the narrator) said: She became pregnant. Allah's Messenger (may peace he upon him) was in the course of a journey and she was along with him and when Allah's Messenger (ﷺ) came back to Medina from the journey he did not enter (his house) (during the night). When the people came near Medina, she felt the pangs of delivery. He (Abu Talha) remained with her and Allah's Messenger (ﷺ) proceeded on. Abu Talha said: O Lord, you know that I love to go along with Allah's Messenger when he goes out and enter along with him when he enters and I have been detained as Thou seest. Umm Sulaim said: Abu Talha, I do not feel (so much pain) as I was feeling formerly, so better proceed on. So we proceeded on and she felt the pangs of delivery as they reached (Medina) and a child was born and my mother said to me: Anas, none should suckle him until you go to Allah's Messenger (ﷺ) tomorrow morning. And when it was morning I carried him (the child) and went along with him to Allah's Messenger (may peace beupon him). He said: I saw that he had in his hand the instrument for the cauterisation of the camels. When he saw me. he said: This is, perhaps, what Umm Sulaim has given birth to. I said: Yes. He laid down that instrument on the ground. I brought that child to him and placed it in his lap and Allah's Messenger (ﷺ) asked Ajwa dates of Medina to be brought and softened them in his month. When these had become palatable he placed them in the mouth of that child. The child began to taste them. Then Allah's Messenger (ﷺ) said: See what love the Ansar have for dates. He then wiped his face and named him 'Abdullah}}
\hadithdefcmd{muslim}{6323}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ بْنِ خِرَاشٍ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ، الْمُغِيرَةِ حَدَّثَنَا ثَابِتٌ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ مَاتَ ابْنٌ لأَبِي طَلْحَةَ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمِثْلِهِ ‏.‏\hadithno{6323}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{6324}{حَدَّثَنَا عُبَيْدُ بْنُ يَعِيشَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أَبِي حَيَّانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو حَيَّانَ التَّيْمِيُّ يَحْيَى بْنُ سَعِيدٍ عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِبِلاَلٍ عِنْدَ صَلاَةِ الْغَدَاةِ ‏ "‏ يَا بِلاَلُ حَدِّثْنِي بِأَرْجَى عَمَلٍ عَمِلْتَهُ عِنْدَكَ فِي الإِسْلاَمِ مَنْفَعَةً فَإِنِّي سَمِعْتُ اللَّيْلَةَ خَشْفَ نَعْلَيْكَ بَيْنَ يَدَىَّ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ بِلاَلٌ مَا عَمِلْتُ عَمَلاً فِي الإِسْلاَمِ أَرْجَى عِنْدِي مَنْفَعَةً مِنْ أَنِّي لاَ أَتَطَهَّرُ طُهُورًا تَامًّا فِي سَاعَةٍ مِنْ لَيْلٍ وَلاَ نَهَارٍ إِلاَّ صَلَّيْتُ بِذَلِكَ الطُّهُورِ مَا كَتَبَ اللَّهُ لِي أَنْ أُصَلِّيَ ‏.‏\hadithno{6324}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said to Bilal:Bilal, narrate to me which act at the time of morning prayer you did in Islam for which you hope to receive good reward, for I heard during the night the sound of your steps before me in Paradise. Bilal said: I did not do any act in Islam for which I hope to get any benefit but this that when I perform complete ablution during the night or day I observe prayer with that purification what Allah has ordained for me to pray}}
\hadithdefcmd{muslim}{6325}{حَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، وَسَهْلُ بْنُ عُثْمَانَ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ، زُرَارَةَ الْحَضْرَمِيُّ وَسُوَيْدُ بْنُ سَعِيدٍ وَالْوَلِيدُ بْنُ شُجَاعٍ قَالَ سَهْلٌ وَمِنْجَابٌ أَخْبَرَنَا وَقَالَ، الآخَرُونَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ لَيْسَ عَلَى الَّذِينَ آمَنُوا وَعَمِلُوا الصَّالِحَاتِ جُنَاحٌ فِيمَا طَعِمُوا إِذَا مَا اتَّقَوْا وَآمَنُوا‏\}‏ إِلَى آخِرِ الآيَةِ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قِيلَ لِي أَنْتَ مِنْهُمْ ‏"‏ ‏.‏\hadithno{6325}\hadithtrans{Abdullah reported that when this verse was revealed:" There is no harm on persons who believe and perform good acts, what they had eaten (formerly) when they avoided it (now) and they affirmed their faith" (v. 93) up to the end. Allah's Messenger (ﷺ) said to me: You are one amongst them}}
\hadithdefcmd{muslim}{6326}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ أَبِي مُوسَى، قَالَ قَدِمْتُ أَنَا وَأَخِي، مِنَ الْيَمَنِ فَكُنَّا حِينًا وَمَا نُرَى ابْنَ مَسْعُودٍ وَأُمَّهُ إِلاَّ مِنْ أَهْلِ بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ كَثْرَةِ دُخُولِهِمْ وَلُزُومِهِمْ لَهُ ‏.‏\hadithno{6326}\hadithtrans{Abu Musa reported:When I and my brother came from Yemen we used to consider Ibn Mas'ud and his mother amongst the members of the household. of Allah's Messenger (ﷺ) because of their visiting them frequently and staying there for long (periods of) time}}
\hadithdefcmd{muslim}{6327}{حَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، أَنَّهُ سَمِعَ الأَسْوَدَ، يَقُولُ سَمِعْتُ أَبَا مُوسَى، يَقُولُ لَقَدْ قَدِمْتُ أَنَا وَأَخِي، مِنَ الْيَمَنِ ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{6327}\hadithtrans{The above hadith is narrated likewise through another chain of transmitters}}
\hadithdefcmd{muslim}{6328}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالُوا حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ أَبِي مُوسَى، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَنَا أُرَى أَنَّ عَبْدَ اللَّهِ مِنْ أَهْلِ الْبَيْتِ ‏.‏ أَوْ مَا ذَكَرَ مِنْ نَحْوِ هَذَا ‏.‏\hadithno{6328}\hadithtrans{Abu Musa. reported:I came to Allah's Messenger (ﷺ) and thought that 'Abdullah was amongst the members of the family, or like that}}
\hadithdefcmd{muslim}{6329}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ أَبَا الأَحْوَصِ، قَالَ شَهِدْتُ أَبَا مُوسَى وَأَبَا مَسْعُودٍ حِينَ مَاتَ ابْنُ مَسْعُودٍ فَقَالَ أَحَدُهُمَا لِصَاحِبِهِ أَتُرَاهُ تَرَكَ بَعْدَهُ مِثْلَهُ فَقَالَ إِنْ قُلْتَ ذَاكَ إِنْ كَانَ لَيُؤْذَنُ لَهُ إِذَا حُجِبْنَا وَيَشْهَدُ إِذَا غِبْنَا ‏.‏\hadithno{6329}\hadithtrans{Abu Ishaq reported that he heard Abu'l-Ahwas say:I was along with Abu Musa and Abu Mas'ud as Ibn Mas'ud died and one of them said to the other: Do you find one like him besides him? Thereupon he said: Do you say this (no one can be his rival)? He was admitted (to the company of the Holy Prophet) whereas we were detained and he had been present in the company of Allah's Messenger (ﷺ) whereas we had been absent}}
\hadithdefcmd{muslim}{6330}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا قُطْبَةُ، هُوَ ابْنُ عَبْدِ الْعَزِيزِ عَنِ الأَعْمَشِ، عَنْ مَالِكِ بْنِ الْحَارِثِ، عَنْ أَبِي الأَحْوَصِ، قَالَ كُنَّا فِي دَارِ أَبِي مُوسَى مَعَ نَفَرٍ مِنْ أَصْحَابِ عَبْدِ اللَّهِ وَهُمْ يَنْظُرُونَ فِي مُصْحَفٍ فَقَامَ عَبْدُ اللَّهِ فَقَالَ أَبُو مَسْعُودٍ مَا أَعْلَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَرَكَ بَعْدَهُ أَعْلَمَ بِمَا أَنْزَلَ اللَّهُ مِنْ هَذَا الْقَائِمِ ‏.‏ فَقَالَ أَبُو مُوسَى أَمَا لَئِنْ قُلْتَ ذَاكَ لَقَدْ كَانَ يَشْهَدُ إِذَا غِبْنَا وَيُؤْذَنُ لَهُ إِذَا حُجِبْنَا ‏.‏\hadithno{6330}\hadithtrans{Abu Ahwas reported:We were in the house of Abu Musa along with some of the companions of 'Abdullah and they were looking at the Holy Book. 'Abdullah stood up, whereupon Abu Mas'ud said: I do not know whether Allah's Messenger, (ﷺ) has left after him one having a better knowledge (of Islam) than the man who is standing. Abu Musa said: If you say this, that is correct, because he had been present when we had been absent and he was permitted when we were detained}}
\hadithdefcmd{muslim}{6331}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - هُوَ ابْنُ مُوسَى - عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ مَالِكِ بْنِ الْحَارِثِ، عَنْ أَبِي الأَحْوَصِ، قَالَ أَتَيْتُ أَبَا مُوسَى فَوَجَدْتُ عَبْدَ اللَّهِ وَأَبَا مُوسَى ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُبَيْدَةَ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، قَالَ كُنْتُ جَالِسًا مَعَ حُذَيْفَةَ وَأَبِي مُوسَى وَسَاقَ الْحَدِيثَ وَحَدِيثُ قُطْبَةَ أَتَمُّ وَأَكْثَرُ ‏.‏\hadithno{6331}\hadithtrans{Zaid b. Wahab reported:I was sitting along with Hudhaifa and Abu Musa, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6332}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ قَالَ ‏\{‏ وَمَنْ يَغْلُلْ يَأْتِ بِمَا غَلَّ يَوْمَ الْقِيَامَةِ‏\}‏ ثُمَّ قَالَ عَلَى قِرَاءَةِ مَنْ تَأْمُرُونِي أَنْ أَقْرَأَ فَلَقَدْ قَرَأْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِضْعًا وَسَبْعِينَ سُورَةً وَلَقَدْ عَلِمَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنِّي أَعْلَمُهُمْ بِكِتَابِ اللَّهِ وَلَوْ أَعْلَمُ أَنَّ أَحَدًا أَعْلَمُ مِنِّي لَرَحَلْتُ إِلَيْهِ ‏.‏ قَالَ شَقِيقٌ فَجَلَسْتُ فِي حَلَقِ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم فَمَا سَمِعْتُ أَحَدًا يَرُدُّ ذَلِكَ عَلَيْهِ وَلاَ يَعِيبُهُ ‏.‏\hadithno{6332}\hadithtrans{Abdullah (b. Mas'ud) reported that he (said to his companions to conceal their copies of the Qur'an) and further said:He who conceals anything he shall have to bring that which he had concealed on the Day of judgment, and then said: After whose mode of recitation you command me to recite? I in fact recited before AIlah's Messenger (ﷺ) more than seventy chapters of the Qur'an and the Companions of Allah's Messenger (ﷺ) know it that I have better understanding of the Book of Allah (than they do), and if I were to know that someone had better understanding than I, I would have gone to him. Shaqiq said: I sat in the company of the Companions of Mubkmmad (ﷺ) but I did not hear anyone having rejected that (that is, his recitation) or finding fault with it}}
\hadithdefcmd{muslim}{6333}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا قُطْبَةُ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ وَالَّذِي لاَ إِلَهَ غَيْرُهُ مَا مِنْ كِتَابِ اللَّهِ سُورَةٌ إِلاَّ أَنَا أَعْلَمُ حَيْثُ نَزَلَتْ وَمَا مِنْ آيَةٍ إِلاَّ أَنَا أَعْلَمُ فِيمَا أُنْزِلَتْ وَلَوْ أَعْلَمُ أَحَدًا هُوَ أَعْلَمُ بِكِتَابِ اللَّهِ مِنِّي تَبْلُغُهُ الإِبِلُ لَرَكِبْتُ إِلَيْهِ ‏.‏\hadithno{6333}\hadithtrans{Abdullah reported:By Him besides Whom there is no god, there is no chapter in the Book of Allah about which I do not know as to where it was revealed and there is no verse about which I do not know in what context it was revealed, and if I were to know of one having a better understanding of the Book of Allah than I (and I could reach him) on the back of the mule, I would have definitely gone to him on camel's back}}
\hadithdefcmd{muslim}{6334}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، قَالَ كُنَّا نَأْتِي عَبْدَ اللَّهِ بْنَ عَمْرٍو فَنَتَحَدَّثُ إِلَيْهِ - وَقَالَ ابْنُ نُمَيْرٍ عِنْدَهُ - فَذَكَرْنَا يَوْمًا عَبْدَ اللَّهِ بْنَ مَسْعُودٍ فَقَالَ لَقَدْ ذَكَرْتُمْ رَجُلاً لاَ أَزَالُ أُحِبُّهُ بَعْدَ شَىْءٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خُذُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنِ ابْنِ أُمِّ عَبْدٍ - فَبَدَأَ بِهِ - وَمُعَاذِ بْنِ جَبَلٍ وَأُبَىِّ بْنِ كَعْبٍ وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ ‏"‏ ‏.‏\hadithno{6334}\hadithtrans{Masruq reported:We used to go to Abdullah b. 'Amr and talk to him, Ibn Numair said: One day we made a mention of Abdullah b. Mas'ud, whereupon he said: You have made mention of a person whom I love more than anything else. I heard Allah's Messenger (ﷺ) as saying: Learn Qur'an from four persons: Ibn Umm 'Abd (i. e. 'Abdullah b. Mas'ud) he started from him-then Mu'adh b. Jabal and Ubayya b. Ka'b, then Salim the ally of Abu Hudhaifa}}
\hadithdefcmd{muslim}{6335}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالُوا حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، قَالَ كُنَّا عِنْدَ عَبْدِ اللَّهِ بْنِ عَمْرٍو فَذَكَرْنَا حَدِيثًا عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، فَقَالَ إِنَّ ذَاكَ الرَّجُلَ لاَ أَزَالُ أُحِبُّهُ بَعْدَ شَىْءٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُهُ سَمِعْتُهُ يَقُولُ ‏ "‏ اقْرَءُوا الْقُرْآنَ مِنْ أَرْبَعَةِ نَفَرٍ مِنِ ابْنِ أُمِّ عَبْدٍ - فَبَدَأَ بِهِ - وَمِنْ أُبَىِّ بْنِ كَعْبٍ وَمِنْ سَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ وَمِنْ مُعَاذِ بْنِ جَبَلٍ ‏"‏ ‏.‏ وَحَرْفٌ لَمْ يَذْكُرْهُ زُهَيْرٌ قَوْلُهُ يَقُولُهُ ‏.‏\hadithno{6335}\hadithtrans{Masruq reported:We were in the company of Abdullah b 'Amr that we made a mention of a hadith from Abdullah b. Mas'ud; thereupon he said: That is a person whose love ever remains (fresh in my heart) after I heard Allah's Messenger (ﷺ) as saying: Learn Qur'an from four persons: Ibn Umm 'Abd, i e. Abdullah b. Mas'ud and he started from his name-then Ubayy b. Ka'b and Mu'adh b Jabal. Zuhri did not make a mention of the words yaquluhu in his narration}}
\hadithdefcmd{muslim}{6336}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِإِسْنَادِ جَرِيرٍ وَوَكِيعٍ فِي رِوَايَةِ أَبِي بَكْرٍ عَنْ أَبِي مُعَاوِيَةَ، قَدَّمَ مُعَاذًا قَبْلَ أُبَىٍّ ‏.‏ وَفِي رِوَايَةِ أَبِي كُرَيْبٍ أُبَىٌّ قَبْلَ مُعَاذٍ ‏.‏\hadithno{6336}\hadithtrans{This hadith has been reported on the authority of Abu Bakr b. Abu Shaiba and Abu Kuraib, and both of them said:Abu Mu'awiya narrated to us from A'mash on the authority of Jarir and Waki', and in a narration of Abu Bakr transmitted on the authority of Abu Mu'awiya the mention of Mu'adh has preceded Ubayy's, and in the narration transmitted on the authority of Abu Kuraib, the name of Ubayy preceded Mu'ddh's}}
\hadithdefcmd{muslim}{6337}{حَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنِي بِشْرُ بْنُ، خَالِدٍ أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - كِلاَهُمَا عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، بِإِسْنَادِهِمْ وَاخْتَلَفَا عَنْ شُعْبَةَ، فِي تَنْسِيقِ الأَرْبَعَةِ ‏.‏\hadithno{6337}\hadithtrans{This tradition has been transmitted on the authority of Shu'ba through A'mash, but there is a difference of order of the four}}
\hadithdefcmd{muslim}{6338}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، قَالَ ذَكَرُوا ابْنَ مَسْعُودٍ عِنْدَ عَبْدِ اللَّهِ بْنِ عَمْرٍو فَقَالَ ذَاكَ رَجُلٌ لاَ أَزَالُ أُحِبُّهُ بَعْدَ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اسْتَقْرِئُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنِ ابْنِ مَسْعُودٍ وَسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ وَأُبَىِّ بْنِ كَعْبٍ وَمُعَاذِ بْنِ جَبَلٍ ‏"‏ ‏.‏\hadithno{6338}\hadithtrans{Masruq reported:They made a mention of Ibn Mas'ud before 'Abdullah b. Amr, whereupon he said: He is a person whose love is always fresh in my heart after I heard Allah's Messenger (ﷺ) as saying: Learn the recita- tion of the Qur'an from four persons: from Ibn Mas'ud, Salim, the ally of Abu Hudhaifa, Ubayy b. Ka'b, Mu'adh b. Jabal}}
\hadithdefcmd{muslim}{6339}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَزَادَ قَالَ شُعْبَةُ بَدَأَ بِهَذَيْنِ لاَ أَدْرِي بِأَيِّهِمَا بَدَأَ ‏.‏\hadithno{6339}\hadithtrans{Ubaidullah b. Mu'adh reported it on the authority of his father Shu'ba with the same chain of transmitters and he made this addition. He made a mention of these two names but I do not know whose name he mentioned first}}
\hadithdefcmd{muslim}{6340}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ جَمَعَ الْقُرْآنَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْبَعَةٌ كُلُّهُمْ مِنَ الأَنْصَارِ مُعَاذُ بْنُ جَبَلٍ وَأُبَىُّ بْنُ كَعْبٍ وَزَيْدُ بْنُ ثَابِتٍ وَأَبُو زَيْدٍ ‏.‏ قَالَ قَتَادَةُ قُلْتُ لأَنَسٍ مَنْ أَبُو زَيْدٍ قَالَ أَحَدُ عُمُومَتِي ‏.‏\hadithno{6340}\hadithtrans{Anas is reported to have said:Four persons collected the Qur'an during the lifetime of Allah's Messenger (ﷺ) and all of them were Ansar: Mu'adh b. Jabal, Ubayy b. Ka'b, Zaid b. Thabit, Abu Zaid. Qatada said: Anas, who was Abu Zaid? He said: He was one of my uncles}}
\hadithdefcmd{muslim}{6341}{حَدَّثَنِي أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ مَعْبَدٍ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ مَنْ جَمَعَ الْقُرْآنَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أَرْبَعَةٌ كُلُّهُمْ مِنَ الأَنْصَارِ أُبَىُّ بْنُ كَعْبٍ وَمُعَاذُ بْنُ جَبَلٍ وَزَيْدُ بْنُ ثَابِتٍ وَرَجُلٌ مِنَ الأَنْصَارِ يُكْنَى أَبَا زَيْدٍ ‏.‏\hadithno{6341}\hadithtrans{Hammam said:I said to Anas b. Malik: Who collected the Qur'an during the lifetime of Allah's Messenger (ﷺ)? He said: Four (persons), all of them belonging to Ansir: Ubayy b. Ka'b, Mu'adh b. Jabal, Zaid b. Thabit and a person from the Ansar whose Kunya was Abu Zaid}}
\hadithdefcmd{muslim}{6342}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأُبَىٍّ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏"‏ ‏.‏ قَالَ آللَّهُ سَمَّانِي لَكَ قَالَ ‏"‏ اللَّهُ سَمَّاكَ لِي ‏"‏ ‏.‏ قَالَ فَجَعَلَ أُبَىٌّ يَبْكِي ‏.‏\hadithno{6342}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said to Ubayy:Verily Allah, the Exalted and Glorious, has commanded me to recite the Qur'an to you, whereupon he said: (Has) Allah mentioned my name to you? He said: Allah has mentioned your name to me. Thereupon he began to shed tears (of joy)}}
\hadithdefcmd{muslim}{6343}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأُبَىِّ بْنِ كَعْبٍ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏\{‏ لَمْ يَكُنِ الَّذِينَ كَفَرُوا‏\}‏ ‏"‏ ‏.‏ قَالَ وَسَمَّانِي قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَبَكَى ‏.‏\hadithno{6343}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said to Ubayy b. Ka'b:I have been commanded to recite to you the Sura (al- Bayyinah) which opens with these words (Lam Yakunil-ladhiyna Kafaruu) He said: Has he mentioned to you my name? He said: Yes; thereupon he shed tears of joy}}
\hadithdefcmd{muslim}{6344}{حَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأُبَىٍّ بِمِثْلِهِ ‏.‏\hadithno{6344}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{6345}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَنَازَةُ سَعْدِ بْنِ مُعَاذٍ بَيْنَ أَيْدِيهِمْ ‏ "‏ اهْتَزَّ لَهَا عَرْشُ الرَّحْمَنِ ‏"‏ ‏.‏\hadithno{6345}\hadithtrans{Jabir b. 'Abdullah reported Allah's Messenger (ﷺ) as saying while the bier of Sa'd b. Mu'adh was placed before them:The Throne of the most Gracious shook at the death of Sa'd b. Mu'adh}}
\hadithdefcmd{muslim}{6346}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ الأَوْدِيُّ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي، سُفْيَانُ عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اهْتَزَّ عَرْشُ الرَّحْمَنِ لِمَوْتِ سَعْدِ بْنِ مُعَاذٍ ‏"‏ ‏.‏\hadithno{6346}\hadithtrans{Jabir reported that the Throne of the most Compassionate shook because of the death of Sa'd b. Mu'adh}}
\hadithdefcmd{muslim}{6347}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرُّزِّيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ الْخَفَّافُ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ وَجِنَازَتُهُ مَوْضُوعَةٌ - يَعْنِي سَعْدًا - ‏ "‏ اهْتَزَّ لَهَا عَرْشُ الرَّحْمَنِ ‏"‏ ‏.‏\hadithno{6347}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as say- ing:That his bier (that of Sa'd) was placed (before them) and the Throne of the most Compassionate shook}}
\hadithdefcmd{muslim}{6348}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ أُهْدِيَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حُلَّةُ حَرِيرٍ فَجَعَلَ أَصْحَابُهُ يَلْمُسُونَهَا وَيَعْجَبُونَ مِنْ لِينِهَا فَقَالَ ‏ "‏ أَتَعْجَبُونَ مِنْ لِينِ هَذِهِ لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ خَيْرٌ مِنْهَا وَأَلْيَنُ ‏"‏ ‏.‏\hadithno{6348}\hadithtrans{Al-Bara' reported that a garment of silk was presented to Allah's Messenger (ﷺ). His Companions touched it and admired its softness; there- upon he said:Do you admire the softness of this (cloth)? The handkerchiefs of Sa'd b. Mu'adh in Paradise are better than this}}
\hadithdefcmd{muslim}{6349}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، أَنْبَأَنِي أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِثَوْبِ حَرِيرٍ ‏.‏ فَذَكَرَ الْحَدِيثَ ثُمَّ قَالَ ابْنُ عَبْدَةَ أَخْبَرَنَا أَبُو دَاوُدَ حَدَّثَنَا شُعْبَةُ حَدَّثَنِي قَتَادَةُ عَنْ أَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ هَذَا أَوْ بِمِثْلِهِ ‏.‏\hadithno{6349}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{6350}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ، حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الْحَدِيثِ بِالإِسْنَادَيْنِ جَمِيعًا كَرِوَايَةِ أَبِي دَاوُدَ ‏.‏\hadithno{6350}\hadithtrans{This hadith has been reported on the authority of Shu'ba combining the two chains of transmitters}}
\hadithdefcmd{muslim}{6351}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّهُ أُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم جُبَّةٌ مِنْ سُنْدُسٍ وَكَانَ يَنْهَى عَنِ الْحَرِيرِ فَعَجِبَ النَّاسُ مِنْهَا فَقَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ إِنَّ مَنَادِيلَ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ أَحْسَنُ مِنْ هَذَا ‏"‏ ‏.‏\hadithno{6351}\hadithtrans{Anas b Malik reported that Allah's Messenger (ﷺ) was presented a garment of sundus and he prohibited the use of silk. The persons admired it, whereupon he said:By Him in Whose Hand is the life of Muhammad, the kerchiefs of Sa'd b. Mu'adh in Paradise are better than this}}
\hadithdefcmd{muslim}{6352}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، حَدَّثَنَا عُمَرُ بْنُ عَامِرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ أُكَيْدِرَ، دُومَةِ الْجَنْدَلِ أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ حُلَّةً فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ وَكَانَ يَنْهَى عَنِ الْحَرِيرِ ‏.‏\hadithno{6352}\hadithtrans{Anas reported the king of Dumat al-Jandal presented to Allah's Messenger (ﷺ) the garment and lie made no mention (of the fact) that he prohibited the use of silk}}
\hadithdefcmd{muslim}{6353}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ سَيْفًا يَوْمَ أُحُدٍ فَقَالَ ‏"‏ مَنْ يَأْخُذُ مِنِّي هَذَا ‏"‏ ‏.‏ فَبَسَطُوا أَيْدِيَهُمْ كُلُّ إِنْسَانٍ مِنْهُمْ يَقُولُ أَنَا أَنَا ‏.‏ قَالَ ‏"‏ فَمَنْ يَأْخُذُهُ بِحَقِّهِ ‏"‏ ‏.‏ قَالَ فَأَحْجَمَ الْقَوْمُ فَقَالَ سِمَاكُ بْنُ خَرَشَةَ أَبُو دُجَانَةَ أَنَا آخُذُهُ بِحَقِّهِ ‏.‏ قَالَ فَأَخَذَهُ فَفَلَقَ بِهِ هَامَ الْمُشْرِكِينَ ‏.‏\hadithno{6353}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) took hold of his sword on the Day of Uhud and said:Who would take it from me? All the persons stretched their hands saying: I would do it, I would do it. He (Allah's Apostle) said: Who would take it in order to fulfil its rights? Then the people withdrew their hands. Simak b. Kharasha Abu Dujana said: I am here to take it and fulfil its rights. He took it and struck the heads of the polytheists}}
\hadithdefcmd{muslim}{6354}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَعَمْرٌو النَّاقِدُ، كِلاَهُمَا عَنْ سُفْيَانَ، قَالَ عُبَيْدُ اللَّهِ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قَالَ سَمِعْتُ ابْنَ الْمُنْكَدِرِ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَمَّا كَانَ يَوْمُ أُحُدٍ جِيءَ بِأَبِي مُسَجًّى وَقَدْ مُثِلَ بِهِ - قَالَ - فَأَرَدْتُ أَنْ أَرْفَعَ الثَّوْبَ فَنَهَانِي قَوْمِي ثُمَّ أَرَدْتُ أَنْ أَرْفَعَ الثَّوْبَ فَنَهَانِي قَوْمِي فَرَفَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ أَمَرَ بِهِ فَرُفِعَ فَسَمِعَ صَوْتَ بَاكِيَةٍ أَوْ صَائِحَةٍ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ فَقَالُوا بِنْتُ عَمْرٍو أَوْ أُخْتُ عَمْرٍو فَقَالَ ‏"‏ وَلِمَ تَبْكِي فَمَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا حَتَّى رُفِعَ ‏"‏ ‏.‏\hadithno{6354}\hadithtrans{Jabir b. 'Abdullah reported:The dead body of my father was brought and he was covered (with cloth) and it had been mutilated. I made an attempt to lift the cloth, but my people prohibited me to do so. I again made an attempt to lift the cloth, but my people prohibited me. Thereupon Allah's Messenger (ﷺ) lifted it or he commanded it to be lifted. He heard the noise (of a loud) weeping, or the noise of a woman mourner. He inquired who she was. They said: The daughter of 'Amr or the sister of Amr, whereupon he said: Why does she weep? The Angels provide him shade with the help of their Wings until he would be lifted (to his heavenly abode)}}
\hadithdefcmd{muslim}{6355}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أُصِيبَ أَبِي يَوْمَ أُحُدٍ فَجَعَلْتُ أَكْشِفُ الثَّوْبَ عَنْ وَجْهِهِ، وَأَبْكِي، وَجَعَلُوا يَنْهَوْنَنِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَنْهَانِي - قَالَ - وَجَعَلَتْ فَاطِمَةُ بِنْتُ عَمْرٍو تَبْكِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَبْكِيهِ أَوْ لاَ تَبْكِيهِ مَا زَالَتِ الْمَلاَئِكَةُ تُظِلُّهُ بِأَجْنِحَتِهَا حَتَّى رَفَعْتُمُوهُ ‏"‏ ‏.‏\hadithno{6355}\hadithtrans{Jabir b. 'Abdullah reported:My father fell as a martyr on the Day of Uhud and I attempted to uncover his face and weep, but they (the Companions of the Holy Prophet) forbade me to do this, whereas Allah's Messenger (ﷺ) did not forbid me and Fatima bint Amr, the sister of my father, was also weeping There- upon Allah's Messenger (ﷺ) said: You may weep or you may not weep; the Angels provide him shade with the help of their wings until you lift him (to be buried in the grave)}}
\hadithdefcmd{muslim}{6356}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، كِلاَهُمَا عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، ‏.‏ بِهَذَا الْحَدِيثِ غَيْرَ أَنَّ ابْنَ جُرَيْجٍ، لَيْسَ فِي حَدِيثِهِ ذِكْرُ الْمَلاَئِكَةِ وَبُكَاءُ الْبَاكِيَةِ ‏.‏\hadithno{6356}\hadithtrans{This hadith has been narrated on the authority of Jabir through another chain of transmitters, but with this difference that there is no mention of the Angels and the weeping of a female mourner}}
\hadithdefcmd{muslim}{6357}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، بْنُ عَمْرٍو عَنْ عَبْدِ الْكَرِيمِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ جِيءَ بِأَبِي يَوْمَ أُحُدٍ مُجَدَّعًا فَوُضِعَ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{6357}\hadithtrans{Jabir reported:My father was brought in a state that his ears had been cut off and (his dead body) was placed before Allah's Apostle (ﷺ), the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6358}{حَدَّثَنَا إِسْحَاقُ بْنُ عُمَرَ بْنِ سَلِيطٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ كِنَانَةَ، بْنِ نُعَيْمٍ عَنْ أَبِي بَرْزَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي مَغْزًى لَهُ فَأَفَاءَ اللَّهُ عَلَيْهِ فَقَالَ لأَصْحَابِهِ ‏"‏ هَلْ تَفْقِدُونَ مِنْ أَحَدٍ ‏"‏ ‏.‏ قَالُوا نَعَمْ فُلاَنًا وَفُلاَنًا وَفُلاَنًا ‏.‏ ثُمَّ قَالَ ‏"‏ هَلْ تَفْقِدُونَ مِنْ أَحَدٍ ‏"‏ ‏.‏ قَالُوا نَعَمْ فُلاَنًا وَفُلاَنًا وَفُلاَنًا ‏.‏ ثُمَّ قَالَ ‏"‏ هَلْ تَفْقِدُونَ مِنْ أَحَدٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ لَكِنِّي أَفْقِدُ جُلَيْبِيبًا فَاطْلُبُوهُ ‏"‏ ‏.‏ فَطُلِبَ فِي الْقَتْلَى فَوَجَدُوهُ إِلَى جَنْبِ سَبْعَةٍ قَدْ قَتَلَهُمْ ثُمَّ قَتَلُوهُ فَأَتَى النَّبِيُّ صلى الله عليه وسلم فَوَقَفَ عَلَيْهِ فَقَالَ ‏"‏ قَتَلَ سَبْعَةً ثُمَّ قَتَلُوهُ هَذَا مِنِّي وَأَنَا مِنْهُ هَذَا مِنِّي وَأَنَا مِنْهُ ‏"‏ ‏.‏ قَالَ فَوَضَعَهُ عَلَى سَاعِدَيْهِ لَيْسَ لَهُ إِلاَّ سَاعِدَا النَّبِيِّ صلى الله عليه وسلم قَالَ فَحُفِرَ لَهُ وَوُضِعَ فِي قَبْرِهِ ‏.‏ وَلَمْ يَذْكُرْ غَسْلاً ‏.‏\hadithno{6358}\hadithtrans{Abu Barza reported that Allah's Apostle (ﷺ) was there in a battlefield that Allah conferred upon him the spoils of war. He said to his Companions:Is anyone missing amongst you? They said: So and so and so. He again said: Is there anyone missing amongst you? They said: So and so and so. He then said: Is there anyone missing amongst you? They said: No. Thereupon he (the Holy Prophet) said: But I am missing Julaibib. They (his Companions) searched him amongst those who had been killed and they found him by the side of seven (dead bodies) whom he had killed and he had been killed (by the oppoments). Allah's Apostle (ﷺ) came there and stood (by his side) and said: He killed seven (persons). Then (his opponents) killed him. He is mine and I am his. He then placed him upon his hands and there was none else to lift but Allah's Apostle (ﷺ). Then the grave was dug for him and he was placed in the grave and no mention is made of a bath}}
\hadithdefcmd{muslim}{6359}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ الأَزْدِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، أَخْبَرَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، قَالَ قَالَ أَبُو ذَرٍّ خَرَجْنَا مِنْ قَوْمِنَا غِفَارٍ وَكَانُوا يُحِلُّونَ الشَّهْرَ الْحَرَامَ فَخَرَجْتُ أَنَا وَأَخِي أُنَيْسٌ وَأُمُّنَا فَنَزَلْنَا عَلَى خَالٍ لَنَا فَأَكْرَمَنَا خَالُنَا وَأَحْسَنَ إِلَيْنَا فَحَسَدَنَا قَوْمُهُ فَقَالُوا إِنَّكَ إِذَا خَرَجْتَ عَنْ أَهْلِكَ خَالَفَ إِلَيْهِمْ أُنَيْسٌ فَجَاءَ خَالُنَا فَنَثَا عَلَيْنَا الَّذِي قِيلَ لَهُ فَقُلْتُ لَهُ أَمَّا مَا مَضَى مِنْ مَعْرُوفِكَ فَقَدْ كَدَّرْتَهُ وَلاَ جِمَاعَ لَكَ فِيمَا بَعْدُ ‏.‏ فَقَرَّبْنَا صِرْمَتَنَا فَاحْتَمَلْنَا عَلَيْهَا وَتَغَطَّى خَالُنَا ثَوْبَهُ فَجَعَلَ يَبْكِي فَانْطَلَقْنَا حَتَّى نَزَلْنَا بِحَضْرَةِ مَكَّةَ فَنَافَرَ أُنَيْسٌ عَنْ صِرْمَتِنَا وَعَنْ مِثْلِهَا فَأَتَيَا الْكَاهِنَ فَخَيَّرَ أُنَيْسًا فَأَتَانَا أُنَيْسٌ بِصِرْمَتِنَا وَمِثْلِهَا مَعَهَا - قَالَ - وَقَدْ صَلَّيْتُ يَا ابْنَ أَخِي قَبْلَ أَنْ أَلْقَى رَسُولَ اللَّهِ صلى الله عليه وسلم بِثَلاَثِ سِنِينَ ‏.‏ قُلْتُ لِمَنْ قَالَ لِلَّهِ ‏.‏ قُلْتُ فَأَيْنَ تَوَجَّهُ قَالَ أَتَوَجَّهُ حَيْثُ يُوَجِّهُنِي رَبِّي أُصَلِّي عِشَاءً حَتَّى إِذَا كَانَ مِنْ آخِرِ اللَّيْلِ أُلْقِيتُ كَأَنِّي خِفَاءٌ حَتَّى تَعْلُوَنِي الشَّمْسُ ‏.‏ فَقَالَ أُنَيْسٌ إِنَّ لِي حَاجَةً بِمَكَّةَ فَاكْفِنِي ‏.‏ فَانْطَلَقَ أُنَيْسٌ حَتَّى أَتَى مَكَّةَ فَرَاثَ عَلَىَّ ثُمَّ جَاءَ فَقُلْتُ مَا صَنَعْتَ قَالَ لَقِيتُ رَجُلاً بِمَكَّةَ عَلَى دِينِكَ يَزْعُمُ أَنَّ اللَّهَ أَرْسَلَهُ ‏.‏ قُلْتُ فَمَا يَقُولُ النَّاسُ قَالَ يَقُولُونَ شَاعِرٌ كَاهِنٌ سَاحِرٌ ‏.‏ وَكَانَ أُنَيْسٌ أَحَدَ الشُّعَرَاءِ ‏.‏ قَالَ أُنَيْسٌ لَقَدْ سَمِعْتُ قَوْلَ الْكَهَنَةِ فَمَا هُوَ بِقَوْلِهِمْ وَلَقَدْ وَضَعْتُ قَوْلَهُ عَلَى أَقْرَاءِ الشِّعْرِ فَمَا يَلْتَئِمُ عَلَى لِسَانِ أَحَدٍ بَعْدِي أَنَّهُ شِعْرٌ وَاللَّهِ إِنَّهُ لَصَادِقٌ وَإِنَّهُمْ لَكَاذِبُونَ ‏.‏ قَالَ قُلْتُ فَاكْفِنِي حَتَّى أَذْهَبَ فَأَنْظُرَ ‏.‏ قَالَ فَأَتَيْتُ مَكَّةَ فَتَضَعَّفْتُ رَجُلاً مِنْهُمْ فَقُلْتُ أَيْنَ هَذَا الَّذِي تَدْعُونَهُ الصَّابِئَ فَأَشَارَ إِلَىَّ فَقَالَ الصَّابِئَ ‏.‏ فَمَالَ عَلَىَّ أَهْلُ الْوَادِي بِكُلِّ مَدَرَةٍ وَعَظْمٍ حَتَّى خَرَرْتُ مَغْشِيًّا عَلَىَّ - قَالَ - فَارْتَفَعْتُ حِينَ ارْتَفَعْتُ كَأَنِّي نُصُبٌ أَحْمَرُ - قَالَ - فَأَتَيْتُ زَمْزَمَ فَغَسَلْتُ عَنِّي الدِّمَاءَ وَشَرِبْتُ مِنْ مَائِهَا وَلَقَدْ لَبِثْتُ يَا ابْنَ أَخِي ثَلاَثِينَ بَيْنَ لَيْلَةٍ وَيَوْمٍ مَا كَانَ لِي طَعَامٌ إِلاَّ مَاءُ زَمْزَمَ فَسَمِنْتُ حَتَّى تَكَسَّرَتْ عُكَنُ بَطْنِي وَمَا وَجَدْتُ عَلَى كَبِدِي سُخْفَةَ جُوعٍ - قَالَ - فَبَيْنَا أَهْلُ مَكَّةَ فِي لَيْلَةٍ قَمْرَاءَ إِضْحِيَانَ إِذْ ضُرِبَ عَلَى أَسْمِخَتِهِمْ فَمَا يَطُوفُ بِالْبَيْتِ أَحَدٌ وَامْرَأَتَيْنِ مِنْهُمْ تَدْعُوَانِ إِسَافًا وَنَائِلَةَ - قَالَ - فَأَتَتَا عَلَىَّ فِي طَوَافِهِمَا فَقُلْتُ أَنْكِحَا أَحَدَهُمَا الأُخْرَى - قَالَ - فَمَا تَنَاهَتَا عَنْ قَوْلِهِمَا - قَالَ - فَأَتَتَا عَلَىَّ فَقُلْتُ هَنٌ مِثْلُ الْخَشَبَةِ غَيْرَ أَنِّي لاَ أَكْنِي ‏.‏ فَانْطَلَقَتَا تُوَلْوِلاَنِ وَتَقُولاَنِ لَوْ كَانَ هَا هُنَا أَحَدٌ مِنْ أَنْفَارِنَا ‏.‏ قَالَ فَاسْتَقْبَلَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَهُمَا هَابِطَانِ قَالَ ‏"‏ مَا لَكُمَا ‏"‏ ‏.‏ قَالَتَا الصَّابِئُ بَيْنَ الْكَعْبَةِ وَأَسْتَارِهَا قَالَ ‏"‏ مَا قَالَ لَكُمَا ‏"‏ ‏.‏ قَالَتَا إِنَّهُ قَالَ لَنَا كَلِمَةً تَمْلأُ الْفَمَ ‏.‏ وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى اسْتَلَمَ الْحَجَرَ وَطَافَ بِالْبَيْتِ هُوَ وَصَاحِبُهُ ثُمَّ صَلَّى فَلَمَّا قَضَى صَلاَتَهُ قَالَ أَبُو ذَرٍّ ‏.‏ فَكُنْتُ أَنَا أَوَّلُ مَنْ حَيَّاهُ بِتَحِيَّةِ الإِسْلاَمِ - قَالَ - فَقُلْتُ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ وَعَلَيْكَ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ أَنْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ مِنْ غِفَارٍ - قَالَ - فَأَهْوَى بِيَدِهِ فَوَضَعَ أَصَابِعَهُ عَلَى جَبْهَتِهِ فَقُلْتُ فِي نَفْسِي كَرِهَ أَنِ انْتَمَيْتُ إِلَى غِفَارٍ ‏.‏ فَذَهَبْتُ آخُذُ بِيَدِهِ فَقَدَعَنِي صَاحِبُهُ وَكَانَ أَعْلَمَ بِهِ مِنِّي ثُمَّ رَفَعَ رَأْسَهُ ثُمَّ قَالَ ‏"‏ مَتَى كُنْتَ هَا هُنَا ‏"‏ ‏.‏ قَالَ قُلْتُ قَدْ كُنْتُ هَا هُنَا مُنْذُ ثَلاَثِينَ بَيْنَ لَيْلَةٍ وَيَوْمٍ قَالَ ‏"‏ فَمَنْ كَانَ يُطْعِمُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ مَا كَانَ لِي طَعَامٌ إِلاَّ مَاءُ زَمْزَمَ ‏.‏ فَسَمِنْتُ حَتَّى تَكَسَّرَتْ عُكَنُ بَطْنِي وَمَا أَجِدُ عَلَى كَبِدِي سُخْفَةَ جُوعٍ قَالَ ‏"‏ إِنَّهَا مُبَارَكَةٌ إِنَّهَا طَعَامُ طُعْمٍ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ ائْذَنْ لِي فِي طَعَامِهِ اللَّيْلَةَ ‏.‏ فَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَانْطَلَقْتُ مَعَهُمَا فَفَتَحَ أَبُو بَكْرٍ بَابًا فَجَعَلَ يَقْبِضُ لَنَا مِنْ زَبِيبِ الطَّائِفِ وَكَانَ ذَلِكَ أَوَّلَ طَعَامٍ أَكَلْتُهُ بِهَا ثُمَّ غَبَرْتُ مَا غَبَرْتُ ثُمَّ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّهُ قَدْ وُجِّهَتْ لِي أَرْضٌ ذَاتُ نَخْلٍ لاَ أُرَاهَا إِلاَّ يَثْرِبَ فَهَلْ أَنْتَ مُبَلِّغٌ عَنِّي قَوْمَكَ عَسَى اللَّهُ أَنْ يَنْفَعَهُمْ بِكَ وَيَأْجُرَكَ فِيهِمْ ‏"‏ ‏.‏ فَأَتَيْتُ أُنَيْسًا فَقَالَ مَا صَنَعْتَ قُلْتُ صَنَعْتُ أَنِّي قَدْ أَسْلَمْتُ وَصَدَّقْتُ ‏.‏ قَالَ مَا بِي رَغْبَةٌ عَنْ دِينِكَ فَإِنِّي قَدْ أَسْلَمْتُ وَصَدَّقْتُ ‏.‏ فَأَتَيْنَا أُمَّنَا فَقَالَتْ مَا بِي رَغْبَةٌ عَنْ دِينِكُمَا فَإِنِّي قَدْ أَسْلَمْتُ وَصَدَّقْتُ ‏.‏ فَاحْتَمَلْنَا حَتَّى أَتَيْنَا قَوْمَنَا غِفَارًا فَأَسْلَمَ نِصْفُهُمْ وَكَانَ يَؤُمُّهُمْ إِيمَاءُ بْنُ رَحَضَةَ الْغِفَارِيُّ وَكَانَ سَيِّدَهُمْ ‏.‏ وَقَالَ نِصْفُهُمْ إِذَا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ أَسْلَمْنَا ‏.‏ فَقَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ فَأَسْلَمَ نِصْفُهُمُ الْبَاقِي وَجَاءَتْ أَسْلَمُ فَقَالُوا يَا رَسُولَ اللَّهِ إِخْوَتُنَا نُسْلِمُ عَلَى الَّذِي أَسْلَمُوا عَلَيْهِ ‏.‏ فَأَسْلَمُوا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ غِفَارُ غَفَرَ اللَّهُ لَهَا وَأَسْلَمُ سَالَمَهَا اللَّهُ ‏"‏ ‏.‏\hadithno{6359}\hadithtrans{Abdullah b. Samit reported that Abu Dharr said:We set out from our tribe Ghafir who look upon the prohibited months as permissible months. I and my brother Unais and our mother stayed with our maternal uncle who treated us well. The men of his tribe fell jealous and they said: When you are anay from your house, Unais commits adultery with your wife. Our -naternal uncle came and he accused us of the sin which was conveyed to him. I said: You have undone the good you did to us. We cannot stay with you after this. We came to our camels and loaded (our) luggage. Our maternal uncle began to weep covering himself with (a piece of) cloth. We proceeded on until we encamped by the side of Mecca. Unais cast lot on the camels (we had) and an equal number (above that). They both went to a Kahin and he made Unais win and Unais came with our camels and an equal number along with them. He (Abu Dharr) said: My nephew, I used to observe prayer three years before my meeting with Allah's Messenger (ﷺ). I said: For whom did you say prayer? He said: For Allah. I said: To which direction did you turn your face (for observing prayer)? He said: I used to turn my face as Allah has directed me to turn my face. I used to observe the night prayer at the time of the end of night and I fell down in prostration like the mantle until the sun rose over me. Unais said: I have a work in Mecca, so you better stay here. Unais went until he came to Mecca and he came to me late. I said: What did you do? He said: I met a person in Mecca who is on your religion and he claims that verily it is Allah Who has sent him. I said: What do the people say about him? He said: They say that he is a poet or a Kahin or a magician. Unais who was himself one of the poets said. I have heard the words of a Kahin but his words in no way resemble his (words). And 1 also compared his words to the verses of poets but such words cannot be uttered by any poet. By Allah, he is truthful and they are liars. Then I said: you stay here, until I go, so that I should see him. He said: I came to Mecca and I selected an insignificant person from amongst them and said to him: Where is he whom you call as-Sabi? He pointed out towards me saying: He is Sabi. Thereupon the people of the valley attacked me with sods and bows until I fell down unconscious. I stood up after havin. regained my consciousness and I found as if I was a red idol. I came to Zamzarn and washed blood from me and drank water from it and listen, O son of my brother, I stayed there for thirty nights or days and there was no food for me but the water of Zamzarn. And I became so bulky that there appeared wrinkles upon my stomach, and I did not feel any hunger in my stomach. It was during this time that the people of Mecca slept in the moonlit night and none was there to eircumambulate the House but only two women who had been invoking the name of Isafa, and Na'ila (the two idols). They came to me while in their circuit and I said: Marry one with the other, but they did not dissuade from their invoking. They came to me and I said to them: Insert wood (in the idols' private parts). (I said this to them in such plain words) as I could not express in metaphorical terms. These women went away crying and saying: Had there been one amongst our people (he would have taught a lesson to you for the obscene words used for our idols before us). These women met Allah's Messenger (ﷺ) and Abu Bakr who had also been coming down the hill. He asked them: What has happened to you? They said: There is Sabi, who has hidden himself between the Ka'ba and its curtain. He said: What did he say to you? They said: He uttered such words before us as we cannot express. Allah's Messenger (ﷺ) came and he kissed the Black Stone and circumambulated the House along with his Companion and then observed prayer, and when he had finished his prayer, Abu Dharr said: I was the first to greet him with the salutation of peace and uttered (these words) in this way; Allah's Messen- ger, may there be peace upon you, whereupon he said: It may be upon you too and the mercy of Allah. He then said: Who are you? I said: From the tribe of Ghifar. He leaned his hand and placed his finger on his forehead and I said to myself: Perhaps he has not liked it that I belong to the tribe of Ghifar. I attempted to catch hold of his hand but his friend who knew about him more than I dissuaded me f rom doing so. He then lifted his head and said: Since how long have you been here? I said: I have been here for the last thirty nights or days. He said: Who has been feeding you? I said: There has been no food for me but the water of Zamzam. I have grown so bulky that there appear wrinkles upon my stomach and I do not feel any hunger. He said: It is blessed (water) and it also serves as food. Thereupon Abu Bakr said: Allah's Messenger, let me serve as a host to him for tonight, and then Allah's Messenger (ﷺ) proceeded forth and so did Abu Bakr and I went along with them. Abu Bakr opened the door and then he brought for us the raisins of Ta'if and that was the first food which I ate there. Then I stayed as long as I had to stay. I then came to Allah's Messenaer (ﷺ) and he said: I have been shown the land abound- ing in trees and I think it cannot be but that of Yathrib (that is the old name of Medina). You are a preacher to your people on my behalf. I hope Allah would benefit them through you and He would reward you. I came to Unais and he said: What have you done? I said: I have done that I have embraced Islam and I have testified (to the prophethood of Allah's Messenger). He said: I have no aversion for your religion and I also embrace Islam and testify (to the prophethood of Muhammad). Then both of us came to our mother and she said: I have no aversion for your religion and I also embrace Islam and testify to the prophethood of Muhammad. We then loaded our camels and came to our tribe Ghifir and half of the tribe embraced Islam and their chief was Aimi' b. Rahada Ghifirl and he was their leader and hall of the tribe said: We will embrace Islam when Allah's Messenger (may p,. ace be upon him) would come to Medina, and when Allah's Messenger (ﷺ) came to Medina the remaining half also embraced Islam. Then a tribe Aslam came to the Prophet (ﷺ) and said: Allah's Messenger, we also embrace Islam like our brothers who have embraced Islam. And they also embraced Islam. Thereupon Allah's Messenger (ﷺ) said: Allah granted pardon to the tribe of Ghifar and Allah saved (from destruction) the tribe of Aslam}}
\hadithdefcmd{muslim}{6360}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا سُلَيْمَانُ، بْنُ الْمُغِيرَةِ حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، بِهَذَا الإِسْنَادِ وَزَادَ بَعْدَ قَوْلِهِ قُلْتُ فَاكْفِنِي حَتَّى أَذْهَبَ فَأَنْظُرَ ‏.‏ قَالَ نَعَمْ وَكُنْ عَلَى حَذَرٍ مِنْ أَهْلِ مَكَّةَ فَإِنَّهُمْ قَدْ شَنِفُوا لَهُ وَتَجَهَّمُوا ‏.‏\hadithno{6360}\hadithtrans{This hadlth has been narrated on the authority of Humaid b. Hilal with the same chain of transmitters but with this addition:" As I came to Mecca, Unais said: (Well), go but be on your guard against the Meccans for they are his enemies and are annoyed with him}}
\hadithdefcmd{muslim}{6361}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنِي ابْنُ أَبِي عَدِيٍّ، قَالَ أَنْبَأَنَا ابْنُ عَوْنٍ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، قَالَ قَالَ أَبُو ذَرٍّ يَا ابْنَ أَخِي صَلَّيْتُ سَنَتَيْنِ قَبْلَ مَبْعَثِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ قُلْتُ فَأَيْنَ كُنْتَ تَوَجَّهُ قَالَ حَيْثُ وَجَّهَنِيَ اللَّهُ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِنَحْوِ حَدِيثِ سُلَيْمَانَ بْنِ الْمُغِيرَةِ وَقَالَ فِي الْحَدِيثِ فَتَنَافَرَا إِلَى رَجُلٍ مِنَ الْكُهَّانِ ‏.‏ قَالَ فَلَمْ يَزَلْ أَخِي أُنَيْسٌ يَمْدَحُهُ حَتَّى غَلَبَهُ - قَالَ - فَأَخَذْنَا صِرْمَتَهُ فَضَمَمْنَاهَا إِلَى صِرْمَتِنَا ‏.‏ وَقَالَ أَيْضًا فِي حَدِيثِهِ قَالَ فَجَاءَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ وَصَلَّى رَكْعَتَيْنِ خَلْفَ الْمَقَامِ - قَالَ - فَأَتَيْتُهُ فَإِنِّي لأَوَّلُ النَّاسِ حَيَّاهُ بِتَحِيَّةِ الإِسْلاَمِ - قَالَ - قُلْتُ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَعَلَيْكَ السَّلاَمُ مَنْ أَنْتَ ‏"‏ ‏.‏ وَفِي حَدِيثِهِ أَيْضًا فَقَالَ ‏"‏ مُنْذُ كَمْ أَنْتَ هَا هُنَا ‏"‏ ‏.‏ قَالَ قُلْتُ مُنْذُ خَمْسَ عَشْرَةَ ‏.‏ وَفِيهِ فَقَالَ أَبُو بَكْرٍ أَتْحِفْنِي بِضِيَافَتِهِ اللَّيْلَةَ ‏.‏\hadithno{6361}\hadithtrans{Abdullah b. Samit reported that Abu Dharr said:Son of my brother, I used to observe prayer two years before the advent of Allah's Apostle (ﷺ). I said: To which direction did you turn your face? He said: To which Allah directed me to turn my face. The rest of the hadith is the same but with this addition that they went to a Kahin and his brother Unais began to praise him until he (in verses declared) him (Unais) as winner (in the contest of poetry), and so we got his camels, mixed them with our camels, and there is in this hadith also these words that Allah's Apostle (ﷺ) came there and he circumambulated the House and observed two Rak'ahs of prayer behind the Station (of Ibrahim). I came to him and I was the first amongst persons to greet him with Assalam-o-'Alaikum, and I said to Allah's Messenger Let there be peace upon you. And he said: Let there be peace upon you too; who are you? And in the hadith (these words are) also found: Since how long have you been here? And Abu Bakr said: Let him be my guest tonight}}
\hadithdefcmd{muslim}{6362}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنُ عَرْعَرَةَ السَّامِيُّ، وَمُحَمَّدُ بْنُ حَاتِمٍ، - وَتَقَارَبَا فِي سِيَاقِ الْحَدِيثِ وَاللَّفْظُ لاِبْنِ حَاتِمٍ - قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ حَدَّثَنَا الْمُثَنَّى بْنُ سَعِيدٍ عَنْ أَبِي جَمْرَةَ عَنِ ابْنِ عَبَّاسٍ قَالَ لَمَّا بَلَغَ أَبَا ذَرٍّ مَبْعَثُ النَّبِيِّ صلى الله عليه وسلم بِمَكَّةَ قَالَ لأَخِيهِ ارْكَبْ إِلَى هَذَا الْوَادِي فَاعْلَمْ لِي عِلْمَ هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ يَأْتِيهِ الْخَبَرُ مِنَ السَّمَاءِ فَاسْمَعْ مِنْ قَوْلِهِ ثُمَّ ائْتِنِي ‏.‏ فَانْطَلَقَ الآخَرُ حَتَّى قَدِمَ مَكَّةَ وَسَمِعَ مِنْ قَوْلِهِ ثُمَّ رَجَعَ إِلَى أَبِي ذَرٍّ فَقَالَ رَأَيْتُهُ يَأْمُرُ بِمَكَارِمِ الأَخْلاَقِ وَكَلاَمًا مَا هُوَ بِالشِّعْرِ ‏.‏ فَقَالَ مَا شَفَيْتَنِي فِيمَا أَرَدْتُ ‏.‏ فَتَزَوَّدَ وَحَمَلَ شَنَّةً لَهُ فِيهَا مَاءٌ حَتَّى قَدِمَ مَكَّةَ فَأَتَى الْمَسْجِدَ فَالْتَمَسَ النَّبِيَّ صلى الله عليه وسلم وَلاَ يَعْرِفُهُ وَكَرِهَ أَنْ يَسْأَلَ عَنْهُ حَتَّى أَدْرَكَهُ - يَعْنِي اللَّيْلَ - فَاضْطَجَعَ فَرَآهُ عَلِيٌّ فَعَرَفَ أَنَّهُ غَرِيبٌ فَلَمَّا رَآهُ تَبِعَهُ فَلَمْ يَسْأَلْ وَاحِدٌ مِنْهُمَا صَاحِبَهُ عَنْ شَىْءٍ حَتَّى أَصْبَحَ ثُمَّ احْتَمَلَ قُرَيْبَتَهُ وَزَادَهُ إِلَى الْمَسْجِدِ فَظَلَّ ذَلِكَ الْيَوْمَ وَلاَ يَرَى النَّبِيَّ صلى الله عليه وسلم حَتَّى أَمْسَى فَعَادَ إِلَى مَضْجَعِهِ فَمَرَّ بِهِ عَلِيٌّ فَقَالَ مَا أَنَى لِلرَّجُلِ أَنْ يَعْلَمَ مَنْزِلَهُ فَأَقَامَهُ فَذَهَبَ بِهِ مَعَهُ وَلاَ يَسْأَلُ وَاحِدٌ مِنْهُمَا صَاحِبَهُ عَنْ شَىْءٍ حَتَّى إِذَا كَانَ يَوْمُ الثَّالِثِ فَعَلَ مِثْلَ ذَلِكَ فَأَقَامَهُ عَلِيٌّ مَعَهُ ثُمَّ قَالَ لَهُ أَلاَ تُحَدِّثُنِي مَا الَّذِي أَقْدَمَكَ هَذَا الْبَلَدَ قَالَ إِنْ أَعْطَيْتَنِي عَهْدًا وَمِيثَاقًا لَتُرْشِدَنِّي فَعَلْتُ ‏.‏ فَفَعَلَ فَأَخْبَرَهُ فَقَالَ فَإِنَّهُ حَقٌّ وَهُوَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَإِذَا أَصْبَحْتَ فَاتَّبِعْنِي فَإِنِّي إِنْ رَأَيْتُ شَيْئًا أَخَافُ عَلَيْكَ قُمْتُ كَأَنِّي أُرِيقُ الْمَاءَ فَإِنْ مَضَيْتُ فَاتَّبِعْنِي حَتَّى تَدْخُلَ مَدْخَلِي ‏.‏ فَفَعَلَ فَانْطَلَقَ يَقْفُوهُ حَتَّى دَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَدَخَلَ مَعَهُ فَسَمِعَ مِنْ قَوْلِهِ وَأَسْلَمَ مَكَانَهُ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ارْجِعْ إِلَى قَوْمِكَ فَأَخْبِرْهُمْ حَتَّى يَأْتِيَكَ أَمْرِي ‏"‏ ‏.‏ فَقَالَ وَالَّذِي نَفْسِي بِيَدِهِ لأَصْرُخَنَّ بِهَا بَيْنَ ظَهْرَانَيْهِمْ ‏.‏ فَخَرَجَ حَتَّى أَتَى الْمَسْجِدَ فَنَادَى بِأَعْلَى صَوْتِهِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏.‏ وَثَارَ الْقَوْمُ فَضَرَبُوهُ حَتَّى أَضْجَعُوهُ فَأَتَى الْعَبَّاسُ فَأَكَبَّ عَلَيْهِ فَقَالَ وَيْلَكُمْ أَلَسْتُمْ تَعْلَمُونَ أَنَّهُ مِنْ غِفَارٍ وَأَنَّ طَرِيقَ تُجَّارِكُمْ إِلَى الشَّامِ عَلَيْهِمْ ‏.‏ فَأَنْقَذَهُ مِنْهُمْ ثُمَّ عَادَ مِنَ الْغَدِ بِمِثْلِهَا وَثَارُوا إِلَيْهِ فَضَرَبُوهُ فَأَكَبَّ عَلَيْهِ الْعَبَّاسُ فَأَنْقَذَهُ ‏.‏\hadithno{6362}\hadithtrans{Ibn `Abbas reported that when Abu Dharr heard of the advent of the Apostle (ﷺ) in Mecca he said:Brother, ride in this valley and bring information for me about the person who claims that there comes to him information from the Heavens. Listen to his words and then come to me. So he rode on until he came to Mecca and he heard his words (the sacred words of the Holy Prophet) and then came back to Abu Dharr and said: I have seen him exhorting (people) to develop good morals and his expressions can in no way be termed as poetry. He (Abu Dharr) said: I have not been satisfied with it regarding that which I had in my mind (as I sent you). So he took up provisions for the journey and a small water-skin containing water (and set forth) until he came to Mecca. He came to the mosque (Ka`bah) and began to look for Allah's Apostle (ﷺ) and he did not recognize him (the Holy Prophet) and he did not even like that he should ask about him from anyone until it was night, and he slept. `Ali saw him and found him to be a stranger. So he went with him. He followed him but one did not make any inquiry from the other about anything until it was morning. He then brought the water and his provisions to the mosque and spent a day there, but he did not see Allah's Apostle (ﷺ) until it was night. He then returned to his bed, and there happened to pass `Ali and he said: This man has not been able to find his destination until this time. He made him stand and he went with him and no one made an inquiry from his companion about anything. And when it was the third day he did the same. `Ali made him stand up and brought him along with him. He said: By Him, besides Whom there is no god, why don't you tell me (the reason) which brought you here to this town? He said: (I shall do this) provided you hold me promise and a covenant that you would guide me aright. He then did that. He (`Ali) said: Verily, he is truthful and he is a Messenger of Allah (ﷺ) and when it is morning, follow me and if I would say anything from which I would sense fear about you I would stand (in a manner) as if I was throwing water and if I move on, you then follow me until I get in (some house). He did that and I followed him until he came to Allah's Messenger (ﷺ). He entered (the house) of Allah's Apostle (ﷺ) along with him and listened to his words and embraced Islam at this very place. Allah's Apostle (ﷺ) said to him: Go to your people and inform them until my command reaches you. Thereupon he said: By Him in Whose Hand is my life, I shall say to the people of Mecca this thing at the top of my voice. So he set forth until he came to the mosque and then spoke at the top of his voice (saying): I bear testimony to the fact that there is no god but Allah and that Muhammad is the Messenger of Allah. The people attacked him and made him fall down when al-`Abbas came and he leaned over him and said: Woe be upon you, don't you know that he is from amongst the tribe of Ghifar and your trading route to Syria passes through (the settlements of this tribe), and he rescued him. He (Abu Dharr) did the same on the next day and they (the Meccans) again attacked him and al-`Abbas leaned upon him and he rescued him}}
\hadithdefcmd{muslim}{6363}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ بَيَانٍ، عَنْ قَيْسِ بْنِ أَبِي، حَازِمٍ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، ح وَحَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ، حَدَّثَنَا خَالِدٌ، عَنْ بَيَانٍ، قَالَ سَمِعْتُ قَيْسَ بْنَ أَبِي، حَازِمٍ يَقُولُ قَالَ جَرِيرُ بْنُ عَبْدِ اللَّهِ مَا حَجَبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ وَلاَ رَآنِي إِلاَّ ضَحِكَ ‏.‏\hadithno{6363}\hadithtrans{Jarir b. 'Abdullah said:Allah's Messenger (ﷺ) never refused me permission to see him since I embraced Islam and never looked at me but with a smile}}
\hadithdefcmd{muslim}{6364}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَ��َا وَكِيعٌ، وَأَبُو أُسَامَةَ عَنْ إِسْمَاعِيلَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، قَالَ مَا حَجَبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مُنْذُ أَسْلَمْتُ وَلاَ رَآنِي إِلاَّ تَبَسَّمَ فِي وَجْهِي ‏.‏ زَادَ ابْنُ نُمَيْرٍ فِي حَدِيثِهِ عَنِ ابْنِ إِدْرِيسَ وَلَقَدْ شَكَوْتُ إِلَيْهِ أَنِّي لاَ أَثْبُتُ عَلَى الْخَيْلِ فَضَرَبَ بِيَدِهِ فِي صَدْرِي وَقَالَ ‏ "‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏ ‏.‏\hadithno{6364}\hadithtrans{Jarir reported:Since I embraced Islam Allah's Messenger (ﷺ) never refused to see me and he did not see me but with a smile on his face. Ibn Numair has made this addition to this hadith which has been reported on the authority of Ibn Idris that he (Jarir) made this complaint to him (to the Holy Prophet): I cannot sit upon the horse with firmness, whereupon he (Allah's Apostle) struck his chest with his hand and prayed: O Allah, make him steadfast and rightly-guided}}
\hadithdefcmd{muslim}{6365}{حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ، أَخْبَرَنَا خَالِدٌ، عَنْ بَيَانٍ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، قَالَ كَانَ فِي الْجَاهِلِيَّةِ بَيْتٌ يُقَالُ لَهُ ذُو الْخَلَصَةِ وَكَانَ يُقَالُ لَهُ الْكَعْبَةُ الْيَمَانِيَةُ وَالْكَعْبَةُ الشَّامِيَّةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَلْ أَنْتَ مُرِيحِي مِنْ ذِي الْخَلَصَةِ وَالْكَعْبَةِ الْيَمَانِيَةِ وَالشَّامِيَّةِ ‏"‏ ‏.‏ فَنَفَرْتُ إِلَيْهِ فِي مِائَةٍ وَخَمْسِينَ مِنْ أَحْمَسَ فَكَسَرْنَاهُ وَقَتَلْنَا مَنْ وَجَدْنَا عِنْدَهُ فَأَتَيْتُهُ فَأَخْبَرْتُهُ - قَالَ - فَدَعَا لَنَا وَلأَحْمَسَ ‏.‏\hadithno{6365}\hadithtrans{Jabir reported that there was in pre-Islamic days a temple called Dhu'l- Khalasah and it was called the Yamanite Ka'ba or the northern Ka'ba. Allah's Messenger (ﷺ) said unto me:Will you rid me of Dhu'l-Khalasah and so I went forth at the head of 350 horsemen of the tribe of Ahmas and we destroyed it and killed whomsoever we found there. Then we came back to him (to the Holy Prophet) and informed him and he blessed us and the tribe of Ahmas}}
\hadithdefcmd{muslim}{6366}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ، بْنِ أَبِي حَازِمٍ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا جَرِيرُ أَلاَ تُرِيحُنِي مِنْ ذِي الْخَلَصَةِ ‏"‏ ‏.‏ بَيْتٍ لِخَثْعَمَ كَانَ يُدْعَى كَعْبَةَ الْيَمَانِيَةِ ‏.‏ قَالَ فَنَفَرْتُ فِي خَمْسِينَ وَمِائَةِ فَارِسٍ وَكُنْتُ لاَ أَثْبُتُ عَلَى الْخَيْلِ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَضَرَبَ يَدَهُ فِي صَدْرِي فَقَالَ ‏"‏ اللَّهُمَّ ثَبِّتْهُ وَاجْعَلْهُ هَادِيًا مَهْدِيًّا ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ فَحَرَّقَهَا بِالنَّارِ ثُمَّ بَعَثَ جَرِيرٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلاً يُبَشِّرُهُ يُكْنَى أَبَا أَرْطَاةَ مِنَّا فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ مَا جِئْتُكَ حَتَّى تَرَكْنَاهَا كَأَنَّهَا جَمَلٌ أَجْرَبُ ‏.‏ فَبَرَّكَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى خَيْلِ أَحْمَسَ وَرِجَالِهَا خَمْسَ مَرَّاتٍ ‏.‏\hadithno{6366}\hadithtrans{Jarir b. 'Abdullah al-Bajali said:Allah's Messenger (ﷺ) said to me: Can't on rid me of Dhu'I-Khalasah, the idol-house of Khath'am, and this idol-house was called the Yamanite Ka'ba. So I went along with 150 horsemen and I could not sit with steadfastness upon the horse. I made the mention of it to Allah's Messenger (ﷺ) and he struck his hand on my chest and said: O Allah, grant him steadfastness and make him the guide of righteousness and the rightly-guided one. So he went away and he set fire to it. Then Jarir sent some person to Allah's Messenger (ﷺ) whose Kunya was Abu Arta to give him the happy news about that. He came to Allah's Messenger (ﷺ) and said: I have not come to you (but with the news) that we have left Dhu'l-Khalasah as a scabed camel. Thereupon Allah's Messenger (ﷺ) blessed the horses of Ahmas and the men of their tribe five times}}
\hadithdefcmd{muslim}{6367}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي الْفَزَارِيَّ ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ وَقَالَ فِي حَدِيثِ مَرْوَانَ فَجَاءَ بَشِيرُ جَرِيرٍ أَبُو أَرْطَاةَ حُصَيْنُ بْنُ رَبِيعَةَ يُبَشِّرُ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{6367}\hadithtrans{This hadith has been narrated on the authority of Ismail with different chains of transmitters and in the hadith transmitted on the authority of Marwan (the words are):"A person giving the glad tidings on behalf of Jarir came or Abu Husain b. Rabi`a came in order to give glad tidings to Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{6368}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو بَكْرِ بْنُ النَّضْرِ قَالاَ حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا وَرْقَاءُ بْنُ عُمَرَ الْيَشْكُرِيُّ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ بْنَ أَبِي يَزِيدَ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، أَنَّوسلم أَتَى الْخَلاَءَ فَوَضَعْتُ لَهُ وَضُوءًا فَلَمَّا خَرَجَ قَالَ ‏"‏ مَنْ وَضَعَ هَذَا ‏"‏ ‏.‏ فِي رِوَايَةِ زُهَيْرٍ قَالُوا ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ قُلْتُ ابْنُ عَبَّاسٍ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ فَقِّهْهُ ‏"‏ ‏.‏\hadithno{6368}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) came to privy and I placed for him water for ablution, When he came out he said:Who placed it here? And in a version of Zuhair they (the Companions) said, and in the version of Abu Bakr (the words are): I said: It is Ibn 'Abbas (who has done that), whereupon he (the Holy Prophet) said: May Allah grant him deep understanding of religion}}
\hadithdefcmd{muslim}{6369}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَخَلَفُ بْنُ هِشَامٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ كُلُّهُمْ عَنْ حَمَّادِ، بْنِ زَيْدٍ - قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، - حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ فِي الْمَنَامِ كَأَنَّ فِي يَدِي قِطْعَةَ إِسْتَبْرَقٍ وَلَيْسَ مَكَانٌ أُرِيدُ مِنَ الْجَنَّةِ إِلاَّ طَارَتْ إِلَيْهِ - قَالَ - فَقَصَصْتُهُ عَلَى حَفْصَةَ فَقَصَّتْهُ حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَرَى عَبْدَ اللَّهِ رَجُلاً صَالِحًا ‏"‏ ‏.‏\hadithno{6369}\hadithtrans{Ibn 'Umar reported:I saw in a state of sleep as if I have in my hand a piece of silk cloth and there is no place in the Paradise where I intend to reach but that piece of cloth does not fly towards it. I made a mention of it to Hafsa (the sister of Ibn 'Umar) and Hafsa made a mention of it to Allah's Apostle (ﷺ), whereupon Allah's Apostle (ﷺ) said: I find 'Abdullah b 'Umar a pious person}}
\hadithdefcmd{muslim}{6370}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لِعَبْدٍ - قَالاَ أَخْبَرَنَا عَبْدُ، الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ الرَّجُلُ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا رَأَى رُؤْيَا قَصَّهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَمَنَّيْتُ أَنْ أَرَى رُؤْيَا أَقُصُّهَا عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ وَكُنْتُ غُلاَمًا شَابًّا عَزَبًا وَكُنْتُ أَنَامُ فِي الْمَسْجِدِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُ فِي النَّوْمِ كَأَنَّ مَلَكَيْنِ أَخَذَانِي فَذَهَبَا بِي إِلَى النَّارِ فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ وَإِذَا لَهَا قَرْنَانِ كَقَرْنَىِ الْبِئْرِ وَإِذَا فِيهَا نَاسٌ قَدْ عَرَفْتُهُمْ فَجَعَلْتُ أَقُولُ أَعُوذُ بِاللَّهِ مِنَ النَّارِ أَعُوذُ بِاللَّهِ مِنَ النَّارِ أَعُوذُ بِاللَّهِ مِنَ النَّارِ - قَالَ - فَلَقِيَهُمَا مَلَكٌ فَقَالَ لِي لَمْ تُرَعْ ‏.‏ فَقَصَصْتُهَا عَلَى حَفْصَةَ فَقَصَّتْهَا حَفْصَةُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ لَوْ كَانَ يُصَلِّي مِنَ اللَّيْلِ ‏"‏ ‏.‏ قَالَ سَالِمٌ فَكَانَ عَبْدُ اللَّهِ بَعْدَ ذَلِكَ لاَ يَنَامُ مِنَ اللَّيْلِ إِلاَّ قَلِيلاً ‏.‏\hadithno{6370}\hadithtrans{Ibn 'Umar reported that when a person saw anything in sleep during the lifetime of Allah's Messenger (may peace he upon him) he narrated it to Allah's Messenger, and I also had a longing that I should also see in a dream something which I should narrate to Allah's Apostle (ﷺ) and I was at that time an unmarried young man. I was sleeping in the mosque during the lifetime of Allah's Messenger (ﷺ) tl) at I saw in a dream as if two Angels have taken hold of me and they have carried me to the fire, and, lo, it was built like the easing of a well and had two pillars like those of a well; and, lo, there were people in it whom I knew and I cried out:I seek refuge with Allah from Hell-fire; I seek refuge with Allah from Hell-fire. Then another Angel joined the two others, and said unto me: You need not fear I narrated this dream to llafsa and she narrated it to Allah's Messenger, whereupon Allah's Apostle said: Worthy is this man Abdullah, O that he would pray at night, and Silim added that Abdullah afterwards slept only but for a small part of the night}}
\hadithdefcmd{muslim}{6371}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُوسَى بْنُ خَالِدٍ، خَتَنُ الْفِرْيَابِيِّ عَنْ أَبِي إِسْحَاقَ الْفَزَارِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنْتُ أَبِيتُ فِي الْمَسْجِدِ وَلَمْ يَكُنْ لِي أَهْلٌ فَرَأَيْتُ فِي الْمَنَامِ كَأَنَّمَا انْطُلِقَ بِي إِلَى بِئْرٍ ‏.‏ فَذَكَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ ‏.‏\hadithno{6371}\hadithtrans{Ibn Umar reported:I used to spend nights in the mosque and by that time I had no wife and children. I saw in a dream as if I am being taken to a well. I made a mention of it to Allah's Messenger (may peacebe upon him). The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6372}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسٍ، عَنْ أُمِّ سُلَيْمٍ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ خَادِمُكَ أَنَسٌ ادْعُ اللَّهَ لَهُ فَقَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ وَبَارِكْ لَهُ فِيمَا أَعْطَيْتَهُ ‏"‏ ‏.‏\hadithno{6372}\hadithtrans{Anas reported that Umm Sulaim said (to the Holy Prophet) Allah's Messenger, here is your servant Anas, invoke blessings of Allah upon him. Thereupon he (the Holy Prophet) said:O Allah, make an increase in his wealth, and progeny, and confer blessings upon him in everything Thou hast bestowed upon him}}
\hadithdefcmd{muslim}{6373}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعْتُ أَنَسًا، يَقُولُ قَالَتْ أُمُّ سُلَيْمٍ يَا رَسُولَ اللَّهِ خَادِمُكَ أَنَسٌ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{6373}\hadithtrans{Anas reported (that his mother) Umm Sulaim said (to the Holy Prophet) Allah's Messenger, here is your servant Anas. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6374}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ مِثْلَ ذَلِكَ ‏.‏\hadithno{6374}\hadithtrans{This hadith has been reported on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{6375}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا سُلَيْمَانُ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَيْنَا وَمَا هُوَ إِلاَّ أَنَا وَأُمِّي وَأُمُّ حَرَامٍ خَالَتِي فَقَالَتْ أُمِّي يَا رَسُولَ اللَّهِ خُوَيْدِمُكَ ادْعُ اللَّهَ لَهُ - قَالَ - فَدَعَا لِي بِكُلِّ خَيْرٍ وَكَانَ فِي آخِرِ مَا دَعَا لِي بِهِ أَنْ قَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ وَبَارِكْ لَهُ فِيهِ ‏"‏ ‏.‏\hadithno{6375}\hadithtrans{Anas reportedAllah's Apostle (ﷺ) visited us and there was none else (in the house) but I, my mother and my mother's sister Umm Haram. My mother said to him:Allah's Messenger, here is a small servant of yours, invoke blessings of Allah upon him. And he invoked blessings for me (that I should be bestowed upon) every good and this was what he (said) at the end of what be supplicated for me: O Allah, make an increase in his wealth, and progeny, and cqnfer blessings (upon him) in (each one) of them}}
\hadithdefcmd{muslim}{6376}{حَدَّثَنِي أَبُو مَعْنٍ الرَّقَاشِيُّ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ، حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا أَنَسٌ، قَالَ جَاءَتْ بِي أُمِّي أُمُّ أَنَسٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أَزَّرَتْنِي بِنِصْفِ خِمَارِهَا وَرَدَّتْنِي بِنِصْفِهِ فَقَالَتْ يَا رَسُولَ اللَّهِ هَذَا أُنَيْسٌ ابْنِي أَتَيْتُكَ بِهِ يَخْدُمُكَ فَادْعُ اللَّهَ لَهُ ‏.‏ فَقَالَ ‏ "‏ اللَّهُمَّ أَكْثِرْ مَالَهُ وَوَلَدَهُ ‏"‏ ‏.‏ قَالَ أَنَسٌ فَوَاللَّهِ إِنَّ مَالِي لَكَثِيرٌ وَإِنَّ وَلَدِي وَوَلَدَ وَلَدِي لَيَتَعَادُّونَ عَلَى نَحْوِ الْمِائَةِ الْيَوْمَ ‏.‏\hadithno{6376}\hadithtrans{Anas reported:My mother Umm Anas came to Allah's Messenger (ﷺ). And she prepared my lower garment out of the half of her headdress and (with the other half) she covered my upper body and said: Allah's Messenger, here is my son Unais; I have brought him to you for serving you. Invoke blessings of Allah upon him. Thereupon he (the Holy Prophet) said: O Allah, make an increase in his wealth, and progeny. Anas said: By Allah, my fortune is huge and my children, and grand-children are now more than one hundred}}
\hadithdefcmd{muslim}{6377}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَعْفَرٌ، - يَعْنِي ابْنَ سُلَيْمَانَ - عَنِ الْجَعْدِ أَبِي عُثْمَانَ، قَالَ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَمِعَتْ أُمِّي أُمُّ سُلَيْمٍ صَوْتَهُ فَقَالَتْ بِأَبِي وَأُمِّي يَا رَسُولَ اللَّهِ أُنَيْسٌ ‏.‏ فَدَعَا لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَ دَعَوَاتٍ قَدْ رَأَيْتُ مِنْهَا اثْنَتَيْنِ فِي الدُّنْيَا وَأَنَا أَرْجُو الثَّالِثَةَ فِي الآخِرَةِ ‏.‏\hadithno{6377}\hadithtrans{Anas b. Malik said:Allah's Messenger (ﷺ) passed (by our house) that my mother Umm Sulaim listened to his voice and said: Allah's Messenger, let my father and mother be sacrificed for thee, here is Unais (and requested him to invoke blessings upon me). So Allah's Messenger (ﷺ) invoked three blessings upon me. I have seen (the results) of the two in this very world (in regard to wealth and progeny) and I hope to see (the result) of the third one in the Hereafter}}
\hadithdefcmd{muslim}{6378}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ أَتَى عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَلْعَبُ مَعَ الْغِلْمَانِ - قَالَ - فَسَلَّمَ عَلَيْنَا فَبَعَثَنِي إِلَى حَاجَةٍ فَأَبْطَأْتُ عَلَى أُمِّي فَلَمَّا جِئْتُ قَالَتْ مَا حَبَسَكَ قُلْتُ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم لِحَاجَةٍ ‏.‏ قَالَتْ مَا حَاجَتُهُ قُلْتُ إِنَّهَا سِرٌّ ‏.‏ قَالَتْ لاَ تُحَدِّثَنَّ بِسِرِّ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَدًا ‏.‏ قَالَ أَنَسٌ وَاللَّهِ لَوْ حَدَّثْتُ بِهِ أَحَدًا لَحَدَّثْتُكَ يَا ثَابِتُ ‏.‏\hadithno{6378}\hadithtrans{Anas reported:Allah's Messenger (ﷺ) came to me as I was playing with playmates. He greeted and sent me on an errand and I made delay in going to my mother. When I came to her she said: What detained you? I said: Allah's Messenger (ﷺ) sent me on an errand. She said: What was the purpose? I said: It is something secret. Therupon she said: Do not then divulge the secret of Allah's Messenger (ﷺ) to anyone. Anas said: By Allah, if I were to divulge it to anyone, then, O Thabit, I would have divulged it to you}}
\hadithdefcmd{muslim}{6379}{حَدَّثَنَا حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَارِمُ بْنُ الْفَضْلِ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَسَرَّ إِلَىَّ نَبِيُّ اللَّهِ صلى الله عليه وسلم سِرًّا فَمَا أَخْبَرْتُ بِهِ أَحَدًا بَعْدُ ‏.‏ وَلَقَدْ سَأَلَتْنِي عَنْهُ أُمُّ سُلَيْمٍ فَمَا أَخْبَرْتُهَا بِهِ ‏.‏\hadithno{6379}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) told me something secretly. I informed none about that and Umm Sulaim asked me about it, but I did not tell her even}}
\hadithdefcmd{muslim}{6380}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ عِيسَى، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي النَّضْرِ، عَنْ عَامِرِ بْنِ سَعْدٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِحَىٍّ يَمْشِي أَنَّهُ فِي الْجَنَّةِ إِلاَّ لِعَبْدِ اللَّهِ بْنِ سَلاَمٍ ‏.‏\hadithno{6380}\hadithtrans{Amir b. Sa'd reported that he heard his father (Sa'd b. Abi Waqqas) say:never heard Allah's Messenger (ﷺ) say unto one living and moving about that he was in Paradise except to 'Abdullah b. Salim}}
\hadithdefcmd{muslim}{6381}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ كُنْتُ بِالْمَدِينَةِ فِي نَاسٍ فِيهِمْ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَجَاءَ رَجُلٌ فِي وَجْهِهِ أَثَرٌ مِنْ خُشُوعٍ فَقَالَ بَعْضُ الْقَوْمِ هَذَا رَجُلٌ مِنْ أَهْلِ الْجَنَّةِ هَذَا رَجُلٌ مِنْ أَهْلِ الْجَنَّةِ ‏.‏ فَصَلَّى رَكْعَتَيْنِ يَتَجَوَّزُ فِيهِمَا ثُمَّ خَرَجَ فَاتَّبَعْتُهُ فَدَخَلَ مَنْزِلَهُ وَدَخَلْتُ فَتَحَدَّثْنَا فَلَمَّا اسْتَأْنَسَ قُلْتُ لَهُ إِنَّكَ لَمَّا دَخَلْتَ قَبْلُ قَالَ رَجُلٌ كَذَا وَكَذَا قَالَ سُبْحَانَ اللَّهِ مَا يَنْبَغِي لأَحَدٍ أَنْ يَقُولَ مَا لاَ يَعْلَمُ وَسَأُحَدِّثُكَ لِمَ ذَاكَ رَأَيْتُ رُؤْيَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَصَصْتُهَا عَلَيْهِ رَأَيْتُنِي فِي رَوْضَةٍ - ذَكَرَ سَعَتَهَا وَعُشْبَهَا وَخُضْرَتَهَا - وَوَسْطَ الرَّوْضَةِ عَمُودٌ مِنْ حَدِيدٍ أَسْفَلُهُ فِي الأَرْضِ وَأَعْلاَهُ فِي السَّمَاءِ فِي أَعْلاَهُ عُرْوَةٌ ‏.‏ فَقِيلَ لِي ارْقَهْ ‏.‏ فَقُلْتُ لَهُ لاَ أَسْتَطِيعُ ‏.‏ فَجَاءَنِي مِنْصَفٌ - قَالَ ابْنُ عَوْنٍ وَالْمِنْصَفُ الْخَادِمُ - فَقَالَ بِثِيَابِي مِنْ خَلْفِي - وَصَفَ أَنَّهُ رَفَعَهُ مِنْ خَلْفِهِ بِيَدِهِ - فَرَقِيتُ حَتَّى كُنْتُ فِي أَعْلَى الْعَمُودِ فَأَخَذْتُ بِالْعُرْوَةِ فَقِيلَ لِيَ اسْتَمْسِكْ ‏.‏ فَلَقَدِ اسْتَيْقَظْتُ وَإِنَّهَا لَفِي يَدِي فَقَصَصْتُهَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ تِلْكَ الرَّوْضَةُ الإِسْلاَمُ وَذَلِكَ الْعَمُودُ عَمُودُ الإِسْلاَمِ وَتِلْكَ الْعُرْوَةُ عُرْوَةُ الْوُثْقَى وَأَنْتَ عَلَى الإِسْلاَمِ حَتَّى تَمُوتَ ‏"‏ ‏.‏ قَالَ وَالرَّجُلُ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ‏.‏\hadithno{6381}\hadithtrans{Qais b. 'Ubada reported:I was in the company of some persons, amongst whom some were the Companions of Allah's Apostle (ﷺ) in Medina, that there came a person whose face depicted the fear (of Allah). Some people said: He is a person from amongst the people of Paradise; he is a person from amongst the people of Paradise. He observed two short rak'ahs of prayer and then went out. I followed him and he got into his house and I also got in and we began to converse with each other. And when he became familiar (with me) I said to Him: When you entered (the mosque) before (your entrance in the house) a person said so and so (that you are amongst the people of Paradise), whereupon he said: It is not meet for anyone to say anything which he does not know. I shall (now) tell you why they (say) this. I saw a dream during the lifetime of Allah's Messenger (ﷺ) and narrated it to him. I seemed to be in a garden [he described its vastness, its rich fructification and its verdure]; in the midst of it, there stood an iron pillar, with its base in the earth and its summit in the sky: and upon its summit there was a handhold. It was said to me: Climb up this (pillar). I said to him (visitant in the dream): I am unable to do it. Thereupon a helper came to me, and he (supported) me (by catching hold of my) garment from behind and thus helped me with his hand and so I climbed up till I was at the summit of the pillar, and grasped the handhold. It was said to me: Ho d it tightly. It was at this that I woke up when (the handhold) was in fthe grip) of my hand. I narrated it (the dream) to Allah's Apostle (ﷺ), whereupon he said: That garden implies al-Islam and that pillar implies the pillar of Islam. And that handhold is the firmest faith (as refered to in the Qur'an). And you will remain attached to Islam until you shall die. And that man was 'Abdullah b. Salim}}
\hadithdefcmd{muslim}{6382}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَبَّادِ بْنِ جَبَلَةَ بْنِ أَبِي رَوَّادٍ، حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ قَالَ قَيْسُ بْنُ عُبَادٍ كُنْتُ فِي حَلْقَةٍ فِيهَا سَعْدُ بْنُ مَالِكٍ وَابْنُ عُمَرَ فَمَرَّ عَبْدُ اللَّهِ بْنُ سَلاَمٍ فَقَالُوا هَذَا رَجُلٌ مِنْ أَهْلِ الْجَنَّةِ ‏.‏ فَقُمْتُ فَقُلْتُ لَهُ إِنَّهُمْ قَالُوا كَذَا وَكَذَا ‏.‏ قَالَ سُبْحَانَ اللَّهِ مَا كَانَ يَنْبَغِي لَهُمْ أَنْ يَقُولُوا مَا لَيْسَ لَهُمْ بِهِ عِلْمٌ إِنَّمَا رَأَيْتُ كَأَنَّ عَمُودًا وُضِعَ فِي رَوْضَةٍ خَضْرَاءَ فَنُصِبَ فِيهَا وَفِي رَأْسِهَا عُرْوَةٌ وَفِي أَسْفَلِهَا مِنْصَفٌ - وَالْمِنْصَفُ الْوَصِيفُ - فَقِيلَ لِيَ ارْقَهْ ‏.‏ فَرَقِيتُ حَتَّى أَخَذْتُ بِالْعُرْوَةِ فَقَصَصْتُهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَمُوتُ عَبْدُ اللَّهِ وَهُوَ آخِذٌ بِالْعُرْوَةِ الْوُثْقَى ‏"‏ ‏.‏\hadithno{6382}\hadithtrans{Qais b. 'Ubaida reported:I was (sitting) in a company in which there were (besides others) Sa'd b. Malik and Ibn 'Umar that 'Abdullah b. Saliim happened to pass (by that side). They (the people sitting in that company) said: He is a person from amongst the dwellers of Paradise. I stood up and said to him: They say such and such (thing about you), whereupon he said: Hallowed be Allah, it is not meet for them to say (anything) of which They have no knowledge. Verily I saw as if a pillar had been raised in a green garden and there had been fixed at its (upper) end a handhold and there was a helper at its base. It was said to me: Climb up. So I climbed up and caught hold of the haildhold. I narrated (the contents of this dream) to Allah's Messenger (ﷺ), whereupon he said: 'Abdullah would die in a state that he would be catching hold of the firmest handhold (he would die holding fast to the faith)}}
\hadithdefcmd{muslim}{6383}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِقُتَيْبَةَ - حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ سُلَيْمَانَ بْنِ مُسْهِرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، قَالَ كُنْتُ جَالِسًا فِي حَلْقَةٍ فِي مَسْجِدِ الْمَدِينَةِ - قَالَ - وَفِيهَا شَيْخٌ حَسَنُ الْهَيْئَةِ وَهُوَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ - قَالَ - فَجَعَلَ يُحَدِّثُهُمْ حَدِيثًا حَسَنًا - قَالَ - فَلَمَّا قَامَ قَالَ الْقَوْمُ مَنْ سَرَّهُ أَنْ يَنْظُرَ إِلَى رَجُلٍ مِنْ أَهْلِ الْجَنَّةِ فَلْيَنْظُرْ إِلَى هَذَا ‏.‏ قَالَ فَقُلْتُ وَاللَّهِ لأَتْبَعَنَّهُ فَلأَعْلَمَنَّ مَكَانَ بَيْتِهِ ‏.‏ قَالَ فَتَبِعْتُهُ فَانْطَلَقَ حَتَّى كَادَ أَنْ يَخْرُجَ مِنَ الْمَدِينَةِ ثُمَّ دَخَلَ مَنْزِلَهُ - قَالَ - فَاسْتَأْذَنْتُ عَلَيْهِ فَأَذِنَ لِي فَقَالَ مَا حَاجَتُكَ يَا ابْنَ أَخِي قَالَ فَقُلْتُ لَهُ سَمِعْتُ الْقَوْمَ يَقُولُونَ لَكَ لَمَّا قُمْتَ مَنْ سَرَّهُ أَنْ يَنْظُرَ إِلَى رَجُلٍ مِنْ أَهْلِ الْجَنَّةِ فَلْيَنْظُرْ إِلَى هَذَا ‏.‏ فَأَعْجَبَنِي أَنْ أَكُونَ مَعَكَ قَالَ اللَّهُ أَعْلَمُ بِأَهْلِ الْجَنَّةِ وَسَأُحَدِّثُكَ مِمَّ قَالُوا ذَاكَ إِنِّي بَيْنَمَا أَنَا نَائِمٌ إِذْ أَتَانِي رَجُلٌ فَقَالَ لِي قُمْ ‏.‏ فَأَخَذَ بِيَدِي فَانْطَلَقْتُ مَعَهُ - قَالَ - فَإِذَا أَنَا بِجَوَادَّ عَنْ شِمَالِي - قَالَ - فَأَخَذْتُ لآخُذَ فِيهَا فَقَالَ لِي لاَ تَأْخُذْ فِيهَا فَإِنَّهَا طُرُقُ أَصْحَابِ الشِّمَالِ - قَالَ - فَإِذَا جَوَادُّ مَنْهَجٌ عَلَى يَمِيِنِي فَقَالَ لِي خُذْ هَا هُنَا ‏.‏ فَأَتَى بِي جَبَلاً فَقَالَ لِي اصْعَدْ - قَالَ - فَجَعَلْتُ إِذَا أَرَدْتُ أَنْ أَصْعَدَ خَرَرْتُ عَلَى اسْتِي - قَالَ - حَتَّى فَعَلْتُ ذَلِكَ مِرَارًا - قَالَ - ثُمَّ انْطَلَقَ بِي حَتَّى أَتَى بِي عَمُودًا رَأْسُهُ فِي السَّمَاءِ وَأَسْفَلُهُ فِي الأَرْضِ فِي أَعْلاَهُ حَلْقَةٌ فَقَالَ لِيَ ‏.‏ اصْعَدْ فَوْقَ هَذَا ‏.‏ قَالَ قُلْتُ كَيْفَ أَصْعَدُ هَذَا وَرَأْسُهُ فِي السَّمَاءِ - قَالَ - فَأَخَذَ بِيَدِي فَزَجَلَ بِي - قَالَ - فَإِذَا أَنَا مُتَعَلِّقٌ بِالْحَلْقَةِ - قَالَ - ثُمَّ ضَرَبَ الْعَمُودَ فَخَرَّ - قَالَ - وَبَقِيتُ مُتَعَلِّقًا بِالْحَلْقَةِ حَتَّى أَصْبَحْتُ - قَالَ - فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَصَصْتُهَا عَلَيْهِ فَقَالَ ‏ "‏ أَمَّا الطُّرُقُ الَّتِي رَأَيْتَ عَنْ يَسَارِكَ فَهِيَ طُرُقُ أَصْحَابِ الشِّمَالِ - قَالَ - وَأَمَّا الطُّرُقُ الَّتِي رَأَيْتَ عَنْ يَمِينِكَ فَهِيَ طُرُقُ أَصْحَابِ الْيَمِينِ وَأَمَّا الْجَبَلُ فَهُوَ مَنْزِلُ الشُّهَدَاءِ وَلَنْ تَنَالَهُ وَأَمَّا الْعَمُودُ فَهُوَ عَمُودُ الإِسْلاَمِ وَأَمَّا الْعُرْوَةُ فَهِيَ عُرْوَةُ الإِسْلاَمِ وَلَنْ تَزَالَ مُتَمَسِّكًا بِهَا حَتَّى تَمُوتَ ‏"‏ ‏.‏\hadithno{6383}\hadithtrans{Kharasha b. Hurr reported:I was sitting in a circle in the mosque of Medina and there was an old man, quite handsome. He was 'Abdullah b. Salim. He was telling good things to them (to the people sitting in that company). As he stood up (to depart) the people said: He who is desirous of looking at a person from amongst the people of Paradise should see him. I said: By Allah, I will follow him, and would try to know his residence. So I followed him and he walked on until he reached the outskirts of Medina. He then entered his house. I sought permission from him to get in, and he granted me the permission, saying: My nephew, what is the need (that has brought you here)? I said to him: As you stood up, I heard people say about you: He who is desirous of seeing a person from among the people of Paradise should look at him. So I became desirous of accompanying you. He ('Abdullah b. Salim) said: It is Allah Who knows best about the people of Paradise. I would, however, narrate to you as to why they said like it. (The story is) that while I was asleep (one night) there came to me a person (in the dream) who asked me to stand up. (So I stood up) and he caught hold of my hand and I walked along with him, and, lo, I found some paths on my left and I was about to set out upon them. Thereupon he said to me Do not set yourself on (them) for these are the paths of the leftists (denizens of Hell-fire). Then there were paths leading to the right side, whereupon he said: Set yourself on these paths. We came across a hill and he said to me: Climb up, and I attempted to climb up that I fell upon my buttocks. I made several attempts (but failed to succeed). He led until he came to a pillar (so high) that its upper end touched the sky and its base was in the earth. And there was a handhold at its upper end. He said to me Climb over it. I said: How can I climb upon it, as its upper end touches the sky? He cought hold of my hand and pushed me up and I found myself suspended with the handhold. He then struck the pillar and it fell down, but I remained attached to that handhold until it was morning (and the dream was thus over). I came to Allah's Apostle (ﷺ) and narrated it to him. He said: So far as the paths which you saw on your left are concerned, these are paths of the leftists (denizens of Hell) and the paths which you saw on your right, these are the paths of the rightists (the dwellers of Paradise) and the mountain represents the destination of the martyrs which you would not be able to attain. The pillar implies the pillar of Islam. and so far as the handhold is concerned, it implies the handhold of Islam, and you would hold to it fastly until you would meet death}}
\hadithdefcmd{muslim}{6384}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، كُلُّهُمْ عَنْ سُفْيَانَ، قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ عُمَرَ، مَرَّ بِحَسَّانَ وَهُوَ يُنْشِدُ الشِّعْرَ فِي الْمَسْجِدِ فَلَحَظَ إِلَيْهِ فَقَالَ قَدْ كُنْتُ أُنْشِدُ وَفِيهِ مَنْ هُوَ خَيْرٌ مِنْكَ ‏.‏ ثُمَّ الْتَفَتَ إِلَى أَبِي هُرَيْرَةَ فَقَالَ أَنْشُدُكَ اللَّهَ أَسَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَجِبْ عَنِّي اللَّهُمَّ أَيِّدْهُ بِرُوحِ الْقُدُسِ ‏"‏ ‏.‏ قَالَ اللَّهُمَّ نَعَمْ ‏.‏\hadithno{6384}\hadithtrans{Abu Huraira reported that 'Umar happened to pass by Hassan as he was reciting verses in the mosque. He (Hadrat 'Umar) looked towards him (meaningfully), whereupon he (gassin) said:I used to recite (verses) when one better than you (the Holy Prophet) had been present (here). He then looked towards Abu Huraira and said to him: I adjure you by Allah (to tell) if you had not heard Allah's Messenger (ﷺ) as saying: (Hassan), give a reply on my behalf; Allah I help him with Ruh-ul-Qudus. He (Abu Huraira) said: By Allah, it is so (i. e. the Prophet actually said these words)}}
\hadithdefcmd{muslim}{6385}{حَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، أَنَّ حَسَّانَ، قَالَ فِي حَلْقَةٍ فِيهِمْ أَبُو هُرَيْرَةَ أَنْشُدُكَ اللَّهَ يَا أَبَا هُرَيْرَةَ أَسَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{6385}\hadithtrans{Ibn Musayyib reported that Hassan said to a circle in which there was also Abu Huraira:Abu Huraira, I adjure you by Allah (to tell) whether you-had not heard Allah's Messenger (ﷺ) saying like this}}
\hadithdefcmd{muslim}{6386}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ حَسَّانَ بْنَ ثَابِتٍ الأَنْصَارِيَّ، يَسْتَشْهِدُ أَبَا هُرَيْرَةَ أَنْشُدُكَ اللَّهَ هَلْ سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَا حَسَّانُ أَجِبْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم اللَّهُمَّ أَيِّدْهُ بِرُوحِ الْقُدُسِ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ نَعَمْ ‏.‏\hadithno{6386}\hadithtrans{Abd al-Rahman reported that he heard Hassin b. Thabit al-Ansari call Abu Huraira to bear witness by saying:I adjure you by Allah if you had not heard Allah's Apostle (ﷺ) saying: Hassin, give a reply on behalf of the Messenger of Allah. O Allah, help him with Ruh-ul-Qudus. Abu Huraira said: Yes, it is so}}
\hadithdefcmd{muslim}{6387}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِحَسَّانَ بْنِ ثَابِتٍ ‏ "‏ اهْجُهُمْ أَوْ هَاجِهِمْ وَجِبْرِيلُ مَعَكَ ‏"‏ ‏.‏\hadithno{6387}\hadithtrans{Al-Bari' b. 'Azib reported:I heard Allah's Messenger (ﷺ) as saying: Hassan b. Thibit, write satire (against the non-believers) ; Gabriel is with you}}
\hadithdefcmd{muslim}{6388}{حَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا غُنْدَرٌ، ح وَحَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6388}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6389}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنَّ حَسَّانَ بْنَ ثَابِتٍ، كَانَ مِمَّنْ كَثَّرَ عَلَى عَائِشَةَ فَسَبَبْتُهُ فَقَالَتْ يَا ابْنَ أُخْتِي دَعْهُ فَإِنَّهُ كَانَ يُنَافِحُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6389}\hadithtrans{Hisham reported on the authority of his father that Hassan b. Thabit talked much about 'A'isha. I scolded him, whereupon she said:My nephew, leave him for he defended Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6390}{حَدَّثَنَاهُ عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6390}\hadithtrans{This hadith has been narrated on the authority of Hishim with the same chain of transmitters}}
\hadithdefcmd{muslim}{6391}{حَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ وَعِنْدَهَا حَسَّانُ بْنُ ثَابِتٍ يُنْشِدُهَا شِعْرًا يُشَبِّبُ بِأَبْيَاتٍ لَهُ فَقَالَ حَصَانٌ رَزَانٌ مَا تُزَنُّ بِرِيبَةٍ وَتُصْبِحُ غَرْثَى مِنْ لُحُومِ الْغَوَافِلِ فَقَالَتْ لَهُ عَائِشَةُ لَكِنَّكَ لَسْتَ كَذَلِكَ ‏.‏ قَالَ مَسْرُوقٌ فَقُلْتُ لَهَا لِمَ تَأْذَنِينَ لَهُ يَدْخُلُ عَلَيْكِ وَقَدْ قَالَ اللَّهُ ‏\{‏ وَالَّذِي تَوَلَّى كِبْرَهُ مِنْهُمْ لَهُ عَذَابٌ عَظِيمٌ‏\}‏ فَقَالَتْ فَأَىُّ عَذَابٍ أَشَدُّ مِنَ الْعَمَى إِنَّهُ كَانَ يُنَافِحُ أَوْ يُهَاجِي عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6391}\hadithtrans{Masruq reported:I visited 'A'isha when Hassin was sitting there and reciting verses from his compilation: She is chaste and prudent. There is no calumny against her and she rises up early in the morning without eating the meat of the un- mindful. 'A'isha said: But you are not so. Masruq said: I said to her: Why do you permit him to visit you, whereas Allah has said:" And as for him among them who took upon himself the main part thereof, he shall have a grievous punishment" (XXIV. ll)? Thereupon she said: What tornient can be more severe than this that he has become blind? He used to write satire as a rebuttal on behalf of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6392}{حَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ وَقَالَ قَالَتْ كَانَ يَذُبُّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرْ حَصَانٌ رَزَانٌ ‏.‏\hadithno{6392}\hadithtrans{This hadith has been reported on the authority of Shu'ba with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6393}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَحْيَى بْنُ زَكَرِيَّاءَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ حَسَّانُ يَا رَسُولَ اللَّهِ ائْذَنْ لِي فِي أَبِي سُفْيَانَ قَالَ ‏ "‏ كَيْفَ بِقَرَابَتِي مِنْهُ ‏"‏ ‏.‏ قَالَ وَالَّذِي أَكْرَمَكَ لأَسُلَّنَّكَ مِنْهُمْ كَمَا تُسَلُّ الشَّعَرَةُ مِنَ الْخَمِيرِ ‏.‏ فَقَالَ حَسَّانُ وَإِنَّ سَنَامَ الْمَجْدِ مِنْ آلِ هَاشِمٍ بَنُو بِنْتِ مَخْزُومٍ وَوَالِدُكَ الْعَبْدُ قَصِيدَتَهُ هَذِهِ ‏.‏\hadithno{6393}\hadithtrans{A'isha reported that Hassin said:Allah's Messenger, permit me to write satire against Abu Sufyan, whereupon he said: How can it be because I am also related to him? Thereupon he (Hassan) said: By Him Who has honoured you. I shall draw you out from them (their family) just as hair is drawn out from the fermented (flour). Thereupon Hassan said: The dignity and greatness belongs to the tribe of Bint Makhzum from amongst the tribe of Hisham, whereas your father was a slave}}
\hadithdefcmd{muslim}{6394}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، بِهَذَا الإِسْنَادِ قَالَتِ اسْتَأْذَنَ حَسَّانُ بْنُ ثَابِتٍ النَّبِيَّ صلى الله عليه وسلم فِي هِجَاءِ الْمُشْرِكِينَ ‏.‏ وَلَمْ يَذْكُرْ أَبَا سُفْيَانَ وَقَالَ بَدَلَ الْخَمِيرِ الْعَجِينِ ‏.‏\hadithno{6394}\hadithtrans{Urwa reported on the same chain of transmitters that Hassan b. Thabit sought permission from Allah's Apostle (ﷺ) to satirise against the polytheists, but he did not mention Abu Sufyan. And instead of the word al- Khamir, the word al-'Ajin was used}}
\hadithdefcmd{muslim}{6395}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي خَالِدُ بْنُ يَزِيدَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي هِلاَلٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، بْنِ عَبْدِ الرَّحْمَنِ عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اهْجُوا قُرَيْشًا فَإِنَّهُ أَشَدُّ عَلَيْهَا مِنْ رَشْقٍ بِالنَّبْلِ ‏"‏ ‏.‏ فَأَرْسَلَ إِلَى ابْنِ رَوَاحَةَ فَقَالَ ‏"‏ اهْجُهُمْ ‏"‏ ‏.‏ فَهَجَاهُمْ فَلَمْ يُرْضِ فَأَرْسَلَ إِلَى كَعْبِ بْنِ مَالِكٍ ثُمَّ أَرْسَلَ إِلَى حَسَّانَ بْنِ ثَابِتٍ فَلَمَّا دَخَلَ عَلَيْهِ قَالَ حَسَّانُ قَدْ آنَ لَكُمْ أَنْ تُرْسِلُوا إِلَى هَذَا الأَسَدِ الضَّارِبِ بِذَنَبِهِ ثُمَّ أَدْلَعَ لِسَانَهُ فَجَعَلَ يُحَرِّكُهُ فَقَالَ وَالَّذِي بَعَثَكَ بِالْحَقِّ لأَفْرِيَنَّهُمْ بِلِسَانِي فَرْىَ الأَدِيمِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَعْجَلْ فَإِنَّ أَبَا بَكْرٍ أَعْلَمُ قُرَيْشٍ بِأَنْسَابِهَا - وَإِنَّ لِي فِيهِمْ نَسَبًا - حَتَّى يُلَخِّصَ لَكَ نَسَبِي ‏"‏ ‏.‏ فَأَتَاهُ حَسَّانُ ثُمَّ رَجَعَ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ لَخَّصَ لِي نَسَبَكَ وَالَّذِي بَعَثَكَ بِالْحَقِّ لأَسُلَّنَّكَ مِنْهُمْ كَمَا تُسَلُّ الشَّعَرَةُ مِنَ الْعَجِينِ ‏.‏ قَالَتْ عَائِشَةُ فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِحَسَّانَ ‏"‏ إِنَّ رُوحَ الْقُدُسِ لاَ يَزَالُ يُؤَيِّدُكَ مَا نَافَحْتَ عَنِ اللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏ وَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ هَجَاهُمْ حَسَّانُ فَشَفَى وَاشْتَفَى ‏"‏ ‏.‏ قَالَ حَسَّانُ هَجَوْتَ مُحَمَّدًا فَأَجَبْتُ عَنْهُ وَعِنْدَ اللَّهِ فِي ذَاكَ الْجَزَاءُ هَجَوْتَ مُحَمَّدًا بَرًّا تَقِيًّا رَسُولَ اللَّهِ شِيمَتُهُ الْوَفَاءُ فَإِنَّ أَبِي وَوَالِدَهُ وَعِرْضِي لِعِرْضِ مُحَمَّدٍ مِنْكُمْ وِقَاءُ ثَكِلْتُ بُنَيَّتِي إِنْ لَمْ تَرَوْهَا تُثِيرُ النَّقْعَ مِنْ كَنَفَىْ كَدَاءِ يُبَارِينَ الأَعِنَّةَ مُصْعِدَاتٍ عَلَى أَكْتَافِهَا الأَسَلُ الظِّمَاءُ تَظَلُّ جِيَادُنَا مُتَمَطِّرَاتٍ تُلَطِّمُهُنَّ بِالْخُمُرِ النِّسَاءُ فَإِنْ أَعْرَضْتُمُو عَنَّا اعْتَمَرْنَا وَكَانَ الْفَتْحُ وَانْكَشَفَ الْغِطَاءُ وَإِلاَّ فَاصْبِرُوا لِضِرَابِ يَوْمٍ يُعِزُّ اللَّهُ فِيهِ مَنْ يَشَاءُ وَقَالَ اللَّهُ قَدْ أَرْسَلْتُ عَبْدًا يَقُولُ الْحَقَّ لَيْسَ بِهِ خَفَاءُ وَقَالَ اللَّهُ قَدْ يَسَّرْتُ جُنْدًا هُمُ الأَنْصَارُ عُرْضَتُهَا اللِّقَاءُ لَنَا فِي كُلِّ يَوْمٍ مِنْ مَعَدٍّ سِبَابٌ أَوْ قِتَالٌ أَوْ هِجَاءُ فَمَنْ يَهْجُو رَسُولَ اللَّهِ مِنْكُمْ وَيَمْدَحُهُ وَيَنْصُرُهُ سَوَاءُ وَجِبْرِيلٌ رَسُولُ اللَّهِ فِينَا وَرُوحُ الْقُدْسِ لَيْسَ لَهُ كِفَاءُ\hadithno{6395}\hadithtrans{A'isha reported that Allah's Messenger (may peace be uport him) said. Satirise against the (non-believing amongst the) Quraish, for (the satire) is more grievous to them than the hurt of an arrow. So he (the Holy Prophet) sent (someone) to Ibn Rawiha and asked him to satirise against them, and he composed a satire, but it did not appeal to him (to the Holy Prophet). He then sent (someone) to Ka'b b. Malik (to do the same, but what he composed did not appeal to the Holy Prophet). He then sent one to Hassan b. Thabit. As he got into his presence, Hassan said:Now you have called for this lion who strikes (the enemies) with his tail. He then brought out his tongue and began to move it and said: By Him Who has sent you with Truth, I shall tear them with my tongue as the leather is torn. Thereupon Allah's Messenger (ﷺ) said: Don't be hasty; (let) Abu Bakr who has the best know- ledge of the lineage of the Quraish draw a distinction for you in regard to my lineage, as my lineage is thesame as theirs. Hassan then came to him (Abu Bakr) and after making inquiry (in regard to the lineage of the Holy Prophet) came back to him (the holy Prophet) and said: Allah's Messenger, he (Abu Bakr) has drawn a distinction in vour lineage (and that of the Quraish) By Him Who has sent you with Truth, I shall draw out from them (your name) as hair is drawn out from the flour. 'A'isha said: I heard Allah's Messenger (ﷺ) as saying to Hassin: Verily Ruh-ul- Qudus would continue to help you so long as you put up a defence on behalf of Allah and His Messenger. And she said: I heard Allah's Messenger (ﷺ) saying: Hassan satirised against them and gave satisfaction to the (Muslims) and disquieted (the non-Muslims). You satirised Muhammad, but I replied on his behalf, And there is reward with Allah for this. You satirised Muhammad. virtuous, righteous, The Apostle of Allah, whose nature is truthfulness. So verily my father and his father and my honour Are a protection to the honour of Muhammad; May I lose my dear daughter, if you don't see her, Wiping away the dust from the two sides of Kada', They pull at the rein, going upward; On their shoulders are spears thirsting (for the blood of the enemy) ; our steeds are sweating-our women wipe them with their mantles. If you had not interfered with us, we would have performed the 'Umra, And (then) there was the Victory, and the darkness cleared away. Otherwise wait for the fighting on the day in which Allah will honour whom He pleases. And Allah said: I have sent a servant who says the Truth in which there is no ambiguity; And Allah said: I have prepared an army-they are the Ansar whose object is fighting (the enemy), There reaches every day from Ma'add abuse, or fighting or satire; Whoever satirises the Apostle from amongst you, or praises him and helps it is all the same, And Gabriel, the Messenger of Allah is among us, and the Holy Spirit who has no match}}
\hadithdefcmd{muslim}{6396}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْيَمَامِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ أَبِي كَثِيرٍ، يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ كُنْتُ أَدْعُو أُمِّي إِلَى الإِسْلاَمِ وَهِيَ مُشْرِكَةٌ فَدَعَوْتُهَا يَوْمًا فَأَسْمَعَتْنِي فِي رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أَكْرَهُ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أَدْعُو أُمِّي إِلَى الإِسْلاَمِ فَتَأْبَى عَلَىَّ فَدَعَوْتُهَا الْيَوْمَ فَأَسْمَعَتْنِي فِيكَ مَا أَكْرَهُ فَادْعُ اللَّهَ أَنْ يَهْدِيَ أُمَّ أَبِي هُرَيْرَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ اهْدِ أُمَّ أَبِي هُرَيْرَةَ ‏"‏ ‏.‏ فَخَرَجْتُ مُسْتَبْشِرًا بِدَعْوَةِ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَلَمَّا جِئْتُ فَصِرْتُ إِلَى الْبَابِ فَإِذَا هُوَ مُجَافٌ فَسَمِعَتْ أُمِّي خَشْفَ قَدَمَىَّ فَقَالَتْ مَكَانَكَ يَا أَبَا هُرَيْرَةَ ‏.‏ وَسَمِعْتُ خَضْخَضَةَ الْمَاءِ قَالَ - فَاغْتَسَلَتْ وَلَبِسَتْ دِرْعَهَا وَعَجِلَتْ عَنْ خِمَارِهَا فَفَتَحَتِ الْبَابَ ثُمَّ قَالَتْ يَا أَبَا هُرَيْرَةَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ - قَالَ - فَرَجَعْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ وَأَنَا أَبْكِي مِنَ الْفَرَحِ - قَالَ - قُلْتُ يَا رَسُولَ اللَّهِ أَبْشِرْ قَدِ اسْتَجَابَ اللَّهُ دَعْوَتَكَ وَهَدَى أُمَّ أَبِي هُرَيْرَةَ ‏.‏ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ خَيْرًا - قَالَ - قُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يُحَبِّبَنِي أَنَا وَأُمِّي إِلَى عِبَادِهِ الْمُؤْمِنِينَ وَيُحَبِّبَهُمْ إِلَيْنَا - قَالَ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ حَبِّبْ عُبَيْدَكَ هَذَا - يَعْنِي أَبَا هُرَيْرَةَ وَأُمَّهُ - إِلَى عِبَادِكَ الْمُؤْمِنِينَ وَحَبِّبْ إِلَيْهِمُ الْمُؤْمِنِينَ ‏"‏ ‏.‏ فَمَا خُلِقَ مُؤْمِنٌ يَسْمَعُ بِي وَلاَ يَرَانِي إِلاَّ أَحَبَّنِي ‏.‏\hadithno{6396}\hadithtrans{Abu Huraira reported:I invited my mother, who was a polytlieist, to Islam. I invited her one day and she said to me something about Allah's Messenger (ﷺ) which I hated. I came to Allah's Messenger (ﷺ) weeping and said: Allah's Messenger, I invited my mother to Islam but she did not accept (my invitation). I invited her today but she said to me something which I did not like. (Kindly) supplicate Allah that He may set the mother of Abu Huraira right. Thereupon Allah's Messenger (ﷺ) said: O Allah, set the mother of Abu Huraira on the right path. I came out quite pleased with the supplication of Allah's Apostle (ﷺ) and when I came near the door it was closed from within. My mother heard the noise of my footsteps and she said: Abu Huraira, just wait. And I heard the noise of falling of water. She took a bath and put on the shirt and quickly covered her head with a headdress and opened the door and then said: Abu Huraira, I bear witness to the fact that there is no god but Allah and Muhammad is His bondsman and His Messenger. He (Abu Huraira) said: I went back to Allah's Messenger (ﷺ) and (this time) I was shedding the tears of joy. I said: Allah's Messenger, be happy, for Allah has responded to your supplication and He has set on the right path the mother of Abu Huraira. He (the Holy Prophet) praised Allah, and extolled Him and uttered good words. I said: Allah's Messenger, supplicate to Allah so that He may instill love of mine and that of my mother too in the believing servants and let our hearts be filled with their love, whereupon Allah's Messenger (ﷺ) said: O Allah, let there be love of these servants of yours, i.e. Abu Huraira and his mother, in the hearts of the believing servants and let their hearts be filled with the love of the believing servants. (Abu Huraira said: This prayer) was so well granted by Allah that no believer was ever born who heard of me and who saw me but did not love me}}
\hadithdefcmd{muslim}{6397}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنْ سُفْيَانَ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ الأَعْرَجِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّكُمْ تَزْعُمُونَ أَنَّ أَبَا هُرَيْرَةَ، يُكْثِرُ الْحَدِيثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاللَّهُ الْمَوْعِدُ كُنْتُ رَجُلاً مِسْكِينًا أَخْدُمُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى مِلْءِ بَطْنِي وَكَانَ الْمُهَاجِرُونَ يَشْغَلُهُمُ الصَّفْقُ بِالأَسْوَاقِ وَكَانَتِ الأَنْصَارُ يَشْغَلُهُمُ الْقِيَامُ عَلَى أَمْوَالِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَبْسُطُ ثَوْبَهُ فَلَنْ يَنْسَى شَيْئًا سَمِعَهُ مِنِّي ‏"‏ ‏.‏ فَبَسَطْتُ ثَوْبِي حَتَّى قَضَى حَدِيثَهُ ثُمَّ ضَمَمْتُهُ إِلَىَّ فَمَا نَسِيتُ شَيْئًا سَمِعْتُهُ مِنْهُ ‏.‏\hadithno{6397}\hadithtrans{Al-A'raj reported that he heard Abu Huraira as saying:You are under the impression that Abu Huraira transmits so many ahadith from Allah's Messenger (may peace up upon him) ; (bear in mind) Allah is the great Reckoner. I was a poor man and I served Allah's Messenger (ﷺ) being satisfied with bare subsistence, whereas the immigrants remained busy with transactions in the bazar; while the Ansar had been engaged in looking after their properties. (He further reported) that Allah's Messenger (ﷺ) said: He who spreads the cloth would not forget anything that he would hear from me. I spread my cloth until he narrated something. I then pressed it against my (chest), so I never forgot anything that I heard from him}}
\hadithdefcmd{muslim}{6398}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ جَعْفَرِ بْنِ يَحْيَى بْنِ خَالِدٍ، أَخْبَرَنَا مَعْنٌ، أَخْبَرَنَا مَالِكٌ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، عَنِ الأَعْرَجِ، عَنْ أَبِي، هُرَيْرَةَ بِهَذَا الْحَدِيثِ غَيْرَ أَنَّ مَالِكًا، انْتَهَى حَدِيثُهُ عِنْدَ انْقِضَاءِ قَوْلِ أَبِي هُرَيْرَةَ وَلَمْ يَذْكُرْ فِي حَدِيثِهِ الرِّوَايَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ مَنْ يَبْسُطْ ثَوْبَهُ ‏"‏ ‏.‏ إِلَى آخِرِهِ ‏.‏\hadithno{6398}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira but with the variation that the hadith transmitted on the authority of Malik conclude with the words of Abu Huraira and there is no mention of a transmission of these from Allah's Apostle (ﷺ):" who spreads his cloth," to the end}}
\hadithdefcmd{muslim}{6399}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ عَائِشَةَ قَالَتْ أَلاَ يُعْجِبُكَ أَبُو هُرَيْرَةَ جَاءَ فَجَلَسَ إِلَى جَنْبِ حُجْرَتِي يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم يُسْمِعُنِي ذَلِكَ وَكُنْتُ أُسَبِّحُ فَقَامَ قَبْلَ أَنْ أَقْضِيَ سُبْحَتِي وَلَوْ أَدْرَكْتُهُ لَرَدَدْتُ عَلَيْهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَسْرُدُ الْحَدِيثَ كَسَرْدِكُمْ ‏.‏\hadithno{6399}\hadithtrans{A'isha reported:Don't you feel surprised at Abu Huraira? He came (one day) and sat beside the nook of my apartment and began to narrate (the hadith of Allah's Apostle). I was hearing while I was engaged in extolling Allah (reciting Subhan Allah) constantly. He stood up before I finished my repetition of Subhan Allah. if I were to meet him I would have warned him in stern words that Allah's Messenger (ﷺ) did not speak so quickly as you talk}}
\hadithdefcmd{muslim}{6400}{قَالَ ابْنُ شِهَابٍ وَقَالَ ابْنُ الْمُسَيَّبِ إِنَّ أَبَا هُرَيْرَةَ قَالَ يَقُولُونَ إِنَّ أَبَا هُرَيْرَةَ قَدْ أَكْثَرَ وَاللَّهُ الْمَوْعِدُ وَيَقُولُونَ مَا بَالُ الْمُهَاجِرِينَ وَالأَنْصَارِ لاَ يَتَحَدَّثُونَ مِثْلَ أَحَادِيثِهِ وَسَأُخْبِرُكُمْ عَنْ ذَلِكَ إِنَّ إِخْوَانِي مِنَ الأَنْصَارِ كَانَ يَشْغَلُهُمْ عَمَلُ أَرَضِيهِمْ وَإِنَّ إِخْوَانِي مِنَ الْمُهَاجِرِينَ كَانَ يَشْغَلُهُمُ الصَّفْقُ بِالأَسْوَاقِ وَكُنْتُ أَلْزَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى مِلْءِ بَطْنِي فَأَشْهَدُ إِذَا غَابُوا وَأَحْفَظُ إِذَا نَسُوا وَلَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا ‏"‏ أَيُّكُمْ يَبْسُطُ ثَوْبَهُ فَيَأْخُذُ مِنْ حَدِيثِي هَذَا ثُمَّ يَجْمَعُهُ إِلَى صَدْرِهِ فَإِنَّهُ لَمْ يَنْسَ شَيْئًا سَمِعَهُ ‏"‏ ‏.‏ فَبَسَطْتُ بُرْدَةً عَلَىَّ حَتَّى فَرَغَ مِنْ حَدِيثِهِ ثُمَّ جَمَعْتُهَا إِلَى صَدْرِي فَمَا نَسِيتُ بَعْدَ ذَلِكَ الْيَوْمِ شَيْئًا حَدَّثَنِي بِهِ وَلَوْلاَ آيَتَانِ أَنْزَلَهُمَا اللَّهُ فِي كِتَابِهِ مَا حَدَّثْتُ شَيْئًا أَبَدًا ‏\{‏ إِنَّ الَّذِينَ يَكْتُمُونَ مَا أَنْزَلْنَا مِنَ الْبَيِّنَاتِ وَالْهُدَى‏\}‏ إِلَى آخِرِ الآيَتَيْنِ ‏.‏\hadithno{6400}\hadithtrans{Ibn Shihab transmitted on the authority of Ibn Musayyib that Abu Huraira said:People say that Abu Huraira transmits so many ahadith, whereas Allah is the Reckoner, and they say: How is it with Muhajirs and the Ansar that they do not narrate ahadith like him (like Abu Huraira)? Abu Huraira said: I tell you that my brothers from Ansar remained busy with their lands and my brothers Muhajirs were busy in transactions in the bazars, but I always kept myself attached to Allah's Messenger (ﷺ) with bare subsistence. I remained present (in the company of the Holy Prophet), whereas they had been absent. I retained in my mind (what the Prophet said), whereas they forgot it. One day Allah's Messenger (ﷺ) said: He who amongst you spreads the cloth and listens to my talk and would then press it against his chest would never forget anything heard from me. So I spread my mantle and when he had concluded his talk I then pressed it against my chest and so I never forgot after that day anything that he (the Holy Prophet) said. And if these two verses would not have been revealed in the Book I would have never transmitted anything (to anybody):" Those who conceal the clear evidence and the guidance that We revealed" (ii. 159) tip to the last verse}}
\hadithdefcmd{muslim}{6401}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ - وَاللَّفْظُ لِعَمْرٍو - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ عَنْ عَمْرٍو، عَنِ الْحَسَنِ بْنِ مُحَمَّدٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي رَافِعٍ، - وَهُوَ كَاتِبُ عَلِيٍّ قَالَ سَمِعْتُ عَلِيًّا، رضى الله عنه وَهُوَ يَقُولُ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَا وَالزُّبَيْرَ وَالْمِقْدَادَ فَقَالَ ‏"‏ ائْتُوا رَوْضَةَ خَاخٍ فَإِنَّ بِهَا ظَعِينَةً مَعَهَا كِتَابٌ فَخُذُوهُ مِنْهَا ‏"‏ ‏.‏ فَانْطَلَقْنَا تَعَادَى بِنَا خَيْلُنَا فَإِذَا نَحْنُ بِالْمَرْأَةِ فَقُلْنَا أَخْرِجِي الْكِتَابَ ‏.‏ فَقَالَتْ مَا مَعِي كِتَابٌ ‏.‏ فَقُلْنَا لَتُخْرِجِنَّ الْكِتَابَ أَوْ لَتُلْقِيَنَّ الثِّيَابَ ‏.‏ فَأَخْرَجَتْهُ مِنْ عِقَاصِهَا فَأَتَيْنَا بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَإِذَا فِيهِ مِنْ حَاطِبِ بْنِ أَبِي بَلْتَعَةَ إِلَى نَاسٍ مِنَ الْمُشْرِكِينَ مِنْ أَهْلِ مَكَّةَ يُخْبِرُهُمْ بِبَعْضِ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا حَاطِبُ مَا هَذَا ‏"‏ ‏.‏ قَالَ لاَ تَعْجَلْ عَلَىَّ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ امْرَأً مُلْصَقًا فِي قُرَيْشٍ - قَالَ سُفْيَانُ كَانَ حَلِيفًا لَهُمْ وَلَمْ يَكُنْ مِنْ أَنْفُسِهَا - وَكَانَ مِمَّنْ كَانَ مَعَكَ مِنَ الْمُهَاجِرِينَ لَهُمْ قَرَابَاتٌ يَحْمُونَ بِهَا أَهْلِيهِمْ فَأَحْبَبْتُ إِذْ فَاتَنِي ذَلِكَ مِنَ النَّسَبِ فِيهِمْ أَنْ أَتَّخِذَ فِيهِمْ يَدًا يَحْمُونَ بِهَا قَرَابَتِي وَلَمْ أَفْعَلْهُ كُفْرًا وَلاَ ارْتِدَادًا عَنْ دِينِي وَلاَ رِضًا بِالْكُفْرِ بَعْدَ الإِسْلاَمِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَدَقَ ‏"‏ ‏.‏ فَقَالَ عُمَرُ دَعْنِي يَا رَسُولَ اللَّهِ أَضْرِبْ عُنُقَ هَذَا الْمُنَافِقِ ‏.‏ فَقَالَ ‏"‏ إِنَّهُ قَدْ شَهِدَ بَدْرًا وَمَا يُدْرِيكَ لَعَلَّ اللَّهَ اطَّلَعَ عَلَى أَهْلِ بَدْرٍ فَقَالَ اعْمَلُوا مَا شِئْتُمْ فَقَدْ غَفَرْتُ لَكُمْ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَتَّخِذُوا عَدُوِّي وَعَدُوَّكُمْ أَوْلِيَاءَ‏\}‏ وَلَيْسَ فِي حَدِيثِ أَبِي بَكْرٍ وَزُهَيْرٍ ذِكْرُ الآيَةِ وَجَعَلَهَا إِسْحَاقُ فِي رِوَايَتِهِ مِنْ تِلاَوَةِ سُفْيَانَ ‏.‏\hadithno{6401}\hadithtrans{Ubaidullah b. Rafi', who was the scribe of 'All, reported:I heard 'Ali (Allah be pleased with him) as saying: Allah's Messenger (ﷺ) sent me and Zubair and Miqdad saying: Go to the garden of, Khakh [it is a place between Medina and Mecca at a distance of twelve miles from Medina] and there you will find a woman riding a camel. She would be in possession of a letter, which you must get from her. So we rushed on horses and when we met that woman, we asked her to deliver that letter to us. She said: There is no letter with me. We said: Either bring out that letter or we would take off your clothes. She brought out that letter from (the plaited hair of) her head. We delivered that letter to Allah's Messenger (ﷺ) in which Hatib b. Abu Balta'a had informed some people amongst the polytheists of Mecca about the affairs of Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) said: Hatib, what is this? He said: Allah's messenger, do not be hasty in judging my intention. I was a person attached to the Quraish. Sufyan said: He was their ally but had no relationship with them. (Hatib further said): Those who are with you amongst the emigrants have blood-relationship with them (the Quraish) and thus they would protect their families. I wished that when I had no blood-relationship with them I should find some supporters from (amongst them) who would help my family. I have not done this because of any unbelief or apostasy and I have no liking for the unbelief after I have (accepted) Islam. Thereupon Allah's Apostle (ﷺ) said: You have told the truth. 'Umar said: Allah's Messenger, permit me to strike the neck of this hypocrite. But he (the Holy Prophet) said: He was a participant in Badr and you little know that Allah revealed about the people of Badr: Do what you like for there is forgiveness for you. And Allah, the Exalted and Glorious, said:" O you who believe, do not take My enemy and your enemy for friends" (lx. 1). And there is no mention of this verse in the hadith transmitted on the authority of Abu Bakr and Zubair and Ishaq has in his narration made a mention of the recitation of this verse by Sufyan}}
\hadithdefcmd{muslim}{6402}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، ح وَحَدَّثَنَا رِفَاعَةُ بْنُ الْهَيْثَمِ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ - كُلُّهُمْ عَنْ حُصَيْنٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبَا مَرْثَدٍ الْغَنَوِيَّ وَالزُّبَيْرَ بْنَ الْعَوَّامِ وَكُلُّنَا فَارِسٌ فَقَالَ ‏ "‏ انْطَلِقُوا حَتَّى تَأْتُوا رَوْضَةَ خَاخٍ فَإِنَّ بِهَا امْرَأَةً مِنَ الْمُشْرِكِينَ مَعَهَا كِتَابٌ مِنْ حَاطِبٍ إِلَى الْمُشْرِكِينَ ‏"‏ ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ عَنْ عَلِيٍّ ‏.‏\hadithno{6402}\hadithtrans{Ali reported that Allah's Messenger (ﷺ) sent me and Abu Marthad al-Ghitnavi and Zubair b. 'Awwam and we were all riders, and he said:Ride on until you reach the garden of Khakh for there is a woman amongst the polytheists and there is a letter with her sent by Hatib to the polytheists; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6403}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ عَبْدًا، لِحَاطِبٍ جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَشْكُو حَاطِبًا فَقَالَ يَا رَسُولَ اللَّهِ لَيَدْخُلَنَّ حَاطِبٌ النَّارَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَذَبْتَ لاَ يَدْخُلُهَا فَإِنَّهُ شَهِدَ بَدْرًا وَالْحُدَيْبِيَةَ ‏"‏ ‏.‏\hadithno{6403}\hadithtrans{Jabir reported that a slave of Hatib came to Allah's Messenger (ﷺ) complaining against Hatib and said:Hatib will definitely go to Hell. (But) Allah's Messenger (ﷺ) said: You tell a lie; he would not get into that for he had taken part in Badr and in (the expedition of) Hudaibiya}}
\hadithdefcmd{muslim}{6404}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَخْبَرَتْنِي أُمُّ مُبَشِّرٍ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقُولُ عِنْدَ حَفْصَةَ ‏"‏ لاَ يَدْخُلُ النَّارَ إِنْ شَاءَ اللَّهُ مِنْ أَصْحَابِ الشَّجَرَةِ أَحَدٌ ‏.‏ الَّذِينَ بَايَعُوا تَحْتَهَا ‏"‏ ‏.‏ قَالَتْ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ فَانْتَهَرَهَا فَقَالَتْ حَفْصَةُ ‏\{‏ وَإِنْ مِنْكُمْ إِلاَّ وَارِدُهَا‏\}‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدْ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ ثُمَّ نُنَجِّي الَّذِينَ اتَّقَوْا وَنَذَرُ الظَّالِمِينَ فِيهَا جِثِيًّا‏\}‏\hadithno{6404}\hadithtrans{Umm Mubashshir reported that she heard Allah's Apostle (ﷺ) as saying in presence of Hafsa:God willing, the people of the Tree would never enter the fire of Hell one amongst those who owed allegiance under that. She said: Allah's Messenger, why not? He scolded her. Hafsa said: And there is none amongst you but shall have to pass over that (narrow Bridge). Thereupon Allah's Apostle (ﷺ) said: Allah, the Exalted and Glorious, has said: We would rescue those persons who are God-conscious and we would leave the tyrants to their fate there (xix)}}
\hadithdefcmd{muslim}{6405}{حَدَّثَنَا أَبُو عَامِرٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي أُسَامَةَ، قَالَ أَبُو عَامِرٍ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدٌ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم وَهُوَ نَازِلٌ بِالْجِعْرَانَةِ بَيْنَ مَكَّةَ وَالْمَدِينَةِ وَمَعَهُ بِلاَلٌ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلٌ أَعْرَابِيٌّ فَقَالَ أَلاَ تُنْجِزُ لِي يَا مُحَمَّدُ مَا وَعَدْتَنِي فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبْشِرْ ‏"‏ ‏.‏ فَقَالَ لَهُ الأَعْرَابِيُّ أَكْثَرْتَ عَلَىَّ مِنْ ‏"‏ أَبْشِرْ ‏"‏ ‏.‏ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَبِي مُوسَى وَبِلاَلٍ كَهَيْئَةِ الْغَضْبَانِ فَقَالَ ‏"‏ إِنَّ هَذَا قَدْ رَدَّ الْبُشْرَى فَاقْبَلاَ أَنْتُمَا ‏"‏ ‏.‏ فَقَالاَ قَبِلْنَا يَا رَسُولَ اللَّهِ ‏.‏ ثُمَّ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَدَحٍ فِيهِ مَاءٌ فَغَسَلَ يَدَيْهِ وَوَجْهَهُ فِيهِ وَمَجَّ فِيهِ ثُمَّ قَالَ ‏"‏ اشْرَبَا مِنْهُ وَأَفْرِغَا عَلَى وُجُوهِكُمَا وَنُحُورِكُمَا وَأَبْشِرَا ‏"‏ ‏.‏ فَأَخَذَا الْقَدَحَ فَفَعَلاَ مَا أَمَرَهُمَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَادَتْهُمَا أُمُّ سَلَمَةَ مِنْ وَرَاءِ السِّتْرِ أَفْضِلاَ لأُمِّكُمَا مِمَّا فِي إِنَائِكُمَا ‏.‏ فَأَفْضَلاَ لَهَا مِنْهُ طَائِفَةً ‏.‏\hadithno{6405}\hadithtrans{Abu Musa reported:I was in the company of Allah's Apostle (ﷺ) as he had been sitting in Ji'rana (a place) between Mecca and Medina and Bilal was also there, that there came to Allah's Apostle (ﷺ) a desert Arab, and he said: Muhammad, fulfill your promise that you made with me. Allah's Messenger (ﷺ) said to him: Accept glad tidings. Thereupon the desert Arab said: You shower glad tidings upon me very much; then Allah's Messenger (ﷺ) turned towards Abu Musa and Bilal seemingly in a state of annoyance and said: Verily he has rejected glad tidings but you two should accept them. We said: Allah's Messenger, we have readily accepted them. Then Allah's Messenger (ﷺ) called for a cup of water and washed his hands in that and face too and put the saliva in it and then said: Drink out of it and pour it over your faces and over your chest and gladden yourselves. They took hold of the cup and did as Allah's Messenger (ﷺ) had commanded them to do. Thereupon Umm Salama called from behind the veil: Spare some water in your vessel for your mother also, and they also gave some water which had been spared for her}}
\hadithdefcmd{muslim}{6406}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ أَبُو عَامِرٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ مُحَمَّدُ بْنُ الْعَلاَءِ - وَاللَّفْظُ لأَبِي عَامِرٍ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ لَمَّا فَرَغَ النَّبِيُّ صلى الله عليه وسلم مِنْ حُنَيْنٍ بَعَثَ أَبَا عَامِرٍ عَلَى جَيْشٍ إِلَى أَوْطَاسٍ فَلَقِيَ دُرَيْدَ بْنَ الصِّمَّةِ فَقُتِلَ دُرَيْدٌ وَهَزَمَ اللَّهُ أَصْحَابَهُ فَقَالَ أَبُو مُوسَى وَبَعَثَنِي مَعَ أَبِي عَامِرٍ - قَالَ - فَرُمِيَ أَبُو عَامِرٍ فِي رُكْبَتِهِ رَمَاهُ رَجُلٌ مِنْ بَنِي جُشَمٍ بِسَهْمٍ فَأَثْبَتَهُ فِي رُكْبَتِهِ فَانْتَهَيْتُ إِلَيْهِ فَقُلْتُ يَا عَمِّ مَنْ رَمَاكَ فَأَشَارَ أَبُو عَامِرٍ إِلَى أَبِي مُوسَى فَقَالَ إِنَّ ذَاكَ قَاتِلِي تَرَاهُ ذَلِكَ الَّذِي رَمَانِي ‏.‏ قَالَ أَبُو مُوسَى فَقَصَدْتُ لَهُ فَاعْتَمَدْتُهُ فَلَحِقْتُهُ فَلَمَّا رَآنِي وَلَّى عَنِّي ذَاهِبًا فَاتَّبَعْتُهُ وَجَعَلْتُ أَقُولُ لَهُ أَلاَ تَسْتَحْيِي أَلَسْتَ عَرَبِيًّا أَلاَ تَثْبُتُ فَكَفَّ فَالْتَقَيْتُ أَنَا وَهُوَ فَاخْتَلَفْنَا أَنَا وَهُوَ ضَرْبَتَيْنِ فَضَرَبْتُهُ بِالسَّيْفِ فَقَتَلْتُهُ ثُمَّ رَجَعْتُ إِلَى أَبِي عَامِرٍ فَقُلْتُ إِنَّ اللَّهَ قَدْ قَتَلَ صَاحِبَكَ ‏.‏ قَالَ فَانْزِعْ هَذَا السَّهْمَ فَنَزَعْتُهُ فَنَزَا مِنْهُ الْمَاءُ فَقَالَ يَا ابْنَ أَخِي انْطَلِقْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَقْرِئْهُ مِنِّي السَّلاَمَ وَقُلْ لَهُ يَقُولُ لَكَ أَبُو عَامِرٍ اسْتَغْفِرْ لِي ‏.‏ قَالَ وَاسْتَعْمَلَنِي أَبُو عَامِرٍ عَلَى النَّاسِ وَمَكَثَ يَسِيرًا ثُمَّ إِنَّهُ مَاتَ فَلَمَّا رَجَعْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم دَخَلْتُ عَلَيْهِ وَهُوَ فِي بَيْتٍ عَلَى سَرِيرٍ مُرْمَلٍ وَعَلَيْهِ فِرَاشٌ وَقَدْ أَثَّرَ رِمَالُ السَّرِيرِ بِظَهْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَجَنْبَيْهِ فَأَخْبَرْتُهُ بِخَبَرِنَا وَخَبَرِ أَبِي عَامِرٍ وَقُلْتُ لَهُ قَالَ قُلْ لَهُ يَسْتَغْفِرْ لِي ‏.‏ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَاءٍ فَتَوَضَّأَ مِنْهُ ثُمَّ رَفَعَ يَدَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِعُبَيْدٍ أَبِي عَامِرٍ ‏"‏ ‏.‏ حَتَّى رَأَيْتُ بَيَاضَ إِبْطَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ اجْعَلْهُ يَوْمَ الْقِيَامَةِ فَوْقَ كَثِيرٍ مِنْ خَلْقِكَ أَوْ مِنَ النَّاسِ ‏"‏ ‏.‏ فَقُلْتُ وَلِي يَا رَسُولَ اللَّهِ فَاسْتَغْفِرْ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ اغْفِرْ لِعَبْدِ اللَّهِ بْنِ قَيْسٍ ذَنْبَهُ وَأَدْخِلْهُ يَوْمَ الْقِيَامَةِ مُدْخَلاً كَرِيمًا ‏"‏ ‏.‏ قَالَ أَبُو بُرْدَةَ إِحْدَاهُمَا لأَبِي عَامِرٍ وَالأُخْرَى لأَبِي مُوسَى ‏.‏\hadithno{6406}\hadithtrans{Abu Burda reported on the authority of his father that when Allah's Apostle (ﷺ) had been free from the Battle of Hunain, he sent Abu 'Amir as the head of the army of Autas. He had an encounter with Duraid b. as\_Simma. Duraid was killed and Allah gave defeat to his friends. Abu Musa said:He (the Holy Prophet) sent me along with Abu 'Amir and Abu 'Amir received a wound in his knee from the arrow, (shot by) a person of Bani Jusham. It stuck in his knee. I went to him and said: Uncle, who shot an arrow upon you? Abu 'Amir pointed out to Abu Musa and said: Verily that one who shot an arrow upon me in fact killed me. Abu Musa said: I followed him with the determination to kill him and overtook him and when he saw me he turned upon his heels. I followed him and I said to him: Don't you feel ashamed (that you run), aren't you an Arab? Why don't you stop? He stopped and I had an encounter with him and we exchanged the strokes of (swords). I struck him with the sword and killed him. Then I came back to Abu Amir and said: Verily Allah has killed the one who killed you. And he said: Now draw out this arrow. I drew out the arrow and there came out from that (wound) water. Abu 'Amir said: My nephew, go to Allah's Messenger (ﷺ) and convey my greetings to him and tell him that Abu Amir begs you to ask forgiveness for him. And Abu Amir appointed me as the chief of the people and he died after a short time. When I came to Allah's Apostle (ﷺ) I visited him and he had been lying on the cot woven by strings and there was (no) bed over it and so there had been marks of the strings on the back of Allah's Messenger (ﷺ) and on his sides. I narrated to him what had happened to us and narrated to him about Abu Amir and said to him that he had made a request to the effect that forgiveness should be sought for him (from Allah). Thereupon Allah's Messenger (may peace be. upon him) called for water and performed ablution with it. He then lifted his hands and said. O Allah, grant pardon to Thy servant Abu Amir. (The Prophet had raised his hands so high for supplication) that I saw the whiteness of his armpits. He again said: O Allah, grant him distinction amongst the majority of Thine created beings or from amongst the people. I said: Allah's Messenger, ask forgiveness for me too. Thereupon Allah's Apostle (ﷺ) said: Allah, forgive the sins of Abdullah b. Qais (Abu Musa Ash'ari) and admit him to an elevated place on the Day of Resurrection. Abu Burda said: One prayer is for abu 'Amir and the other is tor Abu Musa}}
\hadithdefcmd{muslim}{6407}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدٌ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْرِفُ أَصْوَاتَ رُفْقَةِ الأَشْعَرِيِّينَ بِالْقُرْآنِ حِينَ يَدْخُلُونَ بِاللَّيْلِ وَأَعْرِفُ مَنَازِلَهُمْ مِنْ أَصْوَاتِهِمْ بِالْقُرْآنِ بِاللَّيْلِ وَإِنْ كُنْتُ لَمْ أَرَ مَنَازِلَهُمْ حِينَ نَزَلُوا بِالنَّهَارِ وَمِنْهُمْ حَكِيمٌ إِذَا لَقِيَ الْخَيْلَ - أَوْ قَالَ الْعَدُوَّ - قَالَ لَهُمْ إِنَّ أَصْحَابِي يَأْمُرُونَكُمْ أَنْ تَنْظُرُوهُمْ ‏"‏ ‏.‏\hadithno{6407}\hadithtrans{Abu Musa reported that Allah's Messenger (ﷺ) said:I recognise the voice of the Ash'arites while they recite the Qur'an as they arrive during the night and I also recognise their station from the recital of the Qur'an during the night time, although I have not seen their encampments as they encamp during the day time. And there is a person amongst them, Hakim; when he encounters the horsemen or the enemies he says to them: My friends command you to wait for them}}
\hadithdefcmd{muslim}{6408}{حَدَّثَنَا أَبُو عَامِرٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي أُسَامَةَ، قَالَ أَبُو عَامِرٍ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي بُرَيْدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الأَشْعَرِيِّينَ إِذَا أَرْمَلُوا فِي الْغَزْوِ أَوْ قَلَّ طَعَامُ عِيَالِهِمْ بِالْمَدِينَةِ جَمَعُوا مَا كَانَ عِنْدَهُمْ فِي ثَوْبٍ وَاحِدٍ ثُمَّ اقْتَسَمُوهُ بَيْنَهُمْ فِي إِنَاءٍ وَاحِدٍ بِالسَّوِيَّةِ فَهُمْ مِنِّي وَأَنَا مِنْهُمْ ‏"‏ ‏.‏\hadithno{6408}\hadithtrans{Abu Musa reported that Allah's Messenger (ﷺ) said:When the Ash'arites run short of provisions in the campaigns or run short of food for their children in Medina they collect whatever is with them in the cloth and then partake equally from one vessel. They are from me and I am from them}}
\hadithdefcmd{muslim}{6409}{حَدَّثَنِي عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، وَأَحْمَدُ بْنُ جَعْفَرٍ الْمَعْقِرِيُّ، قَالاَ حَدَّثَنَا النَّضْرُ، - وَهُوَ ابْنُ مُحَمَّدٍ الْيَمَامِيُّ - حَدَّثَنَا عِكْرِمَةُ، حَدَّثَنَا أَبُو زُمَيْلٍ، حَدَّثَنِي ابْنُ عَبَّاسٍ، قَالَ كَانَ الْمُسْلِمُونَ لاَ يَنْظُرُونَ إِلَى أَبِي سُفْيَانَ وَلاَ يُقَاعِدُونَهُ فَقَالَ لِلنَّبِيِّ صلى الله عليه وسلم يَا نَبِيَّ اللَّهِ ثَلاَثٌ أَعْطِنِيهِنَّ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ عِنْدِي أَحْسَنُ الْعَرَبِ وَأَجْمَلُهُ أُمُّ حَبِيبَةَ بِنْتُ أَبِي سُفْيَانَ أُزَوِّجُكَهَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَمُعَاوِيَةُ تَجْعَلُهُ كَاتِبًا بَيْنَ يَدَيْكَ ‏.‏ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَتُؤَمِّرُنِي حَتَّى أُقَاتِلَ الْكُفَّارَ كَمَا كُنْتُ أُقَاتِلُ الْمُسْلِمِينَ ‏.‏ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ أَبُو زُمَيْلٍ وَلَوْلاَ أَنَّهُ طَلَبَ ذَلِكَ مِنَ النَّبِيِّ صلى الله عليه وسلم مَا أَعْطَاهُ ذَلِكَ لأَنَّهُ لَمْ يَكُنْ يُسْئَلُ شَيْئًا إِلاَّ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏\hadithno{6409}\hadithtrans{Ibn Abbas reported that the Muslims neither looked to Abu Sufyan (with respect) nor did they sit in his company. he (Abu Sufyan) said to Allah's Apostle (ﷺ):Allah's Apostle, confer upon me three things. He replied in the affirmative. He (further) said: I have with me the most handsome and the best (woman) Umm Habiba, daughter of Abu Sufyan; marry her, whereupon he said: Yes. And he again said: Accept Mu'awiya to serve as your scribe. He said: Yes. He again said: Make me the commander (of the Muslim army) so that I should fight against the unbelievers as I fought against the Muslims. He said: Yes. Abu Zumnail said: If he had not asked for these three things from Allah's Apostle (ﷺ), he would have never conferred them upon him, for it was (his habit) to accede to everybody's (earnest) request}}
\hadithdefcmd{muslim}{6411}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ حَدَّثَنِي بُرَيْدٌ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ بَلَغَنَا مَخْرَجُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ بِالْيَمَنِ فَخَرَجْنَا مُهَاجِرِينَ إِلَيْهِ أَنَا وَأَخَوَانِ لِي أَنَا أَصْغَرُهُمَا أَحَدُهُمَا أَبُو بُرْدَةَ وَالآخَرُ أَبُو رُهْمٍ - إِمَّا قَالَ بِضْعًا وَإِمَّا قَالَ ثَلاَثَةً وَخَمْسِينَ أَوِ اثْنَيْنِ وَخَمْسِينَ رَجُلاً مِنْ قَوْمِي - قَالَ فَرَكِبْنَا سَفِينَةً فَأَلْقَتْنَا سَفِينَتُنَا إِلَى النَّجَاشِيِّ بِالْحَبَشَةِ فَوَافَقْنَا جَعْفَرَ بْنَ أَبِي طَالِبٍ وَأَصْحَابَهُ عِنْدَهُ فَقَالَ جَعْفَرٌ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَنَا هَا هُنَا وَأَمَرَنَا بِالإِقَامَةِ فَأَقِيمُوا مَعَنَا ‏.‏ فَأَقَمْنَا مَعَهُ حَتَّى قَدِمْنَا جَمِيعًا - قَالَ - فَوَافَقْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ افْتَتَحَ خَيْبَرَ فَأَسْهَمَ لَنَا - أَوْ قَالَ أَعْطَانَا مِنْهَا - وَمَا قَسَمَ لأَحَدٍ غَابَ عَنْ فَتْحِ خَيْبَرَ مِنْهَا شَيْئًا إِلاَّ لِمَنْ شَهِدَ مَعَهُ إِلاَّ لأَصْحَابِ سَفِينَتِنَا مَعَ جَعْفَرٍ وَأَصْحَابِهِ قَسَمَ لَهُمْ مَعَهُمْ - قَالَ - فَكَانَ نَاسٌ مِنَ النَّاسِ يَقُولُونَ لَنَا - يَعْنِي لأَهْلِ السَّفِينَةِ - نَحْنُ سَبَقْنَاكُمْ بِالْهِجْرَةِ ‏.‏ قَالَ فَدَخَلَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ - وَهِيَ مِمَّنْ قَدِمَ مَعَنَا - عَلَى حَفْصَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم زَائِرَةً وَقَدْ كَانَتْ هَاجَرَتْ إِلَى النَّجَاشِيِّ فِيمَنْ هَاجَرَ إِلَيْهِ فَدَخَلَ عُمَرُ عَلَى حَفْصَةَ وَأَسْمَاءُ عِنْدَهَا فَقَالَ عُمَرُ حِينَ رَأَى أَسْمَاءَ مَنْ هَذِهِ قَالَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ ‏.‏ قَالَ عُمَرُ الْحَبَشِيَّةُ هَذِهِ الْبَحْرِيَّةُ هَذِهِ فَقَالَتْ أَسْمَاءُ نَعَمْ ‏.‏ فَقَالَ عُمَرُ سَبَقْنَاكُمْ بِالْهِجْرَةِ فَنَحْنُ أَحَقُّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْكُمْ ‏.‏ فَغَضِبَتْ وَقَالَتْ كَلِمَةً كَذَبْتَ يَا عُمَرُ كَلاَّ وَاللَّهِ كُنْتُمْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يُطْعِمُ جَائِعَكُمْ وَيَعِظُ جَاهِلَكُمْ وَكُنَّا فِي دَارِ أَوْ فِي أَرْضِ الْبُعَدَاءِ الْبُغَضَاءِ فِي الْحَبَشَةِ وَذَلِكَ فِي اللَّهِ وَفِي رَسُولِهِ وَايْمُ اللَّهِ لاَ أَطْعَمُ طَعَامًا وَلاَ أَشْرَبُ شَرَابًا حَتَّى أَذْكُرَ مَا قُلْتَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ كُنَّا نُؤْذَى وَنُخَافُ وَسَأَذْكُرُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَأَسْأَلُهُ وَوَاللَّهِ لاَ أَكْذِبُ وَلاَ أَزِيغُ وَلاَ أَزِيدُ عَلَى ذَلِكَ ‏.‏ قَالَ فَلَمَّا جَاءَ النَّبِيُّ صلى الله عليه وسلم قَالَتْ يَا نَبِيَّ اللَّهِ إِنَّ عُمَرَ قَالَ كَذَا وَكَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ بِأَحَقَّ بِي مِنْكُمْ وَلَهُ وَلأَصْحَابِهِ هِجْرَةٌ وَاحِدَةٌ وَلَكُمْ أَنْتُمْ أَهْلَ السَّفِينَةِ هِجْرَتَانِ ‏"‏ ‏.‏ قَالَتْ فَلَقَدْ رَأَيْتُ أَبَا مُوسَى وَأَصْحَابَ السَّفِينَةِ يَأْتُونِي أَرْسَالاً يَسْأَلُونِي عَنْ هَذَا الْحَدِيثِ مَا مِنَ الدُّنْيَا شَىْءٌ هُمْ بِهِ أَفْرَحُ وَلاَ أَعْظَمُ فِي أَنْفُسِهِمْ مِمَّا قَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو بُرْدَةَ فَقَالَتْ أَسْمَاءُ فَلَقَدْ رَأَيْتُ أَبَا مُوسَى وَإِنَّهُ لَيَسْتَعِيدُ هَذَا الْحَدِيثَ مِنِّي ‏.‏\hadithno{6411}\hadithtrans{Abu Musa reported:We were in Yemen when we heard of the migration of Allah's Messenger (ﷺ). We also set out as immigrants to him. And I was accompanied by two brothers of mine, I being the youngest of them; one of them was Abu Burda and the other one was Abu Ruhm, and there were some other persons with them. Some say they were fifty-three or fifty-two persons of my tribe. We embarked upon a boat, and the boat sailed away to the Negus of Abyssinia. There we met Ja'far b. Abu Talib and his companions. Ja'far said: Allall's Messenger (ﷺ) has sent us here and has commanded us to stay here and you should also stay with us. So we stayed with him and we came back (to Medina) and met Allah's Messenger (ﷺ) when Khaibar had been conquered. He (the Holy Prophet) allocated a share to us and in the ordinary course he did not allocate the share to one who had been absent on the occasion of the conquest of Khaibar but conferred (a share) upon him only who had been present there with him. He, however, made an exception for the people of the boat, viz. for Ja'far and his companions. He allocated a share to them, and some persons from amongst the people said to us, viz. the people of the boat: We have preceded you in migration. Asma' bint 'Umais who had migrated to Abyssinia and had come back along with them (along with immigrants) visited Hafsa, the wife of Allah's Apostle (ﷺ). (Accordingly), Umar had been sitting with her (Hafsa). As 'Umar saw Asma, he said: Who is she? She (Hafsa) said: She is Asma, daughter of 'Umais. He said: She is an Abyssinian and a sea-woman. Asma said: Yes, it is so. Thereupon 'Umar said: We preceded you in migration and so we have more right to Allah's Messenger (ﷺ) as compared with you. At this she felt annoyed and said: 'Umar, you are not stating the fact; by Allah, you had the privilege of being in the company of the Messenger (ﷺ) who fed the hungry among you and instructed the ignorant amongst you, whereas we had been far (from here) in the land of Abyssinia amongst the enemies and that was all for Allah and Allah's Messenger (ﷺ) and, by Allah, I would never take food nor take water unless I make a mention to Allah's Messenger (ﷺ) of what you have said. We remained in that country in constant trouble and dread and I shall talk about it to Allah's Messenger (way peace be upon him) and ask him (about it). By Allah, I shall not tell a lie and deviate (from the truth) and add anything to that. So, when Allah's Apostle (ﷺ) came, she said: Allah's Apostle, 'Umar says so and so. Upon this Allah's Messenger (ﷺ) said: His right is not more than yours, for him and his companions there is one migration, but for you, i. e. for the people of the boat, there are two migrations. She said: I saw Abu Musa and the people of the boat coming to me in groups and asking me about this hadith, because there was nothing more pleasing and more significant for them than this. Abu Burda reported that Asma said: I saw Abu Musa, asking me to repeat this hadith to him again and again}}
\hadithdefcmd{muslim}{6412}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ مُعَاوِيَةَ، بْنِ قُرَّةَ عَنْ عَائِذِ بْنِ عَمْرٍو، أَنَّ أَبَا سُفْيَانَ، أَتَى عَلَى سَلْمَانَ وَصُهَيْبٍ وَبِلاَلٍ فِي نَفَرٍ فَقَالُوا وَاللَّهِ مَا أَخَذَتْ سُيُوفُ اللَّهِ مِنْ عُنُقِ عَدُوِّ اللَّهِ مَأْخَذَهَا ‏.‏ قَالَ فَقَالَ أَبُو بَكْرٍ أَتَقُولُونَ هَذَا لِشَيْخِ قُرَيْشٍ وَسَيِّدِهِمْ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ ‏ "‏ يَا أَبَا بَكْرٍ لَعَلَّكَ أَغْضَبْتَهُمْ لَئِنْ كُنْتَ أَغْضَبْتَهُمْ لَقَدْ أَغْضَبْتَ رَبَّكَ ‏"‏ ‏.‏ فَأَتَاهُمْ أَبُو بَكْرٍ فَقَالَ يَا إِخْوَتَاهْ أَغْضَبْتُكُمْ قَالُوا لاَ يَغْفِرُ اللَّهُ لَكَ يَا أُخَىَّ ‏.‏\hadithno{6412}\hadithtrans{A'idh b. Amr reported that Abu Sufyan came to Salman, Suhaib and Bilal in the presence of a group of persons. They said:By Allah, the sword of Allah did not reach the neck of the enemy of Allah as it was required to reach. Thereupon Abu Bakr said: Do you say this to the old man of the Quraish and their chief? Then he came to Allah's Apostle (may peace be upon'him) and informed him of this. Thereupon he (the Holy Prophet) said: Abu Bakr, you have perhaps annoyed them and if you annoyed them you have in fact annoyed your Lord. So Abu Bakr came to them and said: O my brothers, I have annoyed you. They said: No, our brother, may Allah forgive you}}
\hadithdefcmd{muslim}{6413}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَأَحْمَدُ بْنُ عَبْدَةَ، - وَاللَّفْظُ لإِسْحَاقَ - قَالاَ أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ فِينَا نَزَلَتْ ‏\{‏ إِذْ هَمَّتْ طَائِفَتَانِ مِنْكُمْ أَنْ تَفْشَلاَ وَاللَّهُ وَلِيُّهُمَا‏\}‏ بَنُو سَلِمَةَ وَبَنُو حَارِثَةَ وَمَا نُحِبُّ أَنَّهَا لَمْ تَنْزِلْ لِقَوْلِ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ وَاللَّهُ وَلِيُّهُمَا‏\}‏ ‏.‏\hadithno{6413}\hadithtrans{Jabir b. Abdullah reported that it was concerning them (the Ansar) that this verse was revealed, that when the two groups amongst you were about to lose heart and Allah was the Guardian of them both. This concerned Banu Salama and Banu Haritha and we did not like that Allah, the Exalted and Glorious, should not have revealed this verse for the fact that Allah (gave an assurance) of being the Guardian of both}}
\hadithdefcmd{muslim}{6416}{حَدَّثَنِي أَبُو مَعْنٍ الرَّقَاشِيُّ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - حَدَّثَنَا إِسْحَاقُ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ - أَنَّ أَنَسًا، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَغْفَرَ لِلأَنْصَارِ - قَالَ - وَأَحْسِبُهُ قَالَ ‏ "‏ وَلِذَرَارِيِّ الأَنْصَارِ وَلِمَوَالِي الأَنْصَارِ ‏"‏ ‏.‏ لاَ أَشُكُّ فِيهِ ‏.‏\hadithno{6416}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) sought forgiveness for the Ansar and he said:I think (he also sought forgiveness) for the children of the Ansar and the slaves and the freed men of the Ansar. I have no doubt about it}}
\hadithdefcmd{muslim}{6417}{حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، - وَاللَّفْظُ لِزُهَيْرٍ - حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَبْدِ الْعَزِيزِ، - وَهُوَ ابْنُ صُهَيْبٍ - عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى صِبْيَانًا وَنِسَاءً مُقْبِلِينَ مِنْ عُرْسٍ فَقَامَ نَبِيُّ اللَّهِ صلى الله عليه وسلم مُمْثِلاً فَقَالَ ‏ "‏ اللَّهُمَّ أَنْتُمْ مِنْ أَحَبِّ النَّاسِ إِلَىَّ اللَّهُمَّ أَنْتُمْ مِنْ أَحَبِّ النَّاسِ إِلَىَّ ‏"‏ ‏.‏ يَعْنِي الأَنْصَارَ ‏.‏\hadithno{6417}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) saw children and women of the Ansar coming back from a wedding feast. Allah's Apostle (ﷺ) stood up motionless (as a mark of respect) and said:O Allah, (bear witness) (and addressing the Ansar), said: You are dearest to me amongst people, (and said: O Allah (bear witness) (and addressing the Ansar), said: You are dearest to me amongst people. And he meant Ansar}}
\hadithdefcmd{muslim}{6418}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ غُنْدَرٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ جَاءَتِ امْرَأَةٌ مِنَ الأَنْصَارِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - فَخَلاَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّكُمْ لأَحَبُّ النَّاسِ إِلَىَّ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{6418}\hadithtrans{Anas b. Malik reported that a woman from the Ansar came to Allah's Messenger (ﷺ) and Allah's Messenger (ﷺ) stood aside with her and said:By Him in Whose Hand is my life, you are dearest to me amongst the people. He repeated it thrice}}
\hadithdefcmd{muslim}{6419}{حَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ إِدْرِيسَ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6419}\hadithtrans{This hadith has been reported on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6420}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الأَنْصَارَ كَرِشِي وَعَيْبَتِي وَإِنَّ النَّاسَ سَيَكْثُرُونَ وَيَقِلُّونَ فَاقْبَلُوا مِنْ مُحْسِنِهِمْ وَاعْفُوا عَنْ مُسِيئِهِمْ ‏"‏ ‏.‏\hadithno{6420}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:The Ansar are my family and my trusted friends. and the people would increase in number whereas they (the Ansar) would become less and less, so appreciate the deeds of those from amongst them who do good and overlook their failings}}
\hadithdefcmd{muslim}{6421}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي أُسَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ دُورِ الأَنْصَارِ بَنُو النَّجَّارِ ثُمَّ بَنُو عَبْدِ الأَشْهَلِ ثُمَّ بَنُو الْحَارِثِ بْنِ الْخَزْرَجِ ثُمَّ بَنُو سَاعِدَةَ وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏ ‏.‏ فَقَالَ سَعْدٌ مَا أُرَى رَسُولَ اللَّهِ صلى الله عليه وسلم إِلاَّ قَدْ فَضَّلَ عَلَيْنَا ‏.‏ فَقِيلَ قَدْ فَضَّلَكُمْ عَلَى كَثِيرٍ ‏.‏\hadithno{6421}\hadithtrans{Abu Usaid reported Allah's Messenger (ﷺ) as saying:The worthiest clans of the Ansar are Banu Najjar, thereafter Banu al-Ashhal; thereafter Banu Harith b. Banu Khazraj; thereafter Banu Sa'idah and there is goodness in all clans of the Ansar. Sa'd said: I see that he (the Holy Prophet) has placed others above us. It was said to (him): He has placed you above many others}}
\hadithdefcmd{muslim}{6422}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعْتُ أَنَسًا، يُحَدِّثُ عَنْ أَبِي أُسَيْدٍ الأَنْصَارِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{6422}\hadithtrans{Abu Usaid Ansari has reported this hadith through another chain of transmitters. When the Prophet (ﷺ) was marching towards Badr in order}}
\hadithdefcmd{muslim}{6423}{حَدَّثَنَا قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، يَعْنِي ابْنَ مُحَمَّدٍ ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ لاَ يَذْكُرُ فِي الْحَدِيثِ قَوْلَ سَعْدٍ ‏.‏\hadithno{6423}\hadithtrans{Anas reported a hadith like this from Allah's Apostle (ﷺ) but he has made no mention in the hadith of the words of Sa'd}}
\hadithdefcmd{muslim}{6424}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، وَمُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، - وَاللَّفْظُ لاِبْنِ عَبَّادٍ - حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ، قَالَ سَمِعْتُ أَبَا أُسَيْدٍ، خَطِيبًا عِنْدَ ابْنِ عُتْبَةَ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ دُورِ الأَنْصَارِ دَارُ بَنِي النَّجَّارِ وَدَارُ بَنِي عَبْدِ الأَشْهَلِ وَدَارُ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ وَدَارُ بَنِي سَاعِدَةَ ‏"‏ ‏.‏ وَاللَّهِ لَوْ كُنْتُ مُؤْثِرًا بِهَا أَحَدًا لآثَرْتُ بِهَا عَشِيرَتِي ‏.‏\hadithno{6424}\hadithtrans{Ibrahim b. Muhammad b. Talha reported:I heard Abu Sa'ld delivering an address in the presence of Abu 'Utba that the Messenger of Allah (ﷺ) said: The worthiest settlements of the Ansar are those of Banu Najjar, then of Banu 'Abu al-Ashhal and then of Banu Harith and then of Banu Khazraj and then of the clan of Banu Sa'idah, and if I were to give preference to anyone besides them I would have given preference to my relatives}}
\hadithdefcmd{muslim}{6425}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، قَالَ شَهِدَ أَبُو سَلَمَةَ لَسَمِعَ أَبَا أُسَيْدٍ الأَنْصَارِيَّ يَشْهَدُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ دُورِ الأَنْصَارِ بَنُو النَّجَّارِ ثُمَّ بَنُو عَبْدِ الأَشْهَلِ ثُمَّ بَنُو الْحَارِثِ بْنِ الْخَزْرَجِ ثُمَّ بَنُو سَاعِدَةَ وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏ ‏.‏ قَالَ أَبُو سَلَمَةَ قَالَ أَبُو أُسَيْدٍ أُتَّهَمُ أَنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَوْ كُنْتُ كَاذِبًا لَبَدَأْتُ بِقَوْمِي بَنِي سَاعِدَةَ ‏.‏ وَبَلَغَ ذَلِكَ سَعْدَ بْنَ عُبَادَةَ فَوَجَدَ فِي نَفْسِهِ وَقَالَ خُلِّفْنَا فَكُنَّا آخِرَ الأَرْبَعِ أَسْرِجُوا لِي حِمَارِي آتِي رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَكَلَّمَهُ ابْنُ أَخِيهِ سَهْلٌ فَقَالَ أَتَذْهَبُ لِتَرُدَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم أَعْلَمُ أَوَلَيْسَ حَسْبُكَ أَنْ تَكُونَ رَابِعَ أَرْبَعٍ ‏.‏ فَرَجَعَ وَقَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ وَأَمَرَ بِحِمَارِهِ فَحُلَّ عَنْهُ ‏.‏\hadithno{6425}\hadithtrans{Abu Usaid Ansar reported:I bear witness to the fact that Allah's Messenger (ﷺ) said: The best settlements of the Ansar are of those of Banu Najjar, then of Banu 'Abu al-Aslihal and then of Banu Harith b. Khazraj, then of Banu Sa'ida and there is in every settlement of the Ansar good. Abu Salama reported that Abu Usaid said: Can I tell a Iie about Allah's Messenger (ﷺ)? And if I were a liar, I would have started with my tribe Banu Sa'ida. This was conveyed to Sa'd b. 'Ubida and he found (rankling) in his mind and said: We have been left behind (in the sense) that we have been (mentioned) last of the four. He (Sa'd) sid: Saddle my pony so that I should go to Allah's Messenger (ﷺ). His nephew saw him and said: Are you going to contradict (the order of) precedence set by Allah's Messenger (ﷺ), whereas Allah's Messenger (ﷺ) has the best knowledge of it? Is it not sufficient for you that you are the fourth amongst the four (best tribes of the Ansar)? So he returned and said: Allah and His Messenger know best, and he commanded that his pony should be unsaddled}}
\hadithdefcmd{muslim}{6426}{حَدَّثَنَا عَمْرُو بْنُ عَلِيِّ بْنِ بَحْرٍ، حَدَّثَنِي أَبُو دَاوُدَ، حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ حَدَّثَنِي أَبُو سَلَمَةَ، أَنَّ أَبَا أُسَيْدٍ الأَنْصَارِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ الأَنْصَارِ أَوْ خَيْرُ دُورِ الأَنْصَارِ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِهِمْ فِي ذِكْرِ الدُّورِ وَلَمْ يَذْكُرْ قِصَّةَ سَعْدِ بْنِ عُبَادَةَ رضى الله عنه ‏.‏\hadithno{6426}\hadithtrans{Abu Usaid Ansari reported that he heard Allah's Messenger (ﷺ) as saying:The worthiest of the Ansar or the worthiest of the settlements and the clans of Ansar; the rest of the hadith is the same, but there is no mention of the story of Sa'd b. 'Ubida (Allah be pleased with him)}}
\hadithdefcmd{muslim}{6427}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ أَبُو سَلَمَةَ وَعُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي مَجْلِسٍ عَظِيمٍ مِنَ الْمُسْلِمِينَ ‏"‏ أُحَدِّثُكُمْ بِخَيْرِ دُورِ الأَنْصَارِ ‏"‏ ‏.‏ قَالُوا نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَنُو عَبْدِ الأَشْهَلِ ‏"‏ ‏.‏ قَالُوا ثُمَّ مَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ثُمَّ بَنُو النَّجَّارِ ‏"‏ ‏.‏ قَالُوا ثُمَّ مَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ثُمَّ بَنُو الْحَارِثِ بْنِ الْخَزْرَجِ ‏"‏ ‏.‏ قَالُوا ثُمَّ مَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ثُمَّ بَنُو سَاعِدَةَ ‏"‏ ‏.‏ قَالُوا ثُمَّ مَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ثُمَّ فِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏ ‏.‏ فَقَامَ سَعْدُ بْنُ عُبَادَةَ مُغْضَبًا فَقَالَ أَنَحْنُ آخِرُ الأَرْبَعِ حِينَ سَمَّى رَسُولُ اللَّهِ صلى الله عليه وسلم دَارَهُمْ فَأَرَادَ كَلاَمَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ رِجَالٌ مِنْ قَوْمِهِ اجْلِسْ أَلاَ تَرْضَى أَنْ سَمَّى رَسُولُ اللَّهِ صلى الله عليه وسلم دَارَكُمْ فِي الأَرْبَعِ الدُّورِ الَّتِي سَمَّى فَمَنْ تَرَكَ فَلَمْ يُسَمِّ أَكْثَرُ مِمَّنْ سَمَّى ‏.‏ فَانْتَهَى سَعْدُ بْنُ عُبَادَةَ عَنْ كَلاَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6427}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying in a large gathering of the Muslims:Should I not tell you of the best clans of the Ansar? They said: Allah's Messenger, (kindly) do this. Thereupon Allah's Messenger said: That is Banu Abd al-Ashhal. They said: Allah's Messenger, then next? He said: Banu Najjar. They again said: Allah's Messenger, then next? He said: Then of Banu Harith b. Khazraj. They then said: Allah's Messenger, then next? He said. Then of Banu Sa'ida. They said: Allah's Messenger, then next? He said: There is good in all the clans of the Ansar. It was upon this that Sa'd b. Ubida stood up in annoyance and said: Are we the last of the four as Allah's Messenger (ﷺ) has determined (the order of precedence) of their clans? He decided to talk with Allah's Messenger (ﷺ) on this issue, but the people Of his tribe said to him: Be seated, are you not happy with this that Allah's Messenger' (ﷺ) has mentioned your clan as one of the four (best) clans and those whom he left and did not mention (the order of their precedence) are more than those whom he mentioned? And Sa'd b. 'Ubada dropped the idea of talking to Allah's Messenger (ﷺ) (on this issue)}}
\hadithdefcmd{muslim}{6428}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنِ ابْنِ، عَرْعَرَةَ - وَاللَّفْظُ لِلْجَهْضَمِيِّ - حَدَّثَنِي مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَرَجْتُ مَعَ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ فِي سَفَرٍ فَكَانَ يَخْدُمُنِي فَقُلْتُ لَهُ لاَ تَفْعَلْ ‏.‏ فَقَالَ إِنِّي قَدْ رَأَيْتُ الأَنْصَارَ تَصْنَعُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم شَيْئًا آلَيْتُ أَنْ لاَ أَصْحَبَ أَحَدًا مِنْهُمْ إِلاَّ خَدَمْتُهُ ‏.‏ زَادَ ابْنُ الْمُثَنَّى وَابْنُ بَشَّارٍ فِي حَدِيثِهِمَا وَكَانَ جَرِيرٌ أَكْبَرَ مِنْ أَنَسٍ ‏.‏ وَقَالَ ابْنُ بَشَّارٍ أَسَنَّ مِنْ أَنَسٍ ‏.‏\hadithno{6428}\hadithtrans{Anas b. Malik reported:I set out along with Jabrir b. 'Abdullah al-Bajali on a journey and he used to serve me. I said to him: Don't do that. Thereupon he said: I have seen Ansar doing this with Allah's Messenger (ﷺ). I swore by Allah whenever I accompany any one of the Ansar, I would serve him and Ibn Muthanni, and Ibn Bashshir made this addition in their narrations: Jarir was older than Anas, and Ibn Bashshir said: He was of a more advanced age as compared with Anas. Allah's Apostle (ﷺ) invoked blessings for the tribes of Ghifar and Aslam}}
\hadithdefcmd{muslim}{6429}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ عَبْدِ، اللَّهِ بْنِ الصَّامِتِ قَالَ قَالَ أَبُو ذَرٍّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غِفَارُ غَفَرَ اللَّهُ لَهَا وَأَسْلَمُ سَالَمَهَا اللَّهُ ‏"‏ ‏.‏\hadithno{6429}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying:Go to your people and say that the Messenger of Allah (ﷺ) says: Ghifar (is a tribe) to whom Allah granted pardon, and Aslam (is the tribe) to whom Allah granted safety}}
\hadithdefcmd{muslim}{6430}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنِ ابْنِ مَهْدِيٍّ، قَالَ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ، الْجَوْنِيِّ عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ائْتِ قَوْمَكَ فَقُلْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ أَسْلَمُ سَالَمَهَا اللَّهُ وَغِفَارُ غَفَرَ اللَّهُ لَهَا ‏"‏ ‏.‏\hadithno{6430}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying:To the tribe of Aslam Allah has granted safety and to the tribe of Ghifar Allah has granted pardon}}
\hadithdefcmd{muslim}{6431}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{6431}\hadithtrans{This hadith has been reported on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6432}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ وَسُوَيْدُ بْنُ سَعِيدٍ وَابْنُ أَبِي عُمَرَ قَالُوا حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ، الرَّحْمَنِ بْنُ مَهْدِيٍّ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، بْنِ نُمَيْرٍ وَعَبْدُ بْنُ حُمَيْدٍ عَنْ أَبِي عَاصِمٍ، كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، كُلُّهُمْ قَالَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْلَمُ سَالَمَهَا اللَّهُ وَغِفَارُ غَفَرَ اللَّهُ لَهَا ‏"‏ ‏.‏\hadithno{6432}\hadithtrans{This hadith has been narrated through other chains of transmitters on the authority of Jabir and Abu Huraira that Allah's Apostle (ﷺ) said:To the tribe of Aslam Allah has granted safety and to the tribe of Ghifar Allah has granted pardon}}
\hadithdefcmd{muslim}{6433}{وَحَدَّثَنِي حُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ خُثَيْمِ بْنِ عِرَاكٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْلَمُ سَالَمَهَا اللَّهُ وَغِفَارُ غَفَرَ اللَّهُ لَهَا أَمَا إِنِّي لَمْ أَقُلْهَا وَلَكِنْ قَالَهَا اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{6433}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:To the tribe of Aslam Allah has granted safety and to the tribe of Ghifar Allah has granted pardon. Verily it is not I that say this, but (it is) Allah the Exalted and Glorious. (who) says this}}
\hadithdefcmd{muslim}{6434}{حَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ اللَّيْثِ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ حَنْظَلَةَ بْنِ عَلِيٍّ، عَنْ خُفَافِ بْنِ إِيمَاءَ الْغِفَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةٍ ‏ "‏ اللَّهُمَّ الْعَنْ بَنِي لِحْيَانَ وَرِعْلاً وَذَكْوَانَ وَعُصَيَّةَ عَصَوُا اللَّهَ وَرَسُولَهُ غِفَارُ غَفَرَ اللَّهُ لَهَا وَأَسْلَمُ سَالَمَهَا اللَّهُ ‏"‏ ‏.‏\hadithno{6434}\hadithtrans{Khufaf b. Jura' reported that Allah's Messenger (ﷺ) said in prayer:O Allah, hurl curse upon the tribe of Lihyan and Ri'l aid Dhakwan and Usayya for they disobeyed Allah and His Messenger, (and for) Ghifar Allah has granted pardon and for the tribe of Aslam Allah has granted safety}}
\hadithdefcmd{muslim}{6435}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ، عُمَرَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غِفَارُ غَفَرَ اللَّهُ لَهَا وَأَسْلَمُ سَالَمَهَا اللَّهُ وَعُصَيَّةُ عَصَتِ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{6435}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:Allah has granted pardon to the tribe of Ghifar and to the tribe of Aslam Allah has granted safety and as for Usayya tribe, they disobeyed Allah and His Messenger}}
\hadithdefcmd{muslim}{6436}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، ح وَحَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَالْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ وَفِي حَدِيثِ صَالِحٍ وَأُسَامَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ذَلِكَ عَلَى الْمِنْبَرِ ‏.‏\hadithno{6436}\hadithtrans{This hadith has been transmitted on the authority of Ibn Umar with a slight variation of wording (and the wording) that Allah's Messenger (ﷺ) said this on the pulpit}}
\hadithdefcmd{muslim}{6437}{وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، عَنْ يَحْيَى، حَدَّثَنِي أَبُو سَلَمَةَ، حَدَّثَنِي ابْنُ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ مِثْلَ حَدِيثِ هَؤُلاَءِ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{6437}\hadithtrans{This hadith has been reported on the authority of Ibn Umar but through another chain of transmitters}}
\hadithdefcmd{muslim}{6438}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - أَخْبَرَنَا أَبُو مَالِكٍ، الأَشْجَعِيُّ عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي أَيُّوبَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَنْصَارُ وَمُزَيْنَةُ وَجُهَيْنَةُ وَغِفَارُ وَأَشْجَعُ وَمَنْ كَانَ مِنْ بَنِي عَبْدِ اللَّهِ مَوَالِيَّ دُونَ النَّاسِ وَاللَّهُ وَرَسُولُهُ مَوْلاَهُمْ ‏"‏ ‏.‏\hadithno{6438}\hadithtrans{Abu Ayyub reported Allah's Messenger (ﷺ) as saying:The tribes of Ansar, Muzaina and Juhaina and Ghifar and Ashja' and those from Banu 'Abdullah, they are my friends amongst the people and Allah and His Messenger are their protectors}}
\hadithdefcmd{muslim}{6439}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُرَيْشٌ وَالأَنْصَارُ وَمُزَيْنَةُ وَجُهَيْنَةُ وَأَسْلَمُ وَغِفَارُ وَأَشْجَعُ مَوَالِيَّ لَيْسَ لَهُمْ مَوْلًى دُونَ اللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏\hadithno{6439}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Quraish, Ansar, Muzaina, Juhaina and Ghifar, they are my friends and there is no friend of theirs besides Allah and His Messenger}}
\hadithdefcmd{muslim}{6440}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي الْحَدِيثِ قَالَ سَعْدٌ فِي بَعْضِ هَذَا فِيمَا أَعْلَمُ ‏.‏\hadithno{6440}\hadithtrans{This hadith has been transmitted on the authority of Sa'd b. Ibrahim with a slight variation of wording}}
\hadithdefcmd{muslim}{6441}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ أَسْلَمُ وَغِفَارُ وَمُزَيْنَةُ وَمَنْ كَانَ مِنْ جُهَيْنَةَ أَوْ جُهَيْنَةُ خَيْرٌ مِنْ بَنِي تَمِيمٍ وَبَنِي عَامِرٍ وَالْحَلِيفَيْنِ أَسَدٍ وَغَطَفَانَ ‏"‏ ‏.‏\hadithno{6441}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The tribes of Ashja', Ghifar and Muzaina and from the tribe of Juhaina they are better than Banu Tamim, Banu Amir and the allies of Asad and Ghatfan}}
\hadithdefcmd{muslim}{6442}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ، الآخَرَانِ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ الأَعْرَجِ، قَالَ قَالَ أَبُو هُرَيْرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَغِفَارُ وَأَسْلَمُ وَمُزَيْنَةُ وَمَنْ كَانَ مِنْ جُهَيْنَةَ أَوْ قَالَ جُهَيْنَةُ وَمَنْ كَانَ مِنْ مُزَيْنَةَ خَيْرٌ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ مِنْ أَسَدٍ وَطَيِّئٍ وَغَطَفَانَ ‏"‏ ‏.‏\hadithno{6442}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:By Him in Whose Hand is the life of Muhammad, (the tribes of) Ghifar, Aslam, Muzaina, or from the tribe of Juhaina or from the tribe of Muzaina, they would be better in the eye of Allah than Asad, Tayyi, and Ghatfan on the Day of Resurrection}}
\hadithdefcmd{muslim}{6443}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَيَعْقُوبُ الدَّوْرَقِيُّ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِيَانِ ابْنَ عُلَيَّةَ - حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَسْلَمُ وَغِفَارُ وَشَىْءٌ مِنْ مُزَيْنَةَ وَجُهَيْنَةَ أَوْ شَىْءٌ مِنْ جُهَيْنَةَ وَمُزَيْنَةَ خَيْرٌ عِنْدَ اللَّهِ - قَالَ أَحْسِبُهُ قَالَ - يَوْمَ الْقِيَامَةِ مِنْ أَسَدٍ وَغَطَفَانَ وَهَوَازِنَ وَتَمِيمٍ ‏"‏ ‏.‏\hadithno{6443}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Aslam, Ghifar or some people from Muzaina, Juhaina (with the variation of words) are better in the eye of Allah than Asad, Ghatfan, Hawizin and Tamim. The narrator said: I think he also said:" On the Day of Resurrection}}
\hadithdefcmd{muslim}{6444}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ أَبِي يَعْقُوبَ، سَمِعْتُ عَبْدَ، الرَّحْمَنِ بْنَ أَبِي بَكْرَةَ يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ الأَقْرَعَ بْنَ حَابِسٍ، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّمَا بَايَعَكَ سُرَّاقُ الْحَجِيجِ مِنْ أَسْلَمَ وَغِفَارَ وَمُزَيْنَةَ - وَأَحْسِبُ جُهَيْنَةَ - مُحَمَّدٌ الَّذِي شَكَّ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرَأَيْتَ إِنْ كَانَ أَسْلَمُ وَغِفَارُ وَمُزَيْنَةُ - وَأَحْسِبُ جُهَيْنَةَ - خَيْرًا مِنْ بَنِي تَمِيمٍ وَبَنِي عَامِرٍ وَأَسَدٍ وَغَطَفَانَ أَخَابُوا وَخَسِرُوا ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَوَالَّذِي نَفْسِي بِيَدِهِ إِنَّهُمْ لأَخْيَرُ مِنْهُمْ ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ ابْنِ أَبِي شَيْبَةَ مُحَمَّدٌ الَّذِي شَكَّ ‏.‏\hadithno{6444}\hadithtrans{Abu Bakra reported from his father that al-Aqra' b. Habis reported that he came to Allah's Messenger (ﷺ) and said to him:How did the tribes of Aslam, Ghifar, Muzaina (and I think he also said Juhaina and the narrator is in doubt about it) owe allegiance to you, whereas they plundered the pilgrims? Thereupon Allah's Messenger (ﷺ) said:" you were to say that Aslam, Ghifar, Muzaina and I think Juhaina are better than Banu Tamim, Banu 'Amir and Asad, Ghatfan, then would these people (of latter group of tribes) be in loss? He said: Yes. Thereupon he (the Holy Prophet) said: By Him in Whose Hand is my life, these people are better than Banu Tamim, Banu Amir, Asad and Ghatfan, and in this hadith of Abu Shaiba (these words are not found) that Muhammad (the narrator) had a doubt about}}
\hadithdefcmd{muslim}{6445}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي سَيِّدُ بَنِي، تَمِيمٍ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي يَعْقُوبَ الضَّبِّيُّ بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ قَالَ ‏ "‏ وَجُهَيْنَةُ ‏"‏ ‏.‏ وَلَمْ يَقُلْ أَحْسِبُ ‏.‏\hadithno{6445}\hadithtrans{This hadith has been narrated on the authority of Abu Ya'qub Dabbi with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6446}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ عَبْدِ، الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْلَمُ وَغِفَارُ وَمُزَيْنَةُ وَجُهَيْنَةُ خَيْرٌ مِنْ بَنِي تَمِيمٍ وَمِنْ بَنِي عَامِرٍ وَالْحَلِيفَيْنِ بَنِي أَسَدٍ وَغَطَفَانَ ‏"‏ ‏.‏\hadithno{6446}\hadithtrans{Abu Bakra reported from the Messenger of Allah (ﷺ) that Aslam, Ghifar, Muzaina and Juhaina are better than Banu Tamim, Banu Amir and their allies Banu Asad and Ghatfan}}
\hadithdefcmd{muslim}{6447}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ، ح وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6447}\hadithtrans{This hadith has been reported on the authority of Abu Bishr with the same chain of transmitters}}
\hadithdefcmd{muslim}{6448}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرَأَيْتُمْ إِنْ كَانَ جُهَيْنَةُ وَأَسْلَمُ وَغِفَارُ خَيْرًا مِنْ بَنِي تَمِيمٍ وَبَنِي عَبْدِ اللَّهِ بْنِ غَطَفَانَ وَعَامِرِ بْنِ صَعْصَعَةَ ‏"‏ ‏.‏ وَمَدَّ بِهَا صَوْتَهُ فَقَالُوا يَا رَسُولَ اللَّهِ فَقَدْ خَابُوا وَخَسِرُوا ‏.‏ قَالَ ‏"‏ فَإِنَّهُمْ خَيْرٌ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي كُرَيْبٍ ‏"‏ أَرَأَيْتُمْ إِنْ كَانَ جُهَيْنَةُ وَمُزَيْنَةُ وَأَسْلَمُ وَغِفَارُ ‏"‏ ‏.‏\hadithno{6448}\hadithtrans{Abu Bakra reported on the authority of his father that Allah's Messenger (ﷺ) said:What is your view if Juhaina, Aslam, Ghifar were better than Banu Tamim, Banu 'Abdullah b. Ghatfan and 'Amir b. Sa'sa'a' respectively (then what would be status of the latter one)? He said this in a loud voice. They said: Allah's Messenger, they would be definitely at a loss and disadvantage. Thereupon he said: They (the first group) are decidedly better than the others; and in the hadith transmitted on the authority of Abu Kuraib the words are: It you were to find that Juhaina, Muzaina and Aslam and Ghifar (are better than)}}
\hadithdefcmd{muslim}{6449}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ أَتَيْتُ عُمَرَ بْنَ الْخَطَّابِ فَقَالَ لِي إِنَّ أَوَّلَ صَدَقَةٍ بَيَّضَتْ وَجْهَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَوُجُوهَ أَصْحَابِهِ صَدَقَةُ طَيِّئٍ جِئْتَ بِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6449}\hadithtrans{Adi b. Hatim reported:I came to Umar b. Khattab and he said to me: The first consignment of Sadaqa brought to Allah's Messenger (ﷺ) which brightened the face of Allah's Messenger (ﷺ) and the faces of his Companions was that of Tayyi}}
\hadithdefcmd{muslim}{6450}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَدِمَ الطُّفَيْلُ وَأَصْحَابُهُ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّ دَوْسًا قَدْ كَفَرَتْ وَأَبَتْ فَادْعُ اللَّهَ عَلَيْهَا ‏.‏ فَقِيلَ هَلَكَتْ دَوْسٌ فَقَالَ ‏ "‏ اللَّهُمَّ اهْدِ دَوْسًا وَائْتِ بِهِمْ ‏"‏ ‏.‏\hadithno{6450}\hadithtrans{Abu Huraira reported that Tufail and his companions said:Allah's Messenger, the tribe of Daws has disbelieved and has belied you, so invoke curse upon them. It was said: Let Daws be destroyed, whereupon he (Allah's Messenger) said: Allah guide aright the tribe of Daws and direct them to me}}
\hadithdefcmd{muslim}{6451}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنِ الْحَارِثِ، عَنْ أَبِي زُرْعَةَ، قَالَ قَالَ أَبُو هُرَيْرَةَ لاَ أَزَالُ أُحِبُّ بَنِي تَمِيمٍ مِنْ ثَلاَثٍ سَمِعْتُهُنَّ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ هُمْ أَشَدُّ أُمَّتِي عَلَى الدَّجَّالِ ‏"‏ ‏.‏ قَالَ وَجَاءَتْ صَدَقَاتُهُمْ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَذِهِ صَدَقَاتُ قَوْمِنَا ‏"‏ ‏.‏ قَالَ وَكَانَتْ سَبِيَّةٌ مِنْهُمْ عِنْدَ عَائِشَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْتِقِيهَا فَإِنَّهَا مِنْ وَلَدِ إِسْمَاعِيلَ ‏"‏ ‏.‏\hadithno{6451}\hadithtrans{empty}}
\hadithdefcmd{muslim}{6452}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لاَ أَزَالُ أُحِبُّ بَنِي تَمِيمٍ بَعْدَ ثَلاَثٍ سَمِعْتُهُنَّ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُهَا فِيهِمْ ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{6452}\hadithtrans{The other hadith has been transmitted on the authority of Abu Huraira with a slight variation of wording}}
\hadithdefcmd{muslim}{6453}{وَحَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا مَسْلَمَةُ بْنُ عَلْقَمَةَ الْمَازِنِيُّ، إِمَامُ مَسْجِدِ دَاوُدَ حَدَّثَنَا دَاوُدُ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ثَلاَثُ خِصَالٍ سَمِعْتُهُنَّ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَنِي تَمِيمٍ لاَ أَزَالُ أُحِبُّهُمْ بَعْدُ وَسَاقَ الْحَدِيثَ بِهَذَا الْمَعْنَى غَيْرَ أَنَّهُ قَالَ ‏ "‏ هُمْ أَشَدُّ النَّاسِ قِتَالاً فِي الْمَلاَحِمِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الدَّجَّالَ ‏.‏\hadithno{6453}\hadithtrans{Abu Huraira reported:There are some distinguishing features of Banu Tamim which I heard from Allah's Messenger (ﷺ) and my love for them is never on the decline after that and the words are: They are the bravest amongst people in the battlefield and there is no mention of (the word)" Dajjal}}
\hadithdefcmd{muslim}{6454}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَجِدُونَ النَّاسَ مَعَادِنَ فَخِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقُهُوا وَتَجِدُونَ مِنْ خَيْرِ النَّاسِ فِي هَذَا الأَمْرِ أَكْرَهُهُمْ لَهُ قَبْلَ أَنْ يَقَعَ فِيهِ وَتَجِدُونَ مِنْ شِرَارِ النَّاسِ ذَا الْوَجْهَيْنِ الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ وَهَؤُلاَءِ بِوَجْهٍ ‏"‏ ‏.‏\hadithno{6454}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:You would find people like those of mine, the good amongst you in the Days of Ignorance would be good amongst you in the days of Islam, provided they have an understanding of it and you will find good amongst people the persons who would be averse to position of authority until it is thrust upon them, and you will find the worst amongst persons one who has double face. He comes with one face to them and with the other face to the others}}
\hadithdefcmd{muslim}{6455}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَجِدُونَ النَّاسَ مَعَادِنَ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ الزُّهْرِيِّ غَيْرَ أَنَّ فِي حَدِيثِ أَبِي زُرْعَةَ وَالأَعْرَجِ ‏"‏ تَجِدُونَ مِنْ خَيْرِ النَّاسِ فِي هَذَا الشَّأْنِ أَشَدَّهُمْ لَهُ كَرَاهِيَةً حَتَّى يَقَعَ فِيهِ ‏"‏ ‏.‏\hadithno{6455}\hadithtrans{This hadith has been transmitted through other chains of transmitters. The chain of of Abu Zur'a has a slight variation of wording}}
\hadithdefcmd{muslim}{6456}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، وَعَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ نِسَاءٍ رَكِبْنَ الإِبِلَ - قَالَ أَحَدُهُمَا صَالِحُ نِسَاءِ قُرَيْشٍ ‏.‏ وَقَالَ الآخَرُ نِسَاءُ قُرَيْشٍ - أَحْنَاهُ عَلَى يَتِيمٍ فِي صِغَرِهِ وَأَرْعَاهُ عَلَى زَوْجٍ فِي ذَاتِ يَدِهِ ‏"‏ ‏.‏\hadithno{6456}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Good amongst the women are those who ride camels. One of them said: They are pious women of the Quraish, and the other one said: The women of the Quraish are kind to the orphans in their childhood and look after the wealth of their spouses}}
\hadithdefcmd{muslim}{6457}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم وَابْنُ طَاوُسٍ عَنْ أَبِيهِ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ أَرْعَاهُ عَلَى وَلَدٍ فِي صِغَرِهِ ‏"‏ ‏.‏ وَلَمْ يَقُلْ يَتِيمٍ ‏.‏\hadithno{6457}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira with a slight variation of wording and there is no word" orphan}}
\hadithdefcmd{muslim}{6458}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نِسَاءُ قُرَيْشٍ خَيْرُ نِسَاءٍ رَكِبْنَ الإِبِلَ أَحْنَاهُ عَلَى طِفْلٍ وَأَرْعَاهُ عَلَى زَوْجٍ فِي ذَاتِ يَدِهِ ‏"‏ ‏.‏ قَالَ يَقُولُ أَبُو هُرَيْرَةَ عَلَى إِثْرِ ذَلِكَ وَلَمْ تَرْكَبْ مَرْيَمُ بِنْتُ عِمْرَانَ بَعِيرًا قَطُّ ‏.‏\hadithno{6458}\hadithtrans{Abu Huraira reported:I heard Allah's Messenger (ﷺ) as saying: The women of the Quraish are good amongst the womenfolk. They ride camels and show affection to their children and zealously guard the wealth of their husbands. Abu Huraira said at the end of this narration that Mary, the daughter of Imran, never rode the camel}}
\hadithdefcmd{muslim}{6459}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِ��ٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي قَدْ كَبِرْتُ وَلِيَ عِيَالٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ نِسَاءٍ رَكِبْنَ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ يُونُسَ غَيْرَ أَنَّهُ قَالَ ‏"‏ أَحْنَاهُ عَلَى وَلَدٍ فِي صِغَرِهِ ‏"‏ ‏.‏\hadithno{6459}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) gave a proposal of marriage to Umm Hani, the daughter of Abu Talib, whereupon she said:Allah's Messenger, I am of an advanced age with a (large) family. Thereupon Allah's Messenger (ﷺ) said: The best women are those who ride (the camels) ; the rest of the hadith is the same but with this difference that, instead of the word Ar'a the word Ahna has been used (and the complete sentence is like this): That they treat children in their childhood with affection}}
\hadithdefcmd{muslim}{6460}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ عَبْدٌ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ نِسَاءٍ رَكِبْنَ الإِبِلَ صَالِحُ نِسَاءِ قُرَيْشٍ أَحْنَاهُ عَلَى وَلَدٍ فِي صِغَرِهِ وَأَرْعَاهُ عَلَى زَوْجٍ فِي ذَاتِ يَدِهِ ‏"‏ ‏.‏\hadithno{6460}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The best women who ride the camels are the pious women of the Quraish; they treat with affection children in their childhood and keep a strict watch on the wealth of their spouses}}
\hadithdefcmd{muslim}{6461}{حَدَّثَنِي أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ مَخْلَدٍ - حَدَّثَنِي سُلَيْمَانُ، - وَهُوَ ابْنُ بِلاَلٍ - حَدَّثَنِي سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ مَعْمَرٍ هَذَا سَوَاءً ‏.‏\hadithno{6461}\hadithtrans{This hadith has been reported on the authority of Abu Huraira with the same chain of transmitters}}
\hadithdefcmd{muslim}{6462}{حَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم آخَى بَيْنَ أَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ وَبَيْنَ أَبِي طَلْحَةَ ‏.‏\hadithno{6462}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) established fraternity between Abu Ubaida b. Jarrah and Abu Talha}}
\hadithdefcmd{muslim}{6463}{حَدَّثَنِي أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الصَّبَّاحِ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، قَالَ قِيلَ لأَنَسِ بْنِ مَالِكٍ بَلَغَكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ حِلْفَ فِي الإِسْلاَمِ ‏"‏ ‏.‏ فَقَالَ أَنَسٌ قَدْ حَالَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ قُرَيْشٍ وَالأَنْصَارِ فِي دَارِهِ ‏.‏\hadithno{6463}\hadithtrans{It was said to Anas b. Malik:You must have heard this that Allah's Messenger (ﷺ) said: There is no alliance (hilf) of brotherhood in Islam. Anas said: Allah's Messenger (ﷺ) established the bond of fraternity between the Quraish and the Ansar in his home}}
\hadithdefcmd{muslim}{6464}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا عَبْدَةُ بْنُ، سُلَيْمَانَ عَنْ عَاصِمٍ، عَنْ أَنَسٍ، قَالَ حَالَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ قُرَيْشٍ وَالأَنْصَارِ فِي دَارِهِ الَّتِي بِالْمَدِينَةِ ‏.‏\hadithno{6464}\hadithtrans{Anas reported Allah's Messenger (ﷺ) established fraternity between the Quraish and the Ansar in his house at Medina}}
\hadithdefcmd{muslim}{6465}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ زَكَرِيَّاءَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حِلْفَ فِي الإِسْلاَمِ وَأَيُّمَا حِلْفٍ كَانَ فِي الْجَاهِلِيَّةِ لَمْ يَزِدْهُ الإِسْلاَمُ إِلاَّ شِدَّةً ‏"‏ ‏.‏\hadithno{6465}\hadithtrans{Jubair b. Mut'im reported Allah's Messenger (ﷺ) as saying:There is no alliance (hilf) in Islam but (the hilf) established in the pre-Islamic days (for good). Islam intensifies and strengthens it}}
\hadithdefcmd{muslim}{6466}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ أَبَانَ، كُلُّهُمْ عَنْ حُسَيْنٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، - عَنْ مُجَمِّعِ بْنِ يَحْيَى، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ صَلَّيْنَا الْمَغْرِبَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قُلْنَا لَوْ جَلَسْنَا حَتَّى نُصَلِّيَ مَعَهُ الْعِشَاءَ - قَالَ - فَجَلَسْنَا فَخَرَجَ عَلَيْنَا فَقَالَ ‏"‏ مَا زِلْتُمْ هَا هُنَا ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ صَلَّيْنَا مَعَكَ الْمَغْرِبَ ثُمَّ قُلْنَا نَجْلِسُ حَتَّى نُصَلِّيَ مَعَكَ الْعِشَاءَ قَالَ ‏"‏ أَحْسَنْتُمْ أَوْ أَصَبْتُمْ ‏"‏ ‏.‏ قَالَ فَرَفَعَ رَأْسَهُ إِلَى السَّمَاءِ وَكَانَ كَثِيرًا مِمَّا يَرْفَعُ رَأْسَهُ إِلَى السَّمَاءِ فَقَالَ ‏"‏ النُّجُومُ أَمَنَةٌ لِلسَّمَاءِ فَإِذَا ذَهَبَتِ النُّجُومُ أَتَى السَّمَاءَ مَا تُوعَدُ وَأَنَا أَمَنَةٌ لأَصْحَابِي فَإِذَا ذَهَبْتُ أَتَى أَصْحَابِي مَا يُوعَدُونَ وَأَصْحَابِي أَمَنَةٌ لأُمَّتِي فَإِذَا ذَهَبَ أَصْحَابِي أَتَى أُمَّتِي مَا يُوعَدُونَ ‏"‏ ‏.‏\hadithno{6466}\hadithtrans{Abu Burda reported on the authority of his father:We offered the sunset prayer along with Allah's Apostle (ﷺ). We then said: If we sit (along with Allah's Messenger) and observe night prayer with him it would be very good, so we sat down and he came to us and said: You are still sitting here. I said: Allah's Messenger, we observed evening prayer with you, then we said: Let us sit down and observe night prayer along with you, whereupon he said: You have done well or you have done right. He then lifted his head towards the sky and it often happened that as he lifted his head towards the sky, he said: The stars are a source of security for the sky and when the stars disappear there comes to the sky, i. e. (it meets the same fate) as it has been promised (it would plunge into darkness). And I am a source of safety and security to my Companions and when I would go away there would fall to the lot (of my Companions) as they have been promised with and my Companions are a source of security for the Umma and as they would go there would fall to the lot of my Umma as (its people) have been promised}}
\hadithdefcmd{muslim}{6467}{حَدَّثَنَا أَبُو خَيْثَمَةَ، زُهَيْرُ بْنُ حَرْبٍ وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قَالَ سَمِعَ عَمْرٌو، جَابِرًا يُخْبِرُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ يَغْزُو فِئَامٌ مِنَ النَّاسِ فَيُقَالُ لَهُمْ فِيكُمْ مَنْ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَيَقُولُونَ ‏.‏ نَعَمْ فَيُفْتَحُ لَهُمْ ثُمَّ يَغْزُو فِئَامٌ مِنَ النَّاسِ فَيُقَالُ لَهُمْ فِيكُمْ مَنْ رَأَى مَنْ صَحِبَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَيَقُولُونَ نَعَمْ ‏.‏ فَيُفْتَحُ لَهُمْ ثُمَّ يَغْزُو فِئَامٌ مِنَ النَّاسِ فَيُقَالُ لَهُمْ هَلْ فِيكُمْ مَنْ رَأَى مَنْ صَحِبَ مَنْ صَحِبَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَيَقُولُونَ نَعَمْ ‏.‏ فَيُفْتَحُ لَهُمْ ‏"‏ ‏.‏\hadithno{6467}\hadithtrans{Abu Sa'id Khudri reported Allah's Apostle (ﷺ) as saying:A time would come for the people when groups of people would set out for fighting in the cause of Allah and it would be said to them: Is there one amongst you who saw Allah's Messenger (ﷺ)? And they would say: Yes, and they would be victorious. Then the people would set out for fighting in the cause of Allah and it would be said to them: Is there one amongst you who saw those (who have had the privilege of sitting in the company of Allah's Messenger (ﷺ)? And they would say: Yes, and victory would be granted to them. Then a group of persons would set out for fighting in the cause of Allah and it would be said to them: Is there one amongst you who saw one of those who saw those who (had the privilege) of sitting in the company of Allah's Messenger (ﷺ)? And they would say: Yes, and the Victory would be granted to them}}
\hadithdefcmd{muslim}{6468}{حَدَّثَنِي سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرٍ، قَالَ زَعَمَ أَبُو سَعِيدٍ الْخُدْرِيُّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ يُبْعَثُ مِنْهُمُ الْبَعْثُ فَيَقُولُونَ انْظُرُوا هَلْ تَجِدُونَ فِيكُمْ أَحَدًا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَيُوجَدُ الرَّجُلُ فَيُفْتَحُ لَهُمْ بِهِ ثُمَّ يُبْعَثُ الْبَعْثُ الثَّانِي فَيَقُولُونَ هَلْ فِيهِمْ مَنْ رَأَى أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم فَيُفْتَحُ لَهُمْ بِهِ ثُمَّ يُبْعَثُ الْبَعْثُ الثَّالِثُ فَيُقَالُ انْظُرُوا هَلْ تَرَوْنَ فِيهِمْ مَنْ رَأَى مَنْ رَأَى أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَكُونُ الْبَعْثُ الرَّابِعُ فَيُقَالُ انْظُرُوا هَلْ تَرَوْنَ فِيهِمْ أَحَدًا رَأَى مَنْ رَأَى أَحَدًا رَأَى أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم فَيُوجَدُ الرَّجُلُ فَيُفْتَحُ لَهُمْ بِهِ ‏"‏ ‏.‏\hadithno{6468}\hadithtrans{Abu Sa'id Khudri reported Allah's Messenger (ﷺ) as saying:There would come to the people a time when a detachment would be sent for fighting in the cause of Allah and they would say: See, if you can find amongst them someone from amongst the Companions of Allah's Apostle (ﷺ). They would find a person and they would be granted victory because of him. Then a second detachment would be sent to them and they would say: Do you find amongst them one who had had the privilege of seeing the Companions of the Messenger of Allah (ﷺ)? -and the victory would be granted to them because of him. Then the third detachment would be sent and it would be said to them: See, if you find amongst them (who had had the honour of seeing one) who saw those who saw the Companions of Allah's Apostle (ﷺ). Then the fourth detachment would be sent and it would be said to them: See it you find amongst them one who had the privilege (of seeing) one who saw those who saw those who saw the Companions of Allah's Apostle (ﷺ), and a person would be found and they would be granted victory because of him}}
\hadithdefcmd{muslim}{6469}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ بْنِ يَزِيدَ، عَنْ عَبِيدَةَ السَّلْمَانِيِّ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ أُمَّتِي الْقَرْنُ الَّذِينَ يَلُونِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَجِيءُ قَوْمٌ تَسْبِقُ شَهَادَةُ أَحَدِهِمْ يَمِينَهُ وَيَمِينُهُ شَهَادَتَهُ ‏"‏ ‏.‏ لَمْ يَذْكُرْ هَنَّادٌ الْقَرْنَ فِي حَدِيثِهِ وَقَالَ قُتَيْبَةُ ‏"‏ ثُمَّ يَجِيءُ أَقْوَامٌ ‏"‏ ‏.‏\hadithno{6469}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:The best of my Umma would be those of the generation nearest to mine. Then those nearest to them, then those nearest to them, then people would come whose witness would precede the oath and the oath will precede the witness. Hannad has not made the mention of Qarn in his narration. Qutaiba said that, instead of the word Qaum, the word Aqwam has been used}}
\hadithdefcmd{muslim}{6470}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ النَّاسِ خَيْرٌ قَالَ ‏ "‏ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَجِيءُ قَوْمٌ تَبْدُرُ شَهَادَةُ أَحَدِهِمْ يَمِينَهُ وَتَبْدُرُ يَمِينُهُ شَهَادَتَهُ ‏"‏ ‏.‏ قَالَ إِبْرَاهِيمُ كَانُوا يَنْهَوْنَنَا وَنَحْنُ غِلْمَانٌ عَنِ الْعَهْدِ وَالشَّهَادَاتِ ‏.‏\hadithno{6470}\hadithtrans{Abdullah reported:It was asked from Allah's Apostle (ﷺ) who amongst the people were the best. He said: (People) of my generation, then those next to them, then those next to them, then there would come a people whose evidence would precede their oath and their oath would precede their evidence. Ibrahim said: They forbade us to make vows and bear witness when we were too young}}
\hadithdefcmd{muslim}{6471}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ مَنْصُورٍ، بِإِسْنَادِ أَبِي الأَحْوَصِ وَجَرِيرٍ بِمَعْنَى حَدِيثِهِمَا وَلَيْسَ فِي حَدِيثِهِمَا سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6471}\hadithtrans{This hadith has been transmitted by Mansur on the authority of Abu al-Ahwas and Jarir with a slight variation of wording}}
\hadithdefcmd{muslim}{6472}{وَحَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَزْهَرُ بْنُ سَعْدٍ السَّمَّانُ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ خَيْرُ النَّاسِ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ فَلاَ أَدْرِي فِي الثَّالِثَةِ أَوْ فِي الرَّابِعَةِ قَالَ ‏"‏ ثُمَّ يَتَخَلَّفُ مِنْ بَعْدِهِمْ خَلْفٌ تَسْبِقُ شَهَادَةُ أَحَدِهِمْ يَمِينَهُ وَيَمِينُهُ شَهَادَتَهُ ‏"‏ ‏.‏\hadithno{6472}\hadithtrans{Abdullah (b. Mas'ud) reported Allah's Apostle (ﷺ) as saying:The best among people are of my generation, then those next to them. (The narrator said): I do not know whether (he said) it three times or four times. Then there would fellow after them such persons whose evidence would precede the oath, and in case of some others, the oath (would precede) the evidence}}
\hadithdefcmd{muslim}{6473}{حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، ح وَحَدَّثَنِي إِسْمَاعِيلُ، بْنُ سَالِمٍ أَخْبَرَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ أُمَّتِي الْقَرْنُ الَّذِينَ بُعِثْتُ فِيهِمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ وَاللَّهُ أَعْلَمُ أَذَكَرَ الثَّالِثَ أَمْ لاَ قَالَ ‏"‏ ثُمَّ يَخْلُفُ قَوْمٌ يُحِبُّونَ السَّمَانَةَ يَشْهَدُونَ قَبْلَ أَنْ يُسْتَشْهَدُوا ‏"‏ ‏.‏\hadithno{6473}\hadithtrans{Abu Huraira reported Allah's Messenger (may, peace be upon him) as saying:The best age of my Umma is one in which I was sent (by Allah as an Apostle), then the one next to that. (The narrator said): And Allah knows best whether he stated this third (time) or not. Then there would come people who would love (to look) bulky and they would hasten to the witness box before they are asked to bear witness}}
\hadithdefcmd{muslim}{6474}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا أَبُو عَوَانَةَ، كِلاَهُمَا عَنْ أَبِي بِشْرٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ شُعْبَةَ قَالَ أَبُو هُرَيْرَةَ فَلاَ أَدْرِي مَرَّتَيْنِ أَوْ ثَلاَثَةً ‏.‏\hadithno{6474}\hadithtrans{This hadith has been reported on the authority of Abu Huraira through another chain of transmitters (but with this variation) that Abu Huraira said:I do not know whether he (the Holy Prophet) said (these words:" Then next" ) twice or thrice}}
\hadithdefcmd{muslim}{6475}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ غُنْدَرٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ أَبَا جَمْرَةَ، حَدَّثَنِي زَهْدَمُ بْنُ، مُضَرِّبٍ سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ خَيْرَكُمْ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ قَالَ عِمْرَانُ فَلاَ أَدْرِي أَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ قَرْنِهِ مَرَّتَيْنِ أَوْ ثَلاَثَةً ‏"‏ ثُمَّ يَكُونُ بَعْدَهُمْ قَوْمٌ يَشْهَدُونَ وَلاَ يُسْتَشْهَدُونَ وَيَخُونُونَ وَلاَ يُتَّمَنُونَ وَيَنْذُرُونَ وَلاَ يُوفُونَ وَيَظْهَرُ فِيهِمُ السِّمَنُ ‏"‏ ‏.‏\hadithno{6475}\hadithtrans{Imran b. Husain reported Allah's-Messenger (ﷺ) as saying:The best among you (are) the people (who belong to) my age. Then those next to them, then those next to them, then those next to them. 'Imran said: I do not know whether Allah's Messenger (ﷺ) said twice or thrice (the words:" Then next" ) after (saying) about his (own age but he then said): Then after them (after successors or those who would succeed them) would come a people who would give evidence before they are asked for it, and would be dishonest and not trustworthy, who would make vows but would not fulfil them, and would be significant in being bulky}}
\hadithdefcmd{muslim}{6476}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، الْعَبْدِيُّ حَدَّثَنَا بَهْزٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا شَبَابَةُ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمْ قَالَ لاَ أَدْرِي أَذَكَرَ بَعْدَ قَرْنِهِ قَرْنَيْنِ أَوْ ثَلاَثَةً ‏.‏ وَفِي حَدِيثِ شَبَابَةَ قَالَ سَمِعْتُ زَهْدَمَ بْنَ مُضَرِّبٍ وَجَاءَنِي فِي حَاجَةٍ عَلَى فَرَسٍ فَحَدَّثَنِي أَنَّهُ سَمِعَ عِمْرَانَ بْنَ حُصَيْنٍ ‏.‏ وَفِي حَدِيثِ يَحْيَى وَشَبَابَةَ ‏"‏ يَنْذُرُونَ وَلاَ يَفُونَ ‏"‏ ‏.‏ وَفِي حَدِيثِ بَهْزٍ ‏"‏ يُوفُونَ ‏"‏ ‏.‏ كَمَا قَالَ ابْنُ جَعْفَرٍ ‏.‏\hadithno{6476}\hadithtrans{This hadith has been reported on the authority of Shu'ba with the same chain of transmitters (and the words are):I do not know whether he made a mention of two generations after his generation or of the third one too. Shababa said: I heard this from Zahdam b. Mudarrib as he came to me riding a horse for some need and he narrated it to me that he had heard it from 'Imran b. Husain, and in the hadith transmitted on the authority of Yahya and Shababa (the words are): They take an oath but they do not fulfil it, and in the hadith transmitted on the authority of Bahz there the word is Yafun as transmitted on the authority of Ibn Ja'far}}
\hadithdefcmd{muslim}{6477}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الأُمَوِيُّ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي كِلاَهُمَا، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏"‏ خَيْرُ هَذِهِ الأُمَّةِ الْقَرْنُ الَّذِينَ بُعِثْتُ فِيهِمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ زَادَ فِي حَدِيثِ أَبِي عَوَانَةَ قَالَ وَاللَّهُ أَعْلَمُ أَذَكَرَ الثَّالِثَ أَمْ لاَ ‏.‏ بِمِثْلِ حَدِيثِ زَهْدَمٍ عَنْ عِمْرَانَ وَزَادَ فِي حَدِيثِ هِشَامٍ عَنْ قَتَادَةَ ‏"‏ وَيَحْلِفُونَ وَلاَ يُسْتَحْلَفُونَ ‏"‏ ‏.‏\hadithno{6477}\hadithtrans{This hadith has been narrated on the authority of 'Imran b. Husain through another chain of transmitters (and the words are):The best generation of this Umma is the generation to which I have been sent, then the next one, and there is an addition in the hadith transmitted on the authority of Abu 'Awana (and the words are): And Allah knows best whether he made a mention of the third (generation) or not; the rest of the hadith is the same as transmitted by Zahdam on the authority of 'Imran. And in the hadith transmitted by Hisham on the authority of Qatada there is an addition of these words: They take an oath whereas they are not asked to take}}
\hadithdefcmd{muslim}{6478}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَشُجَاعُ بْنُ مَخْلَدٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا حُسَيْنٌ، - وَهُوَ ابْنُ عَلِيٍّ الْجُعْفِيُّ - عَنْ زَائِدَةَ، عَنِ السُّدِّيِّ، عَنْ عَبْدِ اللَّهِ الْبَهِيِّ، عَنْ عَائِشَةَ، قَالَتْ سَأَلَ رَجُلٌ النَّبِيَّ صلى الله عليه وسلم أَىُّ النَّاسِ خَيْرٌ قَالَ ‏ "‏ الْقَرْنُ الَّذِي أَنَا فِيهِ ثُمَّ الثَّانِي ثُمَّ الثَّالِثُ ‏"‏ ‏.‏\hadithno{6478}\hadithtrans{A'isha reported that a person asked Allah's Apostle (ﷺ) as to who amongst the people were the best. He said:Of the generation to which I belong, then of the second generation (generation adjacent to my generation), then of the third generation (generation adjacent to the second generation)}}
\hadithdefcmd{muslim}{6479}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ مُحَمَّدُ بْنُ رَافِعٍ حَدَّثَنَا وَقَالَ عَبْدٌ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، وَأَبُو بَكْرِ بْنُ سُلَيْمَانَ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ صَلاَةَ الْعِشَاءِ فِي آخِرِ حَيَاتِهِ فَلَمَّا سَلَّمَ قَامَ فَقَالَ ‏ "‏ أَرَأَيْتَكُمْ لَيْلَتَكُمْ هَذِهِ فَإِنَّ عَلَى رَأْسِ مِائَةِ سَنَةٍ مِنْهَا لاَ يَبْقَى مِمَّنْ هُوَ عَلَى ظَهْرِ الأَرْضِ أَحَدٌ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ فَوَهَلَ النَّاسُ فِي مَقَالَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم تِلْكَ فِيمَا يَتَحَدَّثُونَ مِنْ هَذِهِ الأَحَادِيثِ عَنْ مِائَةِ سَنَةٍ وَإِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَبْقَى مِمَّنْ هُوَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ ‏.‏ أَحَدٌ يُرِيدُ بِذَلِكَ أَنْ يَنْخَرِمَ ذَلِكَ الْقَرْنُ ‏.‏\hadithno{6479}\hadithtrans{Abdullah b. Umar reported that Allah's Messenger (ﷺ) led us 'Isha' prayer at the latter part of the night and when he had concluded it by salutations he stood up and said:Have you seen this night of yours? At the end of one hundred years after this none would survive on the surface of the earth (from amount my Companions). Ibn Umar said: People were (not understanding) these words of the Messenger of Allah (ﷺ) which had been uttered pertaining to one hundred years. Allah's Messenger (ﷺ) in fact meant (by these words) that on that day none from amongst those who had been living upon the earth (from amongst his Companions) would survive (after one hundred years) and that would be the end of this generation}}
\hadithdefcmd{muslim}{6480}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، وَرَوَاهُ، اللَّيْثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ خَالِدِ بْنِ مُسَافِرٍ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِإِسْنَادِ مَعْمَرٍ كَمِثْلِ حَدِيثِهِ ‏.‏\hadithno{6480}\hadithtrans{This hadith has been transmitted by Zuhri on the authority of Ma'mar}}
\hadithdefcmd{muslim}{6481}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ قَبْلَ أَنْ يَمُوتَ بِشَهْرٍ ‏ "‏ تَسْأَلُونِي عَنِ السَّاعَةِ وَإِنَّمَا عِلْمُهَا عِنْدَ اللَّهِ وَأُقْسِمُ بِاللَّهِ مَا عَلَى الأَرْضِ مِنْ نَفْسٍ مَنْفُوسَةٍ تَأْتِي عَلَيْهَا مِائَةُ سَنَةٍ ‏"‏ ‏.‏\hadithno{6481}\hadithtrans{Jabir b. 'Abdullah reported:I heard Allah's Messenger (ﷺ) as saying this one month before his death: You asked me about the Last Hour whereas its knowledge is with Allah. I, however, take an oath and say that none upon the earth, the created beings (from amongst my Companions), would survive at the end of one hundred years}}
\hadithdefcmd{muslim}{6482}{حَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ قَبْلَ مَوْتِهِ بِشَهْرٍ ‏.‏\hadithno{6482}\hadithtrans{This hadith has been narrated on the authority of Ibn Juraij with the same chain of transmitters, but there is no mention of the words:" one month before his death}}
\hadithdefcmd{muslim}{6483}{حَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، كِلاَهُمَا عَنِ الْمُعْتَمِرِ، قَالَ ابْنُ حَبِيبٍ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ذَلِكَ قَبْلَ مَوْتِهِ بِشَهْرٍ أَوْ نَحْوِ ذَلِكَ ‏ "‏ مَا مِنْ نَفْسٍ مَنْفُوسَةٍ الْيَوْمَ تَأْتِي عَلَيْهَا مِائَةُ سَنَةٍ وَهْىَ حَيَّةٌ يَوْمَئِذٍ ‏"‏ ‏.‏ وَعَنْ عَبْدِ الرَّحْمَنِ، صَاحِبِ السِّقَايَةِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ ذَلِكَ وَفَسَّرَهَا عَبْدُ الرَّحْمَنِ قَالَ نَقْصُ الْعُمُرِ ‏.‏\hadithno{6483}\hadithtrans{Jabir b. 'Abdullah reported Allah's Apostle (ﷺ) as saying one mouth before his death (or something like it):None amongst the created beings who had been living by that time (during the lifetime of Allah's Apostle).... 'Abd al-Rahman has interpreted these words of Allah's Apostle (ﷺ) as: The ages (of the people) would be diminished}}
\hadithdefcmd{muslim}{6484}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، بِالإِسْنَادَيْنِ جَمِيعًا ‏.‏ مِثْلَهُ ‏.‏\hadithno{6484}\hadithtrans{This hadith has been reported on the authority of Sulaiman Taimi through other chains of transmitters}}
\hadithdefcmd{muslim}{6485}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ، عَنْ دَاوُدَ، وَاللَّفْظُ، لَهُ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَيَّانَ، عَنْ دَاوُدَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ لَمَا رَجَعَ النَّبِيُّ صلى الله عليه وسلم مِنْ تَبُوكَ سَأَلُوهُ عَنِ السَّاعَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَأْتِي مِائَةُ سَنَةٍ وَعَلَى الأَرْضِ نَفْسٌ مَنْفُوسَةٌ الْيَوْمَ ‏"‏ ‏.‏\hadithno{6485}\hadithtrans{Abu Sa'id reported that when Allah's Apostle (ﷺ) came back from Tabuk they (his Companions) asked about the Last Hour. Thereupon Allah's Messenger (ﷺ) said:There would be none amongst the created beings living on the earth (who would survive this century)}}
\hadithdefcmd{muslim}{6486}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو الْوَلِيدِ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنٍ، عَنْ سَالِمٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ نَفْسٍ مَنْفُوسَةٍ تَبْلُغُ مِائَةَ سَنَةٍ ‏"‏ ‏.‏ فَقَالَ سَالِمٌ تَذَاكَرْنَا ذَلِكَ عِنْدَهُ إِنَّمَا هِيَ كُلُّ نَفْسٍ مَخْلُوقَةٍ يَوْمَئِذٍ ‏.‏\hadithno{6486}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messenger (ﷺ) said:None amongst the created beings (from my Companions) would survive after one hundred years. Salim said: We made a mention of it to him (Jabir), whereupon he said: It means those who had been living on that day}}
\hadithdefcmd{muslim}{6487}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ الْعَلاَءِ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا أَصْحَابِي لاَ تَسُبُّوا أَصْحَابِي فَوَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنَّ أَحَدَكُمْ أَنْفَقَ مِثْلَ أُحُدٍ ذَهَبًا مَا أَدْرَكَ مُدَّ أَحَدِهِمْ وَلاَ نَصِيفَهُ ‏"‏ ‏.‏\hadithno{6487}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Do not revile my Companions, do not revile my Companions. By Him in Whose Hand is my life, if one amongst you would have spent as much gold as Uhud it would not amount to as much as one much on behalf of one of them or half of it}}
\hadithdefcmd{muslim}{6488}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي، سَعِيدٍ قَالَ كَانَ بَيْنَ خَالِدِ بْنِ الْوَلِيدِ وَبَيْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ شَىْءٌ فَسَبَّهُ خَالِدٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا أَحَدًا مِنْ أَصْحَابِي فَإِنَّ أَحَدَكُمْ لَوْ أَنْفَقَ مِثْلَ أُحُدٍ ذَهَبًا مَا أَدْرَكَ مُدَّ أَحَدِهِمْ وَلاَ نَصِيفَهُ ‏"‏ ‏.‏\hadithno{6488}\hadithtrans{Abu Sa'id reported there was some altercation between Khalid b. Walid and Abd al-Rahman b. 'Auf and Khalid reviled him. Thereupon Allah's Messwger (ﷺ) said:None should revile my Companions. for if one amongst you were to spend as much gold as Uhud, it would not amount to as much as one mudd of one of them or half of it}}
\hadithdefcmd{muslim}{6489}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، جَمِيعًا عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، بِإِسْنَادِ جَرِيرٍ وَأَبِي مُعَاوِيَةَ ‏.‏ بِمِثْلِ حَدِيثِهِمَا وَلَيْسَ فِي حَدِيثِ شُعْبَةَ وَوَكِيعٍ ذِكْرُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَخَالِدِ بْنِ الْوَلِيدِ ‏.‏\hadithno{6489}\hadithtrans{This hadith has been transmitted on the authority of al-A'mash and there is no mention by Shu'ba and Waki' of 'Abd al-Rahman b. Auf and Khalid}}
\hadithdefcmd{muslim}{6490}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنِي سَعِيدٌ الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أُسَيْرِ بْنِ جَابِرٍ، أَنَّ أَهْلَ الْكُوفَةِ، وَفَدُوا، إِلَى عُمَرَ وَفِيهِمْ رَجُلٌ مِمَّنْ كَانَ يَسْخَرُ بِأُوَيْسٍ فَقَالَ عُمَرُ هَلْ هَا هُنَا أَحَدٌ مِنَ الْقَرَنِيِّينَ فَجَاءَ ذَلِكَ الرَّجُلُ فَقَالَ عُمَرُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ قَالَ ‏ "‏ إِنَّ رَجُلاً يَأْتِيكُمْ مِنَ الْيَمَنِ يُقَالُ لَهُ أُوَيْسٌ لاَ يَدَعُ بِالْيَمَنِ غَيْرَ أُمٍّ لَهُ قَدْ كَانَ بِهِ بَيَاضٌ فَدَعَا اللَّهَ فَأَذْهَبَهُ عَنْهُ إِلاَّ مَوْضِعَ الدِّينَارِ أَوِ الدِّرْهَمِ فَمَنْ لَقِيَهُ مِنْكُمْ فَلْيَسْتَغْفِرْ لَكُمْ ‏"‏ ‏.‏\hadithno{6490}\hadithtrans{Usair b. Jabir reported that a delegation from Kufa came to 'Umar and there was a person amongst them who jeered at Uwais. Thereupon Umar said:Is there amongst us one from Qaran? That person came and Umar said: Verily Allah's Messenger (ﷺ) has said: There would come to you a person from Yemen who would be called Uwais and he would leave none in Yemen (behind him) except his mother, and he would have the whiteness (due to leprosy) and he supplicated Allah and it was cured except for the size of a dinar or dirham. He who amongst you meets him should ask him to supplicate for forgiveness (from Allah) for you}}
\hadithdefcmd{muslim}{6491}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ سَلَمَةَ - عَنْ سَعِيدٍ الْجُرَيْرِيِّ، بِهَذَا الإِسْنَادِ عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ خَيْرَ التَّابِعِينَ رَجُلٌ يُقَالُ لَهُ أُوَيْسٌ وَلَهُ وَالِدَةٌ وَكَانَ بِهِ بَيَاضٌ فَمُرُوهُ فَلْيَسْتَغْفِرْ لَكُمْ ‏"‏ ‏.‏\hadithno{6491}\hadithtrans{Umar b. Khattab reported:I heard Allah's Messenger (ﷺ) as saying: Worthy amongst the successors would be a person who would be called Uwais. He would have his mother (living with him) and he would have (a small) sign of leprosy. Ask him to beg pardon for you (from Allah)}}
\hadithdefcmd{muslim}{6492}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا - وَاللَّفْظُ، لاِبْنِ الْمُثَنَّى - حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أُسَيْرِ بْنِ جَابِرٍ، قَالَ كَانَ عُمَرُ بْنُ الْخَطَّابِ إِذَا أَتَى عَلَيْهِ أَمْدَادُ أَهْلِ الْيَمَنِ سَأَلَهُمْ أَفِيكُمْ أُوَيْسُ بْنُ عَامِرٍ حَتَّى أَتَى عَلَى أُوَيْسٍ فَقَالَ أَنْتَ أُوَيْسُ بْنُ عَامِرٍ قَالَ نَعَمْ ‏.‏ قَالَ مِنْ مُرَادٍ ثُمَّ مِنْ قَرَنٍ قَالَ نَعَمْ ‏.‏ قَالَ فَكَانَ بِكَ بَرَصٌ فَبَرَأْتَ مِنْهُ إِلاَّ مَوْضِعَ دِرْهَمٍ قَالَ نَعَمْ ‏.‏ قَالَ لَكَ وَالِدَةٌ قَالَ نَعَمْ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ يَأْتِي عَلَيْكُمْ أُوَيْسُ بْنُ عَامِرٍ مَعَ أَمْدَادِ أَهْلِ الْيَمَنِ مِنْ مُرَادٍ ثُمَّ مِنْ قَرَنٍ كَانَ بِهِ بَرَصٌ فَبَرَأَ مِنْهُ إِلاَّ مَوْضِعَ دِرْهَمٍ لَهُ وَالِدَةٌ هُوَ بِهَا بَرٌّ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ فَإِنِ اسْتَطَعْتَ أَنْ يَسْتَغْفِرَ لَكَ فَافْعَلْ ‏"‏ ‏.‏ فَاسْتَغْفِرْ لِي ‏.‏ فَاسْتَغْفَرَ لَهُ ‏.‏ فَقَالَ لَهُ عُمَرُ أَيْنَ تُرِيدُ قَالَ الْكُوفَةَ ‏.‏ قَالَ أَلاَ أَكْتُبُ لَكَ إِلَى عَامِلِهَا قَالَ أَكُونُ فِي غَبْرَاءِ النَّاسِ أَحَبُّ إِلَىَّ ‏.‏ قَالَ فَلَمَّا كَانَ مِنَ الْعَامِ الْمُقْبِلِ حَجَّ رَجُلٌ مِنْ أَشْرَافِهِمْ فَوَافَقَ عُمَرَ فَسَأَلَهُ عَنْ أُوَيْسٍ قَالَ تَرَكْتُهُ رَثَّ الْبَيْتِ قَلِيلَ الْمَتَاعِ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ يَأْتِي عَلَيْكُمْ أُوَيْسُ بْنُ عَامِرٍ مَعَ أَمْدَادِ أَهْلِ الْيَمَنِ مِنْ مُرَادٍ ثُمَّ مِنْ قَرَنٍ كَانَ بِهِ بَرَصٌ فَبَرَأَ مِنْهُ إِلاَّ مَوْضِعَ دِرْهَمٍ لَهُ وَالِدَةٌ هُوَ بِهَا بَرٌّ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ فَإِنِ اسْتَطَعْتَ أَنْ يَسْتَغْفِرَ لَكَ فَافْعَلْ ‏"‏ ‏.‏ فَأَتَى أُوَيْسًا فَقَالَ اسْتَغْفِرْ لِي ‏.‏ قَالَ أَنْتَ أَحْدَثُ عَهْدًا بِسَفَرٍ صَالِحٍ فَاسْتَغْفِرْ لِي ‏.‏ قَالَ اسْتَغْفِرْ لِي ‏.‏ قَالَ أَنْتَ أَحْدَثُ عَهْدًا بِسَفَرٍ صَالِحٍ فَاسْتَغْفِرْ لِي ‏.‏ قَالَ لَقِيتَ عُمَرَ قَالَ نَعَمْ ‏.‏ فَاسْتَغْفَرَ لَهُ ‏.‏ فَفَطِنَ لَهُ النَّاسُ فَانْطَلَقَ عَلَى وَجْهِهِ ‏.‏ قَالَ أُسَيْرٌ وَكَسَوْتُهُ بُرْدَةً فَكَانَ كُلَّمَا رَآهُ إِنْسَانٌ قَالَ مِنْ أَيْنَ لأُوَيْسٍ هَذِهِ الْبُرْدَةُ\hadithno{6492}\hadithtrans{Usair b. Jabir reported that when people from Yemen came to help (the Muslim army at the time of jihad) he asked them:Is there amongst you Uwais b. 'Amir? (He continued finding him out) until he met Uwais. He said: Are you Uwais b., Amir? He said: Yes. He said: Are you from the tribe of Qaran? He said: Yes. He (Hadrat) 'Umar (again) said: Did you suffer from leprosy and then you were cured from it but for the space of a dirham? He said: Yes. He ('Umar) said: Is your mother (living)? He said: Yes. He ('Umar) said: I heard Allah's Messenger (ﷺ) say: There would come to you Uwais b. Amir with the reinforcement from the people of Yemen. (He would be) from Qaran, (the branch) of Murid. He had been suffering from leprosy from which he was cured but for a spot of a dirham. His treatment with his mother would have been excellent. If he were to take an oath in the name of Allah, He would honour that. And if it is possible for you, then do ask him to beg forgiveness for you (from your Lord). So he (Uwais) begged forgiveness for him. Umar said: Where do you intend to go? He said: To Kufa. He ('Umar) said: Let me write a letter for you to its governor, whereupon he (Uwais) said: I love to live amongst the poor people. When it was the next year, a person from among the elite (of Kufa) performed Hajj and he met Umar. He asked him about Uwais. He said: I left him in a state with meagre means of sustenance. (Thereupon) Umar said: I heard Allah's Messenger (ﷺ) as saying: There would come to you Uwais b. 'Amir, of Qaran, a branch (of the tribe) of Murid, along with the reinforcement of the people of Yemen. He had been suffering from leprosy which would have been cured but for the space of a dirham. His treatment with his mother would have been very kind. If he would take an oath in the name of Allah (for something) He would honour it. Ask him to beg forgiveness for you (from Allah) in case it is possible for you. So he came to Uwais and said.: Beg forgiveness (from Allah) for me. He (Uwais) said: You have just come from a sacred journey (Hajj) ; you, therefore, ask forgiveness for me. He (the person who had performed Hajj) said: Ask forgiveness for me (from Allah). He (Uwais again) said: You have just come from the sacred journey, so you ask forgiveness for me. (Uwais further) said: Did you meet Umar? He said: Yes. He (Uwais) then begged forgiveness for him (from Allah). So the people came to know about (the status of religious piety) of Uwais. He went away (from that place). Usair said: His clothing consisted of a mantle, and whosoever saw him said: From where did Uwais get this mantle?}}
\hadithdefcmd{muslim}{6493}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي حَرْمَلَةُ، ح وَحَدَّثَنِي هَارُونُ بْنُ، سَعِيدٍ الأَيْلِيُّ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي حَرْمَلَةُ، - وَهُوَ ابْنُ عِمْرَانَ التُّجِيبِيُّ - عَنْ عَبْدِ الرَّحْمَنِ، بْنِ شُمَاسَةَ الْمَهْرِيِّ قَالَ سَمِعْتُ أَبَا ذَرٍّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ سَتَفْتَحُونَ أَرْضًا يُذْكَرُ فِيهَا الْقِيرَاطُ فَاسْتَوْصُوا بِأَهْلِهَا خَيْرًا فَإِنَّ لَهُمْ ذِمَّةً وَرَحِمًا فَإِذَا رَأَيْتُمْ رَجُلَيْنِ يَقْتَتِلاَنِ فِي مَوْضِعِ لَبِنَةٍ فَاخْرُجْ مِنْهَا ‏"‏ ‏.‏ قَالَ فَمَرَّ بِرَبِيعَةَ وَعَبْدِ الرَّحْمَنِ ابْنَىْ شُرَحْبِيلَ بْنِ حَسَنَةَ يَتَنَازَعَانِ فِي مَوْضِعِ لَبِنَةٍ فَخَرَجَ مِنْهَا ‏.‏\hadithno{6493}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying:You would soon conquer a land where people are in the habit of using foul language. They have a right of kinship upon you. And when you see two persons fighting for the space of a brick, then get out of that. He (Abu Dharr) then happened to pass by Rabila and 'Abd al-Rahman, the two sons of Shurahbil b. Hasana, and they had been disputing for the space of a brick. So he left the land}}
\hadithdefcmd{muslim}{6494}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، سَمِعْتُ حَرْمَلَةَ الْمِصْرِيَّ، يُحَدِّثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُمَاسَةَ، عَنْ أَبِي بَصْرَةَ، عَنْ أَبِي، ذَرٍّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُمْ سَتَفْتَحُونَ مِصْرَ وَهِيَ أَرْضٌ يُسَمَّى فِيهَا الْقِيرَاطُ فَإِذَا فَتَحْتُمُوهَا فَأَحْسِنُوا إِلَى أَهْلِهَا فَإِنَّ لَهُمْ ذِمَّةً وَرَحِمًا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ ذِمَّةً وَصِهْرًا فَإِذَا رَأَيْتَ رَجُلَيْنِ يَخْتَصِمَانِ فِيهَا فِي مَوْضِعِ لَبِنَةٍ فَاخْرُجْ مِنْهَا ‏"‏ ‏.‏ قَالَ فَرَأَيْتُ عَبْدَ الرَّحْمَنِ بْنَ شُرَحْبِيلَ بْنِ حَسَنَةَ وَأَخَاهُ رَبِيعَةَ يَخْتَصِمَانِ فِي مَوْضِعِ لَبِنَةٍ فَخَرَجْتُ مِنْهَا ‏.‏\hadithno{6494}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying:You would soon conquer Egypt and that is a land which is known (as the land of al-qirat). So when you conquer it, treat its inhabitants well. For there lies upon you the responsibility because of blood-tie or relationship of marriage (with them). And when you see two persons falling into dispute amongst themselves for the space of a brick, than get out of that. He (Abu Dharr) said: I saw Abd al-Rahman b. Shurahbil b. Hasana and his brother Rabi'a disputing with one another for the space of a brick. So I left that (land)}}
\hadithdefcmd{muslim}{6495}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، عَنْ أَبِي الْوَازِعِ، جَابِرِ بْنِ عَمْرٍو الرَّاسِبِيِّ سَمِعْتُ أَبَا بَرْزَةَ، يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً إِلَى حَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ فَسَبُّوهُ وَضَرَبُوهُ فَجَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ أَهْلَ عُمَانَ أَتَيْتَ مَا سَبُّوكَ وَلاَ ضَرَبُوكَ ‏"‏ ‏.‏\hadithno{6495}\hadithtrans{Abu Barza reported that Allah's Messenger (ﷺ) sent a person to a tribe amongst the tribes of Arabia. They reviled him and beat him. He came to Allah's Messenger (ﷺ) and narrated to him (the story of atrocities perpetrated upon him by the people of the tribe). Thereupon he (the Holy Prophet) said:If you were to come to the people of 'Uman, they would have neither reviled you nor beaten you}}
\hadithdefcmd{muslim}{6496}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ إِسْحَاقَ الْحَضْرَمِيَّ - أَخْبَرَنَا الأَسْوَدُ بْنُ شَيْبَانَ، عَنْ أَبِي نَوْفَلٍ، رَأَيْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ عَلَى عَقَبَةِ الْمَدِينَةِ - قَالَ - فَجَعَلَتْ قُرَيْشٌ تَمُرُّ عَلَيْهِ وَالنَّاسُ حَتَّى مَرَّ عَلَيْهِ عَبْدُ اللَّهِ بْنُ عُمَرَ فَوَقَفَ عَلَيْهِ فَقَالَ السَّلاَمُ عَلَيْكَ أَبَا خُبَيْبٍ السَّلاَمُ عَلَيْكَ أَبَا خُبَيْبٍ السَّلاَمُ عَلَيْكَ أَبَا خُبَيْبٍ أَمَا وَاللَّهِ لَقَدْ كُنْتُ أَنْهَاكَ عَنْ هَذَا أَمَا وَاللَّهِ لَقَدْ كُنْتُ أَنْهَاكَ عَنْ هَذَا أَمَا وَاللَّهِ لَقَدْ كُنْتُ أَنْهَاكَ عَنْ هَذَا أَمَا وَاللَّهِ إِنْ كُنْتَ مَا عَلِمْتُ صَوَّامًا قَوَّامًا وَصُولاً لِلرَّحِمِ أَمَا وَاللَّهِ لأُمَّةٌ أَنْتَ أَشَرُّهَا لأُمَّةٌ خَيْرٌ ‏.‏ ثُمَّ نَفَذَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَبَلَغَ الْحَجَّاجَ مَوْقِفُ عَبْدِ اللَّهِ وَقَوْلُهُ فَأَرْسَلَ إِلَيْهِ فَأُنْزِلَ عَنْ جِذْعِهِ فَأُلْقِيَ فِي قُبُورِ الْيَهُودِ ثُمَّ أَرْسَلَ إِلَى أُمِّهِ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ فَأَبَتْ أَنْ تَأْتِيَهُ فَأَعَادَ عَلَيْهَا الرَّسُولَ لَتَأْتِيَنِّي أَوْ لأَبْعَثَنَّ إِلَيْكِ مِنْ يَسْحَبُكِ بِقُرُونِكِ - قَالَ - فَأَبَتْ وَقَالَتْ وَاللَّهِ لاَ آتِيكَ حَتَّى تَبْعَثَ إِلَىَّ مَنْ يَسْحَبُنِي بِقُرُونِي - قَالَ - فَقَالَ أَرُونِي سِبْتَىَّ ‏.‏ فَأَخَذَ نَعْلَيْهِ ثُمَّ انْطَلَقَ يَتَوَذَّفُ حَتَّى دَخَلَ عَلَيْهَا فَقَالَ كَيْفَ رَأَيْتِنِي صَنَعْتُ بِعَدُوِّ اللَّهِ قَالَتْ رَأَيْتُكَ أَفْسَدْتَ عَلَيْهِ دُنْيَاهُ وَأَفْسَدَ عَلَيْكَ آخِرَتَكَ بَلَغَنِي أَنَّكَ تَقُولُ لَهُ يَا ابْنَ ذَاتِ النِّطَاقَيْنِ أَنَا وَاللَّهِ ذَاتُ النِّطَاقَيْنِ أَمَّا أَحَدُهُمَا فَكُنْتُ أَرْفَعُ بِهِ طَعَامَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَطَعَامَ أَبِي بَكْرٍ مِنَ الدَّوَابِّ وَأَمَّا الآخَرُ فَنِطَاقُ الْمَرْأَةِ الَّتِي لاَ تَسْتَغْنِي عَنْهُ أَمَا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَدَّثَنَا ‏ "‏ أَنَّ فِي ثَقِيفٍ كَذَّابًا وَمُبِيرًا ‏"‏ ‏.‏ فَأَمَّا الْكَذَّابُ فَرَأَيْنَاهُ وَأَمَّا الْمُبِيرُ فَلاَ إِخَالُكَ إِلاَّ إِيَّاهُ - قَالَ - فَقَامَ عَنْهَا وَلَمْ يُرَاجِعْهَا ‏.‏\hadithno{6496}\hadithtrans{Abu Naufal reported:I saw (the dead body) of Abdullah b. Zubair hanging on the road of Medina (leading to Mecca). The Quraish passed by it and other people too, that Abdullah b. Umar happened to pass by it. He stood up there and said: May there be peace upon you, Abu Khubaib (the Kunya of Hadrat 'Abdullah b. Zubair), may there be peace upon you Abu Khubaib, may there be peace upon you, Abu Khubaib! By Allah, I used to forbid you from this; by Allah, I used to forbid you from this, by Allah I used to forbid you from this. By Allah, so far as I know, you had been very much devoted to fasting and prayer and you had been paying very much care to cementing the ties of blood. By Allah, the group to which you belong (are labelled) as (a) wicked (person) is indeed a fine group. Then 'Abdullah b. 'Umar went away. The stand 'Abdullah (b. 'Umar) took in regard to the inhuman treatment (meted out to 'Abdullah b. Zubair) and his words (in that connection) were conveyed to Hajjaj (b. Yusuf) and (as a consequence of that) he (the body of Abdullah b. Zubair) was brought down from the stump (the scaffold) by which it was hanging and thrown into the graves of the Jews. He (Hajjaj) sent (his messenger) to Asma' (bint Abu Bakr, 'Abdullah's mother). But she refused to come. He again sent the messenger to her with the message that she must come, otherwise he would bring her forcibly catching hold of her hair. But she again refused and said: By Allah, I will not come to you until you send one to me who would drag me by pulling my hair. Thereupon he said: Bring me my shoes. He put on his shoes and walked on quickly swollen with vanity and pride until he came to her and said: How do you find what I have done with the enemy of Allah? She said: I find that you wronged him in this world, whereas he has spoiled your next life. It has been conveyed to me that you used to call him ('Abdullah b. Zubair) as the son of one having two belts. By Allah, I am indeed (a woman) of two belts. One is that with the help of which I used to suspend high the food of Allah's Messenger (ﷺ) and that of Abu Bakr (making it out of the reach) of animals and, so far as the second belt is concerned, that is the belt which no woman can dispense with. Verily Allah's Messenger (ﷺ) told us that in Thaqif, there would be born a great liar and great murderer. The liar we have seen, and as far as the murderer is concerned, I do not find anyone else besides you. 'Thereupon he (Hajjaj) stood up and did not give any reply to her}}
\hadithdefcmd{muslim}{6497}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ جَعْفَرٍ الْجَزَرِيِّ، عَنِ يَزِيدَ بْنِ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ الدِّينُ عِنْدَ الثُّرَيَّا لَذَهَبَ بِهِ رَجُلٌ مِنْ فَارِسَ - أَوْ قَالَ مِنْ أَبْنَاءِ فَارِسَ - حَتَّى يَتَنَاوَلَهُ ‏"‏ ‏.‏\hadithno{6497}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If the din were at the Pleiades, even then a person from Persia would have taken hold of it, or one amongst the Persian descent would have surely found it}}
\hadithdefcmd{muslim}{6498}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ ثَوْرٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنَّا جُلُوسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ نَزَلَتْ عَلَيْهِ سُورَةُ الْجُمُعَةِ فَلَمَّا قَرَأَ ‏\{‏ وَآخَرِينَ مِنْهُمْ لَمَّا يَلْحَقُوا بِهِمْ‏\}‏ قَالَ رَجُلٌ مَنْ هَؤُلاَءِ يَا رَسُولَ اللَّهِ فَلَمْ يُرَاجِعْهُ النَّبِيُّ صلى الله عليه وسلم حَتَّى سَأَلَهُ مَرَّةً أَوْ مَرَّتَيْنِ أَوْ ثَلاَثًا - قَالَ - وَفِينَا سَلْمَانُ الْفَارِسِيُّ - قَالَ - فَوَضَعَ النَّبِيُّ صلى الله عليه وسلم يَدَهُ عَلَى سَلْمَانَ ثُمَّ قَالَ ‏"‏ لَوْ كَانَ الإِيمَانُ عِنْدَ الثُّرَيَّا لَنَالَهُ رِجَالٌ مِنْ هَؤُلاَءِ ‏"‏ ‏.‏\hadithno{6498}\hadithtrans{Abu Huraira reported:We were sitting in the company of Allah's Apostle (ﷺ) that Sura al-Jumu'a was revealed to him and when he recited (these words):" Others from amongst them who have not yet joined them," a person amongst them (those who were sitting there) said: Allah's Messenger! But Allah's Apostle (ﷺ) made no reply, until he questioned him once, twice or thrice. And there was amongst us Salman the Persian. The Apostle of Allah (ﷺ) placed his hand on Salman and then said: Even if faith were near the Pleiades, a man from amongst these would surely find it}}
\hadithdefcmd{muslim}{6499}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لِمُحَمَّدٍ - قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ، ابْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَجِدُونَ النَّاسَ كَإِبِلٍ مِائَةٍ لاَ يَجِدُ الرَّجُلُ فِيهَا رَاحِلَةً ‏"‏ ‏.‏\hadithno{6499}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:You would find people like one hundred camels and you would not find even one (camel) fit for riding}}
