% Auto-generated chapter 15 for abudawud
% Hadiths in this chapter: 311

\hadithdefcmd{abudawud}{2477}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، حَدَّثَنَا الْوَلِيدُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ أَعْرَابِيًّا، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ الْهِجْرَةِ فَقَالَ ‏"‏ وَيْحَكَ إِنَّ شَأْنَ الْهِجْرَةِ شَدِيدٌ فَهَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَهَلْ تُؤَدِّي صَدَقَتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاعْمَلْ مِنْ وَرَاءِ الْبِحَارِ فَإِنَّ اللَّهَ لَنْ يَتِرَكَ مِنْ عَمَلِكَ شَيْئًا ‏"‏ ‏.‏\hadithno{2477}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6165) Sahih Muslim (1865)}\hadithtrans{Abu Sa’id Al Khudri said “A Bedouin asked the Prophet (ﷺ) about emigration. He replied “Woe to you! The matter of emigration is severe. Have you a Camel? He said, Yes. He asked “Do you pay its zakat? He said, Yes. He said, Then work (anywhere) beyond the seas. Allaah will not reduce anything from (the reward of) your work}}
\hadithdefcmd{abudawud}{2478}{حَدَّثَنَا أَبُو بَكْرٍ، وَعُثْمَانُ، ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا شَرِيكٌ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنِ الْبَدَاوَةِ، فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَبْدُو إِلَى هَذِهِ التِّلاَعِ وَإِنَّهُ أَرَادَ الْبَدَاوَةَ مَرَّةً فَأَرْسَلَ إِلَىَّ نَاقَةً مُحَرَّمَةً مِنْ إِبِلِ الصَّدَقَةِ فَقَالَ لِي ‏ "‏ يَا عَائِشَةُ ارْفُقِي فَإِنَّ الرِّفْقَ لَمْ يَكُنْ فِي شَىْءٍ قَطُّ إِلاَّ زَانَهُ وَلاَ نُزِعَ مِنْ شَىْءٍ قَطُّ إِلاَّ شَانَهُ ‏"‏ ‏.‏\hadithno{2478}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Miqdan bin Shuraih reported on the authority of his father. I asked A’ishah about settling in the desert (to worship Allaah in loneliness). She said “The Apostle of Allaah(ﷺ) would go out (from Madina) to these torrential streams. Once he intended to go out to the desert (for worshipping Allaah). He sent me a She-Camel from the Camels of sadaqah that was not used as a mount. He said to me “A’ishah be lenient, for leniency makes a thing decorated and when it is removed from a thing it makes it defective}}
\hadithdefcmd{abudawud}{2479}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، عَنْ حَرِيزِ بْنِ عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَوْفٍ، عَنْ أَبِي هِنْدٍ، عَنْ مُعَاوِيَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَنْقَطِعُ الْهِجْرَةُ حَتَّى تَنْقَطِعَ التَّوْبَةُ وَلاَ تَنْقَطِعُ التَّوْبَةُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا ‏"‏ ‏.‏\hadithno{2479}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Mu'awiyah: I heard the Messenger of Allah (ﷺ) say: Migration will not end until repentance ends, and repentance will not end until the sun rises in the west}}
\hadithdefcmd{abudawud}{2480}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ فَتْحِ مَكَّةَ ‏ "‏ لاَ هِجْرَةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏\hadithno{2480}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2018)}\hadithtrans{Ibn ‘Abbas reported that Apostle of Allah (ﷺ) as saying on the day of the conquest of Makkah:There is no emigration (after the conquest of Makkah), but only Jihad (striving in the path of Allah) and some intention. So when you are summoned to go forth (for Jihad), go forth}}
\hadithdefcmd{abudawud}{2481}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، حَدَّثَنَا عَامِرٌ، قَالَ أَتَى رَجُلٌ عَبْدَ اللَّهِ بْنَ عَمْرٍو وَعِنْدَهُ الْقَوْمُ حَتَّى جَلَسَ عِنْدَهُ فَقَالَ أَخْبِرْنِي بِشَىْءٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْمُسْلِمُ مَنْ سَلِمَ الْمُسْلِمُونَ مِنْ لِسَانِهِ وَيَدِهِ وَالْمُهَاجِرُ مَنْ هَجَرَ مَا نَهَى اللَّهُ عَنْهُ ‏"‏ ‏.‏\hadithno{2481}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (10)}\hadithtrans{‘Amir said “A man came to ‘Abd Allaah bin ‘Amr while the people were with him. He sat with him and said “Tell me anything that you heard from the Apostle of Allaah(ﷺ)”. He said “I hears the Apostle of Allaah(ﷺ) say “A Muslim is he from whose tongue and hand the Muslims remain safe and an emigrant is he who abandons what Allaah has prohibited.””}}
\hadithdefcmd{abudawud}{2482}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَتَكُونُ هِجْرَةٌ بَعْدَ هِجْرَةٍ فَخِيَارُ أَهْلِ الأَرْضِ أَلْزَمُهُمْ مُهَاجَرَ إِبْرَاهِيمَ وَيَبْقَى فِي الأَرْضِ شِرَارُ أَهْلِهَا تَلْفِظُهُمْ أَرَضُوهُمْ تَقْذَرُهُمْ نَفْسُ اللَّهِ وَتَحْشُرُهُمُ النَّارُ مَعَ الْقِرَدَةِ وَالْخَنَازِيرِ ‏"‏ ‏.‏\hadithno{2482}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{‘Abd Allaah bin ‘Amr said “ I heard the Apostle of Allaah(ﷺ) say “There will be emigration after emigration and the people who are best will be those who cleave most closely to places which Abraham migrated. The worst of its people will remain in the earth cast out by their lands, abhorred by Allaah, collected along with apes and swine by fire.””}}
\hadithdefcmd{abudawud}{2483}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحَضْرَمِيُّ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي بَحِيرٌ، عَنْ خَالِدٍ، - يَعْنِي ابْنَ مَعْدَانَ - عَنْ أَبِي قُتَيْلَةَ، عَنِ ابْنِ حَوَالَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَيَصِيرُ الأَمْرُ إِلَى أَنْ تَكُونُوا جُنُودًا مُجَنَّدَةً جُنْدٌ بِالشَّامِ وَجُنْدٌ بِالْيَمَنِ وَجُنْدٌ بِالْعِرَاقِ ‏"‏ ‏.‏ قَالَ ابْنُ حَوَالَةَ خِرْ لِي يَا رَسُولَ اللَّهِ إِنْ أَدْرَكْتُ ذَلِكَ ‏.‏ فَقَالَ ‏"‏ عَلَيْكَ بِالشَّامِ فَإِنَّهَا خِيَرَةُ اللَّهِ مِنْ أَرْضِهِ يَجْتَبِي إِلَيْهَا خِيَرَتَهُ مِنْ عِبَادِهِ فَأَمَّا إِنْ أَبَيْتُمْ فَعَلَيْكُمْ بِيَمَنِكُمْ وَاسْقُوا مِنْ غُدُرِكُمْ فَإِنَّ اللَّهَ تَوَكَّلَ لِي بِالشَّامِ وَأَهْلِهِ ‏"‏ ‏.‏\hadithno{2483}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn Hawalah: The Prophet (ﷺ) said: It will turn out that you will be armed troops, one is Syria, one in the Yemen and one in Iraq. Ibn Hawalah said: Choose for me, Messenger of Allah, if I reach that time. He replied: Go to Syria, for it is Allah's chosen land, to which his best servants will be gathered, but if you are unwilling, go to your Yemen, and draw water from your tanks, for Allah has on my account taken special charge of Syria and its people}}
\hadithdefcmd{abudawud}{2484}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي يُقَاتِلُونَ عَلَى الْحَقِّ ظَاهِرِينَ عَلَى مَنْ نَاوَأَهُمْ حَتَّى يُقَاتِلَ آخِرُهُمُ الْمَسِيحَ الدَّجَّالَ ‏"‏ ‏.‏\hadithno{2484}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Imran ibn Husayn: The Prophet (ﷺ) said: A section of my community will continue to fight for the right and overcome their opponents till the last of them fights with the Antichrist}}
\hadithdefcmd{abudawud}{2485}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ سُئِلَ أَىُّ الْمُؤْمِنِينَ أَكْمَلُ إِيمَانًا قَالَ ‏ "‏ رَجُلٌ يُجَاهِدُ فِي سَبِيلِ اللَّهِ بِنَفْسِهِ وَمَالِهِ وَرَجُلٌ يَعْبُدُ اللَّهَ فِي شِعْبٍ مِنَ الشِّعَابِ قَدْ كُفِيَ النَّاسُ شَرَّهُ ‏"‏ ‏.‏\hadithno{2485}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2886) Sahih Muslim (1888)}\hadithtrans{Abu Sa’id (Al Khudri) reported The Prophet(ﷺ) was asked “Which believers are most perfect in respect of faith? He replied “A man who strives in the path of Allaah with his life and property and a man who worships Allaah in a mountain valley where he protects the people from his evil.””}}
\hadithdefcmd{abudawud}{2486}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ التَّنُوخِيُّ أَبُو الْجَمَاهِرِ، حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، أَخْبَرَنِي الْعَلاَءُ بْنُ الْحَارِثِ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ ائْذَنْ لِي فِي السِّيَاحَةِ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ سِيَاحَةَ أُمَّتِي الْجِهَادُ فِي سَبِيلِ اللَّهِ تَعَالَى ‏"‏ ‏.‏\hadithno{2486}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuUmamah: A man said: Messenger of Allah, allow tourism for me. The Prophet (ﷺ) said: The tourism of my people is striving in the path of Allah, the Exalted}}
\hadithdefcmd{abudawud}{2487}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنَا حَيْوَةُ، عَنِ ابْنِ شُفَىٍّ، عَنْ شُفَىِّ بْنِ مَاتِعٍ، عَنْ عَبْدِ اللَّهِ، - هُوَ ابْنُ عَمْرٍو - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَفْلَةٌ كَغَزْوَةٍ ‏"‏ ‏.‏\hadithno{2487}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Returning home is like going on an expedition}}
\hadithdefcmd{abudawud}{2488}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنْ فَرَجِ بْنِ فَضَالَةَ، عَنْ عَبْدِ الْخَبِيرِ بْنِ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم يُقَالُ لَهَا أُمُّ خَلاَّدٍ وَهِيَ مُنْتَقِبَةٌ تَسْأَلُ عَنِ ابْنِهَا وَهُوَ مَقْتُولٌ فَقَالَ لَهَا بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم جِئْتِ تَسْأَلِينَ عَنِ ابْنِكِ وَأَنْتِ مُنْتَقِبَةٌ فَقَالَتْ إِنْ أُرْزَإِ ابْنِي فَلَنْ أُرْزَأَ حَيَائِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْنُكِ لَهُ أَجْرُ شَهِيدَيْنِ ‏"‏ ‏.‏ قَالَتْ وَلِمَ ذَاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لأَنَّهُ قَتَلَهُ أَهْلُ الْكِتَابِ ‏"‏ ‏.‏\hadithno{2488}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Thabit ibn Qays: A woman called Umm Khallad came to the Prophet (ﷺ) while she was veiled. She was searching for her son who had been killed (in the battle) Some of the Companions of the Prophet (ﷺ) said to her: You have come here asking for your son while veiling your face? She said: If I am afflicted with the loss of my son, I shall not suffer the loss of my modesty. The Messenger of Allah (ﷺ) said: You will get the reward of two martyrs for your son. She asked: Why is that so, Messenger of Allah? He replied: Because the people of the Book have killed him}}
\hadithdefcmd{abudawud}{2489}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنْ مُطَرِّفٍ، عَنْ بِشْرٍ أَبِي عَبْدِ اللَّهِ، عَنْ بَشِيرِ بْنِ مُسْلِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَرْكَبُ الْبَحْرَ إِلاَّ حَاجٌّ أَوْ مُعْتَمِرٌ أَوْ غَازٍ فِي سَبِيلِ اللَّهِ فَإِنَّ تَحْتَ الْبَحْرِ نَارًا وَتَحْتَ النَّارِ بَحْرًا ‏"‏ ‏.‏\hadithno{2489}\hadithgrade{Al-Albani: Mawdu; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: No one should sail on the sea except the one who is going to perform hajj or umrah, or the one who is fighting in Allah's path for under the sea there is a fire, and under the fire there is a sea}}
\hadithdefcmd{abudawud}{2490}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ حَدَّثَتْنِي أُمُّ حَرَامٍ بِنْتُ مِلْحَانَ، أُخْتُ أُمِّ سُلَيْمٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ عِنْدَهُمْ فَاسْتَيْقَظَ وَهُوَ يَضْحَكُ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَضْحَكَكَ قَالَ ‏"‏ رَأَيْتُ قَوْمًا مِمَّنْ يَرْكَبُ ظَهْرَ هَذَا الْبَحْرِ كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ ‏"‏ فَإِنَّكِ مِنْهُمْ ‏"‏ ‏.‏ قَالَتْ ثُمَّ نَامَ فَاسْتَيْقَظَ وَهُوَ يَضْحَكُ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَضْحَكَكَ فَقَالَ مِثْلَ مَقَالَتِهِ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ ‏.‏ قَالَ فَتَزَوَّجَهَا عُبَادَةُ بْنُ الصَّامِتِ فَغَزَا فِي الْبَحْرِ فَحَمَلَهَا مَعَهُ فَلَمَّا رَجَعَ قُرِّبَتْ لَهَا بَغْلَةٌ لِتَرْكَبَهَا فَصَرَعَتْهَا فَانْدَقَّتْ عُنُقُهَا فَمَاتَتْ ‏.‏\hadithno{2490}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2799، 2800) Sahih Muslim (1912)}\hadithtrans{Anas bin Malik (may Allaah be pleased with him) said “Umm Haram, daughter of Milhan, sister of Umm Sulaim, narrated to me that the Apostle of Allaah(ﷺ) took a mid day nap with them. He then awoke laughing. She said “I asked the Apostle of Allaah(ﷺ), what made you laugh?” He replied “I saw some people who ere sailing in the midst of the sea like kings on thrones. She said “I said the Apostle of Allaah(ﷺ) beseech Allaah that He may put me among them. He replied “You will be among them.” She said “He then slept and awoke laughing. She said “I asked the Apostle of Allaah(ﷺ), what made you laugh? He replied as he said in the first reply. She said “I said the Apostle of Allaah(ﷺ) beseech Allaah that HE may put me amongst them. He replied “You will be among the first. Then ‘Ubadah bin Al Samit married her and sailed on the sea on an expedition and took her with him. When he returned, a riding beast was brought near her to ride, but it threw her down. Her neck was broken and she died}}
\hadithdefcmd{abudawud}{2491}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَهَبَ إِلَى قُبَاءٍ يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ - وَكَانَتْ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ - فَدَخَلَ عَلَيْهَا يَوْمًا فَأَطْعَمَتْهُ وَجَلَسَتْ تَفْلِي رَأْسَهُ ‏.‏ وَسَاقَ هَذَا الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ وَمَاتَتْ بِنْتُ مِلْحَانَ بِقُبْرُصَ ‏.‏\hadithno{2491}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2788، 2789) Sahih Muslim (1912)}\hadithtrans{Anas bin Malik said “Whenever the Apostle of Allaah(ﷺ) went to Quba, he used to visit Umm Haram daughter of Milhan who was married to ‘Ubadah bin Al Samit. One day when he visited her she gave him food an sat clearing his head of lice. The narrator narrated the rest of the tradition. Abu Dawud said “Daughter of Milhan died in Cyprus”}}
\hadithdefcmd{abudawud}{2492}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ مَعْمَرٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أُخْتِ أُمِّ سُلَيْمٍ الرُّمَيْصَاءِ، قَالَتْ نَامَ النَّبِيُّ صلى الله عليه وسلم فَاسْتَيْقَظَ وَكَانَتْ تَغْسِلُ رَأْسَهَا فَاسْتَيْقَظَ وَهُوَ يَضْحَكُ فَقَالَتْ يَا رَسُولَ اللَّهِ أَتَضْحَكُ مِنْ رَأْسِي قَالَ ‏ "‏ لاَ ‏"‏ ‏.‏ وَسَاقَ هَذَا الْخَبَرَ يَزِيدُ وَيَنْقُصُ ‏.‏\hadithno{2492}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Umm Sulaim Al Rumaisa said “The Prophet(ﷺ) slept and awoke while she was washing her head.” He awoke laughing. She asked “Apostle of Allaah(ﷺ) are you laughing at my head?” He replied, No. She then narrated the rest of the tradition enlarging and reducing. Abu Dawud said:Al-Rumaisa was the foster sister of Umm Sulaim}}
\hadithdefcmd{abudawud}{2493}{حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارٍ الْعَيْشِيُّ، حَدَّثَنَا مَرْوَانُ، ح حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الرَّحِيمِ الْجَوْبَرِيُّ الدِّمَشْقِيُّ، - الْمَعْنَى - قَالَ حَدَّثَنَا مَرْوَانُ، أَخْبَرَنَا هِلاَلُ بْنُ مَيْمُونٍ الرَّمْلِيُّ، عَنْ يَعْلَى بْنِ شَدَّادٍ، عَنْ أُمِّ حَرَامٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْمَائِدُ فِي الْبَحْرِ الَّذِي يُصِيبُهُ الْقَىْءُ لَهُ أَجْرُ شَهِيدٍ وَالْغَرِقُ لَهُ أَجْرُ شَهِيدَيْنِ ‏"‏ ‏.‏\hadithno{2493}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umm Haram reported the Prophet(ﷺ) as saying “He who becomes sick on a stormy sea and vomits will have the reward of a martyr. And he who is drowned will have a reward of two martyrs}}
\hadithdefcmd{abudawud}{2494}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ عَتِيقٍ، حَدَّثَنَا أَبُو مُسْهِرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ سَمَاعَةَ - حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي سُلَيْمَانُ بْنُ حَبِيبٍ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ كُلُّهُمْ ضَامِنٌ عَلَى اللَّهِ عَزَّ وَجَلَّ رَجُلٌ خَرَجَ غَازِيًا فِي سَبِيلِ اللَّهِ فَهُوَ ضَامِنٌ عَلَى اللَّهِ حَتَّى يَتَوَفَّاهُ فَيُدْخِلَهُ الْجَنَّةَ أَوْ يَرُدَّهُ بِمَا نَالَ مِنْ أَجْرٍ وَغَنِيمَةٍ وَرَجُلٌ رَاحَ إِلَى الْمَسْجِدِ فَهُوَ ضَامِنٌ عَلَى اللَّهِ حَتَّى يَتَوَفَّاهُ فَيُدْخِلَهُ الْجَنَّةَ أَوْ يَرُدَّهُ بِمَا نَالَ مِنْ أَجْرٍ وَغَنِيمَةٍ وَرَجُلٌ دَخَلَ بَيْتَهُ بِسَلاَمٍ فَهُوَ ضَامِنٌ عَلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2494}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Umamat Al Bahili reported the Apostle of Allaah(ﷺ) as saying “There are three persons who are in the security of Allaah, the Exalted.” “A man who goes out on an expedition to fight in the path of Allaah, the Exalted, is in the security of Allaah, until He takes him unto Him(i.e., he dies) and brings him into Paradise or brings him(alive) with reward and booty he obtains and a man who goes to the mosque is in the security of Allaah, until he takes him unto Him(i.e., he dies), and he brings him into Paradise or brings him with reward and spoils he obtains; and a man who enters his house after giving salutation is in the security of Allaah, the Exalted.”}}
\hadithdefcmd{abudawud}{2495}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَجْتَمِعُ فِي النَّارِ كَافِرٌ وَقَاتِلُهُ أَبَدًا ‏"‏ ‏.‏\hadithno{2495}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1891)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “An infidel and the one who killed him will never be brought together in Hell.”}}
\hadithdefcmd{abudawud}{2496}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، عَنْ قَعْنَبٍ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ حُرْمَةُ نِسَاءِ الْمُجَاهِدِينَ عَلَى الْقَاعِدِينَ كَحُرْمَةِ أُمَّهَاتِهِمْ وَمَا مِنْ رَجُلٍ مِنَ الْقَاعِدِينَ يَخْلُفُ رَجُلاً مِنَ الْمُجَاهِدِينَ فِي أَهْلِهِ إِلاَّ نُصِبَ لَهُ يَوْمَ الْقِيَامَةِ فَقِيلَ لَهُ هَذَا قَدْ خَلَفَكَ فِي أَهْلِكَ فَخُذْ مِنْ حَسَنَاتِهِ مَا شِئْتَ ‏"‏ ‏.‏ فَالْتَفَتَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا ظَنُّكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ قَعْنَبٌ رَجُلاً صَالِحًا وَكَانَ ابْنُ أَبِي لَيْلَى أَرَادَ قَعْنَبًا عَلَى الْقَضَاءِ فَأَبَى عَلَيْهِ وَقَالَ أَنَا أُرِيدُ الْحَاجَةَ بِدِرْهَمٍ فَأَسْتَعِينُ عَلَيْهَا بِرَجُلٍ ‏.‏ قَالَ وَأَيُّنَا لاَ يَسْتَعِينُ فِي حَاجَتِهِ قَالَ أَخْرِجُونِي حَتَّى أَنْظُرَ فَأُخْرِجَ فَتَوَارَى ‏.‏ قَالَ سُفْيَانُ بَيْنَمَا هُوَ مُتَوَارٍ إِذْ وَقَعَ عَلَيْهِ الْبَيْتُ فَمَاتَ ‏.‏\hadithno{2496}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1897)}\hadithtrans{Buraidah reported the Apostle of Allaah(ﷺ) as saying “Respect to be shown by those who stay at home to the women of those who are engaged in jihad is t be like that shown to their mothers. If any man among those who stay at home is entrusted with the oversight of one’s family who is engaged in jihad and betrays him, he will be setup for him on the Day of Resurrection and he (the mujahid) will be told “This (man) was entrusted with the oversight of your family, so take what you want from his good deeds. The Apostle of Allaah(ﷺ) turned towards us and said “So what do you think.” Abu Dawud said “Qa’nab (a narrator of this tradition) was a pious man. Ibn Abi Laila intended to appoint him a judge, but he refused and said “If I intend to fulfill my need of a dirham, I seek the help of a person for it. He said “Which of us does not seek the help in his need? He said “Bring me out so that I may see. So he was brought out, and he concealed himself. Sufyan said “While he was concealing himself.” Sufyan said “While he was concealing himself the house suddenly fell on him and he died.”}}
\hadithdefcmd{abudawud}{2497}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ، وَابْنُ، لَهِيعَةَ قَالاَ حَدَّثَنَا أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ غَازِيَةٍ تَغْزُو فِي سَبِيلِ اللَّهِ فَيُصِيبُونَ غَنِيمَةً إِلاَّ تَعَجَّلُوا ثُلُثَىْ أَجْرِهِمْ مِنَ الآخِرَةِ وَيَبْقَى لَهُمُ الثُّلُثُ فَإِنْ لَمْ يُصِيبُوا غَنِيمَةً تَمَّ لَهُمْ أَجْرُهُمْ ‏"‏ ‏.‏\hadithno{2497}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1906)}\hadithtrans{‘Abd Allah bin Amr reported the Apostle of Allaah(ﷺ) as saying “No warlike party will go out to fight in Allaah’s path and gain booty without getting beforehand two-thirds of their rewards in the next world and one-third (of their reward) will remain. And if they do not gain booty, they will get their rewards in full}}
\hadithdefcmd{abudawud}{2498}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يَحْيَى بْنِ أَيُّوبَ، وَسَعِيدِ بْنِ أَبِي أَيُّوبَ، عَنْ زَبَّانَ بْنِ فَائِدٍ، عَنْ سَهْلِ بْنِ مُعَاذٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الصَّلاَةَ وَالصِّيَامَ وَالذِّكْرَ تُضَاعَفُ عَلَى النَّفَقَةِ فِي سَبِيلِ اللَّهِ بِسَبْعِمِائَةِ ضِعْفٍ ‏"‏ ‏.‏\hadithno{2498}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Anas al-Juhani: The Messenger of Allah (ﷺ) said: (The reward of) prayer, fasting and remembrance of Allah is enhanced seven hundred times over (the reward of) spending in Allah's path}}
\hadithdefcmd{abudawud}{2499}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنِ ابْنِ ثَوْبَانَ، عَنْ أَبِيهِ، يَرُدُّ إِلَى مَكْحُولٍ إِلَى عَبْدِ الرَّحْمَنِ بْنِ غُنْمٍ الأَشْعَرِيِّ أَنَّ أَبَا مَالِكٍ الأَشْعَرِيَّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ فَصَلَ فِي سَبِيلِ اللَّهِ فَمَاتَ أَوْ قُتِلَ فَهُوَ شَهِيدٌ أَوْ وَقَصَهُ فَرَسُهُ أَوْ بَعِيرُهُ أَوْ لَدَغَتْهُ هَامَّةٌ أَوْ مَاتَ عَلَى فِرَاشِهِ أَوْ بِأَىِّ حَتْفٍ شَاءَ اللَّهُ فَإِنَّهُ شَهِيدٌ وَإِنَّ لَهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{2499}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMalik al-Ash'ari: AbuMalik heard the Messenger of Allah (ﷺ) say: He who goes forth in Allah's path and dies or is killed is a martyr, or has his neck broken through being thrown by his horse or by his camel, or is stung by a poisonous creature, or dies on his bed by any kind of death Allah wishes is a martyr and will go to Paradise}}
\hadithdefcmd{abudawud}{2500}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي أَبُو هَانِئٍ، عَنْ عَمْرِو بْنِ مَالِكٍ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ كُلُّ الْمَيِّتِ يُخْتَمُ عَلَى عَمَلِهِ، إِلاَّ الْمُرَابِطَ فَإِنَّهُ يَنْمُو لَهُ عَمَلُهُ إِلَى يَوْمِ الْقِيَامَةِ وَيُؤَمَّنُ مِنْ فَتَّانِ الْقَبْرِ ‏"‏ ‏.‏\hadithno{2500}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Fadalah ibn Ubayd: The Prophet (ﷺ) said: Everyone who dies will have fully complete his action, except one who is on the frontier (in Allah's path), for his deeds will be made to go on increasing till the Day of Resurrection, and he will be safe from the trial in the grave}}
\hadithdefcmd{abudawud}{2501}{حَدَّثَنَا أَبُو تَوْبَةَ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ زَيْدٍ، - يَعْنِي ابْنَ سَلاَّمٍ - أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، قَالَ حَدَّثَنِي السَّلُولِيُّ أَبُو كَبْشَةَ، أَنَّهُ حَدَّثَهُ سَهْلُ ابْنُ الْحَنْظَلِيَّةِ، أَنَّهُمْ سَارُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ فَأَطْنَبُوا السَّيْرَ حَتَّى كَانَتْ عَشِيَّةً، فَحَضَرْتُ الصَّلاَةَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَ رَجُلٌ فَارِسٌ فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ إِنِّي انْطَلَقْتُ بَيْنَ أَيْدِيكُمْ حَتَّى طَلَعْتُ جَبَلَ كَذَا وَكَذَا فَإِذَا أَنَا بِهَوَازِنَ عَلَى بَكْرَةِ آبَائِهِمْ بِظُعُنِهِمْ وَنَعَمِهِمْ وَشَائِهِمُ اجْتَمَعُوا إِلَى حُنَيْنٍ ‏.‏ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏:‏ ‏"‏ تِلْكَ غَنِيمَةُ الْمُسْلِمِينَ غَدًا إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏:‏ ‏"‏ مَنْ يَحْرُسُنَا اللَّيْلَةَ ‏"‏ ‏.‏ قَالَ أَنَسُ بْنُ أَبِي مَرْثَدٍ الْغَنَوِيُّ ‏:‏ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏:‏ ‏"‏ فَارْكَبْ ‏"‏ ‏.‏ فَرَكِبَ فَرَسًا لَهُ فَجَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ اسْتَقْبِلْ هَذَا الشِّعْبَ حَتَّى تَكُونَ فِي أَعْلاَهُ وَلاَ نُغَرَّنَّ مِنْ قِبَلِكَ اللَّيْلَةَ ‏"‏ ‏.‏ فَلَمَّا أَصْبَحْنَا خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى مُصَلاَّهُ فَرَكَعَ رَكْعَتَيْنِ ثُمَّ قَالَ ‏:‏ ‏"‏ هَلْ أَحْسَسْتُمْ فَارِسَكُمْ ‏"‏ ‏.‏ قَالُوا ‏:‏ يَا رَسُولَ اللَّهِ مَا أَحْسَسْنَاهُ ‏.‏ فَثُوِّبَ بِالصَّلاَةِ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَهُوَ يَلْتَفِتُ إِلَى الشِّعْبِ حَتَّى إِذَا قَضَى صَلاَتَهُ وَسَلَّمَ قَالَ ‏:‏ ‏"‏ أَبْشِرُوا فَقَدْ جَاءَكُمْ فَارِسُكُمْ ‏"‏ ‏.‏ فَجَعَلْنَا نَنْظُرُ إِلَى خِلاَلِ الشَّجَرِ فِي الشِّعْبِ فَإِذَا هُوَ قَدْ جَاءَ حَتَّى وَقَفَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ فَقَالَ ‏:‏ إِنِّي انْطَلَقْتُ حَتَّى كُنْتُ فِي أَعْلَى هَذَا الشِّعْبِ حَيْثُ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا أَصْبَحْتُ اطَّلَعْتُ الشِّعْبَيْنِ كِلَيْهِمَا فَنَظَرْتُ فَلَمْ أَرَ أَحَدًا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ هَلْ نَزَلْتَ اللَّيْلَةَ ‏"‏ ‏.‏ قَالَ ‏:‏ لاَ إِلاَّ مُصَلِّيًا أَوْ قَاضِيًا حَاجَةً ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ قَدْ أَوْجَبْتَ فَلاَ عَلَيْكَ أَنْ لاَ تَعْمَلَ بَعْدَهَا ‏"‏ ‏.‏\hadithno{2501}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sahl ibn al-Hanzaliyyah: On the day of Hunayn we travelled with the Messenger of Allah (ﷺ) and we journeyed for a long time until the evening came. I attended the prayer along with the Messenger of Allah (ﷺ). A horseman came and said: Messenger of Allah, I went before you and climbed a certain mountain where saw Hawazin all together with their women, cattle, and sheep, having gathered at Hunayn. The Messenger of Allah (ﷺ) smiled and said: That will be the booty of the Muslims tomorrow if Allah wills. He then asked: Who will be on guard tonight? Anas ibn AbuMarthad al-Ghanawi said: I shall , Messenger of Allah. He said: Then mount your horse. He then mounted his horse, and came to the Messenger of Allah (ﷺ). The Messenger of Allah said to him: Go forward to this ravine till you get to the top of it. We should not be exposed to danger from your side. In the morning the Apostle of of Allah (ﷺ) came out to his place of prayer, and offered two rak'ahs. He then said: Have you seen any sign of your horseman? They said: We have not, Messenger of Allah. The announcement of the time for prayer was then made, and while the Messenger of Allah (ﷺ) was saying the prayer, he began to glance towards the ravine. When he finished his prayer and uttered salutation, he said: Cheer up, for your horseman has come. We therefore began to look between the trees in the ravine, and sure enough he had come. He stood beside the Messenger of Allah (ﷺ), saluted him and said: I continued till I reached the top of this ravine where the Messenger of Allah (ﷺ) commanded me, and in the morning I looked down into both ravines but saw no one. The Messenger of Allah (ﷺ) asked him: Did you dismount during the night? He replied: No, except to pray or to relieve myself. The Messenger of Allah (ﷺ) said: You have ensured your entry to (Paradise). No blame will be attached to you supposing you do not work after it}}
\hadithdefcmd{abudawud}{2502}{حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ الْمَرْوَزِيُّ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا وُهَيْبٌ، - قَالَ عَبْدَةُ ‏:‏ يَعْنِي ابْنَ الْوَرْدِ - أَخْبَرَنِي عُمَرُ بْنُ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ مَنْ مَاتَ وَلَمْ يَغْزُ وَلَمْ يُحَدِّثْ نَفْسَهُ بِالْغَزْوِ مَاتَ عَلَى شُعْبَةٍ مِنْ نِفَاقٍ ‏"‏ ‏.‏\hadithno{2502}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1910)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying “He who dies without having fought or having felt fighting (against the infidels) to be his duty will die guilty of a kind of hypocrisy.”}}
\hadithdefcmd{abudawud}{2503}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، وَقَرَأْتُهُ، عَلَى يَزِيدَ بْنِ عَبْدِ رَبِّهِ الْجُرْجُسِيِّ قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ يَحْيَى بْنِ الْحَارِثِ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ مَنْ لَمْ يَغْزُ أَوْ يُجَهِّزْ غَازِيًا أَوْ يَخْلُفْ غَازِيًا فِي أَهْلِهِ بِخَيْرٍ أَصَابَهُ اللَّهُ بِقَارِعَةٍ ‏"‏ ‏.‏ قَالَ يَزِيدُ بْنُ عَبْدِ رَبِّهِ فِي حَدِيثِهِ ‏:‏ ‏"‏ قَبْلَ يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2503}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuUmamah: The Prophet (ﷺ) said: He who does not join the warlike expedition (jihad), or equip, or looks well after a warrior's family when he is away, will be smitten by Allah with a sudden calamity. Yazid ibn Abdu Rabbihi said in his tradition: 'before the Day of Resurrection}}
\hadithdefcmd{abudawud}{2504}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ جَاهِدُوا الْمُشْرِكِينَ بِأَمْوَالِكُمْ وَأَنْفُسِكُمْ وَأَلْسِنَتِكُمْ ‏"‏ ‏.‏\hadithno{2504}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: Use your property, your persons any your tongues in striving against the polytheists}}
\hadithdefcmd{abudawud}{2505}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ الْحُسَيْنِ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ إِلاَّ تَنْفِرُوا يُعَذِّبْكُمْ عَذَابًا أَلِيمًا ‏\}‏ وَ ‏\{‏ مَا كَانَ لأَهْلِ الْمَدِينَةِ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ يَعْمَلُونَ ‏\}‏ نَسَخَتْهَا الآيَةُ الَّتِي تَلِيهَا ‏\{‏ وَمَا كَانَ الْمُؤْمِنُونَ لِيَنْفِرُوا كَافَّةً ‏\}‏\hadithno{2505}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Abbas said “The Qur’anic verse “Unless you go forth, He will punish you with a grievous penalty, and the verse “It is not fitting for the people of Medina”... up to “that Allaah might required their deed with the best (possible reward) have been repealed by the verse. Nor should the believers all go forth together.”}}
\hadithdefcmd{abudawud}{2506}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ عَبْدِ الْمُؤْمِنِ بْنِ خَالِدٍ الْحَنَفِيِّ، حَدَّثَنِي نَجْدَةُ بْنُ نُفَيْعٍ، قَالَ ‏:‏ سَأَلْتُ ابْنَ عَبَّاسٍ عَنْ هَذِهِ الآيَةِ، ‏\{‏ إِلاَّ تَنْفِرُوا يُعَذِّبْكُمْ عَذَابًا أَلِيمًا ‏\}‏ قَالَ ‏:‏ فَأُمْسِكَ عَنْهُمُ الْمَطَرُ وَكَانَ عَذَابَهُمْ ‏.‏\hadithno{2506}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Najdah bin Nufai’ said “I asked Ibn ‘Abbas about the verse. “Unless you go forth, He will punish you with a grievous penalty.” He replied “The rain stopped from them. This was their punishment.”}}
\hadithdefcmd{abudawud}{2507}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ خَارِجَةَ بْنِ زَيْدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ ‏:‏ كُنْتُ إِلَى جَنْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَغَشِيَتْهُ السَّكِينَةُ فَوَقَعَتْ فَخِذُ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَخِذِي، فَمَا وَجَدْتُ ثِقَلَ شَىْءٍ أَثْقَلَ مِنْ فَخِذِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ سُرِّيَ عَنْهُ فَقَالَ ‏:‏ ‏"‏ اكْتُبْ ‏"‏ ‏.‏ فَكَتَبْتُ فِي كَتِفٍ ‏:‏ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ ‏.‏ إِلَى آخِرِ الآيَةِ، فَقَامَ ابْنُ أُمِّ مَكْتُومٍ - وَكَانَ رَجُلاً أَعْمَى - لَمَّا سَمِعَ فَضِيلَةَ الْمُجَاهِدِينَ فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ فَكَيْفَ بِمَنْ لاَ يَسْتَطِيعُ الْجِهَادَ مِنَ الْمُؤْمِنِينَ فَلَمَّا قَضَى كَلاَمَهُ غَشِيَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم السَّكِينَةُ فَوَقَعَتْ فَخِذُهُ عَلَى فَخِذِي وَوَجَدْتُ مِنْ ثِقَلِهَا فِي الْمَرَّةِ الثَّانِيَةِ كَمَا وَجَدْتُ فِي الْمَرَّةِ الأُولَى ثُمَّ سُرِّيَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ ‏"‏ اقْرَأْ يَا زَيْدُ ‏"‏ ‏.‏ فَقَرَأْتُ ‏\{‏ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ ‏\}‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ غَيْرُ أُولِي الضَّرَرِ ‏\}‏ الآيَةَ كُلَّهَا ‏.‏ قَالَ زَيْدٌ ‏:‏ فَأَنْزَلَهَا اللَّهُ وَحْدَهَا فَأَلْحَقْتُهَا، وَالَّذِي نَفْسِي بِيَدِهِ لَكَأَنِّي أَنْظُرُ إِلَى مُلْحَقِهَا عِنْدَ صَدْعٍ فِي كَتِفٍ ‏.‏\hadithno{2507}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Zaid bin Thabit said “I was beside the Apostle of Allaah(ﷺ) when the divinely-inspired calmness overtook him and the thigh of the Apostle of Allaah(ﷺ) fell on my thigh. I did not find any weightier than the thigh of the Apostle of Allaah(ﷺ). He then regained his composure and said “Write down. I wrote on a shoulder. Not equal are thise believers who sit (at home), other than those who have a (disabling) hurt, and those who strive in the way of Allaah. When Ibn Umm Makhtum who was blind heard the excellence of the warriors. He stood up and said “Apostle of Allaah(ﷺ) how is it for those believers who are unable to fight (in the path of Allaah)? When he finished his question his divinely-inspired calmness overtook him, and his thigh fell on my thigh and I found its weight the second time as I found the first time.” When the Apostle of Allaah(ﷺ) regained his composure, he said “Apostle of Allaah(ﷺ) said “Other than those who have a (disabling hurt). Zaid said “Allaah, the exalted, revealed it alone and I appended it.” By Him in Whose hands is my life, I am seeing, as it were the place where I put it (i.e., the verse) at the crack in the shoulder.”}}
\hadithdefcmd{abudawud}{2508}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ حُمَيْدٍ، عَنْ مُوسَى بْنِ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ لَقَدْ تَرَكْتُمْ بِالْمَدِينَةِ أَقْوَامًا مَا سِرْتُمْ مَسِيرًا وَلاَ أَنْفَقْتُمْ مِنْ نَفَقَةٍ وَلاَ قَطَعْتُمْ مِنْ وَادٍ إِلاَّ وَهُمْ مَعَكُمْ فِيهِ ‏"‏ ‏.‏ قَالُوا ‏:‏ يَا رَسُولَ اللَّهِ وَكَيْفَ يَكُونُونَ مَعَنَا وَهُمْ بِالْمَدِينَةِ فَقَالَ ‏:‏ ‏"‏ حَبَسَهُمُ الْعُذْرُ ‏"‏ ‏.‏\hadithno{2508}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik reported on the authority of his father, The Apostle of Allaah(ﷺ) said “ You left behind some people in Madeenah who did not fail to be with you wherever you went and whatever you spent (of your goods) and whatever valley you crossed. They asked Apostle of Allaah(ﷺ) how can they be with us when they are still in Madeenah? He replied “They were declined by a valid excuse.”}}
\hadithdefcmd{abudawud}{2509}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا الْحُسَيْنُ، حَدَّثَنِي يَحْيَى، حَدَّثَنِي أَبُو سَلَمَةَ، حَدَّثَنِي بُسْرُ بْنُ سَعِيدٍ، حَدَّثَنِي زَيْدُ بْنُ خَالِدٍ الْجُهَنِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ مَنْ جَهَّزَ غَاَزِيًا فِي سَبِيلِ اللَّهِ فَقَدْ غَزَا، وَمَنْ خَلَفَهُ فِي أَهْلِهِ بِخَيْرٍ فَقَدْ غَزَا ‏"‏ ‏.‏\hadithno{2509}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2843) Sahih Muslim (1895)}\hadithtrans{Zaid bin Khalid al Juhani reported that Apostle of Allaah(ﷺ) as saying “He who equips a fighter in Allaah’s path has taken part in the fighting. And he looks after a fighter’s family when he is away has taken part in the fighting.”}}
\hadithdefcmd{abudawud}{2510}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ يَزِيدَ بْنِ أَبِي سَعِيدٍ، مَوْلَى الْمَهْرِيِّ عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ إِلَى بَنِي لِحْيَانَ وَقَالَ ‏:‏ ‏"‏ لِيَخْرُجْ مِنْ كُلِّ رَجُلَيْنِ رَجُلٌ ‏"‏ ‏.‏ ثُمَّ قَالَ لِلْقَاعِدِينَ ‏:‏ ‏"‏ أَيُّكُمْ خَلَفَ الْخَارِجَ فِي أَهْلِهِ وَمَالِهِ بِخَيْرٍ كَانَ لَهُ مِثْلُ نِصْفِ أَجْرِ الْخَارِجِ ‏"‏ ‏.‏\hadithno{2510}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1896)}\hadithtrans{Abu Sa’id Al Khudri said “The Apostle of Allaah(ﷺ) sent an expedition towards Banu Lihyan and said “One of the two persons should go forth. He then said to those who sat (at home), If any one of you looks after the family and property of a warrior, he will receive half the reward of the one who goes forth (in jihad).”}}
\hadithdefcmd{abudawud}{2511}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ مُوسَى بْنِ عُلَىِّ بْنِ رَبَاحٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ مَرْوَانَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ شَرُّ مَا فِي رَجُلٍ شُحٌّ هَالِعٌ وَجُبْنٌ خَالِعٌ ‏"‏ ‏.‏\hadithno{2511}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: I heard the Messenger of Allah (ﷺ) say: What is evil in a man are alarming niggardliness and unrestrained cowardice}}
\hadithdefcmd{abudawud}{2512}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، وَابْنِ، لَهِيعَةَ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَسْلَمَ أَبِي عِمْرَانَ، قَالَ ‏:‏ غَزَوْنَا مِنَ الْمَدِينَةِ نُرِيدُ الْقُسْطَنْطِينِيَّةَ، وَعَلَى الْجَمَاعَةِ عَبْدُ الرَّحْمَنِ بْنُ خَالِدِ بْنِ الْوَلِيدِ وَالرُّومُ مُلْصِقُو ظُهُورِهِمْ بِحَائِطِ الْمَدِينَةِ، فَحَمَلَ رَجُلٌ عَلَى الْعَدُوِّ فَقَالَ النَّاسُ ‏:‏ مَهْ، مَهْ، لاَ إِلَهَ إِلاَّ اللَّهُ، يُلْقِي بِيَدَيْهِ إِلَى التَّهْلُكَةِ ‏.‏ فَقَالَ أَبُو أَيُّوبَ ‏:‏ إِنَّمَا نَزَلَتْ هَذِهِ الآيَةُ فِينَا مَعْشَرَ الأَنْصَارِ لَمَّا نَصَرَ اللَّهُ نَبِيَّهُ وَأَظْهَرَ الإِسْلاَمَ، قُلْنَا ‏:‏ هَلُمَّ نُقِيمُ فِي أَمْوَالِنَا وَنُصْلِحُهَا، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ وَأَنْفِقُوا فِي سَبِيلِ اللَّهِ وَلاَ تُلْقُوا بِأَيْدِيكُمْ إِلَى التَّهْلُكَةِ ‏\}‏ فَالإِلْقَاءُ بِالأَيْدِي إِلَى التَّهْلُكَةِ أَنْ نُقِيمَ فِي أَمْوَالِنَا وَنُصْلِحَهَا وَنَدَعَ الْجِهَادَ ‏.‏ قَالَ أَبُو عِمْرَانَ ‏:‏ فَلَمْ يَزَلْ أَبُو أَيُّوبَ يُجَاهِدُ فِي سَبِيلِ اللَّهِ حَتَّى دُفِنَ بِالْقُسْطَنْطِينِيَّةِ ‏.‏\hadithno{2512}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuAyyub: AbuImran said: We went out on an expedition from Medina with the intention of (attacking) Constantinople. AbdurRahman ibn Khalid ibn al-Walid was the leader of the company. The Romans were just keeping their backs to the walls of the city. A man (suddenly) attacked the enemy. Thereupon the people said: Stop! Stop! There is no god but Allah. He is putting himself into danger. AbuAyyub said: This verse was revealed about us, the group of the Ansar (the Helpers). When Allah helped His Prophet (ﷺ) and gave Islam dominance, we said (i.e. thought): Come on! Let us stay in our property and improve it. Thereupon Allah, the Exalted, revealed, "And spend of your substance in the cause of Allah, and make not your hands contribute to (your destruction)". To put oneself into danger means that we stay in our property and commit ourselves to its improvement, and abandon fighting (i.e. jihad). AbuImran said: AbuAyyub continued to strive in the cause of Allah until he (died and) was buried in Constantinople}}
\hadithdefcmd{abudawud}{2513}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنِي أَبُو سَلاَّمٍ، عَنْ خَالِدِ بْنِ زَيْدٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يُدْخِلُ بِالسَّهْمِ الْوَاحِدِ ثَلاَثَةَ نَفَرٍ الْجَنَّةَ ‏:‏ صَانِعَهُ يَحْتَسِبُ فِي صَنْعَتِهِ الْخَيْرَ، وَالرَّامِيَ بِهِ، وَمُنْبِلَهُ، وَارْمُوا وَارْكَبُوا، وَأَنْ تَرْمُوا أَحَبُّ إِلَىَّ مِنْ أَنْ تَرْكَبُوا، لَيْسَ مِنَ اللَّهْوِ إِلاَّ ثَلاَثٌ ‏:‏ تَأْدِيبُ الرَّجُلِ فَرَسَهُ وَمُلاَعَبَتُهُ أَهْلَهُ وَرَمْيُهُ بِقَوْسِهِ وَنَبْلِهِ، وَمَنْ تَرَكَ الرَّمْىَ بَعْدَ مَا عَلِمَهُ رَغْبَةً عَنْهُ فَإِنَّهَا نِعْمَةٌ تَرَكَهَا ‏"‏ ‏.‏ أَوْ قَالَ ‏:‏ ‏"‏ كَفَرَهَا ‏"‏ ‏.‏\hadithno{2513}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Uqbah ibn Amir: I heard the Messenger of Allah (ﷺ) say: Allah, Most High, will cause three persons to enter Paradise for one arrow: the maker when he has a good motive in making it, the one who shoots it, and the one who hands it; so shoot and ride, but your shooting is dearer to me than your riding. Everything with which a man amuses himself is vain except three (things): a man's training of his horse, his playing with his wife, and his shooting with his bow and arrow. If anyone abandons archery after becoming an adept through distaste for it, it is a blessing he has abandoned; or he said: for which he has been ungrateful}}
\hadithdefcmd{abudawud}{2514}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَبِي عَلِيٍّ، ‏:‏ ثُمَامَةَ بْنِ شُفَىٍّ الْهَمْدَانِيِّ أَنَّهُ سَمِعَ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ ‏:‏ ‏"‏ ‏\{‏ وَأَعِدُّوا لَهُمْ مَا اسْتَطَعْتُمْ مِنْ قُوَّةٍ ‏\}‏ أَلاَ إِنَّ الْقُوَّةَ الرَّمْىُ، أَلاَ إِنَّ الْقُوَّةَ الرَّمْىُ، أَلاَ إِنَّ الْقُوَّةَ الرَّمْىُ ‏"‏ ‏.‏\hadithno{2514}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1917)}\hadithtrans{‘Uqabah bin Amir Al Juhani said “I heard the Apostle of Allaah(ﷺ) recite when he was on the pulpit “Against them make ready your strength to the utmost of your power. Beware, strength is shooting, beware strength is shooting, beware strength is shooting.”}}
\hadithdefcmd{abudawud}{2515}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحَضْرَمِيُّ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي بَحِيرٌ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي بَحْرِيَّةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏:‏ ‏ "‏ الْغَزْوُ غَزْوَانِ فَأَمَّا مَنِ ابْتَغَى وَجْهَ اللَّهِ، وَأَطَاعَ الإِمَامَ، وَأَنْفَقَ الْكَرِيمَةَ، وَيَاسَرَ الشَّرِيكَ، وَاجْتَنَبَ الْفَسَادَ، فَإِنَّ نَوْمَهُ وَنَبْهَهُ أَجْرٌ كُلُّهُ وَأَمَّا مَنْ غَزَا فَخْرًا وَرِيَاءً وَسُمْعَةً، وَعَصَى الإِمَامَ، وَأَفْسَدَ فِي الأَرْضِ، فَإِنَّهُ لَمْ يَرْجِعْ بِالْكَفَافِ ‏"‏ ‏.‏\hadithno{2515}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Mu'adh ibn Jabal: The Prophet (ﷺ) said: Fighting is of two kinds: The one who seeks Allah's favour, obeys the leader, gives the property he values, treats his associates gently and avoids doing mischief, will have the reward for all the time whether he is asleep or awake; but the one who fights in a boasting spirit, for the sake of display and to gain a reputation, who disobeys the leader and does mischief in the earth will not return credit or without blame}}
\hadithdefcmd{abudawud}{2516}{حَدَّثَنَا أَبُو تَوْبَةَ، ‏:‏ الرَّبِيعُ بْنُ نَافِعٍ عَنِ ابْنِ الْمُبَارَكِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْقَاسِمِ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنِ ابْنِ مِكْرَزٍ، - رَجُلٍ مِنْ أَهْلِ الشَّامِ - عَنْ أَبِي هُرَيْرَةَ، ‏:‏ أَنَّ رَجُلاً، قَالَ ‏:‏ يَا رَسُولَ اللَّهِ، رَجُلٌ يُرِيدُ الْجِهَادَ فِي سَبِيلِ اللَّهِ وَهُوَ يَبْتَغِي عَرَضًا مِنْ عَرَضِ الدُّنْيَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ لاَ أَجْرَ لَهُ ‏"‏ ‏.‏ فَأَعْظَمَ ذَلِكَ النَّاسُ، وَقَالُوا لِلرَّجُلِ ‏:‏ عُدْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَلَعَلَّكَ لَمْ تُفَهِّمْهُ ‏.‏ فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ، رَجُلٌ يُرِيدُ الْجِهَادَ فِي سَبِيلِ اللَّهِ وَهُوَ يَبْتَغِي عَرَضًا مِنْ عَرَضِ الدُّنْيَا ‏.‏ فَقَالَ ‏:‏ ‏"‏ لاَ أَجْرَ لَهُ ‏"‏ ‏.‏ فَقَالُوا لِلرَّجُلِ ‏:‏ عُدْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ لَهُ الثَّالِثَةَ، فَقَالَ لَهُ ‏:‏ ‏"‏ لاَ أَجْرَ لَهُ ‏"‏ ‏.‏\hadithno{2516}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: A man said: Messenger of Allah, a man wishes to take part in jihad in Allah's path desiring some worldly advantage? The Prophet (ﷺ) said: He will have not reward. The people thought it terrible, and they said to the man: Go back to the Messenger of Allah (ﷺ), for you might not have made him understand well. He, therefore, (went and again) asked: Messenger of Allah, a man wishes to take part in jihad in Allah's path desiring some worldly advantage? He replied: There is no reward for him. They again said to the man: Return to the Messenger of Allah. He, therefore, said to him third time. He replied: There is no reward for him}}
\hadithdefcmd{abudawud}{2517}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى، ‏:‏ أَنَّ أَعْرَابِيًّا، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ إِنَّ الرَّجُلَ يُقَاتِلُ لِلذِّكْرِ، وَيُقَاتِلُ لِيُحْمَدَ، وَيُقَاتِلُ لِيَغْنَمَ، وَيُقَاتِلُ لِيُرَى مَكَانُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ مَنْ قَاتَلَ حَتَّى تَكُونَ كَلِمَةُ اللَّهِ هِيَ أَعْلَى فَهُوَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2517}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2810) Sahih Muslim (1904)}\hadithtrans{Abu Musa said “A beduoin came to the Apostle of Allaah(ﷺ) and said “One man fights for reputation, one fights for being praised, one fights for booty and one for his place to be seen. (Which of them is in Allaah’s path?)”. The Apostle of Allaah(ﷺ) replied “The one who fights that Allaah’s word may have pre-eminence is in Allaah’s path.”}}
\hadithdefcmd{abudawud}{2518}{حَدَّثَنَا عَلِيُّ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ عَمْرٍو، قَالَ ‏:‏ سَمِعْتُ مِنْ أَبِي وَائِلٍ، حَدِيثًا أَعْجَبَنِي ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{2518}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Amr said “I heard from Abu Wa’il a tradition which surprised me, he then narrated the tradition to the same effect (as mentioned before)}}
\hadithdefcmd{abudawud}{2519}{حَدَّثَنَا مُسْلِمُ بْنُ حَاتِمٍ الأَنْصَارِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الْوَضَّاحِ، عَنِ الْعَلاَءِ بْنِ عَبْدِ اللَّهِ بْنِ رَافِعٍ، عَنْ حَنَانِ بْنِ خَارِجَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو ‏:‏ يَا رَسُولَ اللَّهِ أَخْبِرْنِي عَنِ الْجِهَادِ، وَالْغَزْوِفَقَالَ ‏:‏ ‏ "‏ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو، إِنْ قَاتَلْتَ صَابِرًا مُحْتَسِبًا بَعَثَكَ اللَّهُ صَابِرًا مُحْتَسِبًا، وَإِنْ قَاتَلْتَ مُرَائِيًا مُكَاثِرًا بَعَثَكَ اللَّهُ مُرَائِيًا مُكَاثِرًا، يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو، عَلَى أَىِّ حَالٍ قَاتَلْتَ أَوْ قُتِلْتَ بَعَثَكَ اللَّهُ عَلَى تِيكَ الْحَالِ ‏"‏ ‏.‏\hadithno{2519}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: Messenger of Allah, tell me about jihad and fighting. He replied: Abdullah ibn Amr, if you fight with endurance seeking from Allah your reward, Allah will resurrect you showing endurance and seeking your reward from Him, but, if you fight for vain show seeking to acquire much, Allah will resurrect you making a vain show and seeking to acquire much. In whatever you fight or are killed, Abdullah ibn Amr, in that state Allah will resurrect you}}
\hadithdefcmd{abudawud}{2520}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ لَمَّا أُصِيبَ إِخْوَانُكُمْ بِأُحُدٍ جَعَلَ اللَّهُ أَرْوَاحَهُمْ فِي جَوْفِ طَيْرٍ خُضْرٍ تَرِدُ أَنْهَارَ الْجَنَّةِ، تَأْكُلُ مِنْ ثِمَارِهَا، وَتَأْوِي إِلَى قَنَادِيلَ مِنْ ذَهَبٍ مُعَلَّقَةٍ فِي ظِلِّ الْعَرْشِ، فَلَمَّا وَجَدُوا طِيبَ مَأْكَلِهِمْ وَمَشْرَبِهِمْ وَمَقِيلِهِمْ قَالُوا ‏:‏ مَنْ يُبَلِّغُ إِخْوَانَنَا عَنَّا أَنَّا أَحْيَاءٌ فِي الْجَنَّةِ نُرْزَقُ لِئَلاَّ يَزْهَدُوا فِي الْجِهَادِ وَلاَ يَنْكُلُوا عِنْدَ الْحَرْبِ فَقَالَ اللَّهُ سُبْحَانَهُ ‏:‏ أَنَا أُبَلِّغُهُمْ عَنْكُمْ ‏.‏ قَالَ ‏:‏ فَأَنْزَلَ اللَّهُ ‏\{‏ وَلاَ تَحْسَبَنَّ الَّذِينَ قُتِلُوا فِي سَبِيلِ اللَّهِ أَمْوَاتًا ‏\}‏ ‏"‏ ‏.‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{2520}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: When your brethren were smitten at the battle of Uhud, Allah put their spirits in the crops of green birds which go down to the rivers of Paradise, eat its fruit and nestle in lamps of gold in the shade of the Throne. Then when they experienced the sweetness of their food, drink and rest, they asked: Who will tell our brethren about us that we are alive in Paradise provided with provision, in order that they might not be disinterested in jihad and recoil in war? Allah Most High said: I shall tell them about you; so Allah sent down; "And do not consider those who have been killed in Allah's path." till the end of the verse}}
\hadithdefcmd{abudawud}{2521}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا عَوْفٌ، حَدَّثَتْنَا حَسْنَاءُ بِنْتُ مُعَاوِيَةَ الصَّرِيمِيَّةُ، قَالَتْ حَدَّثَنَا عَمِّي، قَالَ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم ‏:‏ مَنْ فِي الْجَنَّةِ قَالَ ‏:‏ ‏ "‏ النَّبِيُّ فِي الْجَنَّةِ، وَالشَّهِيدُ فِي الْجَنَّةِ، وَالْمَوْلُودُ فِي الْجَنَّةِ، وَالْوَئِيدُ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{2521}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hasana' daughter of Mu'awiyah: She reported on the authority of her paternal uncle: I asked the Prophet (ﷺ): Who are in Paradise? He replied: Prophets are in Paradise, martyrs are in Paradise, infants are in Paradise and children buried alive are in Paradise}}
\hadithdefcmd{abudawud}{2522}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا الْوَلِيدُ بْنُ رَبَاحٍ الذِّمَارِيُّ، حَدَّثَنِي عَمِّي، ‏:‏ نِمْرَانُ بْنُ عُتْبَةَ الذِّمَارِيُّ قَالَ ‏:‏ دَخَلْنَا عَلَى أُمِّ الدَّرْدَاءِ وَنَحْنُ أَيْتَامٌ فَقَالَتْ ‏:‏ أَبْشِرُوا فَإِنِّي سَمِعْتُ أَبَا الدَّرْدَاءِ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ يُشَفَّعُ الشَّهِيدُ فِي سَبْعِينَ مِنْ أَهْلِ بَيْتِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ صَوَابُهُ رَبَاحُ بْنُ الْوَلِيدِ ‏.‏\hadithno{2522}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbudDarda': The Prophet (ﷺ) said: The intercession of a martyr will be accepted for seventy members of his family. Abu Dawud said: The correct name if the narrator is Rabah b. al-Walid (and not al-walid b. Rabah as occurred in the chain of narrators in the text of the tradition)}}
\hadithdefcmd{abudawud}{2523}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الْفَضْلِ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي يَزِيدُ بْنُ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ ‏:‏ لَمَّا مَاتَ النَّجَاشِيُّ كُنَّا نَتَحَدَّثُ أَنَّهُ لاَ يَزَالُ يُرَى عَلَى قَبْرِهِ نُورٌ ‏.‏\hadithno{2523}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When Negus died, we were told that a light would be seen perpetually at his grave}}
\hadithdefcmd{abudawud}{2524}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ عَمْرَو بْنَ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ رُبَيِّعَةَ، عَنْ عُبَيْدِ بْنِ خَالِدٍ السُّلَمِيِّ، قَالَ ‏:‏ آخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ رَجُلَيْنِ فَقُتِلَ أَحَدُهُمَا وَمَاتَ الآخَرُ بَعْدَهُ بِجُمُعَةٍ أَوْ نَحْوِهَا، فَصَلَّيْنَا عَلَيْهِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ مَا قُلْتُمْ ‏"‏ ‏.‏ فَقُلْنَا ‏:‏ دَعَوْنَا لَهُ، وَقُلْنَا ‏:‏ اللَّهُمَّ اغْفِرْ لَهُ وَأَلْحِقْهُ بِصَاحِبِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ فَأَيْنَ صَلاَتُهُ بَعْدَ صَلاَتِهِ وَصَوْمُهُ بَعْدَ صَوْمِهِ ‏"‏ ‏.‏ شَكَّ شُعْبَةُ فِي صَوْمِهِ ‏:‏ ‏"‏ وَعَمَلُهُ بَعْدَ عَمَلِهِ إِنَّ بَيْنَهُمَا كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏\hadithno{2524}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ubaydullah ibn Khalid as-Sulami: The Messenger of Allah (ﷺ) made a brotherhood between two men, one of whom was killed (in Allah's path), and a week or thereabouts later the other died, and we prayed at his funeral). The Messenger of Allah (ﷺ) asked: What did you say? We replied: We prayed for him and said: O Allah, forgive him, and join him to his companion. The Messenger of Allah (ﷺ) said: What about his prayers since the time the other died, and his fasting since the time the other died--the narrator Shu'bah doubted the words, "his fasting--and his deeds since the time the other died. The distance between them is just like the distance between heaven and earth}}
\hadithdefcmd{abudawud}{2525}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا ح، وَحَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، - الْمَعْنَى وَأَنَا لِحَدِيثِهِ، أَتْقَنُ - عَنْ أَبِي سَلَمَةَ، ‏:‏ سُلَيْمَانَ بْنِ سُلَيْمٍ عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ، عَنِ ابْنِ أَخِي أَبِي أَيُّوبَ الأَنْصَارِيِّ، عَنْ أَبِي أَيُّوبَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ سَتُفْتَحُ عَلَيْكُمُ الأَمْصَارُ، وَسَتَكُونُ جُنُودٌ مُجَنَّدَةٌ تُقْطَعُ عَلَيْكُمْ فِيهَا بُعُوثٌ فَيَكْرَهُ الرَّجُلُ مِنْكُمُ الْبَعْثَ فِيهَا فَيَتَخَلَّصُ مِنْ قَوْمِهِ ثُمَّ يَتَصَفَّحُ الْقَبَائِلَ يَعْرِضُ نَفْسَهُ عَلَيْهِمْ يَقُولُ ‏:‏ مَنْ أَكْفِيهِ بَعْثَ كَذَا، مَنْ أَكْفِيهِ بَعْثَ كَذَا أَلاَ وَذَلِكَ الأَجِيرُ إِلَى آخِرِ قَطْرَةٍ مِنْ دَمِهِ ‏"‏ ‏.‏\hadithno{2525}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuAyyub al-Ansari: AbuAyyub heard the Messenger of Allah (ﷺ) say: Capitals will be conquered at your hands, and you will have to raise companies in large armies. A man will be unwilling to join a company, so he will escape from his people and go round the tribes offering himself to them, saying: Whose place may I take in such and such expedition? Whose place may I take in such and such expedition? Beware: That man is a hireling to the last drop of his blood}}
\hadithdefcmd{abudawud}{2526}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ الْمِصِّيصِيُّ، حَدَّثَنَا حَجَّاجٌ، - يَعْنِي ابْنَ مُحَمَّدٍ - ح وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، عَنِ ابْنِ شُفَىٍّ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ لِلْغَازِي أَجْرُهُ، وَلِلْجَاعِلِ أَجْرُهُ وَأَجْرُ الْغَازِي ‏"‏ ‏.‏\hadithno{2526}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: The warrior gets his reward, and the one who equips him gets his own reward and that of the warrior}}
\hadithdefcmd{abudawud}{2527}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَاصِمُ بْنُ حَكِيمٍ، عَنْ يَحْيَى بْنِ أَبِي عَمْرٍو السَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الدَّيْلَمِيِّ، أَنَّ يَعْلَى بْنَ مُنْيَةَ، قَالَ ‏:‏ آذَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْغَزْوِ وَأَنَا شَيْخٌ كَبِيرٌ لَيْسَ لِي خَادِمٌ، فَالْتَمَسْتُ أَجِيرًا يَكْفِينِي وَأُجْرِي لَهُ سَهْمَهُ، فَوَجَدْتُ رَجُلاً، فَلَمَّا دَنَا الرَّحِيلُ أَتَانِي فَقَالَ ‏:‏ مَا أَدْرِي مَا السُّهْمَانُ وَمَا يَبْلُغُ سَهْمِي فَسَمِّ لِي شَيْئًا كَانَ السَّهْمُ أَوْ لَمْ يَكُنْ ‏.‏ فَسَمَّيْتُ لَهُ ثَلاَثَةَ دَنَانِيرَ، فَلَمَّا حَضَرَتْ غَنِيمَتُهُ أَرَدْتُ أَنْ أُجْرِيَ لَهُ سَهْمَهُ، فَذَكَرْتُ الدَّنَانِيرَ، فَجِئْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ لَهُ أَمْرَهُ، فَقَالَ ‏:‏ ‏ "‏ مَا أَجِدُ لَهُ فِي غَزْوَتِهِ هَذِهِ فِي الدُّنْيَا وَالآخِرَةِ إِلاَّ دَنَانِيرَهُ الَّتِي سَمَّى ‏"‏ ‏.‏\hadithno{2527}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ya'la ibn Munyah: The Messenger of Allah (ﷺ) announced an expedition, and I was a very old man and I had no servant. I, therefore, sought a hireling who would serve instead of me, and I would give him his portion. So I found a man. When the time of departure arrived, he came to me and said: I do not know what would be the portions, and how much would be my portion. So offer something (as wages) to me, whether there would be any portion or not. I offered three dinars (as his wages) for him. When some booty arrived, I wanted to offer him his portion. But I remembered the dinars, so I went to the Prophet (ﷺ) and mentioned the matter to him. He said: All I can find for him regarding this expedition of his in this world and the next is three dinars which were offered him}}
\hadithdefcmd{abudawud}{2528}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ ‏:‏ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ جِئْتُ أُبَايِعُكَ عَلَى الْهِجْرَةِ وَتَرَكْتُ أَبَوَىَّ يَبْكِيَانِ ‏.‏ فَقَالَ ‏:‏ ‏ "‏ ارْجِعْ عَلَيْهِمَا فَأَضْحِكْهُمَا كَمَا أَبْكَيْتَهُمَا ‏"‏ ‏.‏\hadithno{2528}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: A man came to the Messenger of Allah (ﷺ) and said: I came to you to take the oath of allegiance to you on emigration, and I left my parents weeping. He (the Prophet) said: Return to them and make them laugh as you made them weep}}
\hadithdefcmd{abudawud}{2529}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ ‏:‏ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ أُجَاهِدُ قَالَ ‏:‏ ‏"‏ أَلَكَ أَبَوَانِ ‏"‏ ‏.‏ قَالَ ‏:‏ نَعَمْ ‏.‏ قَالَ ‏:‏ ‏"‏ فَفِيهِمَا فَجَاهِدْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ أَبُو الْعَبَّاسِ هَذَا الشَّاعِرُ اسْمُهُ السَّائِبُ بْنُ فَرُّوخَ ‏.‏\hadithno{2529}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3004) Sahih Muslim (2549)}\hadithtrans{‘Abd Allah bin ‘Amr said “A man came to the Prophet(ﷺ) and said “Apostle of Allaah(ﷺ), May I take part in jihad?” He asked “Do you have parents?” He replied “Yes”. So, strive for them.” Abu Dawud said:The name of the narrator Abu al-'Abbas, a poet, is al-Sa'ib b. Farrukh}}
\hadithdefcmd{abudawud}{2530}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ دَرَّاجًا أَبَا السَّمْحِ، حَدَّثَهُ عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، ‏:‏ أَنَّ رَجُلاً، هَاجَرَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْيَمَنِ، فَقَالَ ‏:‏ ‏"‏ هَلْ لَكَ أَحَدٌ بِالْيَمَنِ ‏"‏ ‏.‏ قَالَ ‏:‏ أَبَوَاىَ ‏.‏ قَالَ ‏:‏ ‏"‏ أَذِنَا لَكَ ‏"‏ ‏.‏ قَالَ ‏:‏ لاَ ‏.‏ قَالَ ‏:‏ ‏"‏ ارْجِعْ إِلَيْهِمَا فَاسْتَأْذِنْهُمَا، فَإِنْ أَذِنَا لَكَ فَجَاهِدْ، وَإِلاَّ فَبِرَّهُمَا ‏"‏ ‏.‏\hadithno{2530}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: A man emigrated to the Messenger of Allah (ﷺ) from the Yemen. He asked (him): Have you anyone (of your relatives) in the Yemen? He replied: My parents. He asked: Did they permit you? He replied: No. He said: Go back to them and ask for their permission. If they permit you, then fight (in the path of Allah), otherwise be devoted to them}}
\hadithdefcmd{abudawud}{2531}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ مُطَهِّرٍ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْزُو بِأُمِّ سُلَيْمٍ وَنِسْوَةٍ مِنَ الأَنْصَارِ لِيَسْقِينَ الْمَاءَ وَيُدَاوِينَ الْجَرْحَى ‏.‏\hadithno{2531}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1810)}\hadithtrans{Narrated Anas ibn Malik: When the Messenger of Allah (ﷺ) went on an expedition, he took Umm Sulaym, and he had some women of the Ansar who supplied water and tended the wounded}}
\hadithdefcmd{abudawud}{2532}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنْ يَزِيدَ بْنِ أَبِي نُشْبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ ثَلاَثَةٌ مِنْ أَصْلِ الإِيمَانِ ‏:‏ الْكَفُّ عَمَّنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَلاَ تُكَفِّرْهُ بِذَنْبٍ وَلاَ تُخْرِجْهُ مِنَ الإِسْلاَمِ بِعَمَلٍ، وَالْجِهَادُ مَاضٍ مُنْذُ بَعَثَنِيَ اللَّهُ إِلَى أَنْ يُقَاتِلَ آخِرُ أُمَّتِي الدَّجَّالَ لاَ يُبْطِلُهُ جَوْرُ جَائِرٍ وَلاَ عَدْلُ عَادِلٍ، وَالإِيمَانُ بِالأَقْدَارِ ‏"‏ ‏.‏\hadithno{2532}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: Three things are the roots of faith: to refrain from (killing) a person who utters, "There is no god but Allah" and not to declare him unbeliever whatever sin he commits, and not to excommunicate him from Islam for his any action; and jihad will be performed continuously since the day Allah sent me as a prophet until the day the last member of my community will fight with the Dajjal (Antichrist). The tyranny of any tyrant and the justice of any just (ruler) will not invalidate it. One must have faith in Divine decree}}
\hadithdefcmd{abudawud}{2533}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ مَكْحُولٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ الْجِهَادُ وَاجِبٌ عَلَيْكُمْ مَعَ كُلِّ أَمِيرٍ بَرًّا كَانَ أَوْ فَاجِرًا، وَالصَّلاَةُ وَاجِبَةٌ عَلَيْكُمْ خَلْفَ كُلِّ مُسْلِمٍ بَرًّا كَانَ أَوْ فَاجِرًا وَإِنْ عَمِلَ الْكَبَائِرَ، وَالصَّلاَةُ وَاجِبَةٌ عَلَى كُلِّ مُسْلِمٍ بَرًّا كَانَ أَوْ فَاجِرًا وَإِنْ عَمِلَ الْكَبَائِرَ ‏"‏ ‏.‏\hadithno{2533}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Striving in the path of Allah (jihad) is incumbent on you along with every ruler, whether he is pious or impious; the prayer is obligatory on you behind every believer, pious or impious, even if he commits grave sins; the (funeral) prayer is incumbent upon every Muslim, pious and impious, even if he commits major sins}}
\hadithdefcmd{abudawud}{2534}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ نُبَيْحٍ الْعَنَزِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، حَدَّثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَرَادَ أَنْ يَغْزُوَ فَقَالَ ‏:‏ ‏ "‏ يَا مَعْشَرَ الْمُهَاجِرِينَ وَالأَنْصَارِ، إِنَّ مِنْ إِخْوَانِكُمْ قَوْمًا لَيْسَ لَهُمْ مَالٌ وَلاَ عَشِيرَةٌ فَلْيَضُمَّ أَحَدُكُمْ إِلَيْهِ الرَّجُلَيْنِ أَوِ الثَّلاَثَةَ فَمَا لأَحَدِنَا مِنْ ظَهْرٍ يَحْمِلُهُ إِلاَّ عُقْبَةٌ كَعُقْبَةِ ‏"‏ ‏.‏ يَعْنِي أَحَدِهِمْ ‏.‏ فَضَمَمْتُ إِلَىَّ اثْنَيْنِ أَوْ ثَلاَثَةً، قَالَ ‏:‏ مَا لِي إِلاَّ عُقْبَةٌ كَعُقْبَةِ أَحَدِهِمْ مِنْ جَمَلِي ‏.‏\hadithno{2534}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: Once the Messenger of Allah (ﷺ) intended to go on an expedition. He said: O group of the emigrants (Muhajirun) and the helpers (Ansar), among your brethren there are people who have neither property nor family. So one of you should take with him two or three persons; with me. I also rode on my camel by turns like one of them}}
\hadithdefcmd{abudawud}{2535}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا أَسَدُ بْنُ مُوسَى، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، حَدَّثَنِي ضَمْرَةُ، أَنَّ ابْنَ زُغْبٍ الإِيَادِيَّ، حَدَّثَهُ قَالَ ‏:‏ نَزَلَ عَلَىَّ عَبْدُ اللَّهِ بْنُ حَوَالَةَ الأَزْدِيُّ فَقَالَ لِي ‏:‏ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَغْنَمَ عَلَى أَقْدَامِنَا فَرَجَعْنَا فَلَمْ نَغْنَمْ شَيْئًا وَعَرَفَ الْجُهْدَ فِي وُجُوهِنَا فَقَامَ فِينَا فَقَالَ ‏:‏ ‏"‏ اللَّهُمَّ لاَ تَكِلْهُمْ إِلَىَّ فَأَضْعُفَ عَنْهُمْ، وَلاَ تَكِلْهُمْ إِلَى أَنْفُسِهِمْ فَيَعْجِزُوا عَنْهَا، وَلاَ تَكِلْهُمْ إِلَى النَّاسِ فَيَسْتَأْثِرُوا عَلَيْهِمْ ‏"‏ ‏.‏ ثُمَّ وَضَعَ يَدَهُ عَلَى رَأْسِي - أَوْ قَالَ ‏:‏ عَلَى هَامَتِي - ثُمَّ قَالَ ‏:‏ ‏"‏ يَا ابْنَ حَوَالَةَ إِذَا رَأَيْتَ الْخِلاَفَةَ قَدْ نَزَلَتْ أَرْضَ الْمُقَدَّسَةِ فَقَدْ دَنَتِ الزَّلاَزِلُ وَالْبَلاَبِلُ وَالأُمُورُ الْعِظَامُ، وَالسَّاعَةُ يَوْمَئِذٍ أَقْرَبُ مِنَ النَّاسِ مِنْ يَدِي هَذِهِ مِنْ رَأْسِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ عَبْدُ اللَّهِ بْنُ حَوَالَةَ حِمْصِيٌّ ‏.‏\hadithno{2535}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Hawalah al-Azdi: The Messenger of Allah (ﷺ) sent us on foot to get spoil, but we returned without getting any. When he saw the signs of distress on our faces, he stood up on our faces and said: O Allah, do not put them under my care, for I would be too weak to care for them; do not put them in care of themselves, for they would be incapable of that, and do not put them in the care of men, for they would choose the best things for themselves. He then placed his hand on my head and said: Ibn Hawalah, when you see the caliphate has settled in the holy land, earthquakes, sorrows and serious matters will have drawn near and on that day the Last Hour will be nearer to mankind than this hand of mine is to your head. Abu Dawud said: 'Abd Allah b. Hawalah belongs to Hims}}
\hadithdefcmd{abudawud}{2536}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ مُرَّةَ الْهَمْدَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ عَجِبَ رَبُّنَا مِنْ رَجُلٍ غَزَا فِي سَبِيلِ اللَّهِ فَانْهَزَمَ ‏"‏ ‏.‏ يَعْنِي أَصْحَابَهُ ‏:‏ ‏"‏ فَعَلِمَ مَا عَلَيْهِ فَرَجَعَ حَتَّى أُهْرِيقَ دَمُهُ، فَيَقُولُ اللَّهُ تَعَالَى لِمَلاَئِكَتِهِ ‏:‏ انْظُرُوا إِلَى عَبْدِي رَجَعَ رَغْبَةً فِيمَا عِنْدِي وَشَفَقَةً مِمَّا عِنْدِي حَتَّى أُهَرِيقَ دَمُهُ ‏"‏ ‏.‏\hadithno{2536}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: Our Lord Most High is pleased with a man who fights in the path of Allah, the Exalted; then his companions fled away (i.e. retreated). But he knew that it was a sin (to flee away from the battlefield), so he returned, and his blood was shed. Thereupon Allah, the Exalted, says to His angels: Look at My servant; he returned seeking what I have for him (i.e. the reward), and fearing (the punishment) I have, until his blood was shed}}
\hadithdefcmd{abudawud}{2537}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ عَمْرَو بْنَ أُقَيْشٍ، كَانَ لَهُ رِبًا فِي الْجَاهِلِيَّةِ فَكَرِهَ أَنْ يُسْلِمَ حَتَّى يَأْخُذَهُ فَجَاءَ يَوْمَ أُحُدٍ ‏.‏ فَقَالَ ‏:‏ أَيْنَ بَنُو عَمِّي قَالُوا ‏:‏ بِأُحُدٍ ‏.‏ قَالَ ‏:‏ أَيْنَ فُلاَنٌ قَالُوا ‏:‏ بِأُحُدٍ ‏.‏ قَالَ ‏:‏ أَيْنَ فُلاَنٌ قَالُوا ‏:‏ بِأُحُدٍ ‏.‏ فَلَبِسَ لأْمَتَهُ وَرَكِبَ فَرَسَهُ ثُمَّ تَوَجَّهَ قِبَلَهُمْ، فَلَمَّا رَآهُ الْمُسْلِمُونَ قَالُوا ‏:‏ إِلَيْكَ عَنَّا يَا عَمْرُو ‏.‏ قَالَ ‏:‏ إِنِّي قَدْ آمَنْتُ ‏.‏ فَقَاتَلَ حَتَّى جُرِحَ، فَحُمِلَ إِلَى أَهْلِهِ جَرِيحًا، فَجَاءَهُ سَعْدُ بْنُ مُعَاذٍ فَقَالَ لأُخْتِهِ ‏:‏ سَلِيهِ حَمِيَّةً لِقَوْمِكَ أَوْ غَضَبًا لَهُمْ أَمْ غَضَبًا لِلَّهِ فَقَالَ ‏:‏ بَلْ غَضَبًا لِلَّهِ وَلِرَسُولِهِ فَمَاتَ ‏.‏ فَدَخَلَ الْجَنَّةَ وَمَا صَلَّى لِلَّهِ صَلاَةً ‏.‏\hadithno{2537}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: Amr ibn Uqaysh had given usurious loans in pre-Islamic period; so he disliked to embrace Islam until he took them. He came on the day of Uhud and asked: Where are my cousins? They (the people) replied: At Uhud. He asked: Where is so-and-so? They said: At Uhud. He asked: Where is so-and-so? They said: At Uhud. He then put on his coat of mail and rode his horse; he then proceeded towards them. When the Muslims saw him, they said: Keep away, Amir. He said: I have become a believer. He fought until he was wounded. He was then taken to his family wounded. Sa'd ibn Mu'adh came to his sister: Ask him (whether he fought) out of partisanship, out of anger for them, or out of anger for Allah. He said: Out of anger of Allah and His Apostle. He then died and entered Paradise. He did not offer any prayer for Allah}}
\hadithdefcmd{abudawud}{2538}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ، وَعَبْدُ اللَّهِ بْنُ كَعْبِ بْنِ مَالِكٍ، قَالَ أَبُو دَاوُدَ قَالَ أَحْمَدُ ‏:‏ كَذَا قَالَ هُوَ - يَعْنِي ابْنَ وَهْبٍ - وَعَنْبَسَةُ - يَعْنِي ابْنَ خَالِدٍ - جَمِيعًا عَنْ يُونُسَ قَالَ أَحْمَدُ ‏:‏ وَالصَّوَابُ عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ أَنَّ سَلَمَةَ بْنَ الأَكْوَعِ قَالَ ‏:‏ لَمَّا كَانَ يَوْمُ خَيْبَرَ قَاتَلَ أَخِي قِتَالاً شَدِيدًا، فَارْتَدَّ عَلَيْهِ سَيْفُهُ فَقَتَلَهُ فَقَالَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ - وَشَكُّوا فِيهِ - ‏:‏ رَجُلٌ مَاتَ بِسِلاَحِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ مَاتَ جَاهِدًا مُجَاهِدًا ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ ‏:‏ ثُمَّ سَأَلْتُ ابْنًا لِسَلَمَةَ بْنِ الأَكْوَعِ فَحَدَّثَنِي عَنْ أَبِيهِ بِمِثْلِ ذَلِكَ، غَيْرَ أَنَّهُ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ كَذَبُوا مَاتَ جَاهِدًا مُجَاهِدًا فَلَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{2538}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1802)}\hadithtrans{Salamah bin Al Akwa’ said “On the day of the battle of the Khaibar, my brother fought desperately. But his sword fell back on him and killed him. The Companions of the Apostle of Allaah(ﷺ) talked about him and doubted it (his martyrdom) saying “A man who died with his own weapon”. The Apostle of Allaah(ﷺ) said “he died as a warrior striving in the path of Allaah. Ibn Shihab said “I asked the son of Salamah bin Al Akwa’.” He narrated to me on the authority of his father similar to that except that he said “The Apostle of Allaah(ﷺ) said “They told a lie, he died as a warrior striving in the path of Allaah. There is a double reward for him.””}}
\hadithdefcmd{abudawud}{2539}{حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سَلاَّمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ أَبِي سَلاَّمٍ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ أَغَرْنَا عَلَى حَىٍّ مِنْ جُهَيْنَةَ فَطَلَبَ رَجُلٌ مِنَ الْمُسْلِمِينَ رَجُلاً مِنْهُمْ فَضَرَبَهُ فَأَخْطَأَهُ وَأَصَابَ نَفْسَهُ بِالسَّيْفِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ أَخُوكُمْ يَا مَعْشَرَ الْمُسْلِمِينَ ‏"‏ ‏.‏ فَابْتَدَرَهُ النَّاسُ فَوَجَدُوهُ قَدْ مَاتَ، فَلَفَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِثِيَابِهِ وَدِمَائِهِ وَصَلَّى عَلَيْهِ وَدَفَنَهُ، فَقَالُوا ‏:‏ يَا رَسُولَ اللَّهِ أَشَهِيدٌ هُوَ قَالَ ‏:‏ ‏"‏ نَعَمْ، وَأَنَا لَهُ شَهِيدٌ ‏"‏ ‏.‏\hadithno{2539}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSalam: AbuSalam reported on the authority of a man from the companion of the Prophet (ﷺ). He said: We attacked a tribe of Juhaynah. A man from the Muslims pursued a man of them, and struck him but missed him. He struck himself with the sword. The Messenger of Allah (ﷺ) said: Your brother, O group of Muslims. The people hastened towards him, but found him dead. The Messenger of Allah (ﷺ) wrapped him with his clothes and his blood, and offered (funeral) prayer for him and buried him. They said: Messenger of Allah, is he a martyr? He said: Yes, and I am witness to him}}
\hadithdefcmd{abudawud}{2540}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُوسَى بْنُ يَعْقُوبَ الزَّمْعِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ ثِنْتَانِ لاَ تُرَدَّانِ، أَوْ قَلَّمَا تُرَدَّانِ ‏:‏ الدُّعَاءُ عِنْدَ النِّدَاءِ، وَعِنْدَ الْبَأْسِ حِينَ يُلْحِمُ بَعْضُهُمْ بَعْضًا ‏"‏ ‏.‏ قَالَ مُوسَى ‏:‏ وَحَدَّثَنِي رِزْقُ بْنُ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي حَازِمٍ عَنْ سَهْلِ بْنِ سَعْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ وَوَقْتَ الْمَطَرِ ‏.‏\hadithno{2540}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sahl ibn Sa'd: The Prophet (ﷺ) said: Two (prayers) are not rejected, or seldom rejected: Prayer at the time of the call to prayer, and (the prayer) at the time of fighting, when the people grapple with each other. Musa said: Rizq ibn Sa'id ibn AbdurRahman reported from AbuHazim on the authority of Sahl ibn Sa'd from the Prophet (ﷺ) as saying: And while it is raining}}
\hadithdefcmd{abudawud}{2541}{حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ أَبُو مَرْوَانَ، وَابْنُ الْمُصَفَّى، قَالاَ حَدَّثَنَا بَقِيَّةُ، عَنِ ابْنِ ثَوْبَانَ، عَنْ أَبِيهِ، يَرُدُّ إِلَى مَكْحُولٍ إِلَى مَالِكِ بْنِ يُخَامِرَ أَنَّ مُعَاذَ بْنَ جَبَلٍ، حَدَّثَهُمْ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏"‏ مَنْ قَاتَلَ فِي سَبِيلِ اللَّهِ فُوَاقَ نَاقَةٍ فَقَدْ وَجَبَتْ لَهُ الْجَنَّةُ، وَمَنْ سَأَلَ اللَّهَ الْقَتْلَ مِنْ نَفْسِهِ صَادِقًا ثُمَّ مَاتَ أَوْ قُتِلَ فَإِنَّ لَهُ أَجْرَ شَهِيدٍ ‏"‏ ‏.‏ زَادَ ابْنُ الْمُصَفَّى مِنْ هُنَا ‏:‏ ‏"‏ وَمَنْ جُرِحَ جُرْحًا فِي سَبِيلِ اللَّهِ أَوْ نُكِبَ نَكْبَةً فَإِنَّهَا تَجِيءُ يَوْمَ الْقِيَامَةِ كَأَغْزَرِ مَا كَانَتْ، لَوْنُهَا لَوْنُ الزَّعْفَرَانِ، وَرِيحُهَا رِيحُ الْمِسْكِ، وَمَنْ خَرَجَ بِهِ خُرَاجٌ فِي سَبِيلِ اللَّهِ فَإِنَّ عَلَيْهِ طَابَعَ الشُّهَدَاءِ ‏"‏ ‏.‏\hadithno{2541}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Mu'adh ibn Jabal: The Messenger of Allah (ﷺ) said: If anyone fights in Allah's path as long as the time between two milkings of a she-camel, Paradise will be assured for him. If anyone sincerely asks Allah for being killed and then dies or is killed, there will be a reward of a martyr for him. Ibn al-Musaffa added from here: If anyone is wounded in Allah's path, or suffers a misfortune, it will come on the Day of resurrection as copious as possible, its colour saffron, and its odour musk; and if anyone suffers from ulcers while in Allah's path, he will have on him the stamp of the martyrs}}
\hadithdefcmd{abudawud}{2542}{حَدَّثَنَا أَبُو تَوْبَةَ، عَنِ الْهَيْثَمِ بْنِ حُمَيْدٍ، ح وَحَدَّثَنَا خُشَيْشُ بْنُ أَصْرَمَ، حَدَّثَنَا أَبُو عَاصِمٍ، جَمِيعًا عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ نَصْرٍ الْكِنَانِيِّ، عَنْ رَجُلٍوَقَالَ أَبُو تَوْبَةَ ‏:‏ عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ شَيْخٍ، مِنْ بَنِي سُلَيْمٍ عَنْ عُتْبَةَ بْنِ عَبْدٍ السُّلَمِيِّ، - وَهَذَا لَفْظُهُ - أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ لاَ تَقُصُّوا نَوَاصِيَ الْخَيْلِ وَلاَ مَعَارِفَهَا وَلاَ أَذْنَابَهَا، فَإِنَّ أَذْنَابَهَا مَذَابُّهَا، وَمَعَارِفَهَا دِفَاؤُهَا، وَنَوَاصِيهَا مَعْقُودٌ فِيهَا الْخَيْرُ ‏"‏ ‏.‏\hadithno{2542}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Utbah ibn AbdusSulami: Utbah heard the Messenger of Allah (ﷺ) say: Do not cut the forelocks, manes, or tails of horse, for their tails are their means of driving flies, their manes provide them with warmth, and blessing is tide to their forelocks}}
\hadithdefcmd{abudawud}{2543}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هِشَامُ بْنُ سَعِيدٍ الطَّالْقَانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُهَاجِرِ الأَنْصَارِيُّ، حَدَّثَنِي عَقِيلُ بْنُ شَبِيبٍ، عَنْ أَبِي وَهْبٍ الْجُشَمِيِّ، - وَكَانَتْ لَهُ صُحْبَةٌ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ عَلَيْكُمْ بِكُلِّ كُمَيْتٍ أَغَرَّ مُحَجَّلٍ، أَوْ أَشْقَرَ أَغَرَّ مُحَجَّلٍ، أَوْ أَدْهَمَ أَغَرَّ مُحَجَّلٍ ‏"‏ ‏.‏\hadithno{2543}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuWahb al-Jushami,: The Messenger of Allah (ﷺ) said: Keep to every dark bay horse with a white blaze and white on the legs, or sorrel with a white blaze and white on the legs , or black with a white blaze and white on the legs}}
\hadithdefcmd{abudawud}{2544}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا مُحَمَّدُ بْنُ مُهَاجِرٍ، حَدَّثَنَا عَقِيلُ بْنُ شَبِيبٍ، عَنْ أَبِي وَهْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ عَلَيْكُمْ بِكُلِّ أَشْقَرَ أَغَرَّ مُحَجَّلٍ، أَوْ كُمَيْتٍ أَغَرَّ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ مُحَمَّدٌ - يَعْنِي ابْنَ مُهَاجِرٍ - سَأَلْتُهُ ‏:‏ لِمَ فَضَّلَ الأَشْقَرَ قَالَ ‏:‏ لأَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ سَرِيَّةً فَكَانَ أَوَّلَ مَنْ جَاءَ بِالْفَتْحِ صَاحِبُ أَشْقَرَ ‏.‏\hadithno{2544}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuWahb: The Prophet (ﷺ) said: Keep to every sorrel horse with a white blaze and white on the legs, or dark bay with a white blaze. He then mentioned something similar. Muhammad ibn al-Muhajir said: I asked him: Why was a sorrel horse preferred? He replied: Because the Prophet (ﷺ) had sent a contingent, and the man who first brought the news of victory was the rider of a sorrel horse}}
\hadithdefcmd{abudawud}{2545}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، عَنْ شَيْبَانَ، عَنْ عِيسَى بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ يُمْنُ الْخَيْلِ فِي شُقْرِهَا ‏"‏ ‏.‏\hadithno{2545}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: The most favoured horses are the sorrel}}
\hadithdefcmd{abudawud}{2546}{حَدَّثَنَا مُوسَى بْنُ مَرْوَانَ الرَّقِّيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، حَدَّثَنَا أَبُو زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُسَمِّي الأُنْثَى مِنَ الْخَيْلِ فَرَسًا ‏.‏\hadithno{2546}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) used to name a mare a horse}}
\hadithdefcmd{abudawud}{2547}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَلْمٍ، - هُوَ ابْنُ عَبْدِ الرَّحْمَنِ - عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏:‏ كَانَ النَّبِيُّ صلى الله عليه وسلم يَكْرَهُ الشِّكَالَ مِنَ الْخَيْلِ ‏.‏ وَالشِّكَالُ ‏:‏ يَكُونُ الْفَرَسُ فِي رِجْلِهِ الْيُمْنَى بَيَاضٌ وَفِي يَدِهِ الْيُسْرَى بَيَاضٌ، أَوْ فِي يَدِهِ الْيُمْنَى وَفِي رِجْلِهِ الْيُسْرَى ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ أَىْ مُخَالِفٌ ‏.‏\hadithno{2547}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1875)}\hadithtrans{Abu Hurairah said “The Prophet (ﷺ) disapproved the shikal horses. Shikal are the horses that are white on their right hind leg and white on their left foreleg or white on their right foreleg and left hind leg. Abu Dawud said “This means alternate legs”}}
\hadithdefcmd{abudawud}{2548}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مِسْكِينٌ، - يَعْنِي ابْنَ بُكَيْرٍ - حَدَّثَنَا مُحَمَّدُ بْنُ مُهَاجِرٍ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي كَبْشَةَ السَّلُولِيِّ، عَنْ سَهْلِ ابْنِ الْحَنْظَلِيَّةِ، قَالَ ‏:‏ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِبَعِيرٍ قَدْ لَحِقَ ظَهْرُهُ بِبَطْنِهِ، فَقَالَ ‏:‏ ‏ "‏ اتَّقُوا اللَّهَ فِي هَذِهِ الْبَهَائِمِ الْمُعْجَمَةِ فَارْكَبُوهَا وَكُلُوهَا صَالِحَةً ‏"‏ ‏.‏\hadithno{2548}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Sahl ibn al-Hanzaliyyah: The Messenger of Allah (ﷺ) came upon an emaciated camel and said: Fear Allah regarding these dumb animals. Ride them when they are in good condition and feed them when they are in good condition}}
\hadithdefcmd{abudawud}{2549}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مَهْدِيٌّ، حَدَّثَنَا ابْنُ أَبِي يَعْقُوبَ، عَنِ الْحَسَنِ بْنِ سَعْدٍ، مَوْلَى الْحَسَنِ بْنِ عَلِيٍّ عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ ‏:‏ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ ذَاتَ يَوْمٍ فَأَسَرَّ إِلَىَّ حَدِيثًا لاَ أُحَدِّثُ بِهِ أَحَدًا مِنَ النَّاسِ، وَكَانَ أَحَبُّ مَا اسْتَتَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحَاجَتِهِ هَدَفًا أَوْ حَائِشَ نَخْلٍ ‏.‏ قَالَ ‏:‏ فَدَخَلَ حَائِطًا لِرَجُلٍ مِنَ الأَنْصَارِ فَإِذَا جَمَلٌ فَلَمَّا رَأَى النَّبِيَّ صلى الله عليه وسلم حَنَّ وَذَرَفَتْ عَيْنَاهُ، فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم فَمَسَحَ ذِفْرَاهُ فَسَكَتَ، فَقَالَ ‏:‏ ‏"‏ مَنْ رَبُّ هَذَا الْجَمَلِ، لِمَنْ هَذَا الْجَمَلُ ‏"‏ ‏.‏ فَجَاءَ فَتًى مِنَ الأَنْصَارِ فَقَالَ ‏:‏ لِي يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏:‏ ‏"‏ أَفَلاَ تَتَّقِي اللَّهَ فِي هَذِهِ الْبَهِيمَةِ الَّتِي مَلَّكَكَ اللَّهُ إِيَّاهَا، فَإِنَّهُ شَكَى إِلَىَّ أَنَّكَ تُجِيعُهُ وَتُدْئِبُهُ ‏"‏ ‏.‏\hadithno{2549}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (342 Mukhtasar)}\hadithtrans{‘Abd Allaah bin Jafar said “The Apostle of Allaah(ﷺ) seated me behind him(on his ride) one day, and told me secretly a thing asking me not to tell it to anyone. The place for easing dearer to the Apostle of Allaah(ﷺ) was a mound or host of palm trees by which he could conceal himself. He entered the garden of a man from the Ansar(Helpers). All of a sudden when a Camel saw the Prophet (ﷺ) it wept tenderly producing yearning sound and it eyes flowed. The Prophet (ﷺ) came to it and wiped the temple of its head. So it kept silence. He then said “Who is the master of this Camel? Whose Camel is this? A young man from the Ansar came and said “This is mine, Apostle of Allaah(ﷺ).” He said “Don’t you fear Allaah about this beast which Allaah has given in your possession. It has complained to me that you keep it hungry and load it heavily which fatigues it.”}}
\hadithdefcmd{abudawud}{2550}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ فَاشْتَدَّ عَلَيْهِ الْعَطَشُ، فَوَجَدَ بِئْرًا فَنَزَلَ فِيهَا فَشَرِبَ ثُمَّ خَرَجَ فَإِذَا كَلْبٌ يَلْهَثُ يَأْكُلُ الثَّرَى مِنَ الْعَطَشِ، فَقَالَ الرَّجُلُ ‏:‏ لَقَدْ بَلَغَ هَذَا الْكَلْبَ مِنَ الْعَطَشِ مِثْلُ الَّذِي كَانَ بَلَغَنِي، فَنَزَلَ الْبِئْرَ فَمَلأَ خُفَّيْهِ فَأَمْسَكَهُ بِفِيهِ حَتَّى رَقِيَ فَسَقَى الْكَلْبَ، فَشَكَرَ اللَّهُ لَهُ فَغَفَرَ لَهُ ‏"‏ ‏.‏ فَقَالُوا ‏:‏ يَا رَسُولَ اللَّهِ وَإِنَّ لَنَا فِي الْبَهَائِمِ لأَجْرًا فَقَالَ ‏:‏ ‏"‏ فِي كُلِّ ذَاتِ كَبِدٍ رَطْبَةٍ أَجْرٌ ‏"‏ ‏.‏\hadithno{2550}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2363) Sahih Muslim (2244)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “ While a man was going on his way, he felt himself thirsty severely. He found a well and e went down in it. He drank water and came out. Suddenly he saw a dog panting and eating soil due to thirst. The man said (to himself) “This dog must have reached the same condition due to thirst as I had reached. So he went down into the well, filled his sock with water, held it with his mouth and came up. He supplied water to the dog. Allaah appreciated this and forgave him.” They asked “Apostle of Allaah(ﷺ), Is there any reward for us for these beasts? He replied, For every cool liver there is a reward.”}}
\hadithdefcmd{abudawud}{2551}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حَمْزَةَ الضَّبِّيِّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، قَالَ كُنَّا إِذَا نَزَلْنَا مَنْزِلاً لاَ نُسَبِّحُ حَتَّى نَحُلَّ الرِّحَالَ ‏.‏\hadithno{2551}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: When we alighted at a station (for stay), we did not pray until we united the saddles of the camels}}
\hadithdefcmd{abudawud}{2552}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، أَنَّ أَبَا بَشِيرٍ الأَنْصَارِيَّ، أَخْبَرَهُ أَنَّهُ، كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَسُولاً - قَالَ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ حَسِبْتُ أَنَّهُ قَالَ - وَالنَّاسُ فِي مَبِيتِهِمْ ‏ "‏ لاَ يُبْقَيَنَّ فِي رَقَبَةِ بَعِيرٍ قِلاَدَةٌ مِنْ وَتَرٍ وَلاَ قِلاَدَةٌ إِلاَّ قُطِعَتْ ‏"‏ ‏.‏ قَالَ مَالِكٌ أَرَى أَنَّ ذَلِكَ مِنْ أَجْلِ الْعَيْنِ ‏.‏\hadithno{2552}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3005) Sahih Muslim (2115)}\hadithtrans{Abu Bashir Al Ansari said that he was with the Apostle of Allaah(ﷺ) on one of his journeys. The Apostle of Allaah(ﷺ)sent a messenger. The narrator ‘Abd Allah bin Abu Bakr said “I think he said while the people were sleeping. No necklace of bowstring or anything else must be left on a Camels’ neck, must be cut off. The narrator Malik said “I think this was due to evil eye.”}}
\hadithdefcmd{abudawud}{2553}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هِشَامُ بْنُ سَعِيدٍ الطَّالْقَانِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُهَاجِرِ، حَدَّثَنِي عَقِيلُ بْنُ شَبِيبٍ، عَنْ أَبِي وَهْبٍ الْجُشَمِيِّ، - وَكَانَتْ لَهُ صُحْبَةٌ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ارْتَبِطُوا الْخَيْلَ وَامْسَحُوا بِنَوَاصِيهَا وَأَعْجَازِهَا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ أَكْفَالِهَا ‏"‏ ‏.‏ ‏"‏ وَقَلِّدُوهَا وَلاَ تُقَلِّدُوهَا الأَوْتَارَ ‏"‏ ‏.‏\hadithno{2553}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuWahb al-Jushami,: The Messenger of Allah (ﷺ) said: Tie the horses, rub down their forelocks and their buttocks (or he said: Their rumps), and put things on their necks, but do not put bowstrings}}
\hadithdefcmd{abudawud}{2554}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ سَالِمٍ، عَنْ أَبِي الْجَرَّاحِ، مَوْلَى أُمِّ حَبِيبَةَ عَنْ أُمِّ حَبِيبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا جَرَسٌ ‏"‏ ‏.‏\hadithno{2554}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Umm Habibah: The Prophet (ﷺ) said: The angels do not go with a travelling company in which there is a bell}}
\hadithdefcmd{abudawud}{2555}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا كَلْبٌ أَوْ جَرَسٌ ‏"‏ ‏.‏\hadithno{2555}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2113)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “The angels do not accompany the fellow travelers who have a dog or bell (with them).”}}
\hadithdefcmd{abudawud}{2556}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فِي الْجَرَسِ ‏ "‏ مِزْمَارُ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{2556}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2114)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “The bell is a wooden wind musical instrument of Satan.”}}
\hadithdefcmd{abudawud}{2557}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نُهِيَ عَنْ رُكُوبِ الْجَلاَّلَةِ\hadithno{2557}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: It has been prohibited to ride the beast which eats dung}}
\hadithdefcmd{abudawud}{2558}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ الرَّازِيُّ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ الْجَهْمِ، حَدَّثَنَا عَمْرٌو، - يَعْنِي ابْنَ أَبِي قَيْسٍ - عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْجَلاَّلَةِ فِي الإِبِلِ أَنْ يُرْكَبَ عَلَيْهَا ‏.‏\hadithno{2558}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) prohibited to ride a camel which eats dung}}
\hadithdefcmd{abudawud}{2559}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ مُعَاذٍ، قَالَ كُنْتُ رِدْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى حِمَارٍ يُقَالُ لَهُ عُفَيْرٌ ‏.‏\hadithno{2559}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2856)}\hadithtrans{Mu’adh said “I was seated behind the Prophet (ﷺ) on a donkey that was called ‘Ufair”}}
\hadithdefcmd{abudawud}{2560}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، حَدَّثَنِي يَحْيَى بْنُ حَسَّانَ، أَخْبَرَنَا سُلَيْمَانُ بْنُ مُوسَى أَبُو دَاوُدَ، حَدَّثَنَا جَعْفَرُ بْنُ سَعْدِ بْنِ سَمُرَةَ بْنِ جُنْدُبٍ، حَدَّثَنِي خُبَيْبُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، سُلَيْمَانَ بْنِ سَمُرَةَ عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَمَّا بَعْدُ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم سَمَّى خَيْلَنَا خَيْلَ اللَّهِ إِذَا فَزِعْنَا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا إِذَا فَزِعْنَا بِالْجَمَاعَةِ وَالصَّبْرِ وَالسَّكِينَةِ وَإِذَا قَاتَلْنَا ‏.‏\hadithno{2560}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) named our cavalry "the Cavalry of Allah," when we were struck with panic, and when panic overtook us, the Messenger of Allah (ﷺ) commanded us to be united, to have patience and perseverance; and to be so when we fought}}
\hadithdefcmd{abudawud}{2561}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي سَفَرٍ فَسَمِعَ لَعْنَةً فَقَالَ ‏"‏ مَا هَذِهِ ‏"‏ ‏.‏ قَالُوا هَذِهِ فُلاَنَةُ لَعَنَتْ رَاحِلَتَهَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ضَعُوا عَنْهَا فَإِنَّهَا مَلْعُونَةٌ ‏"‏ ‏.‏ فَوَضَعُوا عَنْهَا ‏.‏ قَالَ عِمْرَانُ فَكَأَنِّي أَنْظُرُ إِلَيْهَا نَاقَةً وَرْقَاءَ ‏.‏\hadithno{2561}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2595)}\hadithtrans{‘Imran bin Hussain said “The Prophet (ﷺ) was on a journey. He heard a curse. He asked “What is this? They (the people) said “This is so and so (a woman) who cursed her riding beast. The Prophet (ﷺ) said “Remove the saddle from it, for it is accursed. So, they removed (the saddle) from it. ‘Imran said “As if I am looking at it a grey she Camel.”}}
\hadithdefcmd{abudawud}{2562}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، عَنْ قُطْبَةَ بْنِ عَبْدِ الْعَزِيزِ بْنِ سِيَاهٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي يَحْيَى الْقَتَّاتِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّحْرِيشِ بَيْنَ الْبَهَائِمِ ‏.‏\hadithno{2562}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) prohibited to provoke the beasts for fighting}}
\hadithdefcmd{abudawud}{2563}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِأَخٍ لِي حِينَ وُلِدَ لِيُحَنِّكَهُ فَإِذَا هُوَ فِي مِرْبَدٍ يَسِمُ غَنَمًا - أَحْسِبُهُ قَالَ - فِي آذَانِهَا ‏.‏\hadithno{2563}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5542) Sahih Muslim (2119)}\hadithtrans{Anas bin Malik said “I brought my brother when he was born to Prophet(ﷺ) to chew something for him and rub his palate with it and found him in a sheep pen branding the sheep, I think, on their ears.”}}
\hadithdefcmd{abudawud}{2564}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مُرَّ عَلَيْهِ بِحِمَارٍ قَدْ وُسِمَ فِي وَجْهِهِ فَقَالَ ‏ "‏ أَمَا بَلَغَكُمْ أَنِّي قَدْ لَعَنْتُ مَنْ وَسَمَ الْبَهِيمَةَ فِي وَجْهِهَا أَوْ ضَرَبَهَا فِي وَجْهِهَا ‏"‏ ‏.‏ فَنَهَى عَنْ ذَلِكَ ‏.‏\hadithno{2564}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2117)}\hadithtrans{Jabir reported the Prophet (ﷺ) as saying when an ass which had been branded on its face passed him. Did it not reach you that I cursed him who branded the animals on their faces or struck them on their faces. So he prohibited it}}
\hadithdefcmd{abudawud}{2565}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنِ ابْنِ زُرَيْرٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، - رضى الله عنه - قَالَ أُهْدِيَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم بَغْلَةٌ فَرَكِبَهَا ‏.‏ فَقَالَ عَلِيٌّ لَوْ حَمَلْنَا الْحَمِيرَ عَلَى الْخَيْلِ فَكَانَتْ لَنَا مِثْلُ هَذِهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا يَفْعَلُ ذَلِكَ الَّذِينَ لاَ يَعْلَمُونَ ‏"‏ ‏.‏\hadithno{2565}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) was present with a she-mule which he rode, so Ali said: If we made asses cover mares we would have animals of this type. The Messenger of Allah (ﷺ) said: Only those who do not know do that}}
\hadithdefcmd{abudawud}{2566}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ عَاصِمِ بْنِ سُلَيْمَانَ، عَنْ مُوَرِّقٍ، - يَعْنِي الْعِجْلِيَّ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَدِمَ مِنْ سَفَرٍ اسْتُقْبِلَ بِنَا فَأَيُّنَا اسْتُقْبِلَ أَوَّلاً جَعَلَهُ أَمَامَهُ فَاسْتُقْبِلَ بِي فَحَمَلَنِي أَمَامَهُ ثُمَّ اسْتُقْبِلَ بِحَسَنٍ أَوْ حُسَيْنٍ فَجَعَلَهُ خَلْفَهُ فَدَخَلْنَا الْمَدِينَةَ وَإِنَّا لَكَذَلِكَ ‏.‏\hadithno{2566}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2428)}\hadithtrans{‘Abd Allah bin Ja’far said “When the Prophet (ﷺ) arrived after a journey, we were taken for his reception. Any of us who met him first he lifted him in front of him. As I was the first to meet him, he lifted me in front of him. Then Hasan or Hussain was brought to him and he set him behind him. We the entered Madeenah and we (were) riding so (three on one beast).”}}
\hadithdefcmd{abudawud}{2567}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا ابْنُ عَيَّاشٍ، عَنْ يَحْيَى بْنِ أَبِي عَمْرٍو السَّيْبَانِيِّ، عَنِ ابْنِ أَبِي مَرْيَمَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ أَنْ تَتَّخِذُوا ظُهُورَ دَوَابِّكُمْ مَنَابِرَ فَإِنَّ اللَّهَ إِنَّمَا سَخَّرَهَا لَكُمْ لِتُبَلِّغَكُمْ إِلَى بَلَدٍ لَمْ تَكُونُوا بَالِغِيهِ إِلاَّ بِشِقِّ الأَنْفُسِ وَجَعَلَ لَكُمُ الأَرْضَ فَعَلَيْهَا فَاقْضُوا حَاجَتَكُمْ ‏"‏ ‏.‏\hadithno{2567}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah reported the Prophet(ﷺ) as saying “Do not treat the backs of your beasts as pulpits, for Allaah has made them subject to you only to convey you to a town which you cannot reach without difficulty and He has appointed the earth (a floor to work) for you, so conduct your business on it}}
\hadithdefcmd{abudawud}{2568}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي يَحْيَى، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَكُونُ إِبِلٌ لِلشَّيَاطِينِ وَبُيُوتٌ لِلشَّيَاطِينِ فَأَمَّا إِبِلُ الشَّيَاطِينِ فَقَدْ رَأَيْتُهَا يَخْرُجُ أَحَدُكُمْ بِجَنِيبَاتٍ مَعَهُ قَدْ أَسْمَنَهَا فَلاَ يَعْلُو بَعِيرًا مِنْهَا وَيَمُرُّ بِأَخِيهِ قَدِ انْقَطَعَ بِهِ فَلاَ يَحْمِلُهُ وَأَمَّا بُيُوتُ الشَّيَاطِينِ فَلَمْ أَرَهَا ‏"‏ ‏.‏ كَانَ سَعِيدٌ يَقُولُ لاَ أُرَاهَا إِلاَّ هَذِهِ الأَقْفَاصَ الَّتِي يَسْتُرُ النَّاسُ بِالدِّيبَاجِ ‏.‏\hadithno{2568}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “There are Camels which belong to devils and there are houses which belong to devils. As for the Camels of the devils, I have seen them. One of you goes out with his side Camels which he has fattened neither riding any of them nor giving a lift to a tired brother when he meets. As regard the houses of the devils, I have not seen them. The narrator Sa’id says “I think they are those cages (Camel litters) which conceal people with brocade.”}}
\hadithdefcmd{abudawud}{2569}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَافَرْتُمْ فِي الْخِصْبِ فَأَعْطُوا الإِبِلَ حَقَّهَا وَإِذَا سَافَرْتُمْ فِي الْجَدْبِ فَأَسْرِعُوا السَّيْرَ فَإِذَا أَرَدْتُمُ التَّعْرِيسَ فَتَنَكَّبُوا عَنِ الطَّرِيقِ ‏"‏ ‏.‏\hadithno{2569}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1926)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “When you travel in fertile country, give the Camel their due (from the ground), and when you travel in time of drought make them go quickly. When you intend to encamp in the last hours of the night, keep away from the roads.”}}
\hadithdefcmd{abudawud}{2570}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامٌ، عَنِ الْحَسَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا قَالَ بَعْدَ قَوْلِهِ ‏"‏ حَقَّهَا ‏"‏ ‏.‏ ‏"‏ وَلاَ تَعْدُوا الْمَنَازِلَ ‏"‏ ‏.‏\hadithno{2570}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been narrated by Jabir bin ‘Abd Allaah from the Prophet (ﷺ). But this version adds after the phrase “their due” And do not go beyond the destinations}}
\hadithdefcmd{abudawud}{2571}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ، حَدَّثَنَا أَبُو جَعْفَرٍ الرَّازِيُّ، عَنِ الرَّبِيعِ بْنِ أَنَسٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكُمْ بِالدُّلْجَةِ فَإِنَّ الأَرْضَ تُطْوَى بِاللَّيْلِ ‏"‏ ‏.‏\hadithno{2571}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Anas reported the Apostle of Allaah(ﷺ) as saying “Keep to travelling by night, for the earth is traversed (more easily) by night}}
\hadithdefcmd{abudawud}{2572}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، حَدَّثَنِي أَبِي، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ سَمِعْتُ أَبِي بُرَيْدَةَ، يَقُولُ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي جَاءَ رَجُلٌ وَمَعَهُ حِمَارٌ فَقَالَ يَا رَسُولَ اللَّهِ ارْكَبْ ‏.‏ وَتَأَخَّرَ الرَّجُلُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ أَنْتَ أَحَقُّ بِصَدْرِ دَابَّتِكَ مِنِّي إِلاَّ أَنْ تَجْعَلَهُ لِي ‏"‏ ‏.‏ قَالَ فَإِنِّي قَدْ جَعَلْتُهُ لَكَ ‏.‏ فَرَكِبَ ‏.‏\hadithno{2572}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraydah ibn al-Hasib: While the Messenger of Allah (ﷺ) was walking a man who had an ass came to him and said: Messenger of Allah, ride; and the man moved to the back of the animal. The Messenger of Allah (ﷺ) said: No, you have more right to ride in front on your animal than me unless you grant that right to me. He said: I grant it to you. So he mounted}}
\hadithdefcmd{abudawud}{2573}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي ابْنُ عَبَّادٍ، عَنْ أَبِيهِ، عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ قَالَ أَبُو دَاوُدَ وَهُوَ يَحْيَى بْنُ عَبَّادٍ - حَدَّثَنِي أَبِي الَّذِي، أَرْضَعَنِي وَهُوَ أَحَدُ بَنِي مُرَّةَ بْنِ عَوْفٍ - وَكَانَ فِي تِلْكَ الْغَزَاةِ غَزَاةِ مُؤْتَةَ - قَالَ وَاللَّهِ لَكَأَنِّي أَنْظُرُ إِلَى جَعْفَرٍ حِينَ اقْتَحَمَ عَنْ فَرَسٍ لَهُ شَقْرَاءَ فَعَقَرَهَا ثُمَّ قَاتَلَ الْقَوْمَ حَتَّى قُتِلَ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْحَدِيثُ لَيْسَ بِالْقَوِيِّ ‏.‏\hadithno{2573}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abbad ibn Abdullah ibn az-Zubayr: My foster-father said to me - he was one of Banu Murrah ibn Awf, and he was present in that battle, the battle of Mu'tah: By Allah, as if I am seeing Ja'far who jumped from his reddish horse and hamstrung it; he then fought with the people until he was killed. Abu Dawud said: The tradition is not strong}}
\hadithdefcmd{abudawud}{2574}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ نَافِعِ بْنِ أَبِي نَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ سَبْقَ إِلاَّ فِي خُفٍّ أَوْ فِي حَافِرٍ أَوْ نَصْلٍ ‏"‏ ‏.‏\hadithno{2574}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Wagers are allowed only for racing camels, or horses or shooting arrows}}
\hadithdefcmd{abudawud}{2575}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَابَقَ بَيْنَ الْخَيْلِ الَّتِي قَدْ ضُمِّرَتْ مِنَ الْحَفْيَاءِ وَكَانَ أَمَدُهَا ثَنِيَّةَ الْوَدَاعِ وَسَابَقَ بَيْنَ الْخَيْلِ الَّتِي لَمْ تُضْمَرْ مِنَ الثَّنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ وَإِنَّ عَبْدَ اللَّهِ كَانَ مِمَّنْ سَابَقَ بِهَا ‏.‏\hadithno{2575}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (420) Sahih Muslim (1870)}\hadithtrans{‘Abd Allah bin Umar said “The Apostle of Allaah(ﷺ) held race between the horses which had been made lean by training from Al Hafya’. The goal was Thaniyyat Al Wada’ and he held a race between the horses Banu Zuraiq and ‘Abd Allaah was one of the racers}}
\hadithdefcmd{abudawud}{2576}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يُضَمِّرُ الْخَيْلَ يُسَابِقُ بِهَا ‏.‏\hadithno{2576}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1870)}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) used to make lean by training horses which he employed in the race}}
\hadithdefcmd{abudawud}{2577}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَبَّقَ بَيْنَ الْخَيْلِ وَفَضَّلَ الْقُرَّحَ فِي الْغَايَةِ ‏.‏\hadithno{2577}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) used to hold a race between horses and kept the one in the fifth year at a long distance}}
\hadithdefcmd{abudawud}{2578}{حَدَّثَنَا أَبُو صَالِحٍ الأَنْطَاكِيُّ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ، - يَعْنِي الْفَزَارِيَّ - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، وَعَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا أَنَّهَا كَانَتْ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ قَالَتْ فَسَابَقْتُهُ فَسَبَقْتُهُ عَلَى رِجْلَىَّ فَلَمَّا حَمَلْتُ اللَّحْمَ سَابَقْتُهُ فَسَبَقَنِي فَقَالَ ‏ "‏ هَذِهِ بِتِلْكَ السَّبْقَةِ ‏"‏ ‏.‏\hadithno{2578}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: while she was on a journey along with the Messenger of Allah (ﷺ): I had a race with him (the Prophet) and I outstripped him on my feet. When I became fleshy, (again) I had a race with him (the Prophet) and he outstripped me. He said: This is for that outstripping}}
\hadithdefcmd{abudawud}{2579}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حُصَيْنُ بْنُ نُمَيْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ حُسَيْنٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، أَخْبَرَنَا سُفْيَانُ بْنُ حُسَيْنٍ، - الْمَعْنَى - عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَدْخَلَ فَرَسًا بَيْنَ فَرَسَيْنِ ‏"‏ ‏.‏ يَعْنِي وَهُوَ لاَ يُؤْمَنُ أَنْ يُسْبَقَ ‏"‏ فَلَيْسَ بِقِمَارٍ وَمَنْ أَدْخَلَ فَرَسًا بَيْنَ فَرَسَيْنِ وَقَدْ أَمِنَ أَنْ يُسْبَقَ فَهُوَ قِمَارٌ ‏"‏ ‏.‏\hadithno{2579}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If one enters a horse with two others when he is not certain that it cannot be beaten, it is not gambling; but when one enters a horse with two others when he is certain it cannot be beaten, it is gambling}}
\hadithdefcmd{abudawud}{2580}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ بَشِيرٍ، عَنِ الزُّهْرِيِّ، بِإِسْنَادِ عَبَّادٍ وَمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ مَعْمَرٌ وَشُعَيْبٌ وَعَقِيلٌ عَنِ الزُّهْرِيِّ، عَنْ رِجَالٍ، مِنْ أَهْلِ الْعِلْمِ وَهَذَا أَصَحُّ عِنْدَنَا ‏.‏\hadithno{2580}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Al Zuhri with the chain of ‘Abbad and to the same affect. Abu Dawud said “This tradition has also been narrated by Ma’mar, Shu’aib and ‘Aqil on the authority of Al Zuhri from a number of scholars and this is the soundest one in our opinion}}
\hadithdefcmd{abudawud}{2581}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا عَنْبَسَةُ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ حُمَيْدٍ الطَّوِيلِ، جَمِيعًا عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ جَلَبَ وَلاَ جَنَبَ ‏"‏ ‏.‏ زَادَ يَحْيَى فِي حَدِيثِهِ ‏"‏ فِي الرِّهَانِ ‏"‏ ‏.‏\hadithno{2581}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Imran ibn Husayn: The Prophet (ﷺ) said: There must be no shouting or leading another horse at one's side. Yahya added in his tradition: When racing for a wager}}
\hadithdefcmd{abudawud}{2582}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، قَالَ الْجَلَبُ وَالْجَنَبُ فِي الرِّهَانِ ‏.‏\hadithno{2582}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Qatadah said “Taking another horse behind one’s horse to urge it on and taking another horse at one’s side are (done) in a horse race}}
\hadithdefcmd{abudawud}{2583}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ كَانَتْ قَبِيعَةُ سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِضَّةً ‏.‏\hadithno{2583}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas ibn Malik: The pommel of the sword of the Messenger of Allah (ﷺ) was of silver}}
\hadithdefcmd{abudawud}{2584}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، قَالَ كَانَتْ قَبِيعَةُ سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِضَّةً ‏.‏ قَالَ قَتَادَةُ وَمَا عَلِمْتُ أَحَدًا تَابَعَهُ عَلَى ذَلِكَ ‏.‏\hadithno{2584}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'id ibn AbulHasan: The pommel of the sword of the Messenger of Allah (ﷺ) was of silver. Qatadah said: I do not know that anyone has supported him for that (for the tradition narrated by Sa'id b. Abu al-Hasan)}}
\hadithdefcmd{abudawud}{2585}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنِي يَحْيَى بْنُ كَثِيرٍ أَبُو غَسَّانَ الْعَنْبَرِيُّ، عَنْ عُثْمَانَ بْنِ سَعْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَتْ ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ أَقْوَى هَذِهِ الأَحَادِيثِ حَدِيثُ سَعِيدِ بْنِ أَبِي الْحَسَنِ وَالْبَاقِيَةُ ضِعَافٌ ‏.‏\hadithno{2585}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi}\hadithtrans{The tradition mentioned above has also been narrated by Anas bin Malik through a different chain of narrators. He mentioned similar words. Abu Dawud said “the strongest of these traditions is the one of Sa’id bin Abu Al Hasan. The rest are weak}}
\hadithdefcmd{abudawud}{2586}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَمَرَ رَجُلاً كَانَ يَتَصَدَّقُ بِالنَّبْلِ فِي الْمَسْجِدِ أَنْ لاَ يَمُرَّ بِهَا إِلاَّ وَهُوَ آخِذٌ بِنُصُولِهَا ‏.‏\hadithno{2586}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2614)}\hadithtrans{Jabir said “The Apostle of Allaah(ﷺ) ordered a man who was distributing arrows not to pass the mosque with them except that he is holding their heads}}
\hadithdefcmd{abudawud}{2587}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا مَرَّ أَحَدُكُمْ فِي مَسْجِدِنَا أَوْ فِي سُوقِنَا وَمَعَهُ نَبْلٌ فَلْيُمْسِكْ عَلَى نِصَالِهَا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فَلْيَقْبِضْ كَفَّهُ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فَلْيَقْبِضْ بِكَفِّهِ أَنْ يُصِيبَ أَحَدًا مِنَ الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{2587}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7075) Sahih Muslim (2515)}\hadithtrans{Abu Musa reported the Apostle of Allaah(ﷺ) as saying “ When one of you passes our Masjid or our market with an arrow, he should hold its head or hold it with its hand (the narrator is doubtful) so that no harm may be done to any Muslim.”}}
\hadithdefcmd{abudawud}{2588}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُتَعَاطَى السَّيْفُ مَسْلُولاً ‏.‏\hadithno{2588}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) prohibited to hand the drawn sword}}
\hadithdefcmd{abudawud}{2589}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا قُرَيْشُ بْنُ أَنَسٍ، حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُقَدَّ السَّيْرُ بَيْنَ أُصْبُعَيْنِ ‏.‏\hadithno{2589}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Samurah ibn Jundub: The Messenger of Allah (ﷺ) prohibited to cut a piece of leather between two fingers}}
\hadithdefcmd{abudawud}{2590}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، قَالَ حَسِبْتُ أَنِّي سَمِعْتُ يَزِيدَ بْنَ خُصَيْفَةَ، يَذْكُرُ عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ رَجُلٍ، قَدْ سَمَّاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ظَاهَرَ يَوْمَ أُحُدٍ بَيْنَ دِرْعَيْنِ أَوْ لَبِسَ دِرْعَيْنِ ‏.‏\hadithno{2590}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated As-Sa'ib ibn Yazid: As-Sa'ib reported on the authority of a man whom he named: The Messenger of Allah (ﷺ) put on two coats of mail during the battle of Uhud as a double protection. (The narrator is doubtful about the word zahara or labisa)}}
\hadithdefcmd{abudawud}{2591}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، أَخْبَرَنَا أَبُو يَعْقُوبَ الثَّقَفِيُّ، حَدَّثَنِي يُونُسُ بْنُ عُبَيْدٍ، - رَجُلٌ مِنْ ثَقِيفٍ مَوْلَى مُحَمَّدِ بْنِ الْقَاسِمِ - قَالَ بَعَثَنِي مُحَمَّدُ بْنُ الْقَاسِمِ إِلَى الْبَرَاءِ بْنِ عَازِبٍ يَسْأَلُهُ عَنْ رَايَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم مَا كَانَتْ فَقَالَ كَانَتْ سَوْدَاءَ مُرَبَّعَةً مِنْ نَمِرَةٍ ‏.‏\hadithno{2591}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Bara' ibn Azib: Yunus ibn Ubayd, client of Muhammad ibn al-Qasim, said that Muhammad ibn al-Qasim sent to al-Bara' ibn Azib to ask him about the standard of the Messenger of Allah (ﷺ). He said: It was black and square, being made of a woollen rug}}
\hadithdefcmd{abudawud}{2592}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْمَرْوَزِيُّ، - وَهُوَ ابْنُ رَاهَوَيْهِ - حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا شَرِيكٌ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، يَرْفَعُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ لِوَاؤُهُ يَوْمَ دَخَلَ مَكَّةَ أَبْيَضَ ‏.‏\hadithno{2592}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: When the Prophet (ﷺ) entered Mecca his banner was white}}
\hadithdefcmd{abudawud}{2593}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ الشَّعِيرِيُّ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، عَنْ رَجُلٍ، مِنْ قَوْمِهِ عَنْ آخَرَ، مِنْهُمْ قَالَ رَأَيْتُ رَايَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَفْرَاءَ ‏.‏\hadithno{2593}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Simak ibn Harb: Simak reported on the authority of a man from his people, on the authority of another man from them: I saw that the standard of the Messenger of Allah (ﷺ) was yellow}}
\hadithdefcmd{abudawud}{2594}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا ابْنُ جَابِرٍ، عَنْ زَيْدِ بْنِ أَرْطَاةَ الْفَزَارِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ الْحَضْرَمِيِّ، أَنَّهُ سَمِعَ أَبَا الدَّرْدَاءِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ ابْغُونِي الضُّعَفَاءَ فَإِنَّمَا تُرْزَقُونَ وَتُنْصَرُونَ بِضُعَفَائِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ زَيْدُ بْنُ أَرْطَاةَ أَخُو عَدِيِّ بْنِ أَرْطَاةَ ‏.‏\hadithno{2594}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbudDarda': I heard the Messenger of Allah (ﷺ) say: Seek for me weak persons, for you are provided means of subsistence and helped through your weaklings. Abu Dawud said: Zaid b. Artat is the brother of 'Adi b. Artat}}
\hadithdefcmd{abudawud}{2595}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ الْحَجَّاجِ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ كَانَ شِعَارُ الْمُهَاجِرِينَ عَبْدُ اللَّهِ وَشِعَارُ الأَنْصَارِ عَبْدُ الرَّحْمَنِ ‏.‏\hadithno{2595}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Samurah bin Jundub said “The war-cry of the Emigrants was ‘Abd Allah and that of the helpers ‘Abd Al Rahman.”}}
\hadithdefcmd{abudawud}{2596}{حَدَّثَنَا هَنَّادٌ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ، عَنْ أَبِيهِ، قَالَ غَزَوْنَا مَعَ أَبِي بَكْرٍ - رضى الله عنه - زَمَنَ النَّبِيِّ صلى الله عليه وسلم فَكَانَ شِعَارُنَا أَمِتْ أَمِتْ ‏.‏\hadithno{2596}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ilyas bin Salamah(bin Al Akwa’) said on the authority of his father “We went on an expedition with Abu Bakr (Allaah be pleased with him) in the time of the Apostle of Allaah(ﷺ) and our war cry was “Put to death” “Put to death”.”}}
\hadithdefcmd{abudawud}{2597}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْمُهَلَّبِ بْنِ أَبِي صُفْرَةَ، قَالَ أَخْبَرَنِي مَنْ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنْ بُيِّتُّمْ فَلْيَكُنْ شِعَارُكُمْ حم لاَ يُنْصَرُونَ ‏"‏ ‏.‏\hadithno{2597}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated A man who heard the Prophet: Al-Muhallab ibn AbuSufrah said: A man who heard the Prophet (ﷺ) say: If the enemy attacks you at night, let your war cry be Ha-Mim. They will not be helped}}
\hadithdefcmd{abudawud}{2598}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، حَدَّثَنِي سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَافَرَ قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ وَسُوءِ الْمَنْظَرِ فِي الأَهْلِ وَالْمَالِ اللَّهُمَّ اطْوِ لَنَا الأَرْضَ وَهَوِّنْ عَلَيْنَا السَّفَرَ ‏"‏ ‏.‏\hadithno{2598}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: When the Messenger of Allah (ﷺ) proceeded on journey, he would say: O Allah, Thou art the Companion in the journey, and the One Who looks after the family; O Allah, I seek refuge in Thee from the difficulty of travelling, finding harm when I return, and unhappiness in what I see coming to my family and property. O Allah, make the length of his journey short for us, and the journey easy for us}}
\hadithdefcmd{abudawud}{2599}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّ عَلِيًّا الأَزْدِيَّ، أَخْبَرَهُ أَنَّ ابْنَ عُمَرَ عَلَّمَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اسْتَوَى عَلَى بَعِيرِهِ خَارِجًا إِلَى سَفَرٍ كَبَّرَ ثَلاَثًا ثُمَّ قَالَ ‏"‏ ‏\{‏ سُبْحَانَ الَّذِي سَخَّرَ لَنَا هَذَا وَمَا كُنَّا لَهُ مُقْرِنِينَ * وَإِنَّا إِلَى رَبِّنَا لَمُنْقَلِبُونَ ‏\}‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ فِي سَفَرِنَا هَذَا الْبِرَّ وَالتَّقْوَى وَمِنَ الْعَمَلِ مَا تَرْضَى اللَّهُمَّ هَوِّنْ عَلَيْنَا سَفَرَنَا هَذَا اللَّهُمَّ اطْوِ لَنَا الْبُعْدَ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ وَالْمَالِ ‏"‏ ‏.‏ وَإِذَا رَجَعَ قَالَهُنَّ وَزَادَ فِيهِنَّ ‏"‏ آيِبُونَ تَائِبُونَ عَابِدُونَ لِرَبِّنَا حَامِدُونَ ‏"‏ ‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم وَجُيُوشُهُ إِذَا عَلَوُا الثَّنَايَا كَبَّرُوا وَإِذَا هَبَطُوا سَبَّحُوا فَوُضِعَتِ الصَّلاَةُ عَلَى ذَلِكَ ‏.‏\hadithno{2599}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1342)}\hadithtrans{Narrated Abdullah ibn Umar: When the Messenger of Allah (ﷺ) sat on his camel to go out on a journey, he said: "Allah is Most Great" three times. Then he said: "Glory be to Him Who has made subservient to us, for we had not the strength for it, and to our Lord do we return. O Allah, we ask Thee in this journey of ours, uprightness, piety and such deeds as are pleasing to Thee. O Allah, make easy for us this journey of ours and make its length short for us. O Allah, Thou art the Companion in the journey, and the One Who looks after the family and property in our absence." When he returned, he said these words adding: "Returning, repentant, serving and praising our Lord." The Prophet (ﷺ) and his armies said: "Allah is Most Great" when they went up to high ground; and when armies said: "Allah is most Great" when they went up to high ground; and when they descended, they said: "Glory be to Allah." So the prayer was patterned on that}}
\hadithdefcmd{abudawud}{2600}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، عَنْ إِسْمَاعِيلَ بْنِ جَرِيرٍ، عَنْ قَزَعَةَ، قَالَ قَالَ لِي ابْنُ عُمَرَ هَلُمَّ أُوَدِّعْكَ كَمَا وَدَّعَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَسْتَوْدِعُ اللَّهَ دِينَكَ وَأَمَانَتَكَ وَخَوَاتِيمَ عَمَلِكَ ‏"‏ ‏.‏\hadithno{2600}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qaza’ah said Ibn ‘Umar told me “Come, I see off you as the Apostle of Allaah(ﷺ) saw me off. I entrust to Allaah your religion what you are responsible for and your final deeds.”}}
\hadithdefcmd{abudawud}{2601}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ السَّيْلَحِينِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي جَعْفَرٍ الْخَطْمِيِّ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنْ عَبْدِ اللَّهِ الْخَطْمِيِّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَسْتَوْدِعَ الْجَيْشَ قَالَ ‏ "‏ أَسْتَوْدِعُ اللَّهَ دِينَكُمْ وَأَمَانَتَكُمْ وَخَوَاتِيمَ أَعْمَالِكُمْ ‏"‏ ‏.‏\hadithno{2601}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah al-Khutami: When the Prophet (ﷺ) wanted to say farewell to an army, he would say: I entrust to Allah your religion, what you are responsible for, and your final deeds}}
\hadithdefcmd{abudawud}{2602}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَبُو إِسْحَاقَ الْهَمْدَانِيُّ، عَنْ عَلِيِّ بْنِ رَبِيعَةَ، قَالَ شَهِدْتُ عَلِيًّا - رضى الله عنه - وَأُتِيَ بِدَابَّةٍ لِيَرْكَبَهَا فَلَمَّا وَضَعَ رِجْلَهُ فِي الرِّكَابِ قَالَ بِسْمِ اللَّهِ فَلَمَّا اسْتَوَى عَلَى ظَهْرِهَا قَالَ الْحَمْدُ لِلَّهِ ثُمَّ قَالَ ‏\{‏ سُبْحَانَ الَّذِي سَخَّرَ لَنَا هَذَا وَمَا كُنَّا لَهُ مُقْرِنِينَ * وَإِنَّا إِلَى رَبِّنَا لَمُنْقَلِبُونَ ‏\}‏ ثُمَّ قَالَ الْحَمْدُ لِلَّهِ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏ ثُمَّ قَالَ اللَّهُ أَكْبَرُ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ قَالَ سُبْحَانَكَ إِنِّي ظَلَمْتُ نَفْسِي فَاغْفِرْ لِي فَإِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ ‏.‏ ثُمَّ ضَحِكَ فَقِيلَ يَا أَمِيرَ الْمُؤْمِنِينَ مِنْ أَىِّ شَىْءٍ ضَحِكْتَ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم فَعَلَ كَمَا فَعَلْتُ ثُمَّ ضَحِكَ فَقُلْتُ يَا رَسُولَ اللَّهِ مِنْ أَىِّ شَىْءٍ ضَحِكْتَ قَالَ ‏"‏ إِنَّ رَبَّكَ يَعْجَبُ مِنْ عَبْدِهِ إِذَا قَالَ اغْفِرْ لِي ذُنُوبِي يَعْلَمُ أَنَّهُ لاَ يَغْفِرُ الذُّنُوبَ غَيْرِي ‏"‏ ‏.‏\hadithno{2602}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ali ibn AbuTalib: Ali ibn Rabi'ah said: I was present with Ali while a beast was brought to him to ride. When he put his foot in the stirrup, he said: "In the name of Allah." Then when he sat on its back, he said: "Praise be to Allah." He then said: "Glory be to Him Who has made this subservient to us, for we had not the strength, and to our Lord do we return." He then said: "Praise be to Allah (thrice); Allah is Most Great (thrice): glory be to Thee, I have wronged myself, so forgive me, for only Thou forgivest sins." He then laughed. He was asked: At what did you laugh? He replied: I saw the Messenger of Allah (ﷺ) do as I have done, and laugh after that. I asked: Messenger of Allah , at what are you laughing? He replied: Your Lord, Most High, is pleased with His servant when he says: "Forgive me my sins." He know that no one forgives sins except Him}}
\hadithdefcmd{abudawud}{2603}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي صَفْوَانُ، حَدَّثَنِي شُرَيْحُ بْنُ عُبَيْدٍ، عَنِ الزُّبَيْرِ بْنِ الْوَلِيدِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَافَرَ فَأَقْبَلَ اللَّيْلُ قَالَ ‏ "‏ يَا أَرْضُ رَبِّي وَرَبُّكِ اللَّهُ أَعُوذُ بِاللَّهِ مِنْ شَرِّكِ وَشَرِّ مَا فِيكِ وَشَرِّ مَا خُلِقَ فِيكِ وَمِنْ شَرِّ مَا يَدِبُّ عَلَيْكِ وَأَعُوذُ بِاللَّهِ مِنْ أَسَدٍ وَأَسْوَدَ وَمِنَ الْحَيَّةِ وَالْعَقْرَبِ وَمِنْ سَاكِنِ الْبَلَدِ وَمِنْ وَالِدٍ وَمَا وَلَدَ ‏"‏ ‏.‏\hadithno{2603}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr: When the Messenger of Allah (ﷺ) was travelling and night came on, he said: O earth, my Lord and your Lord is Allah; I seek refuge in Allah from your evil, the evil of what you contain, the evil of what has been created in you, and the evil of what creeps upon you; I seek refuge in Allah from lions, from large black snakes, from other snakes, from scorpions, from the evil of jinn which inhabit a settlement, and from a parent and his offspring}}
\hadithdefcmd{abudawud}{2604}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُرْسِلُوا فَوَاشِيَكُمْ إِذَا غَابَتِ الشَّمْسُ حَتَّى تَذْهَبَ فَحْمَةُ الْعِشَاءِ فَإِنَّ الشَّيَاطِينَ تَعِيثُ إِذَا غَابَتِ الشَّمْسُ حَتَّى تَذْهَبَ فَحْمَةُ الْعِشَاءِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْفَوَاشِي مَا يَفْشُو مِنْ كُلِّ شَىْءٍ ‏.‏\hadithno{2604}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2013)}\hadithtrans{Jabir bin ‘Abd Allaah reported the Apostle of Allaah(ﷺ) as saying “Do not send out your beasts when the sun has set till the darkness of the night prevails, for the devils grope about in the dark when the sun has set till the darkness of the night prevails.”}}
\hadithdefcmd{abudawud}{2605}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ كَعْبِ بْنِ مَالِكٍ، قَالَ قَلَّمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْرُجُ فِي سَفَرٍ إِلاَّ يَوْمَ الْخَمِيسِ ‏.‏\hadithno{2605}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2948)}\hadithtrans{Narrated Ka'b ibn Malik: It was rarely that the Messenger of Allah (ﷺ) set out on a journey on any day but on a Thursday}}
\hadithdefcmd{abudawud}{2606}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا يَعْلَى بْنُ عَطَاءٍ، حَدَّثَنَا عُمَارَةُ بْنُ حَدِيدٍ، عَنْ صَخْرٍ الْغَامِدِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لأُمَّتِي فِي بُكُورِهَا ‏"‏ ‏.‏ وَكَانَ إِذَا بَعَثَ سَرِيَّةً أَوْ جَيْشًا بَعَثَهُمْ فِي أَوَّلِ النَّهَارِ ‏.‏ وَكَانَ صَخْرٌ رَجُلاً تَاجِرًا وَكَانَ يَبْعَثُ تِجَارَتَهُ مِنْ أَوَّلِ النَّهَارِ فَأَثْرَى وَكَثُرَ مَالُهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ صَخْرُ بْنُ وَدَاعَةَ ‏.‏\hadithno{2606}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sakhr al-Ghamidi: The Prophet (ﷺ) said: "O Allah, bless my people in their early mornings." When he sent out a detachment or an army, he sent them at the beginning of the day. Sakhr was a merchant, and he would send off his merchandise at the beginning of the day; and he became rich and had much wealth. Abu Dawud said: He is Sakhr b. Wada'ah}}
\hadithdefcmd{abudawud}{2607}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّاكِبُ شَيْطَانٌ وَالرَّاكِبَانِ شَيْطَانَانِ وَالثَّلاَثَةُ رَكْبٌ ‏"‏ ‏.‏\hadithno{2607}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: A single rider is a devil, and a pair of riders are a pair of devils, but three are a company of riders}}
\hadithdefcmd{abudawud}{2608}{حَدَّثَنَا عَلِيُّ بْنُ بَحْرِ بْنِ بَرِّيٍّ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنْ نَافِعٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا خَرَجَ ثَلاَثَةٌ فِي سَفَرٍ فَلْيُؤَمِّرُوا أَحَدَهُمْ ‏"‏ ‏.‏\hadithno{2608}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: When three are on a journey, they should appoint one of them as their commander}}
\hadithdefcmd{abudawud}{2609}{حَدَّثَنَا عَلِيُّ بْنُ بَحْرٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنْ نَافِعٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ ثَلاَثَةٌ فِي سَفَرٍ فَلْيُؤَمِّرُوا أَحَدَهُمْ ‏"‏ ‏.‏ قَالَ نَافِعٌ فَقُلْنَا لأَبِي سَلَمَةَ فَأَنْتَ أَمِيرُنَا ‏.‏\hadithno{2609}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When three are on a journey, they should appoint one of them as their commander. Nafi' said: We said to AbuSalamah: You are our commander}}
\hadithdefcmd{abudawud}{2610}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُسَافَرَ بِالْقُرْآنِ إِلَى أَرْضِ الْعَدُوِّ ‏.‏ قَالَ مَالِكٌ أُرَاهُ مَخَافَةَ أَنْ يَنَالَهُ الْعَدُوُّ ‏.‏\hadithno{2610}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2990) Sahih Muslim (1869)}\hadithtrans{‘Abd Allaah bin ‘Umar said “The Apostle of Allaah(ﷺ) prohibited to travel with a copy of the Qur’an to the enemy territory. The narrator Malik said “(It is) I think lest the enemy should take it}}
\hadithdefcmd{abudawud}{2611}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ أَبُو خَيْثَمَةَ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الصَّحَابَةِ أَرْبَعَةٌ وَخَيْرُ السَّرَايَا أَرْبَعُمِائَةٍ وَخَيْرُ الْجُيُوشِ أَرْبَعَةُ آلاَفٍ وَلَنْ يُغْلَبَ اثْنَا عَشَرَ أَلْفًا مِنْ قِلَّةٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَالصَّحِيحُ أَنَّهُ مُرْسَلٌ ‏.‏\hadithno{2611}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: The best number of companions is four, the best number in expeditions four hundred, and the best number in armies four thousand; and twelve thousand will not be overcome through smallness of numbers. Abu Dawud said: What is correct is that this tradition is mursal (i.e. the link of the Companion is missing)}}
\hadithdefcmd{abudawud}{2612}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا بَعَثَ أَمِيرًا عَلَى سَرِيَّةٍ أَوْ جَيْشٍ أَوْصَاهُ بِتَقْوَى اللَّهِ فِي خَاصَّةِ نَفْسِهِ وَبِمَنْ مَعَهُ مِنَ الْمُسْلِمِينَ خَيْرًا وَقَالَ ‏ "‏ إِذَا لَقِيتَ عَدُوَّكَ مِنَ الْمُشْرِكِينَ فَادْعُهُمْ إِلَى إِحْدَى ثَلاَثِ خِصَالٍ أَوْ خِلاَلٍ فَأَيَّتُهَا أَجَابُوكَ إِلَيْهَا فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمُ ادْعُهُمْ إِلَى الإِسْلاَمِ فَإِنْ أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ ثُمَّ ادْعُهُمْ إِلَى التَّحَوُّلِ مِنْ دَارِهِمْ إِلَى دَارِ الْمُهَاجِرِينَ وَأَعْلِمْهُمْ أَنَّهُمْ إِنْ فَعَلُوا ذَلِكَ أَنَّ لَهُمْ مَا لِلْمُهَاجِرِينَ وَأَنَّ عَلَيْهِمْ مَا عَلَى الْمُهَاجِرِينَ فَإِنْ أَبَوْا وَاخْتَارُوا دَارَهُمْ فَأَعْلِمْهُمْ أَنَّهُمْ يَكُونُونَ كَأَعْرَابِ الْمُسْلِمِينَ يُجْرَى عَلَيْهِمْ حُكْمُ اللَّهِ الَّذِي يَجْرِي عَلَى الْمُؤْمِنِينَ وَلاَ يَكُونُ لَهُمْ فِي الْفَىْءِ وَالْغَنِيمَةِ نَصِيبٌ إِلاَّ أَنْ يُجَاهِدُوا مَعَ الْمُسْلِمِينَ فَإِنْ هُمْ أَبَوْا فَادْعُهُمْ إِلَى إِعْطَاءِ الْجِزْيَةِ فَإِنْ أَجَابُوا فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ فَإِنْ أَبَوْا فَاسْتَعِنْ بِاللَّهِ تَعَالَى وَقَاتِلْهُمْ وَإِذَا حَاصَرْتَ أَهْلَ حِصْنٍ فَأَرَادُوكَ أَنْ تُنْزِلَهُمْ عَلَى حُكْمِ اللَّهِ تَعَالَى فَلاَ تُنْزِلْهُمْ فَإِنَّكُمْ لاَ تَدْرُونَ مَا يَحْكُمُ اللَّهُ فِيهِمْ وَلَكِنْ أَنْزِلُوهُمْ عَلَى حُكْمِكُمْ ثُمَّ اقْضُوا فِيهِمْ بَعْدُ مَا شِئْتُمْ ‏"‏ ‏.‏ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ قَالَ عَلْقَمَةُ فَذَكَرْتُ هَذَا الْحَدِيثَ لِمُقَاتِلِ بْنِ حَيَّانَ فَقَالَ حَدَّثَنِي مُسْلِمٌ - قَالَ أَبُو دَاوُدَ هُوَ ابْنُ هَيْصَمٍ - عَنِ النُّعْمَانِ بْنِ مُقَرِّنٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ حَدِيثِ سُلَيْمَانَ بْنِ بُرَيْدَةَ ‏.‏\hadithno{2612}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1731)}\hadithtrans{Sulaiman bin Buraidah reported on the authority of his father. When the Apostle of Allaah(ﷺ) appointed a Commander over an Army or a detachment, he instructed him to fear Allaah himself and consider the welfare of the Muslims who were with him. He then said “When you meet the polytheists who are your enemy, summon them tone of three things and accept whichever of them they are willing to agree to, and refrain from them. Summon them to Islam and if they agree, accept it from them and refrain from them. Then summon them to leave their territory and transfer to the abode of the Emigrants and tell them that if they do so, they will have the same rights and responsibilities as the Emigrants, but if they refuse and choose their own abode, tell them that they will be like the desert Arabs who are Muslims subject to Allaah’s jurisdiction which applies to the believers, but will have no spoil or booty unless they strive with the Muslims. If they refuse demand jizyah (poll tax) from them, if they agree accept it from them and refrain from them. But if they refuse, seek Alaah’s help and fight with them. When you invade the fortress and they (its people) offer to capitulate and have the matter referred to Allaah’s jurisdiction, do not grant this, for you do not know whether or not you will hit on Allaah’s jurisdiction regarding them. But let them capitulate and have the matter refereed to your jurisdiction and make a decision about them later on as you wish. Sufyan (bin ‘Uyainah) said thah ‘Alqamah said “I mentioned this tradition to Muqatil bin Habban, He said “Muslim narrated it to me.” Abu Dawud said “He is Ibn Haidam narrated from Al Nu’man in Muqqarin from the Prophet (ﷺ) like the tradition of Sulaiman bin Buraidah}}
\hadithdefcmd{abudawud}{2613}{حَدَّثَنَا أَبُو صَالِحٍ الأَنْطَاكِيُّ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ اغْزُوا بِاسْمِ اللَّهِ وَفِي سَبِيلِ اللَّهِ وَقَاتِلُوا مَنْ كَفَرَ بِاللَّهِ اغْزُوا وَلاَ تَغْدِرُوا وَلاَ تَغُلُّوا وَلاَ تُمَثِّلُوا وَلاَ تَقْتُلُوا وَلِيدًا ‏"‏ ‏.‏\hadithno{2613}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sulaiman bin Buraidah reported on his father’s authority The Prophet(ﷺ) said “Fight in the name of Allaah and in the path of Allaah and with him who disbelieves in Allaah fight and do not be treacherous and do not be dishonest about boot yand do not deface (in killing) and do not kill a child.”}}
\hadithdefcmd{abudawud}{2614}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، وَعُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ حَسَنِ بْنِ صَالِحٍ، عَنْ خَالِدِ بْنِ الْفِرْزِ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ انْطَلِقُوا بِاسْمِ اللَّهِ وَبِاللَّهِ وَعَلَى مِلَّةِ رَسُولِ اللَّهِ وَلاَ تَقْتُلُوا شَيْخًا فَانِيًا وَلاَ طِفْلاً وَلاَ صَغِيرًا وَلاَ امْرَأَةً وَلاَ تَغُلُّوا وَضُمُّوا غَنَائِمَكُمْ وَأَصْلِحُوا وَأَحْسِنُوا ‏\{‏ إِنَّ اللَّهَ يُحِبُّ الْمُحْسِنِينَ ‏\}‏ ‏"‏ ‏.‏\hadithno{2614}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: Go in Allah's name, trusting in Allah, and adhering to the religion of Allah's Apostle. Do not kill a decrepit old man, or a young infant, or a child, or a woman; do not be dishonest about booty, but collect your spoils, do right and act well, for Allah loves those who do well}}
\hadithdefcmd{abudawud}{2615}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّقَ نَخْلَ بَنِي النَّضِيرِ وَقَطَعَ وَهِيَ الْبُوَيْرَةُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ مَا قَطَعْتُمْ مِنْ لِينَةٍ أَوْ تَرَكْتُمُوهَا ‏\}‏‏.‏\hadithno{2615}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4884) Sahih Muslim (1746)}\hadithtrans{Ibn “umar said “The Apostle of Allaah(ﷺ) burned the palm tree of Banu Al Nadr and cut (them) down at Al Buwairah. So, Allaah the exalted sent down “the palm trees you cut down or left.”}}
\hadithdefcmd{abudawud}{2616}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ صَالِحِ بْنِ أَبِي الأَخْضَرِ، عَنِ الزُّهْرِيِّ، قَالَ عُرْوَةُ فَحَدَّثَنِي أُسَامَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَهِدَ إِلَيْهِ فَقَالَ ‏ "‏ أَغِرْ عَلَى أُبْنَى صَبَاحًا وَحَرِّقْ ‏"‏ ‏.‏\hadithno{2616}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Usamah: The Messenger of Allah (ﷺ) enjoined upon him to attack Ubna in the morning and burn the place}}
\hadithdefcmd{abudawud}{2617}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرٍو الْغَزِّيُّ، سَمِعْتُ أَبَا مُسْهِرٍ، قِيلَ لَهُ أُبْنَى ‏.‏ قَالَ نَحْنُ أَعْلَمُ هِيَ يُبْنَى فِلَسْطِينَ ‏.‏\hadithno{2617}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Mishar was told about Ubna. He said “We know it better. This is Yubna of Palestine}}
\hadithdefcmd{abudawud}{2618}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ بَعَثَ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - بُسْبَسَةَ عَيْنًا يَنْظُرُ مَا صَنَعَتْ عِيرُ أَبِي سُفْيَانَ ‏.‏\hadithno{2618}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1901)}\hadithtrans{Anas said “the Prophet(ﷺ) sent Busaisah as a spy to see what the caravan of Abu Sufyan was doing.”}}
\hadithdefcmd{abudawud}{2619}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ الرَّقَّامُ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَتَى أَحَدُكُمْ عَلَى مَاشِيَةٍ فَإِنْ كَانَ فِيهَا صَاحِبُهَا فَلْيَسْتَأْذِنْهُ فَإِنْ أَذِنَ لَهُ فَلْيَحْلِبْ وَلْيَشْرَبْ فَإِنْ لَمْ يَكُنْ فِيهَا فَلْيُصَوِّتْ ثَلاَثًا فَإِنْ أَجَابَهُ فَلْيَسْتَأْذِنْهُ وَإِلاَّ فَلْيَحْتَلِبْ وَلْيَشْرَبْ وَلاَ يَحْمِلْ ‏"‏ ‏.‏\hadithno{2619}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: When one of you comes to the cattle, he should seek permission of their master if he is there; if he permits, he should milk (the animals) and drink. If he is not there, he should call three times. If he responds, he should seek his permission; otherwise, he may milk (the animals) and drink, but should not carry (with him)}}
\hadithdefcmd{abudawud}{2620}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ عَبَّادِ بْنِ شُرَحْبِيلَ، قَالَ أَصَابَتْنِي سَنَةٌ فَدَخَلْتُ حَائِطًا مِنْ حِيطَانِ الْمَدِينَةِ فَفَرَكْتُ سُنْبُلاً فَأَكَلْتُ وَحَمَلْتُ فِي ثَوْبِي فَجَاءَ صَاحِبُهُ فَضَرَبَنِي وَأَخَذَ ثَوْبِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ ‏"‏ مَا عَلَّمْتَ إِذْ كَانَ جَاهِلاً وَلاَ أَطْعَمْتَ إِذْ كَانَ جَائِعًا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ سَاغِبًا ‏"‏ ‏.‏ وَأَمَرَهُ فَرَدَّ عَلَىَّ ثَوْبِي وَأَعْطَانِي وَسْقًا أَوْ نِصْفَ وَسْقٍ مِنْ طَعَامٍ ‏.‏\hadithno{2620}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abbad ibn Shurahbil: I suffered from drought; so I entered a garden of Medina, and rubbed an ear-corn. I ate and carried in my garment. Then its master came, he beat me and took my garment. He came to the Messenger of Allah (ﷺ) who said to him: You did not teach him if he was ignorant; and you did not feed him if he was hungry. He ordered him, so he returned my garment to me, and gave me one or half a wasq (sixty or thirty sa's) of corn}}
\hadithdefcmd{abudawud}{2621}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، قَالَ سَمِعْتُ عَبَّادَ بْنَ شُرَحْبِيلَ، - رَجُلاً مِنَّا مِنْ بَنِي غُبَرَ - بِمَعْنَاهُ ‏.‏\hadithno{2621}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Bishr said “I heard ‘Abbad bin ‘Shurahbil a man of us from Banu Ghubar. He narrated the reast of the tradition to the same effect.”}}
\hadithdefcmd{abudawud}{2622}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ - وَهَذَا لَفْظُ أَبِي بَكْرٍ - عَنْ مُعْتَمِرِ بْنِ سُلَيْمَانَ، قَالَ سَمِعْتُ ابْنَ أَبِي حَكَمٍ الْغِفَارِيَّ، يَقُولُ حَدَّثَتْنِي جَدَّتِي، عَنْ عَمِّ أَبِي رَافِعِ بْنِ عَمْرٍو الْغِفَارِيِّ، قَالَ كُنْتُ غُلاَمًا أَرْمِي نَخْلَ الأَنْصَارِ فَأُتِيَ بِي النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا غُلاَمُ لِمَ تَرْمِي النَّخْلَ ‏"‏ ‏.‏ قَالَ آكُلُ ‏.‏ قَالَ ‏"‏ فَلاَ تَرْمِ النَّخْلَ وَكُلْ مِمَّا يَسْقُطُ فِي أَسْفَلِهَا ‏"‏ ‏.‏ ثُمَّ مَسَحَ رَأْسَهُ فَقَالَ ‏"‏ اللَّهُمَّ أَشْبِعْ بَطْنَهُ ‏"‏ ‏.‏\hadithno{2622}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated The uncle of AbuRafi ibn Amr al-Ghifari: I was a boy. I used to throw stones at the palm-trees of the Ansar. So I was brought to the Prophet (ﷺ) who said: O boy, why do you throw stones at the palm-trees? I said: eat (dates). He said: Do not throw stones at the palm trees, but eat what falls beneath them. He then wiped his head and said: O Allah, fill his belly}}
\hadithdefcmd{abudawud}{2623}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحْلُبَنَّ أَحَدٌ مَاشِيَةَ أَحَدٍ بِغَيْرِ إِذْنِهِ أَيُحِبُّ أَحَدُكُمْ أَنْ تُؤْتَى مَشْرَبَتُهُ فَتُكْسَرَ خِزَانَتُهُ فَيُنْتَثَلَ طَعَامُهُ فَإِنَّمَا تَخْزُنُ لَهُمْ ضُرُوعُ مَوَاشِيهِمْ أَطْعِمَتَهُمْ فَلاَ يَحْلُبَنَّ أَحَدٌ مَاشِيَةَ أَحَدٍ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{2623}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2435) Sahih Muslim (1726)}\hadithtrans{‘Abd Allah bin Umar reported the Apostle of Allaah(ﷺ) as saying “One should not milk the cattle of anyone without his permission. Does anyone of you like that any one approaches his corn cell and its storage is broken and then the corn scatters away? Likewise, the teats of their Cattle store their food. Therefore none of you should milk the cattle of anyone without his permission.”}}
\hadithdefcmd{abudawud}{2624}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا أَطِيعُوا اللَّهَ وَأَطِيعُوا الرَّسُولَ وَأُولِي الأَمْرِ مِنْكُمْ ‏\}‏ فِي عَبْدِ اللَّهِ بْنِ قَيْسِ بْنِ عَدِيٍّ بَعَثَهُ النَّبِيُّ صلى الله عليه وسلم فِي سَرِيَّةٍ أَخْبَرَنِيهِ يَعْلَى عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{2624}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4584) Sahih Muslim (1834)}\hadithtrans{Ibn Juraij said “O ye who believe, Obey Allaah and obey the Apostle and those charged with authority amongst you.” This verse was revealed about ‘Abd Allaah bin Qais bin ‘Adi whom the Prophet (ﷺ) sent along with a detachment. Ya’la narrated it to me from Sa’id bin Jubair on the authority of Ibn ‘Abbas}}
\hadithdefcmd{abudawud}{2625}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ زُبَيْدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ جَيْشًا وَأَمَّرَ عَلَيْهِمْ رَجُلاً وَأَمَرَهُمْ أَنْ يَسْمَعُوا لَهُ وَيُطِيعُوا فَأَجَّجَ نَارًا وَأَمَرَهُمْ أَنْ يَقْتَحِمُوا فِيهَا فَأَبَى قَوْمٌ أَنْ يَدْخُلُوهَا وَقَالُوا إِنَّمَا فَرَرْنَا مِنَ النَّارِ وَأَرَادَ قَوْمٌ أَنْ يَدْخُلُوهَا فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ لَوْ دَخَلُوهَا - أَوْ دَخَلُوا فِيهَا - لَمْ يَزَالُوا فِيهَا ‏"‏ ‏.‏ وَقَالَ ‏"‏ لاَ طَاعَةَ فِي مَعْصِيَةِ اللَّهِ إِنَّمَا الطَّاعَةُ فِي الْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{2625}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7257) Sahih Muslim (1840)}\hadithtrans{‘Ali (Allaah be pleased with him) said “The Messenger of Allah(ﷺ) sent an army and appointed a man as a commander for them and he commanded them to listen to him and obey. He kindled fire and ordered them to jump into it. A group refused to enter into it and said “We escaped from the fire; a group intended to enter into it. When the Prophet (ﷺ) was informed about it, he said “Had they entered into it, they would have remained into it. There is no obedience in matters involving disobedience to Allaah. Obedience is in matters which are good and universally recognized}}
\hadithdefcmd{abudawud}{2626}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ السَّمْعُ وَالطَّاعَةُ عَلَى الْمَرْءِ الْمُسْلِمِ فِيمَا أَحَبَّ وَكَرِهَ مَا لَمْ يُؤْمَرْ بِمَعْصِيَةٍ فَإِذَا أُمِرَ بِمَعْصِيَةٍ فَلاَ سَمْعَ وَلاَ طَاعَةَ ‏"‏ ‏.‏\hadithno{2626}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7144) Sahih Muslim (1839)}\hadithtrans{‘Abd Allaah bin Masud reported the Apostle of Allaah(ﷺ) as saying “Listening and Obedience are binding on a Muslim whether he likes or dislikes, so long as he is not commanded for disobedience (to Allaah). If he is commanded to disobedience (to Allaah), no listening and disobedience are binding (on him)}}
\hadithdefcmd{abudawud}{2627}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ بِشْرِ بْنِ عَاصِمٍ، عَنْ عُقْبَةَ بْنِ مَالِكٍ، مِنْ رَهْطِهِ قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم سَرِيَّةً فَسَلَحْتُ رَجُلاً مِنْهُمْ سَيْفًا فَلَمَّا رَجَعَ قَالَ لَوْ رَأَيْتَ مَا لاَمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَعَجَزْتُمْ إِذْ بَعَثْتُ رَجُلاً مِنْكُمْ فَلَمْ يَمْضِ لأَمْرِي أَنْ تَجْعَلُوا مَكَانَهُ مَنْ يَمْضِي لأَمْرِي ‏"‏ ‏.‏\hadithno{2627}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Uqbah ibn Malik: The Prophet (ﷺ) sent a detachment. I gave a sword to a man from among them. When he came back, he said: Would that you saw us how the Messenger of Allah (ﷺ) rebuked us, saying: When I sent out a man who does not fulfil my command, are you unable to appoint in his place one who will fulfil my command}}
\hadithdefcmd{abudawud}{2628}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ الْحِمْصِيُّ، وَيَزِيدُ بْنُ قُبَيْسٍ، - مِنْ أَهْلِ جَبَلَةَ سَاحِلِ حِمْصٍ وَهَذَا لَفْظُ يَزِيدَ - قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ عَنْ عَبْدِ اللَّهِ بْنِ الْعَلاَءِ أَنَّهُ سَمِعَ مُسْلِمَ بْنَ مِشْكَمٍ أَبَا عُبَيْدِ اللَّهِ يَقُولُ حَدَّثَنَا أَبُو ثَعْلَبَةَ الْخُشَنِيُّ قَالَ كَانَ النَّاسُ إِذَا نَزَلُوا مَنْزِلاً - قَالَ عَمْرٌو كَانَ النَّاسُ إِذَا نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْزِلاً - تَفَرَّقُوا فِي الشِّعَابِ وَالأَوْدِيَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ تَفَرُّقَكُمْ فِي هَذِهِ الشِّعَابِ وَالأَوْدِيَةِ إِنَّمَا ذَلِكُمْ مِنَ الشَّيْطَانِ ‏"‏ ‏.‏ فَلَمْ يَنْزِلْ بَعْدَ ذَلِكَ مَنْزِلاً إِلاَّ انْضَمَّ بَعْضُهُمْ إِلَى بَعْضٍ حَتَّى يُقَالُ لَوْ بُسِطَ عَلَيْهِمْ ثَوْبٌ لَعَمَّهُمْ ‏.‏\hadithno{2628}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuTha'labah al-Khushani: When the people encamped, (the narrator Amr ibn Uthman al-Himsi) said: When the Messenger of Allah (ﷺ) encamped, the people scattered in the glens and wadis. The Messenger of Allah (ﷺ) said: Your scattering in these glens and wadis is only of the devil. They afterwards kept close together when they encamped to such an extent that it used to be said that if a cloth were spread over them, it would cover them all}}
\hadithdefcmd{abudawud}{2629}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ أَسِيدِ بْنِ عَبْدِ الرَّحْمَنِ الْخَثْعَمِيِّ، عَنْ فَرْوَةَ بْنِ مُجَاهِدٍ اللَّخْمِيِّ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، قَالَ غَزَوْتُ مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم غَزْوَةَ كَذَا وَكَذَا فَضَيَّقَ النَّاسُ الْمَنَازِلَ وَقَطَعُوا الطَّرِيقَ فَبَعَثَ نَبِيُّ اللَّهِ صلى الله عليه وسلم مُنَادِيًا يُنَادِي فِي النَّاسِ أَنَّ مَنْ ضَيَّقَ مَنْزِلاً أَوْ قَطَعَ طَرِيقًا فَلاَ جِهَادَ لَهُ ‏.‏\hadithno{2629}\hadithgrade{Al-Albani: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Mu'adh ibn Anas al-Juhani: I fought along with the Prophet (ﷺ) in such and such battles. The people occupied much space and encroached on the road. The Prophet (ﷺ) sent an announcer to announce among the people: Those who occupy much space or encroach on the road will not be credited with jihad}}
\hadithdefcmd{abudawud}{2630}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا بَقِيَّةُ، عَنِ الأَوْزَاعِيِّ، عَنْ أَسِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ فَرْوَةَ بْنِ مُجَاهِدٍ، عَنْ سَهْلِ بْنِ مُعَاذٍ، عَنْ أَبِيهِ، قَالَ غَزَوْنَا مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمَعْنَاهُ ‏.‏\hadithno{2630}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Sahl bin Mu’adh reported on the authority of his father “We fought along with the Prophet of Allaah(ﷺ). The rest of the tradition is to the same effect.”}}
\hadithdefcmd{abudawud}{2631}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ - يَعْنِي ابْنَ مَعْمَرٍ وَكَانَ كَاتِبًا لَهُ - قَالَ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى حِينَ خَرَجَ إِلَى الْحَرُورِيَّةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَيَّامِهِ الَّتِي لَقِيَ فِيهَا الْعَدُوَّ قَالَ ‏"‏ يَا أَيُّهَا النَّاسُ لاَ تَتَمَنَّوْا لِقَاءَ الْعَدُوِّ وَسَلُوا اللَّهَ تَعَالَى الْعَافِيَةَ فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا وَاعْلَمُوا أَنَّ الْجَنَّةَ تَحْتَ ظِلاَلِ السُّيُوفِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ وَمُجْرِيَ السَّحَابِ وَهَازِمَ الأَحْزَابِ اهْزِمْهُمْ وَانْصُرْنَا عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{2631}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3024) Sahih Muslim (1742)}\hadithtrans{Salim Abu Al Nadr, client of ‘Umar bin ‘Ubaid Allaah that is Ibn Ma’mar who Salim was his (‘Umar’s) secretary reported “When ‘Abd Allah bin Abi Afwa went out to the Haruriyyah (Khawarij), he wrote to him (‘Umar bin ‘Ubaid Allaah), The Messenger of Allah(ﷺ) said on a ceratin day when he was fighting with the enemy. O people do not desire to meet the enemy, ask Allaah, Most High, for health and security. When you meet them (the enemy) have patience and endurance, you should know that paradise is under the shade of swords. He then said “O Allaah, Who sends down the Book, makes the cloud to travel and rotes the confederates, tout them and give us victory over them.”}}
\hadithdefcmd{abudawud}{2632}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا أَبِي، حَدَّثَنَا الْمُثَنَّى بْنُ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا غَزَا قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ عَضُدِي وَنَصِيرِي بِكَ أَحُولُ وَبِكَ أَصُولُ وَبِكَ أُقَاتِلُ ‏"‏ ‏.‏\hadithno{2632}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: When the Messenger of Allah (ﷺ) went on an expedition, he said: O Allah, Thou art my aider and helper; by Thee I move, by Thee I attack, and by Thee I fight}}
\hadithdefcmd{abudawud}{2633}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا ابْنُ عَوْنٍ، قَالَ كَتَبْتُ إِلَى نَافِعٍ أَسْأَلُهُ عَنْ دُعَاءِ الْمُشْرِكِينَ، عِنْدَ الْقِتَالِ فَكَتَبَ إِلَىَّ أَنَّ ذَلِكَ كَانَ فِي أَوَّلِ الإِسْلاَمِ وَقَدْ أَغَارَ نَبِيُّ اللَّهِ صلى الله عليه وسلم عَلَى بَنِي الْمُصْطَلِقِ وَهُمْ غَارُّونَ وَأَنْعَامُهُمْ تُسْقَى عَلَى الْمَاءِ فَقَتَلَ مُقَاتِلَتَهُمْ وَسَبَى سَبْيَهُمْ وَأَصَابَ يَوْمَئِذٍ جُوَيْرِيَةَ بِنْتَ الْحَارِثِ حَدَّثَنِي بِذَلِكَ عَبْدُ اللَّهِ وَكَانَ فِي ذَلِكَ الْجَيْشِ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثٌ نَبِيلٌ رَوَاهُ ابْنُ عَوْنٍ عَنْ نَافِعٍ وَلَمْ يُشْرِكْهُ فِيهِ أَحَدٌ ‏.‏\hadithno{2633}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2541) Sahih Muslim (1730)}\hadithtrans{Ibn ‘Awn said “I wrote to Nafi’ asking him about summoning the polytheists (to Islam) at the time of fighting. So, he wrote to me “This was in the early days of Islam. The Prophet of Allaah(ﷺ) attacked Banu Al Mustaliq while they were inattentive and their cattle were drinking water. So their fighters were killed and the survivors (i.e., women and children) were taken prisoners. On that day Juwairiyyah daughter of Al Harith was obtained. ‘Abd Allaah narrated this to me, he was in that army.” Abu Dawud said “This is a good tradition narrtted by Ibn ‘Awn from Nafi’ and no one shared him in narrating it.”}}
\hadithdefcmd{abudawud}{2634}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُغِيرُ عِنْدَ صَلاَةِ الصُّبْحِ وَكَانَ يَتَسَمَّعُ فَإِذَا سَمِعَ أَذَانًا أَمْسَكَ وَإِلاَّ أَغَارَ ‏.‏\hadithno{2634}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (382)}\hadithtrans{Anas said “The Prophet (ﷺ) used to attack at the time of the dawn prayer and hear. If he heard a call to prayer, he would refrain from them, otherwise would attack (them)}}
\hadithdefcmd{abudawud}{2635}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ نَوْفَلِ بْنِ مُسَاحِقٍ، عَنِ ابْنِ عِصَامٍ الْمُزَنِيِّ، عَنْ أَبِيهِ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَرِيَّةٍ فَقَالَ ‏ "‏ إِذَا رَأَيْتُمْ مَسْجِدًا أَوْ سَمِعْتُمْ مُؤَذِّنًا فَلاَ تَقْتُلُوا أَحَدًا ‏"‏ ‏.‏\hadithno{2635}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Isam al-Muzani: The Messenger of Allah (ﷺ) sent us in a detachment and said (to us): If you see a mosque or hear a mu'adhdhin (calling to prayer), do not kill anyone}}
\hadithdefcmd{abudawud}{2636}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، أَنَّهُ سَمِعَ جَابِرًا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْحَرْبُ خُدْعَةٌ ‏"‏ ‏.‏\hadithno{2636}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3030) Sahih Muslim (1739)}\hadithtrans{Jabir reported the Apostle of Allaah(ﷺ) as saying “War is deception.”}}
\hadithdefcmd{abudawud}{2637}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا ابْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ غَزْوَةً وَرَّى غَيْرَهَا وَكَانَ يَقُولُ ‏"‏ الْحَرْبُ خُدْعَةٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَجِئْ بِهِ إِلاَّ مَعْمَرٌ يُرِيدُ قَوْلَهُ ‏"‏ الْحَرْبُ خُدْعَةٌ ‏"‏ ‏.‏ بِهَذَا الإِسْنَادِ إِنَّمَا يُرْوَى مِنْ حَدِيثِ عَمْرِو بْنِ دِينَارٍ عَنْ جَابِرٍ وَمِنْ حَدِيثِ مَعْمَرٍ عَنْ هَمَّامِ بْنِ مُنَبِّهٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2637}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ka'b ibn Malik: When the Prophet (ﷺ) intended to go on an expedition, he always pretended to be going somewhere else, and he would say: War is deception. Abu Dawud said: Only Ma'mar has transmitted this tradition. By this he refers to his statement "War is deception" through this chain of narrators. He narrated it from the tradition of 'Amr b. Dinar from Jabir, and from the tradition of Ma'mar from Hammam b. Munabbih on the authority of Abu Hurairah}}
\hadithdefcmd{abudawud}{2638}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، وَأَبُو عَامِرٍ عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، حَدَّثَنَا إِيَاسُ بْنُ سَلَمَةَ، عَنْ أَبِيهِ، قَالَ أَمَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْنَا أَبَا بَكْرٍ - رضى الله عنه - فَغَزَوْنَا نَاسًا مِنَ الْمُشْرِكِينَ فَبَيَّتْنَاهُمْ نَقْتُلُهُمْ وَكَانَ شِعَارُنَا تِلْكَ اللَّيْلَةَ أَمِتْ أَمِتْ ‏.‏ قَالَ سَلَمَةُ فَقَتَلْتُ بِيَدِي تِلْكَ اللَّيْلَةَ سَبْعَةَ أَهْلِ أَبْيَاتٍ مِنَ الْمُشْرِكِينَ ‏.‏\hadithno{2638}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Salamah ibn al-Akwa': The Messenger of Allah (ﷺ) appointed AbuBakr our commander and we fought with some people who were polytheists, and we attacked them at night, killing them. Our war-cry that night was "put to death; put to death." Salamah said: I killed that night with my hand polytheists belonging to seven houses}}
\hadithdefcmd{abudawud}{2639}{حَدَّثَنَا الْحَسَنُ بْنُ شَوْكَرٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا الْحَجَّاجُ بْنُ أَبِي عُثْمَانَ، عَنْ أَبِي الزُّبَيْرِ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُمْ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَخَلَّفُ فِي الْمَسِيرِ فَيُزْجِي الضَّعِيفَ وَيُرْدِفُ وَيَدْعُو لَهُمْ ‏.‏\hadithno{2639}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) used to keep to the rear when travelling and urge on the weak. He would take someone up behind him and make supplication for them all}}
\hadithdefcmd{abudawud}{2640}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا مَنَعُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ تَعَالَى ‏"‏ ‏.‏\hadithno{2640}\hadithgrade{Al-Albani: Sahih Mutawatir; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Mutawatir; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (21)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “ I am commanded to fight with men till they testify that there is no god but Allaah, when they do that they will keep their life and property safe from me, except what is due to them. (i.e., life and property) and their reckoning will be at Allaah’s hands.”}}
\hadithdefcmd{abudawud}{2641}{حَدَّثَنَا سَعِيدُ بْنُ يَعْقُوبَ الطَّالْقَانِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ وَأَنْ يَسْتَقْبِلُوا قِبْلَتَنَا وَأَنْ يَأْكُلُوا ذَبِيحَتَنَا وَأَنْ يُصَلُّوا صَلاَتَنَا فَإِذَا فَعَلُوا ذَلِكَ حَرُمَتْ عَلَيْنَا دِمَاؤُهُمْ وَأَمْوَالُهُمْ إِلاَّ بِحَقِّهَا لَهُمْ مَا لِلْمُسْلِمِينَ وَعَلَيْهِمْ مَا عَلَى الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{2641}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (392)}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: I am commanded to fight with men till they testify that there is no god but Allah, and that Muhammad is His servant and His Apostle, face our qiblah (direction of prayer), eat what we slaughter, and pray like us. When they do that, their life and property are unlawful for us except what is due to them. They will have the same rights as the Muslims have, and have the same responsibilities as the Muslims have}}
\hadithdefcmd{abudawud}{2642}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ الْمُشْرِكِينَ ‏"‏ ‏.‏ بِمَعْنَاهُ ‏.‏\hadithno{2642}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik reported the Apostle of Allaah(ﷺ) as saying “ I am commanded to fight with the polytheists. The rest of the tradition is to the same effect as mentioned above.”}}
\hadithdefcmd{abudawud}{2643}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ الْمَعْنَى، قَالاَ حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي ظَبْيَانَ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً إِلَى الْحُرَقَاتِ فَنَذِرُوا بِنَا فَهَرَبُوا فَأَدْرَكْنَا رَجُلاً فَلَمَّا غَشَيْنَاهُ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ فَضَرَبْنَاهُ حَتَّى قَتَلْنَاهُ فَذَكَرْتُهُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ لَكَ بِلاَ إِلَهَ إِلاَّ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا قَالَهَا مَخَافَةَ السِّلاَحِ ‏.‏ قَالَ ‏"‏ أَفَلاَ شَقَقْتَ عَنْ قَلْبِهِ حَتَّى تَعْلَمَ مِنْ أَجْلِ ذَلِكَ قَالَهَا أَمْ لاَ مَنْ لَكَ بِلاَ إِلَهَ إِلاَّ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَمَا زَالَ يَقُولُهَا حَتَّى وَدِدْتُ أَنِّي لَمْ أُسْلِمْ إِلاَّ يَوْمَئِذٍ ‏.‏\hadithno{2643}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6872) Sahih Muslim (96)}\hadithtrans{Usamah bin Zaid said “The Messenger of Allah (ﷺ) sent us with a detachment to Al Huruqat. They learnt about us and fled away. But we found a man, when we attacked him he uttered “There is no god but Allaah, still we struck him till we killed him.” When I mentioned it to the Prophet (ﷺ) he said “Who will save you from “There is no god but Allaah” on the Day of Judgment? I said “Messenger of Allah (ﷺ), he uttered it for the fear of the weapon.” He said “Did you tear his heart so that you learnt whether he actually uttered it for this or not. Who will support you against “There is no god but Allaah”? He kept on repeating this till I wished I would have embraced Islam on that day}}
\hadithdefcmd{abudawud}{2644}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنِ اللَّيْثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَدِيِّ بْنِ الْخِيَارِ، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، قَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ لَقِيتُ رَجُلاً مِنَ الْكُفَّارِ فَقَاتَلَنِي فَضَرَبَ إِحْدَى يَدَىَّ بِالسَّيْفِ ثُمَّ لاَذَ مِنِّي بِشَجَرَةٍ فَقَالَ أَسْلَمْتُ لِلَّهِ ‏.‏ أَفَأَقْتُلُهُ يَا رَسُولَ اللَّهِ بَعْدَ أَنْ قَالَهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقْتُلْهُ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ قَطَعَ يَدِي ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقْتُلْهُ فَإِنْ قَتَلْتَهُ فَإِنَّهُ بِمَنْزِلَتِكَ قَبْلَ أَنْ تَقْتُلَهُ وَأَنْتَ بِمَنْزِلَتِهِ قَبْلَ أَنْ يَقُولَ كَلِمَتَهُ الَّتِي قَالَ ‏"‏ ‏.‏\hadithno{2644}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6869) Sahih Muslim (95)}\hadithtrans{Al Miqdad bin Al Aswad reported that he said “Apostle of Allaah(ﷺ) tell me if I meet a man who is a disbeliever and he fights with me and cuts off one hand of mine with the sword and then takes refuge by a tree and says “I embraced Islam for Allah’s sake. Should I kill him, Apostle of Allaah(ﷺ) after he uttered it (the credo of Islam)? The Apostle of Allaah(ﷺ) said “Do not kill him”. I said “Apostle of Allaah(ﷺ), he cut off my hand. The Apostle of Allaah(ﷺ) said, Do not kill him. I f you kill him, he will become like you before you kill him and you will become like him before he uttered his credo which he has uttered now}}
\hadithdefcmd{abudawud}{2645}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً إِلَى خَثْعَمٍ فَاعْتَصَمَ نَاسٌ مِنْهُمْ بِالسُّجُودِ فَأَسْرَعَ فِيهِمُ الْقَتْلُ - قَالَ - فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَ لَهُمْ بِنِصْفِ الْعَقْلِ وَقَالَ ‏"‏ أَنَا بَرِيءٌ مِنْ كُلِّ مُسْلِمٍ يُقِيمُ بَيْنَ أَظْهُرِ الْمُشْرِكِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ لِمَ قَالَ ‏"‏ لاَ تَرَاءَى نَارَاهُمَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ هُشَيْمٌ وَمُعْتَمِرٌ وَخَالِدٌ الْوَاسِطِيُّ وَجَمَاعَةٌ لَمْ يَذْكُرُوا جَرِيرًا ‏.‏\hadithno{2645}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jarir ibn Abdullah: The Messenger of Allah (ﷺ) sent an expedition to Khath'am. Some people sought protection by having recourse to prostration, and were hastily killed. When the Prophet (ﷺ) heard that, he ordered half the blood-wit to be paid for them, saying: I am not responsible for any Muslim who stays among polytheists. They asked: Why, Messenger of Allah? He said: Their fires should not be visible to one another. Abu Dawud said: Hushaim, Ma'mar, Khalid b. al-Wasiti and a group of narrators have also narrated it, but did not mention Jarir}}
\hadithdefcmd{abudawud}{2646}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ جَرِيرِ بْنِ حَازِمٍ، عَنِ الزُّبَيْرِ بْنِ خِرِّيتٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَزَلَتْ ‏\{‏ إِنْ يَكُنْ مِنْكُمْ عِشْرُونَ صَابِرُونَ يَغْلِبُوا مِائَتَيْنِ ‏\}‏ فَشَقَّ ذَلِكَ عَلَى الْمُسْلِمِينَ حِينَ فَرَضَ اللَّهُ عَلَيْهِمْ أَنْ لاَ يَفِرَّ وَاحِدٌ مِنْ عَشَرَةٍ ثُمَّ إِنَّهُ جَاءَ تَخْفِيفٌ فَقَالَ ‏\{‏ الآنَ خَفَّفَ اللَّهُ عَنْكُمْ ‏\}‏ قَرَأَ أَبُو تَوْبَةَ إِلَى قَوْلِهِ ‏\{‏ يَغْلِبُوا مِائَتَيْنِ ‏\}‏ قَالَ فَلَمَّا خَفَّفَ اللَّهُ تَعَالَى عَنْهُمْ مِنَ الْعِدَّةِ نَقَصَ مِنَ الصَّبْرِ بِقَدْرِ مَا خَفَّفَ عَنْهُمْ ‏.‏\hadithno{2646}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4653)}\hadithtrans{Ibn ‘Abbas said “When the verse “If there are twenty amongst you patient and persevering, they will vanquish two hundred” was revealed. It was heavy and troublesome for Muslims when Allaah prescribed for them that one (fighting Muslim) should not fly from ten (fighting Non-Muslims). Then a light commandment was revealed saying “For the present Allaah hath lightened your (task).” The narrator Abu Tawbah recited the verse to “they will vanquish two hundred.” When Allaah lightened the number, patient and perseverance also decreased according to the number lightened from them.”}}
\hadithdefcmd{abudawud}{2647}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ حَدَّثَهُ أَنَّهُ، كَانَ فِي سَرِيَّةٍ مِنْ سَرَايَا رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَحَاصَ النَّاسُ حَيْصَةً فَكُنْتُ فِيمَنْ حَاصَ - قَالَ - فَلَمَّا بَرَزْنَا قُلْنَا كَيْفَ نَصْنَعُ وَقَدْ فَرَرْنَا مِنَ الزَّحْفِ وَبُؤْنَا بِالْغَضَبِ فَقُلْنَا نَدْخُلُ الْمَدِينَةَ فَنَتَثَبَّتُ فِيهَا وَنَذْهَبُ وَلاَ يَرَانَا أَحَدٌ - قَالَ - فَدَخَلْنَا فَقُلْنَا لَوْ عَرَضْنَا أَنْفُسَنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنْ كَانَتْ لَنَا تَوْبَةٌ أَقَمْنَا وَإِنْ كَانَ غَيْرَ ذَلِكَ ذَهَبْنَا - قَالَ - فَجَلَسْنَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم قَبْلَ صَلاَةِ الْفَجْرِ فَلَمَّا خَرَجَ قُمْنَا إِلَيْهِ فَقُلْنَا نَحْنُ الْفَرَّارُونَ فَأَقْبَلَ إِلَيْنَا فَقَالَ ‏"‏ لاَ بَلْ أَنْتُمُ الْعَكَّارُونَ ‏"‏ ‏.‏ قَالَ فَدَنَوْنَا فَقَبَّلْنَا يَدَهُ فَقَالَ ‏"‏ أَنَا فِئَةُ الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{2647}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Ibn Umar was sent with a detachment of the Messenger of Allah (ﷺ). The people wheeled round in flight. He said: I was one of those who wheeled round in flight. When we stopped, we said (i.e. thought): How should we do? We have run away from the battlefield and deserve Allah's wrath. Then we said (thought): Let us enter Medina, stay there, and go there while no one sees us. So we entered (Medina) and thought: If we present ourselves before the Messenger of Allah (ﷺ), and if there is a change of repentance for us, we shall stay; if there is something else, we shall go away. So we sat down (waiting) for the Messenger of Allah (ﷺ) before the dawn prayer. When he came out, we stood up to him and said: We are the ones who have fled. He turned to us and said: No, you are the ones who return to fight after wheeling away. We then approached and kissed his hand, and he said; I am the main body of the Muslims}}
\hadithdefcmd{abudawud}{2648}{حَدَّثَنَا مُحَمَّدُ بْنُ هِشَامٍ الْمِصْرِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ نَزَلَتْ فِي يَوْمِ بَدْرٍ ‏\{‏ وَمَنْ يُوَلِّهِمْ يَوْمَئِذٍ دُبُرَهُ ‏\}‏ ‏.‏\hadithno{2648}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Sa’id said “The verse “If any do turn his back to them on such a day” was revealed on the day of the Battle of Badr.”}}
\hadithdefcmd{abudawud}{2649}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا هُشَيْمٌ، وَخَالِدٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ خَبَّابٍ، قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ مُتَوَسِّدٌ بُرْدَةً فِي ظِلِّ الْكَعْبَةِ فَشَكَوْنَا إِلَيْهِ فَقُلْنَا أَلاَ تَسْتَنْصِرْ لَنَا أَلاَ تَدْعُو اللَّهَ لَنَا فَجَلَسَ مُحْمَرًّا وَجْهُهُ فَقَالَ ‏ "‏ قَدْ كَانَ مَنْ قَبْلَكُمْ يُؤْخَذُ الرَّجُلُ فَيُحْفَرُ لَهُ فِي الأَرْضِ ثُمَّ يُؤْتَى بِالْمِنْشَارِ فَيُجْعَلُ عَلَى رَأْسِهِ فَيُجْعَلُ فِرْقَتَيْنِ مَا يَصْرِفُهُ ذَلِكَ عَنْ دِينِهِ وَيُمْشَطُ بِأَمْشَاطِ الْحَدِيدِ مَا دُونَ عَظْمِهِ مِنْ لَحْمٍ وَعَصَبٍ مَا يَصْرِفُهُ ذَلِكَ عَنْ دِينِهِ وَاللَّهِ لَيُتِمَّنَّ اللَّهُ هَذَا الأَمْرَ حَتَّى يَسِيرَ الرَّاكِبُ مَا بَيْنَ صَنْعَاءَ وَحَضْرَمَوْتَ مَا يَخَافُ إِلاَّ اللَّهَ تَعَالَى وَالذِّئْبَ عَلَى غَنَمِهِ وَلَكِنَّكُمْ تَعْجَلُونَ ‏"‏ ‏.‏\hadithno{2649}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6943)}\hadithtrans{Khabbab said “We came to the Apostle of Allaah(ﷺ) while he was reclining on an outer garment in the shade of the Ka’bah. Complaining to him we said “Do you not ask Allaah for help for us? And do you not pray to Allaah for us? He sat aright turning red in his face and said “A man before you (i.e., in ancient times) was caught and a pit was dug for him in the earth and then a saw was brought placed on his head and it was broken into two pieces but that did not turn him away from his religion. They were combed in iron combs in flesh and sinews above the bones. Even that did not turn them away from their religion. I swear by Allaah, Allaah will accomplish this affair until a rider will travel between San’a and Hadramaut and he will not fear anyone except Allaah, Most High(nor will he fear the attack of) a wolf on his sheep, but you are making haste}}
\hadithdefcmd{abudawud}{2650}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، حَدَّثَهُ حَسَنُ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ، أَخْبَرَهُ عُبَيْدُ اللَّهِ بْنُ أَبِي رَافِعٍ، - وَكَانَ كَاتِبًا لِعَلِيِّ بْنِ أَبِي طَالِبٍ - قَالَ سَمِعْتُ عَلِيًّا، عَلَيْهِ السَّلاَمُ يَقُولُ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَا وَالزُّبَيْرَ وَالْمِقْدَادَ فَقَالَ ‏"‏ انْطَلِقُوا حَتَّى تَأْتُوا رَوْضَةَ خَاخٍ فَإِنَّ بِهَا ظَعِينَةً مَعَهَا كِتَابٌ فَخُذُوهُ مِنْهَا فَانْطَلَقْنَا تَتَعَادَى بِنَا خَيْلُنَا حَتَّى أَتَيْنَا الرَّوْضَةَ فَإِذَا نَحْنُ بِالظَّعِينَةِ فَقُلْنَا هَلُمِّي الْكِتَابَ ‏.‏ فَقَالَتْ مَا عِنْدِي مِنْ كِتَابٍ ‏.‏ فَقُلْتُ لَتُخْرِجِنَّ الْكِتَابَ أَوْ لَنُلْقِيَنَّ الثِّيَابَ ‏.‏ فَأَخْرَجَتْهُ مِنْ عِقَاصِهَا فَأَتَيْنَا بِهِ النَّبِيَّ صلى الله عليه وسلم فَإِذَا هُوَ مِنْ حَاطِبِ بْنِ أَبِي بَلْتَعَةَ إِلَى نَاسٍ مِنَ الْمُشْرِكِينَ يُخْبِرُهُمْ بِبَعْضِ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا هَذَا يَا حَاطِبُ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ لاَ تَعْجَلْ عَلَىَّ فَإِنِّي كُنْتُ امْرَأً مُلْصَقًا فِي قُرَيْشٍ وَلَمْ أَكُنْ مِنْ أَنْفُسِهَا وَإِنَّ قُرَيْشًا لَهُمْ بِهَا قَرَابَاتٌ يَحْمُونَ بِهَا أَهْلِيهِمْ بِمَكَّةَ فَأَحْبَبْتُ إِذْ فَاتَنِي ذَلِكَ أَنْ أَتَّخِذَ فِيهِمْ يَدًا يَحْمُونَ قَرَابَتِي بِهَا وَاللَّهِ يَا رَسُولَ اللَّهِ مَا كَانَ بِي مِنْ كُفْرٍ وَلاَ ارْتِدَادٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقَكُمْ ‏"‏ ‏.‏ فَقَالَ عُمَرُ دَعْنِي أَضْرِبْ عُنُقَ هَذَا الْمُنَافِقِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ شَهِدَ بَدْرًا وَمَا يُدْرِيكَ لَعَلَّ اللَّهَ اطَّلَعَ عَلَى أَهْلِ بَدْرٍ فَقَالَ اعْمَلُوا مَا شِئْتُمْ فَقَدْ غَفَرْتُ لَكُمْ ‏"‏ ‏.‏\hadithno{2650}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3007) Sahih Muslim (2494)}\hadithtrans{‘Ali said “The Apostle of Allaah(ﷺ) sent me Al Zubair and Al Miqdad and said “Go till you come to the meadow of Khakh for there Is a woman there travelling on a Camel who has a letter which you must take from her. We went off racing one another on our horses till we came to the meadow and when we found the woman, we aid “Bring out the letter. She said “I have no letter”. I said “You must bring out the letter else we strip off your clothes”. She then brought it out from the tresses and we took it to the Prophet(ﷺ). It was addressed from Hatib bin Abi Balta’ah to some of the polytheists(in Makkah) giving them some information about the Apostle of Allaah(ﷺ). He asked “What is this, Hatib? He replied, Apostle of Allaah(ﷺ) do not be hasty with me. I have been a man attached as an ally to the Quraish and am not one of them while those of the Quraish (i.e. the emigrants) have relationship with them by which they guarded their family in Makkah. As I did not have that advantage I wanted to give them some help for which they might guard my relations. I swear by Allaah I am not guilty of unbelief or apostasy (from my religion). The Apostle of Allaah(ﷺ) said “he has told you the truth. ‘Umar said “Let me cut off this hypocrite’s head. The Apostle of Allaah(ﷺ) said “He was present at Badr and what do you know, perhaps Allaah might look with pity on those who were present at Badr? And said “Do what you wish, I have forgiven you.”}}
\hadithdefcmd{abudawud}{2651}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ حُصَيْنٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، بِهَذِهِ الْقِصَّةِ قَالَ انْطَلَقَ حَاطِبٌ فَكَتَبَ إِلَى أَهْلِ مَكَّةَ أَنَّ مُحَمَّدًا صلى الله عليه وسلم قَدْ سَارَ إِلَيْكُمْ وَقَالَ فِيهِ قَالَتْ مَا مَعِي كِتَابٌ ‏.‏ فَانْتَحَيْنَاهَا فَمَا وَجَدْنَا مَعَهَا كِتَابًا فَقَالَ عَلِيٌّ وَالَّذِي يُحْلَفُ بِهِ لأَقْتُلَنَّكِ أَوْ لَتُخْرِجِنَّ الْكِتَابَ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{2651}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3081) Sahih Muslim (2494)}\hadithtrans{‘Ali said “Hatib went and wrote to the people of Makkah that Muhammad (ﷺ) is going to proceed to them. This version has “She said “I have no letter. We made her Camel kneel down, but we did not find any letter with her. ’Ali said “By Him in Whose name oath is taken, I shall kill you or you should bring out the letter. He then narrated the rest of the tradition}}
\hadithdefcmd{abudawud}{2652}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنِي مُحَمَّدُ بْنُ مُحَبَّبٍ أَبُو هَمَّامٍ الدَّلاَّلُ، حَدَّثَنَا سُفْيَانُ بْنُ سَعِيدٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ مُضَرِّبٍ، عَنْ فُرَاتِ بْنِ حَيَّانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِهِ وَكَانَ عَيْنًا لأَبِي سُفْيَانَ وَكَانَ حَلِيفًا لِرَجُلٍ مِنَ الأَنْصَارِ فَمَرَّ بِحَلْقَةٍ مِنَ الأَنْصَارِ فَقَالَ إِنِّي مُسْلِمٌ ‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ يَا رَسُولَ اللَّهِ إِنَّهُ يَقُولُ إِنِّي مُسْلِمٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْكُمْ رِجَالاً نَكِلُهُمْ إِلَى إِيمَانِهِمْ مِنْهُمْ فُرَاتُ بْنُ حَيَّانَ ‏"‏ ‏.‏\hadithno{2652}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Furat ibn Hayyan: The Messenger of Allah (ﷺ) commanded to kill him: he was a spy of AbuSufyan and an ally of a man of the Ansar. He passed a circle of the Ansar and said: I am a Muslim. A man from the Ansar said, Messenger of Allah, he is saying that he is a Muslim. The Messenger of Allah (ﷺ) said: There are people among you in whose faith we trust. Furat ibn Hayyan is one of them}}
\hadithdefcmd{abudawud}{2653}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا أَبُو عُمَيْسٍ، عَنِ ابْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم عَيْنٌ مِنَ الْمُشْرِكِينَ - وَهُوَ فِي سَفَرٍ - فَجَلَسَ عِنْدَ أَصْحَابِهِ ثُمَّ انْسَلَّ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اطْلُبُوهُ فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ فَسَبَقْتُهُمْ إِلَيْهِ فَقَتَلْتُهُ وَأَخَذْتُ سَلَبَهُ فَنَفَّلَنِي إِيَّاهُ ‏.‏\hadithno{2653}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3051)}\hadithtrans{Ibn Salamah bin Al Akwa’ repoted on the authority of his father. A spy of the polytheists came to the Prophet(ﷺ) when he was on a journey. He sat near his Companions and then slipped away. The Prophet(ﷺ) said “look for him and kill him”. He said “I raced to him and killed him. I took his belongings which he (the Prophet) gave me}}
\hadithdefcmd{abudawud}{2654}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، أَنَّ هَاشِمَ بْنَ الْقَاسِمِ، وَهِشَامًا، حَدَّثَاهُمْ قَالاَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبِي قَالَ، غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم هَوَازِنَ - قَالَ - فَبَيْنَمَا نَحْنُ نَتَضَحَّى وَعَامَّتُنَا مُشَاةٌ وَفِينَا ضَعَفَةٌ إِذْ جَاءَ رَجُلٌ عَلَى جَمَلٍ أَحْمَرَ فَانْتَزَعَ طَلَقًا مِنْ حِقْوِ الْبَعِيرِ فَقَيَّدَ بِهِ جَمَلَهُ ثُمَّ جَاءَ يَتَغَدَّى مَعَ الْقَوْمِ فَلَمَّا رَأَى ضَعَفَتَهُمْ وَرِقَّةَ ظَهْرِهِمْ خَرَجَ يَعْدُو إِلَى جَمَلِهِ فَأَطْلَقَهُ ثُمَّ أَنَاخَهُ فَقَعَدَ عَلَيْهِ ثُمَّ خَرَجَ يَرْكُضُهُ وَاتَّبَعَهُ رَجُلٌ مِنْ أَسْلَمَ عَلَى نَاقَةٍ وَرْقَاءَ هِيَ أَمْثَلُ ظَهْرِ الْقَوْمِ - قَالَ - فَخَرَجْتُ أَعْدُو فَأَدْرَكْتُهُ وَرَأْسُ النَّاقَةِ عِنْدَ وَرِكِ الْجَمَلِ وَكُنْتُ عِنْدَ وَرِكِ النَّاقَةِ ثُمَّ تَقَدَّمْتُ حَتَّى كُنْتُ عِنْدَ وَرِكِ الْجَمَلِ ثُمَّ تَقَدَّمْتُ حَتَّى أَخَذْتُ بِخِطَامِ الْجَمَلِ فَأَنَخْتُهُ فَلَمَّا وَضَعَ رُكْبَتَهُ بِالأَرْضِ اخْتَرَطْتُ سَيْفِي فَأَضْرِبَ رَأْسَهُ فَنَدَرَ فَجِئْتُ بِرَاحِلَتِهِ وَمَا عَلَيْهَا أَقُودُهَا فَاسْتَقْبَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ مُقْبِلاً فَقَالَ ‏"‏ مَنْ قَتَلَ الرَّجُلَ ‏"‏ ‏.‏ فَقَالُوا سَلَمَةُ بْنُ الأَكْوَعِ ‏.‏ قَالَ ‏"‏ لَهُ سَلَبُهُ أَجْمَعُ ‏"‏ ‏.‏ قَالَ هَارُونُ هَذَا لَفْظُ هَاشِمٍ ‏.‏\hadithno{2654}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1754)}\hadithtrans{Salamh (bin Al Akwa’) said “I went on an expedition with the Apostle of Allaah(ﷺ) against Hawazin and while we were having a meal in the forenoon and most of our people were on foot and some of us were weak, a man came on a red Camel. He took out a rope from the lion of the Camel and tied his Camel with it and began to take meal with the people. When he saw the weak condition of their people and lack of mounts he went out in a hurry to his Camel, untied it made it kneel down and sat on it and went off galloping it. A man of the tribe of Aslam followed him on a brown she Camel which was best of those of the people. I hastened out and I found him while the head of the she Camel was near the paddock of the she Camel. I then went ahead till I reached near the paddock of the Camel. I then went ahead till I caught the Camel’s nose string. I made it kneel. When it placed its knee on the ground, I drew my sword and struck the man on his head and it fell down. I then brought the Camel leading it with (its equipment) on it. The Apostle of Allaah(ﷺ) came forward facing me and asked “Who killed the man? They (the people) said “Salamah bin Akwa’. He said “he gets all his spoil.” Harun said “This is Hashim’s version}}
\hadithdefcmd{abudawud}{2655}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ عَلْقَمَةَ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، أَنَّ النُّعْمَانَ، - يَعْنِي ابْنَ مُقَرِّنٍ - قَالَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا لَمْ يُقَاتِلْ مِنْ أَوَّلِ النَّهَارِ أَخَّرَ الْقِتَالَ حَتَّى تَزُولَ الشَّمْسُ وَتَهُبَّ الرِّيَاحُ وَيَنْزِلَ النَّصْرُ ‏.‏\hadithno{2655}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated An-Nu'man ibn Muqarrin: I was present at fighting along with the Messenger of Allah (ﷺ), and when he did not fight at the beginning of the day, he waited till the sun had passed the meridian, the winds blew, and help came down}}
\hadithdefcmd{abudawud}{2656}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ كَانَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم يَكْرَهُونَ الصَّوْتَ عِنْدَ الْقِتَالِ ‏.‏\hadithno{2656}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qays ibn Abbad: The Companions of the Prophet (ﷺ), disliked shouting while fighting}}
\hadithdefcmd{abudawud}{2657}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ هَمَّامٍ، حَدَّثَنِي مَطَرٌ، عَنْ قَتَادَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ ذَلِكَ ‏.‏\hadithno{2657}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Abu Bardah on the authority of his father from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{2658}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ لَمَّا لَقِيَ النَّبِيُّ صلى الله عليه وسلم الْمُشْرِكِينَ يَوْمَ حُنَيْنٍ فَانْكَشَفُوا نَزَلَ عَنْ بَغْلَتِهِ فَتَرَجَّلَ ‏.‏\hadithno{2658}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3042) Sahih Muslim (1776)}\hadithtrans{Al Bara’ said “When the Prophet (ﷺ) fought the polytheists in the battle of Hunain, they (the Muslims) retreated, he (the Prophet) came down from his mule and walked on foot}}
\hadithdefcmd{abudawud}{2659}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، - الْمَعْنَى وَاحِدٌ - قَالاَ حَدَّثَنَا أَبَانُ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنِ ابْنِ جَابِرِ بْنِ عَتِيكٍ، عَنْ جَابِرِ بْنِ عَتِيكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏"‏ مِنَ الْغَيْرَةِ مَا يُحِبُّ اللَّهُ وَمِنْهَا مَا يُبْغِضُ اللَّهُ فَأَمَّا الَّتِي يُحِبُّهَا اللَّهُ فَالْغَيْرَةُ فِي الرِّيبَةِ وَأَمَّا الْغَيْرَةُ الَّتِي يُبْغِضُهَا اللَّهُ فَالْغَيْرَةُ فِي غَيْرِ رِيبَةٍ وَإِنَّ مِنَ الْخُيَلاَءِ مَا يُبْغِضُ اللَّهُ وَمِنْهَا مَا يُحِبُّ اللَّهُ فَأَمَّا الْخُيَلاَءُ الَّتِي يُحِبُّ اللَّهُ فَاخْتِيَالُ الرَّجُلِ نَفْسَهُ عِنْدَ الْقِتَالِ وَاخْتِيَالُهُ عِنْدَ الصَّدَقَةِ وَأَمَّا الَّتِي يُبْغِضُ اللَّهُ فَاخْتِيَالُهُ فِي الْبَغْىِ ‏"‏ ‏.‏ قَالَ مُوسَى ‏"‏ وَالْفَخْرِ ‏"‏ ‏.‏\hadithno{2659}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir ibn Atik: The Prophet (ﷺ) said: There is jealousy which Allah loves and jealousy which Allah hates. That which Allah loves is jealousy regarding a matter of doubt, and that which Allah hates is jealousy regarding something which is not doubtful. There is pride which Allah hates and pride which Allah loves. That which Allah loves is a man's pride when fighting and when giving sadaqah and that which Allah hates is pride shown by oppression. The narrator Musa said: "by boasting}}
\hadithdefcmd{abudawud}{2660}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - أَخْبَرَنَا ابْنُ شِهَابٍ، أَخْبَرَنِي عَمْرُو بْنُ جَارِيَةَ الثَّقَفِيُّ، - حَلِيفُ بَنِي زُهْرَةَ - عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشَرَةً عَيْنًا وَأَمَّرَ عَلَيْهِمْ عَاصِمَ بْنَ ثَابِتٍ فَنَفَرُوا لَهُمْ هُذَيْلٌ بِقَرِيبٍ مِنْ مِائَةِ رَجُلٍ رَامٍ فَلَمَّا أَحَسَّ بِهِمْ عَاصِمٌ لَجَئُوا إِلَى قَرْدَدٍ فَقَالُوا لَهُمُ انْزِلُوا فَأَعْطُوا بِأَيْدِيكُمْ وَلَكُمُ الْعَهْدُ وَالْمِيثَاقُ أَنْ لاَ نَقْتُلَ مِنْكُمْ أَحَدًا فَقَالَ عَاصِمٌ أَمَّا أَنَا فَلاَ أَنْزِلُ فِي ذِمَّةِ كَافِرٍ ‏.‏ فَرَمَوْهُمْ بِالنَّبْلِ فَقَتَلُوا عَاصِمًا فِي سَبْعَةِ نَفَرٍ وَنَزَلَ إِلَيْهِمْ ثَلاَثَةُ نَفَرٍ عَلَى الْعَهْدِ وَالْمِيثَاقِ مِنْهُمْ خُبَيْبٌ وَزَيْدُ بْنُ الدَّثِنَةِ وَرَجُلٌ آخَرُ فَلَمَّا اسْتَمْكَنُوا مِنْهُمْ أَطْلَقُوا أَوْتَارَ قِسِيِّهِمْ فَرَبَطُوهُمْ بِهَا فَقَالَ الرَّجُلُ الثَّالِثُ هَذَا أَوَّلُ الْغَدْرِ وَاللَّهِ لاَ أَصْحَبُكُمْ إِنَّ لِي بِهَؤُلاَءِ لأُسْوَةً ‏.‏ فَجَرُّوهُ فَأَبَى أَنْ يَصْحَبَهُمْ فَقَتَلُوهُ فَلَبِثَ خُبَيْبٌ أَسِيرًا حَتَّى أَجْمَعُوا قَتْلَهُ فَاسْتَعَارَ مُوسَى يَسْتَحِدُّ بِهَا فَلَمَّا خَرَجُوا بِهِ لِيَقْتُلُوهُ قَالَ لَهُمْ خُبَيْبٌ دَعُونِي أَرْكَعْ رَكْعَتَيْنِ ثُمَّ قَالَ وَاللَّهِ لَوْلاَ أَنْ تَحْسِبُوا مَا بِي جَزَعًا لَزِدْتُ ‏.‏\hadithno{2660}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3045)}\hadithtrans{Abu Hurairah said “The Prophet (ﷺ) sent ten persons (on an expedition) and appointed ‘Asim bin Thabit their commander. About one hundred men of Hudhail who were archers came out to (attack) them. When ‘Asim felt their presence, they took cover in a hillock. They aid to them “Come down and surrender and we make a covenant and pact with you that we shall not kill any of you”. ‘Asim said “I do not come to the protection of a disbeliever. Then they shot them with arrows and killed ‘Asim in a company of seven persons. The other three persons came down to their covenant and pact. They were Khubaib, Zaid bin Al Lathnah and another man. When they overpowered them, they untied their bow strings and tied them with them”. The third person said “This is the first treachery. I swear by Allaah, I shall not accompany you. In them (my companions) is an example for me. They pulled him, but he refused to accompany them, so they killed him. Khubaib remained their captive until they agreed to kill him. He asked for a razor to shave his pubes. When they brought him outside to kill him. Khubaib said to them “Let me offer two rak’ahs of prayer”. He then said “I swear by Allaah, if you did not think that I did this out of fear. I would have increased (the number of rak’ahs)}}
\hadithdefcmd{abudawud}{2661}{حَدَّثَنَا ابْنُ عَوْفٍ، حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَمْرُو بْنُ أَبِي سُفْيَانَ بْنِ أَسِيدِ بْنِ جَارِيَةَ الثَّقَفِيُّ، - وَهُوَ حَلِيفٌ لِبَنِي زُهْرَةَ - وَكَانَ مِنْ أَصْحَابِ أَبِي هُرَيْرَةَ فَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{2661}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3045)}\hadithtrans{Al Zuhri said “This tradition has been transmitted to me by ‘Amr bin Abu Sufyan bin Usaid bin Jariyat Al Thaqafi who was an ally of Banu Zuhrah and a companion of Abu Hurairah. He then narrated the tradition.”}}
\hadithdefcmd{abudawud}{2662}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، سَمِعْتُ الْبَرَاءَ، يُحَدِّثُ قَالَ جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الرُّمَاةِ يَوْمَ أُحُدٍ - وَكَانُوا خَمْسِينَ رَجُلاً - عَبْدَ اللَّهِ بْنَ جُبَيْرٍ وَقَالَ ‏ "‏ إِنْ رَأَيْتُمُونَا تَخَطَّفُنَا الطَّيْرُ فَلاَ تَبْرَحُوا مِنْ مَكَانِكُمْ هَذَا حَتَّى أُرْسِلَ إِلَيْكُمْ وَإِنْ رَأَيْتُمُونَا هَزَمْنَا الْقَوْمَ وَأَوْطَأْنَاهُمْ فَلاَ تَبْرَحُوا حَتَّى أُرْسِلَ إِلَيْكُمْ ‏"‏ ‏.‏ قَالَ فَهَزَمَهُمُ اللَّهُ ‏.‏ قَالَ فَأَنَا وَاللَّهِ رَأَيْتُ النِّسَاءَ يَشْتَدِدْنَ عَلَى الْجَبَلِ فَقَالَ أَصْحَابُ عَبْدِ اللَّهِ بْنِ جُبَيْرٍ الْغَنِيمَةَ أَىْ قَوْمِ الْغَنِيمَةَ ظَهَرَ أَصْحَابُكُمْ فَمَا تَنْتَظِرُونَ فَقَالَ عَبْدُ اللَّهِ بْنُ جُبَيْرٍ أَنَسِيتُمْ مَا قَالَ لَكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالُوا وَاللَّهِ لَنَأْتِيَنَّ النَّاسَ فَلَنُصِيبَنَّ مِنَ الْغَنِيمَةِ فَأَتَوْهُمْ فَصُرِفَتْ وُجُوهُهُمْ وَأَقْبَلُوا مُنْهَزِمِينَ ‏.‏\hadithno{2662}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3039)}\hadithtrans{Al bara’ bin Azib said “On the day of the battle of Uhud the Apostle of Allaah(ﷺ) appointed ‘Abd Allaah bin Jubair commander of the archers who were fifty(in number). He said “If you see that the birds are snatching at us, do not move from this place of yours until I send for you and if you see that we defeated the people (the enemy) and trod them down, do not move until I send for you. Allaah then defeated them. He (narrator) said “I swear by Allaah, I saw women ascending the mountain. The companions of ‘Abd Allaah bin Jubair said “Booty, O People, booty! Your companions vanquished, for what are you waiting?” ‘Ad Allaah bin Jubair said “Have you forgotten what the Apostle of Allaah(ﷺ) had told you?” They said “We swear by Allaah. We shall come to the people and get the booty. So they came to them. Their faces were turned and they came defeated.”}}
\hadithdefcmd{abudawud}{2663}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سُلَيْمَانَ بْنِ الْغَسِيلِ، عَنْ حَمْزَةَ بْنِ أَبِي أُسَيْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ اصْطَفَفْنَا يَوْمَ بَدْرٍ ‏ "‏ إِذَا أَكْثَبُوكُمْ - يَعْنِي إِذَا غَشُوكُمْ - فَارْمُوهُمْ بِالنَّبْلِ وَاسْتَبْقُوا نَبْلَكُمْ ‏"‏ ‏.‏\hadithno{2663}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3984، 3985)}\hadithtrans{Abu Usaid reported the Apostle of Allaah(ﷺ) as saying to us at the battle of Badr when he drew up in rows. When they came near you, shoot arrows at them, but do not use all your arrows}}
\hadithdefcmd{abudawud}{2664}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا إِسْحَاقُ بْنُ نَجِيحٍ، - وَلَيْسَ بِالْمَلْطِيِّ - عَنْ مَالِكِ بْنِ حَمْزَةَ بْنِ أَبِي أُسَيْدٍ السَّاعِدِيِّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ بَدْرٍ ‏ "‏ إِذَا أَكْثَبُوكُمْ فَارْمُوهُمْ بِالنَّبْلِ وَلاَ تَسُلُّوا السُّيُوفَ حَتَّى يَغْشَوْكُمْ ‏"‏ ‏.‏\hadithno{2664}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUsayd as-Sa'idi: The Prophet (ﷺ) said at the battle of Badr: When they come near you shoot arrows at them; and do not draw swords at them until they come near you}}
\hadithdefcmd{abudawud}{2665}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ مُضَرِّبٍ، عَنْ عَلِيٍّ، قَالَ تَقَدَّمَ - يَعْنِي عُتْبَةَ بْنَ رَبِيعَةَ - وَتَبِعَهُ ابْنُهُ وَأَخُوهُ فَنَادَى مَنْ يُبَارِزُ فَانْتَدَبَ لَهُ شَبَابٌ مِنَ الأَنْصَارِ فَقَالَ مَنْ أَنْتُمْ فَأَخْبَرُوهُ فَقَالَ لاَ حَاجَةَ لَنَا فِيكُمْ إِنَّمَا أَرَدْنَا بَنِي عَمِّنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُمْ يَا حَمْزَةُ قُمْ يَا عَلِيُّ قُمْ يَا عُبَيْدَةُ بْنَ الْحَارِثِ ‏"‏ ‏.‏ فَأَقْبَلَ حَمْزَةُ إِلَى عُتْبَةَ وَأَقْبَلْتُ إِلَى شَيْبَةَ وَاخْتُلِفَ بَيْنَ عُبَيْدَةَ وَالْوَلِيدِ ضَرْبَتَانِ فَأَثْخَنَ كُلُّ وَاحِدٍ مِنْهُمَا صَاحِبَهُ ثُمَّ مِلْنَا عَلَى الْوَلِيدِ فَقَتَلْنَاهُ وَاحْتَمَلْنَا عُبَيْدَةَ ‏.‏\hadithno{2665}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: (At the battle of Badr) Utbah ibn Rabi'ah came forward followed by his son and his brother and cried out: Who will be engaged in single combat? Some young men of the Helpers responded to his call. He asked: Who are you? They told him. He said: We do not want you; we, in fact, want only our cousins. The Prophet (ﷺ) said: Get up Hamzah get up Ali; get up Ubaydah ibn al-Harith. Hamzah went forward to Utbah, I went forward to Shaybah; and after two blows had been exchanged between Ubaydah and al-Walid, they wounded one another severely; so we turned against al-Walid and killed him, and we carried Ubaydah away}}
\hadithdefcmd{abudawud}{2666}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَزِيَادُ بْنُ أَيُّوبَ، قَالاَ حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مُغِيرَةُ، عَنْ شِبَاكٍ، عَنْ إِبْرَاهِيمَ، عَنْ هُنَىِّ بْنِ نُوَيْرَةَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعَفُّ النَّاسِ قِتْلَةً أَهْلُ الإِيمَانِ ‏"‏ ‏.‏\hadithno{2666}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: The most merciful of the people in respect of killing are believers (in Allah)}}
\hadithdefcmd{abudawud}{2667}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنِ الْهَيَّاجِ بْنِ عِمْرَانَ، أَنَّ عِمْرَانَ، أَبَقَ لَهُ غُلاَمٌ فَجَعَلَ لِلَّهِ عَلَيْهِ لَئِنْ قَدَرَ عَلَيْهِ لَيَقْطَعَنَّ يَدَهُ فَأَرْسَلَنِي لأَسْأَلَ لَهُ فَأَتَيْتُ سَمُرَةَ بْنَ جُنْدَبٍ فَسَأَلْتُهُ فَقَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَحُثُّنَا عَلَى الصَّدَقَةِ وَيَنْهَانَا عَنِ الْمُثْلَةِ فَأَتَيْتُ عِمْرَانَ بْنَ حُصَيْنٍ فَسَأَلْتُهُ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَحُثُّنَا عَلَى الصَّدَقَةِ وَيَنْهَانَا عَنِ الْمُثْلَةِ ‏.‏\hadithno{2667}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: Al-Hayyaj ibn Imran ibn Husayn reported that a slave of Imran ran away. He took a vow to Allah that if he overpowers him, he will cut off his head. He then sent me (to Samurah ibn Jundub) to ask him about this question for him. I came to Samurah ibn Jundub and asked him. He said: The Messenger of Allah (ﷺ) used to exhort us to give alms (sadaqah) and forbid us to mutilate (a slain). I then came to Imran ibn Husayn and asked him. He said: The Messenger of Allah (ﷺ) used to exhort us to give alms (sadaqah) and forbid us to mutilate (a slain)}}
\hadithdefcmd{abudawud}{2668}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ، وَقُتَيْبَةُ، - يَعْنِي ابْنَ سَعِيدٍ - قَالاَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ امْرَأَةً، وُجِدَتْ، فِي بَعْضِ مَغَازِي رَسُولِ اللَّهِ صلى الله عليه وسلم مَقْتُولَةً فَأَنْكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَتْلَ النِّسَاءِ وَالصِّبْيَانِ ‏.‏\hadithno{2668}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3014) Sahih Muslim (1744)}\hadithtrans{‘Abd Allaah bin (mas’ud) said “A woman was found slain in one of the battles of the Apostle of Allaah(ﷺ). The Apostle of Allaah(ﷺ) forbade to kill women and children}}
\hadithdefcmd{abudawud}{2669}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا عُمَرُ بْنُ الْمُرَقِّعِ بْنِ صَيْفِيِّ بْنِ رَبَاحٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّهِ، رَبَاحِ بْنِ رَبِيعٍ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ فَرَأَى النَّاسَ مُجْتَمِعِينَ عَلَى شَىْءٍ فَبَعَثَ رَجُلاً فَقَالَ ‏"‏ انْظُرْ عَلاَمَ اجْتَمَعَ هَؤُلاَءِ ‏"‏ فَجَاءَ فَقَالَ عَلَى امْرَأَةٍ قَتِيلٍ ‏.‏ فَقَالَ ‏"‏ مَا كَانَتْ هَذِهِ لِتُقَاتِلَ ‏"‏ ‏.‏ قَالَ وَعَلَى الْمُقَدِّمَةِ خَالِدُ بْنُ الْوَلِيدِ فَبَعَثَ رَجُلاً فَقَالَ ‏"‏ قُلْ لِخَالِدٍ لاَ يَقْتُلَنَّ امْرَأَةً وَلاَ عَسِيفًا ‏"‏ ‏.‏\hadithno{2669}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Rabah ibn Rabi': When we were with the Messenger of Allah (ﷺ) on an expedition, he saw some people collected together over something and sent a man and said: See, what are these people collected around? He then came and said: They are round a woman who has been killed. He said: This is not one with whom fighting should have taken place. Khalid ibn al-Walid was in charge of the van; so he sent a man and said: Tell Khalid not to kill a woman or a hired servant}}
\hadithdefcmd{abudawud}{2670}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْتُلُوا شُيُوخَ الْمُشْرِكِينَ وَاسْتَبْقُوا شَرْخَهُمْ ‏"‏ ‏.‏\hadithno{2670}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: Kill the old men who are polytheists, but spare their children}}
\hadithdefcmd{abudawud}{2671}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ لَمْ يُقْتَلْ مِنْ نِسَائِهِمْ - تَعْنِي بَنِي قُرَيْظَةَ - إِلاَّ امْرَأَةً إِنَّهَا لَعِنْدِي تُحَدِّثُ تَضْحَكُ ظَهْرًا وَبَطْنًا وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَقْتُلُ رِجَالَهُمْ بِالسُّيُوفِ إِذْ هَتَفَ هَاتِفٌ بِاسْمِهَا أَيْنَ فُلاَنَةُ قَالَتْ أَنَا ‏.‏ قُلْتُ وَمَا شَأْنُكِ قَالَتْ حَدَثٌ أَحْدَثْتُهُ ‏.‏ قَالَتْ فَانْطَلَقَ بِهَا فَضُرِبَتْ عُنُقُهَا فَمَا أَنْسَى عَجَبًا مِنْهَا أَنَّهَا تَضْحَكُ ظَهْرًا وَبَطْنًا وَقَدْ عَلِمَتْ أَنَّهَا تُقْتَلُ ‏.‏\hadithno{2671}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: No woman of Banu Qurayzah was killed except one. She was with me, talking and laughing on her back and belly (extremely), while the Messenger of Allah (ﷺ) was killing her people with the swords. Suddenly a man called her name: Where is so-and-so? She said: I I asked: What is the matter with you? She said: I did a new act. She said: The man took her and beheaded her. She said: I will not forget that she was laughing extremely although she knew that she would be killed}}
\hadithdefcmd{abudawud}{2672}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ - عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ، أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ الدَّارِ مِنَ الْمُشْرِكِينَ يُبَيَّتُونَ فَيُصَابُ مِنْ ذَرَارِيِّهِمْ وَنِسَائِهِمْ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هُمْ مِنْهُمْ ‏"‏ ‏.‏ وَكَانَ عَمْرٌو - يَعْنِي ابْنَ دِينَارٍ - يَقُولُ هُمْ مِنْ آبَائِهِمْ ‏.‏ قَالَ الزُّهْرِيُّ ثُمَّ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ عَنْ قَتْلِ النِّسَاءِ وَالْوِلْدَانِ ‏.‏\hadithno{2672}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Bukhari (3012) Sahih Muslim (1745)}\hadithtrans{Al Sa’b bin Jaththamah said that he asked the Apostle of Allaah(ﷺ) about the polytheists whose settlemnst were attacked at night when some of their offspring and women were smitten. The Prophet(ﷺ) “They are of them. ‘Amr bin Dinar used to say “they are regarded in the same way as their parents.” Al-Zuhri said:Thereafter the Messenger of Allah (ﷺ) prohibited to kill women and children}}
\hadithdefcmd{abudawud}{2673}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا مُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ، عَنْ أَبِي الزِّنَادِ، حَدَّثَنِي مُحَمَّدُ بْنُ حَمْزَةَ الأَسْلَمِيُّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَّرَهُ عَلَى سَرِيَّةٍ قَالَ فَخَرَجْتُ فِيهَا وَقَالَ ‏"‏ إِنْ وَجَدْتُمْ فُلاَنًا فَاحْرِقُوهُ بِالنَّارِ ‏"‏ ‏.‏ فَوَلَّيْتُ فَنَادَانِي فَرَجَعْتُ إِلَيْهِ فَقَالَ ‏"‏ إِنْ وَجَدْتُمْ فُلاَنًا فَاقْتُلُوهُ وَلاَ تُحْرِقُوهُ فَإِنَّهُ لاَ يُعَذِّبُ بِالنَّارِ إِلاَّ رَبُّ النَّارِ ‏"‏ ‏.‏\hadithno{2673}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hamzah al-Aslami: The Messenger of Allah (ﷺ) appointed him commander over a detachment. He said: I went out along with it. He (the Prophet) said: If you find so-and-so, burn him with the fire. I then turned away, and he called me. So I returned to him, and he said: If you find so-and-so, kill him, and do not burn him, for no one punishes with fire except the Lord of the fire}}
\hadithdefcmd{abudawud}{2674}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ، وَقُتَيْبَةُ، أَنَّ اللَّيْثَ بْنَ سَعْدٍ، حَدَّثَهُمْ عَنْ بُكَيْرٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْثٍ فَقَالَ ‏ "‏ إِنْ وَجَدْتُمْ فُلاَنًا وَفُلاَنًا ‏"‏ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{2674}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (3016)}\hadithtrans{Abu Hurairah said:The Messenger of Allah (ﷺ) sent us along with a contingent, and said: If you find so-and-so. He then narrated the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{2675}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنِ ابْنِ سَعْدٍ، - قَالَ غَيْرُ أَبِي صَالِحٍ عَنِ الْحَسَنِ بْنِ سَعْدٍ، - عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَانْطَلَقَ لِحَاجَتِهِ فَرَأَيْنَا حُمَّرَةً مَعَهَا فَرْخَانِ فَأَخَذْنَا فَرْخَيْهَا فَجَاءَتِ الْحُمَّرَةُ فَجَعَلَتْ تَفْرُشُ فَجَاءَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ فَجَعَ هَذِهِ بِوَلَدِهَا رُدُّوا وَلَدَهَا إِلَيْهَا ‏"‏ ‏.‏ وَرَأَى قَرْيَةَ نَمْلٍ قَدْ حَرَّقْنَاهَا فَقَالَ ‏"‏ مَنْ حَرَّقَ هَذِهِ ‏"‏ ‏.‏ قُلْنَا نَحْنُ ‏.‏ قَالَ ‏"‏ إِنَّهُ لاَ يَنْبَغِي أَنْ يُعَذِّبَ بِالنَّارِ إِلاَّ رَبُّ النَّارِ ‏"‏ ‏.‏\hadithno{2675}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: We were with the Messenger of Allah (ﷺ) during a journey. He went to ease himself. We saw a bird with her two young ones and we captured her young ones. The bird came and began to spread its wings. The Messenger of Allah (ﷺ) came and said: Who grieved this for its young ones? Return its young ones to it. He also saw an ant village that we had burnt. He asked: Who has burnt this? We replied: We. He said: It is not proper to punish with fire except the Lord of fire}}
\hadithdefcmd{abudawud}{2676}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ أَبُو النَّضْرِ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، أَخْبَرَنِي أَبُو زُرْعَةَ، يَحْيَى بْنُ أَبِي عَمْرٍو السَّيْبَانِيُّ عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ، أَنَّهُ حَدَّثَهُ عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ نَادَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ فَخَرَجْتُ إِلَى أَهْلِي فَأَقْبَلْتُ وَقَدْ خَرَجَ أَوَّلُ صَحَابَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَطَفِقْتُ فِي الْمَدِينَةِ أُنَادِي أَلاَ مَنْ يَحْمِلُ رَجُلاً لَهُ سَهْمُهُ فَنَادَى شَيْخٌ مِنَ الأَنْصَارِ قَالَ لَنَا سَهْمُهُ عَلَى أَنْ نَحْمِلَهُ عَقَبَةً وَطَعَامُهُ مَعَنَا قُلْتُ نَعَمْ ‏.‏ قَالَ فَسِرْ عَلَى بَرَكَةِ اللَّهِ تَعَالَى ‏.‏ قَالَ فَخَرَجْتُ مَعَ خَيْرِ صَاحِبٍ حَتَّى أَفَاءَ اللَّهُ عَلَيْنَا فَأَصَابَنِي قَلاَئِصُ فَسُقْتُهُنَّ حَتَّى أَتَيْتُهُ فَخَرَجَ فَقَعَدَ عَلَى حَقِيبَةٍ مِنْ حَقَائِبِ إِبِلِهِ ثُمَّ قَالَ سُقْهُنَّ مُدْبِرَاتٍ ‏.‏ ثُمَّ قَالَ سُقْهُنَّ مُقْبِلاَتٍ ‏.‏ فَقَالَ مَا أَرَى قَلاَئِصَكَ إِلاَّ كِرَامًا - قَالَ - إِنَّمَا هِيَ غَنِيمَتُكَ الَّتِي شَرَطْتُ لَكَ ‏.‏ قَالَ خُذْ قَلاَئِصَكَ يَا ابْنَ أَخِي فَغَيْرَ سَهْمِكَ أَرَدْنَا ‏.‏\hadithno{2676}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Wathilah ibn al-Asqa: The Messenger of Allah (ﷺ) announced to go on expedition for Tabuk. I went to my family and then proceeded (on journey). The vanguard of the Companions of the Messenger of Allah (ﷺ) had already proceeded. So I began to announce loudly in Medina: Is there anyone who takes a man on his ride, and he will get his share (from the booty? An old man from the Ansar (Helpers) spoke loudly: We shall have his share if we take him with us on our mount by turns, and he will have his meal with us. I said: Yes. He said: So go on journey with Allah's blessing. I then proceeded along with my best companion and Allah gave us booty. Some she-camels were given to me as my share of booty. I drove them till I reached him. He came out and sat on the rear part of the saddle of his camel. He then said: Drive them backward. He again said: Drive them forward. He then said: I find your she-camels very gentle. He said: This is your booty which I stipulated for you. He replied: Take your she-camels, my nephew; we did not intend (to get) your portion}}
\hadithdefcmd{abudawud}{2677}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - أَخْبَرَنَا مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَقَدْ عَجِبَ رَبُّنَا عَزَّ وَجَلَّ مِنْ قَوْمٍ يُقَادُونَ إِلَى الْجَنَّةِ فِي السَّلاَسِلِ ‏"‏ ‏.‏\hadithno{2677}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “Our Lord Most High is charmed with people who will be led to Paradise in chains.”}}
\hadithdefcmd{abudawud}{2678}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَعْقُوبَ بْنِ عُتْبَةَ، عَنْ مُسْلِمِ بْنِ عَبْدِ اللَّهِ، عَنْ جُنْدُبِ بْنِ مَكِيثٍ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَبْدَ اللَّهِ بْنَ غَالِبٍ اللَّيْثِيَّ فِي سَرِيَّةٍ وَكُنْتُ فِيهِمْ وَأَمَرَهُمْ أَنْ يَشُنُّوا الْغَارَةَ عَلَى بَنِي الْمُلَوِّحِ بِالْكَدِيدِ فَخَرَجْنَا حَتَّى إِذَا كُنَّا بِالْكَدِيدِ لَقِينَا الْحَارِثَ بْنَ الْبَرْصَاءِ اللَّيْثِيَّ فَأَخَذْنَاهُ فَقَالَ إِنَّمَا جِئْتُ أُرِيدُ الإِسْلاَمَ وَإِنَّمَا خَرَجْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْنَا إِنْ تَكُنْ مُسْلِمًا لَمْ يَضُرَّكَ رِبَاطُنَا يَوْمًا وَلَيْلَةً وَإِنْ تَكُنْ غَيْرَ ذَلِكَ نَسْتَوْثِقْ مِنْكَ فَشَدَدْنَاهُ وِثَاقًا ‏.‏\hadithno{2678}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jundub ibn Makith: The Messenger of Allah (ﷺ) sent Abdullah ibn Ghalib al-Laythi along with a detachment and I was also with them. He ordered them to attach Banu al-Mulawwih from all sides at al-Kadid. So we went out and when we reached al-Kadid we met al-Harith ibn al-Barsa al-Laythi, and seized him. He said: I came with the intention of embracing Islam, and I came out to go to the Messenger of Allah (ﷺ). We said: If you are a Muslim, there is no harm if we keep you in chains for a day and night; and if you are not, we shall tie you with chains. So we tied him with chains}}
\hadithdefcmd{abudawud}{2679}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، وَقُتَيْبَةُ، قَالَ قُتَيْبَةُ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْلاً قِبَلَ نَجْدٍ فَجَاءَتْ بِرَجُلٍ مِنْ بَنِي حَنِيفَةَ يُقَالُ لَهُ ثُمَامَةُ بْنُ أُثَالٍ سَيِّدُ أَهْلِ الْيَمَامَةِ فَرَبَطُوهُ بِسَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ فَخَرَجَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَاذَا عِنْدَكَ يَا ثُمَامَةُ ‏"‏ ‏.‏ قَالَ عِنْدِي يَا مُحَمَّدُ خَيْرٌ إِنْ تَقْتُلْ تَقْتُلْ ذَا دَمٍ وَإِنْ تُنْعِمْ تُنْعِمْ عَلَى شَاكِرٍ وَإِنْ كُنْتَ تُرِيدُ الْمَالَ فَسَلْ تُعْطَ مِنْهُ مَا شِئْتَ ‏.‏ فَتَرَكَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ الْغَدُ ثُمَّ قَالَ لَهُ ‏"‏ مَا عِنْدَكَ يَا ثُمَامَةُ ‏"‏ ‏.‏ فَأَعَادَ مِثْلَ هَذَا الْكَلاَمِ فَتَرَكَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى كَانَ بَعْدَ الْغَدِ فَذَكَرَ مِثْلَ هَذَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَطْلِقُوا ثُمَامَةَ ‏"‏ ‏.‏ فَانْطَلَقَ إِلَى نَخْلٍ قَرِيبٍ مِنَ الْمَسْجِدِ فَاغْتَسَلَ فِيهِ ثُمَّ دَخَلَ الْمَسْجِدَ فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ عِيسَى أَخْبَرَنَا اللَّيْثُ وَقَالَ ذَا ذِمٍّ ‏.‏\hadithno{2679}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (469) Sahih Muslim (1764)}\hadithtrans{Abu Hurairah said “ The Apostle of Allaah(ﷺ) sent some horsemen to Najd and they brought a man of the Banu Hanifah called Thumamah bint Uthal who was the chief of the people of Al Yamamah and bound him to one of the pillars of the mosque. The Apostle of Allaah(ﷺ) came out to him and said “What are you expecting, Thumamah?”. He replied “I expect good, Muhammad. If you kill (me), you will kill one whose blood will be avenged, if you show favor, you will show it to one who is grateful and if you want property and ask you will be given as much of it as you wish. The Apostle of Allaah(ﷺ) left him till the following day and asked him ”What are you expecting, Thumamah?” He repeated the same words (in reply). The Apostle of Allaah(ﷺ)left him till the day after the following one and he mentioned the same words. The Apostle of Allaah(ﷺ) then said “Set Thumamah free.” He went off to some palm trees near the mosque. He took a bath there and entered the mosque and said “I testify that there is no god but Allaah and I testify that Muhammd is His servant and His apostle. He then narrated the rest of the tradition. The narrator ‘Isa said “Al Laith narrated to us”. He said “a man of respect and reverence.”}}
\hadithdefcmd{abudawud}{2680}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، قَالَ حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الْفَضْلِ - عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ، قَالَ قُدِمَ بِالأُسَارَى حِينَ قُدِمَ بِهِمْ وَسَوْدَةُ بِنْتُ زَمْعَةَ عِنْدَ آلِ عَفْرَاءَ فِي مُنَاخِهِمْ عَلَى عَوْفٍ وَمُعَوِّذٍ ابْنَىْ عَفْرَاءَ قَالَ وَذَلِكَ قَبْلَ أَنْ يُضْرَبَ عَلَيْهِنَّ الْحِجَابُ قَالَ تَقُولُ سَوْدَةُ وَاللَّهِ إِنِّي لَعِنْدَهُمْ إِذْ أَتَيْتُ فَقِيلَ هَؤُلاَءِ الأُسَارَى قَدْ أُتِيَ بِهِمْ ‏.‏ فَرَجَعْتُ إِلَى بَيْتِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِيهِ وَإِذَا أَبُو يَزِيدَ سُهَيْلُ بْنُ عَمْرٍو فِي نَاحِيَةِ الْحُجْرَةِ مَجْمُوعَةٌ يَدَاهُ إِلَى عُنُقِهِ بِحَبْلٍ ‏.‏ ثُمَّ ذَكَرَ الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُمَا قَتَلاَ أَبَا جَهْلِ بْنَ هِشَامٍ وَكَانَا انْتَدَبَا لَهُ وَلَمْ يَعْرِفَاهُ وَقُتِلاَ يَوْمَ بَدْرٍ ‏.‏\hadithno{2680}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sawdah daughter of Zam'ah: Yahya ibn Abdullah said: When the captives (of the battle of Badr) were brought, Sawdah daughter of Zam'ah was present with the children of Afra' at the halting place of their camels, that is, Awf and Mu'awwidh sons of Afra'. This happened before the prescription of veil for them. Sawdah said: I swear by Allah, I was with them when I came (from there to the people) and I was told: These are captives recently brought (here). I returned to my house, and the Messenger of Allah (ﷺ) was there, and AbuZayd Suhayl ibn Amr was in the corner of the apartment and his hands were tied up on his neck with a rope. He then narrated the rest of the tradition. Abu Dawud said: They (the sons of 'Afra') killed Abu Jahl b. Hisham. They were deputed for him though they did not realize him: and they were killed in the battle of Badr}}
\hadithdefcmd{abudawud}{2681}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَدَبَ أَصْحَابَهُ فَانْطَلَقُوا إِلَى بَدْرٍ فَإِذَا هُمْ بِرَوَايَا قُرَيْشٍ فِيهَا عَبْدٌ أَسْوَدُ لِبَنِي الْحَجَّاجِ فَأَخَذَهُ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلُوا يَسْأَلُونَهُ أَيْنَ أَبُو سُفْيَانَ فَيَقُولُ وَاللَّهِ مَا لِي بِشَىْءٍ مِنْ أَمْرِهِ عِلْمٌ وَلَكِنْ هَذِهِ قُرَيْشٌ قَدْ جَاءَتْ فِيهِمْ أَبُو جَهْلٍ وَعُتْبَةُ وَشَيْبَةُ ابْنَا رَبِيعَةَ وَأُمَيَّةُ بْنُ خَلَفٍ ‏.‏ فَإِذَا قَالَ لَهُمْ ذَلِكَ ضَرَبُوهُ فَيَقُولُ دَعُونِي دَعُونِي أُخْبِرْكُمْ ‏.‏ فَإِذَا تَرَكُوهُ قَالَ وَاللَّهِ مَا لِي بِأَبِي سُفْيَانَ مِنْ عِلْمٍ وَلَكِنْ هَذِهِ قُرَيْشٌ قَدْ أَقْبَلَتْ فِيهِمْ أَبُو جَهْلٍ وَعُتْبَةُ وَشَيْبَةُ ابْنَا رَبِيعَةَ وَأُمَيَّةُ بْنُ خَلَفٍ قَدْ أَقْبَلُوا ‏.‏ وَالنَّبِيُّ صلى الله عليه وسلم يُصَلِّي وَهُوَ يَسْمَعُ ذَلِكَ فَلَمَّا انْصَرَفَ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّكُمْ لَتَضْرِبُونَهُ إِذَا صَدَقَكُمْ وَتَدَعُونَهُ إِذَا كَذَبَكُمْ هَذِهِ قُرَيْشٌ قَدْ أَقْبَلَتْ لِتَمْنَعَ أَبَا سُفْيَانَ ‏"‏ ‏.‏ قَالَ أَنَسٌ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا مَصْرَعُ فُلاَنٍ غَدًا ‏"‏ ‏.‏ وَوَضَعَ يَدَهُ عَلَى الأَرْضِ ‏"‏ وَهَذَا مَصْرَعُ فُلاَنٍ غَدًا ‏"‏ ‏.‏ وَوَضَعَ يَدَهُ عَلَى الأَرْضِ ‏"‏ وَهَذَا مَصْرَعُ فُلاَنٍ غَدًا ‏"‏ ‏.‏ وَوَضَعَ يَدَهُ عَلَى الأَرْضِ فَقَالَ وَالَّذِي نَفْسِي بِيَدِهِ مَا جَاوَزَ أَحَدٌ مِنْهُمْ عَنْ مَوْضِعِ يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأُخِذَ بِأَرْجُلِهِمْ فَسُحِبُوا فَأُلْقُوا فِي قَلِيبِ بَدْرٍ ‏.‏\hadithno{2681}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1779)}\hadithtrans{Anas said “The Apostle of Allaah(ﷺ) called on his Companions and they proceeded towards Badr. Suddenly they found the watering Camels of the Quraish, there was among them a black slave of Banu Al Hajjaj. The Companions of the Apostle of Allaah(ﷺ) seized him and began to ask “Where is Abu Sufyan?” He said “I swear by Allaah, I do not know anything about him, but this is the Quraish who have come here, among them are Abu Jahl, ‘Utbah, Shaibah the two sons of Rabi’ah and Umayyah bin Khalaf. When he aid this to them, they beat him and he began to say “Leave me, leave me. I shall tell you. When they left him he said “I know nothing about Abu Sufyan, but this is the Quraish who have come (here), among them are Abu Jahl, ‘Utbah, Shaibah the two sons of Rab’iah and Umayyah bin Khalaf who have come here. The Prophet (ﷺ) was praying and hearing all that (dialogue). When he finished, he said “By Him in Whose hand my soul is, you beat him when he speaks the truth to you and you leave him when he tells a lie. This is the Quraish who have come here to defend Abu Sufyan. Anas said, The Apostle of Allaah(ﷺ) said “This will be the place of falling of so and so tomorrow and he placed his hand on the ground. This will be the place of falling of so and so tomorrow and he put his hand on the ground. And this will be the place of falling of so and so tomorrow and he put his hand on the ground. He (Ansas) said “By Him in Whose hand my soul is, no one fell beyond the place of the hand of the Apostle of Allaah(ﷺ), The Apostle of Allaah(ﷺ) ordered for them, and they were caught by their feet and dragged and thrown in a well at Badr}}
\hadithdefcmd{abudawud}{2682}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيُّ، قَالَ حَدَّثَنَا أَشْعَثُ بْنُ عَبْدِ اللَّهِ، - يَعْنِي السِّجِسْتَانِيَّ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَهَذَا، لَفْظُهُ ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتِ الْمَرْأَةُ تَكُونُ مِقْلاَتًا فَتَجْعَلُ عَلَى نَفْسِهَا إِنْ عَاشَ لَهَا وَلَدٌ أَنْ تُهَوِّدَهُ فَلَمَّا أُجْلِيَتْ بَنُو النَّضِيرِ كَانَ فِيهِمْ مِنْ أَبْنَاءِ الأَنْصَارِ فَقَالُوا لاَ نَدَعُ أَبْنَاءَنَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لاَ إِكْرَاهَ فِي الدِّينِ قَدْ تَبَيَّنَ الرُّشْدُ مِنَ الْغَىِّ ‏\}‏ قَالَ أَبُو دَاوُدَ الْمِقْلاَتُ الَّتِي لاَ يَعِيشُ لَهَا وَلَدٌ ‏.‏\hadithno{2682}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: When the children of a woman (in pre-Islamic days) did not survive, she took a vow on herself that if her child survives, she would convert it a Jew. When Banu an-Nadir were expelled (from Arabia), there were some children of the Ansar (Helpers) among them. They said: We shall not leave our children. So Allah the Exalted revealed; "Let there be no compulsion in religion. Truth stands out clear from error." Abu Dawud said: Muqlat means a woman whose children do not survive}}
\hadithdefcmd{abudawud}{2683}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا أَسْبَاطُ بْنُ نَصْرٍ، قَالَ زَعَمَ السُّدِّيُّ عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، قَالَ لَمَّا كَانَ يَوْمُ فَتْحِ مَكَّةَ أَمَّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ إِلاَّ أَرْبَعَةَ نَفَرٍ وَامْرَأَتَيْنِ وَسَمَّاهُمْ وَابْنُ أَبِي سَرْحٍ ‏.‏ فَذَكَرَ الْحَدِيثَ قَالَ وَأَمَّا ابْنُ أَبِي سَرْحٍ فَإِنَّهُ اخْتَبَأَ عِنْدَ عُثْمَانَ بْنِ عَفَّانَ فَلَمَّا دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ إِلَى الْبَيْعَةِ جَاءَ بِهِ حَتَّى أَوْقَفَهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ بَايِعْ عَبْدَ اللَّهِ فَرَفَعَ رَأْسَهُ فَنَظَرَ إِلَيْهِ ثَلاَثًا كُلُّ ذَلِكَ يَأْبَى فَبَايَعَهُ بَعْدَ ثَلاَثٍ ثُمَّ أَقْبَلَ عَلَى أَصْحَابِهِ فَقَالَ ‏"‏ أَمَا كَانَ فِيكُمْ رَجُلٌ رَشِيدٌ يَقُومُ إِلَى هَذَا حَيْثُ رَآنِي كَفَفْتُ يَدِي عَنْ بَيْعَتِهِ فَيَقْتُلُهُ ‏"‏ ‏.‏ فَقَالُوا مَا نَدْرِي يَا رَسُولَ اللَّهِ مَا فِي نَفْسِكَ أَلاَ أَوْمَأْتَ إِلَيْنَا بِعَيْنِكَ قَالَ ‏"‏ إِنَّهُ لاَ يَنْبَغِي لِنَبِيٍّ أَنْ تَكُونَ لَهُ خَائِنَةُ الأَعْيُنِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ عَبْدُ اللَّهِ أَخَا عُثْمَانَ مِنَ الرَّضَاعَةِ وَكَانَ الْوَلِيدُ بْنُ عُقْبَةَ أَخَا عُثْمَانَ لأُمِّهِ وَضَرَبَهُ عُثْمَانُ الْحَدَّ إِذْ شَرِبَ الْخَمْرَ ‏.‏\hadithno{2683}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sa'd: On the day when Mecca was conquered, the Messenger of Allah (ﷺ) gave protection to the People except four men and two women and he named them. Ibn AbuSarh was one of them. He then narrated the tradition. He said: Ibn AbuSarh hid himself with Uthman ibn Affan. When the Messenger of Allah (ﷺ) called the people to take the oath of allegiance, he brought him and made him stand before the Messenger of Allah (ﷺ). He said: Messenger of Allah, receive the oath of allegiance from him. He raised his head and looked at him thrice, denying him every time. After the third time he received his oath. He then turned to his Companions and said: Is not there any intelligent man among you who would stand to this (man) when he saw me desisting from receiving the oath of allegiance, and kill him? They replied: We do not know, Messenger of Allah, what lies in your heart; did you not give us an hint with your eye? He said: It is not proper for a Prophet to have a treacherous eye. Abu Dawud said: 'Abd Allah (b. Abi Sarh) was the foster brother of 'Uthman, and Walid b. 'Uqbah was his brother by mother, and 'Uthman inflicted on him hadd punishment when he drank wine}}
\hadithdefcmd{abudawud}{2684}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، قَالَ أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعِيدِ بْنِ يَرْبُوعٍ الْمَخْزُومِيُّ، قَالَ حَدَّثَنِي جَدِّي، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَوْمَ فَتْحِ مَكَّةَ ‏ "‏ أَرْبَعَةٌ لاَ أُؤْمِنُهُمْ فِي حِلٍّ وَلاَ حَرَمٍ ‏"‏ ‏.‏ فَسَمَّاهُمْ ‏.‏ قَالَ وَقَيْنَتَيْنِ كَانَتَا لِمِقْيَسٍ فَقُتِلَتْ إِحْدَاهُمَا وَأُفْلِتَتِ الأُخْرَى فَأَسْلَمَتْ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ أَفْهَمْ إِسْنَادَهُ مِنِ ابْنِ الْعَلاَءِ كَمَا أُحِبُّ ‏.‏\hadithno{2684}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'id ibn Yarbu' al-Makhzumi: The Prophet (ﷺ) said: on the day of the conquest of Mecca: There are four persons whom I shall not give protection in the sacred and non-sacred territory. He then named them. There were two singing girls of al-Maqis; one of them was killed and the other escaped and embraced Islam. Abu Dawud said: I could not understand its chain of narrators from Ibn al-'Ala' as I liked}}
\hadithdefcmd{abudawud}{2685}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ مَكَّةَ عَامَ الْفَتْحِ وَعَلَى رَأْسِهِ الْمِغْفَرُ فَلَمَّا نَزَعَهُ جَاءَهُ رَجُلٌ فَقَالَ ابْنُ خَطَلٍ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ فَقَالَ ‏ "‏ اقْتُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ابْنُ خَطَلٍ اسْمُهُ عَبْدُ اللَّهِ وَكَانَ أَبُو بَرْزَةَ الأَسْلَمِيُّ قَتَلَهُ ‏.‏\hadithno{2685}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3044) Sahih Muslim (1357)}\hadithtrans{Anas bin Malik said “The Apostle of Allaah(ﷺ) entered Makkah in the year of the conquest (of Makkah) wearing a helmet on his head. When he took off it a man came to him and said “Ibn Akhtal is hanging with the curtains of the Ka’bah.” He said “Kill him”. Abu Dawud said “The name of Ibn Akhtal is ‘Abd Allaah and Abu Barzat Al Aslami killed him}}
\hadithdefcmd{abudawud}{2686}{حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ الرَّقِّيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ إِبْرَاهِيمَ، قَالَ أَرَادَ الضَّحَّاكُ بْنُ قَيْسٍ أَنْ يَسْتَعْمِلَ، مَسْرُوقًا فَقَالَ لَهُ عُمَارَةُ بْنُ عُقْبَةَ أَتَسْتَعْمِلُ رَجُلاً مِنْ بَقَايَا قَتَلَةِ عُثْمَانَ فَقَالَ لَهُ مَسْرُوقٌ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْعُودٍ - وَكَانَ فِي أَنْفُسِنَا مَوْثُوقَ الْحَدِيثِ - أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا أَرَادَ قَتْلَ أَبِيكَ قَالَ مَنْ لِلصِّبْيَةِ قَالَ ‏ "‏ النَّارُ ‏"‏ ‏.‏ فَقَدْ رَضِيتُ لَكَ مَا رَضِيَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2686}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: Ibrahim said: Ad-Dahhak ibn Qays intended to appoint Masruq as governor. Thereupon Umarah ibn Uqbah said to him: Are you appointing a man from the remnants of the murderers of Uthman? Masruq said to him: Ibn Mas'ud narrated to us, and he was trustworthy in respect of traditions, that when the Prophet (ﷺ) intended to kill your father, he said: Who will look after my children? He replied: Fire. I also like for you what the Messenger of Allah (ﷺ) liked for you}}
\hadithdefcmd{abudawud}{2687}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنِ ابْنِ تِعْلَى، قَالَ غَزَوْنَا مَعَ عَبْدِ الرَّحْمَنِ بْنِ خَالِدِ بْنِ الْوَلِيدِ فَأُتِيَ بِأَرْبَعَةِ أَعْلاَجٍ مِنَ الْعَدُوِّ فَأَمَرَ بِهِمْ فَقُتِلُوا صَبْرًا ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ لَنَا غَيْرُ سَعِيدٍ عَنِ ابْنِ وَهْبٍ فِي هَذَا الْحَدِيثِ قَالَ بِالنَّبْلِ صَبْرًا فَبَلَغَ ذَلِكَ أَبَا أَيُّوبَ الأَنْصَارِيَّ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ قَتْلِ الصَّبْرِ فَوَالَّذِي نَفْسِي بِيَدِهِ لَوْ كَانَتْ دَجَاجَةٌ مَا صَبَرْتُهَا ‏.‏ فَبَلَغَ ذَلِكَ عَبْدَ الرَّحْمَنِ بْنَ خَالِدِ بْنِ الْوَلِيدِ فَأَعْتَقَ أَرْبَعَ رِقَابٍ ‏.‏\hadithno{2687}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Ti'li: We fought along with AbdurRahman ibn Khalid ibn al-Walid. Four infidels from the enemy were brought to him. He commanded about them and they were killed in confinement. Abu Dawud said: The narrators other than Sa'id reported from Ibn Wahb in this tradition: "(killed him) with arrows in confinement." When Abu Ayyub al-Ansari was informed about it, he said: I heard the Messenger of Allah (ﷺ) prohibiting to kill in confinement. By Him in Whose hands my soul is, if there were a hen, I would not kill it in confinement. 'Abd al-Rahman b. Khalid b. al-Walid was informed about it (the Prophet's prohibition). He set four slaves free}}
\hadithdefcmd{abudawud}{2688}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ ثَمَانِينَ، رَجُلاً مِنْ أَهْلِ مَكَّةَ هَبَطُوا عَلَى النَّبِيِّ صلى الله عليه وسلم وَأَصْحَابِهِ مِنْ جِبَالِ التَّنْعِيمِ عِنْدَ صَلاَةِ الْفَجْرِ لِيَقْتُلُوهُمْ فَأَخَذَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم سَلَمًا فَأَعْتَقَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَهُوَ الَّذِي كَفَّ أَيْدِيَهُمْ عَنْكُمْ وَأَيْدِيَكُمْ عَنْهُمْ بِبَطْنِ مَكَّةَ ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{2688}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1808)}\hadithtrans{Anas said “Eighty Meccans came down from the mountain of Al Tan’im against the Prophet(ﷺ) and his Companions at the (time of the) dawn prayer to kill them. The Apostle of Allaah(ﷺ) took them captive without fighting and the Apostle of Allaah(ﷺ) set them free. Thereupon Allaah Most High sent down “He it is Who averted their hands from you and your hands from them in the valley of Makkah,” till the end of the verse}}
\hadithdefcmd{abudawud}{2689}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأُسَارَى بَدْرٍ ‏ "‏ لَوْ كَانَ مُطْعِمُ بْنُ عَدِيٍّ حَيًّا ثُمَّ كَلَّمَنِي فِي هَؤُلاَءِ النَّتْنَى لأَطْلَقْتُهُمْ لَهُ ‏"‏ ‏.‏\hadithno{2689}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3139)}\hadithtrans{Jubair bin Mut’im reported the Prophet (ﷺ) as saying about the prisoners taken at Badr. If Mut’im bin ‘Adi had been alive and spoken to me about these filthy ones, I would have left them for him}}
\hadithdefcmd{abudawud}{2690}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، قَالَ حَدَّثَنَا أَبُو نُوحٍ، قَالَ أَخْبَرَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا سِمَاكٌ الْحَنَفِيُّ، قَالَ حَدَّثَنَا ابْنُ عَبَّاسٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ لَمَّا كَانَ يَوْمُ بَدْرٍ فَأَخَذَ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - الْفِدَاءَ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ مَا كَانَ لِنَبِيٍّ أَنْ يَكُونَ لَهُ أَسْرَى حَتَّى يُثْخِنَ فِي الأَرْضِ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ لَمَسَّكُمْ فِيمَا أَخَذْتُمْ ‏\}‏ مِنَ الْفِدَاءِ ثُمَّ أَحَلَّ لَهُمُ اللَّهُ الْغَنَائِمَ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يُسْأَلُ عَنِ اسْمِ أَبِي نُوحٍ فَقَالَ أَيْشٍ تَصْنَعُ بِاسْمِهِ اسْمُهُ اسْمٌ شَنِيعٌ ‏.‏ قَالَ أَبُو دَاوُدَ اسْمُ أَبِي نُوحٍ قُرَادٌ وَالصَّحِيحُ عَبْدُ الرَّحْمَنِ بْنُ غَزْوَانَ ‏.‏\hadithno{2690}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1763)}\hadithtrans{‘Umar bin Al Khattab said “During the battle of Badr, the Prophet (ﷺ) took ransom”. Thereupon Allaah Most High sent down “It is not fitting for an Apostle that he should have prisoners of war until he hath thoroughly subdued the land. You look on the temporal goods of this world, but Allaah looketh to the Hereafter”. And Allaah is exalted in might and Wise. Had it not been for a previous ordainment from Allaah, a severe penalty would have reached you for the (ransom) that you took. Allaah then made the spoils of war lawful. Abu Dawud said “I heard that Ahmad bin Hanbal was asked about the name of Abu Nuh”. He said “What will you do with his name? His name is a bad one. Abu Dawud said “the name of Abu Nuh is Qurad. What is correct is that his name is ‘Abd Al Rahman bin Ghazwan}}
\hadithdefcmd{abudawud}{2691}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ الْعَيْشِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي الْعَنْبَسِ، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَعَلَ فِدَاءَ أَهْلِ الْجَاهِلِيَّةِ يَوْمَ بَدْرٍ أَرْبَعَمِائَةٍ ‏.‏\hadithno{2691}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) fixed the ransom of the people of pre-Islamic Arabia at four hundred dirhams per head on the day of the battle of Badr}}
\hadithdefcmd{abudawud}{2692}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادٍ، عَنْ أَبِيهِ، عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنْ عَائِشَةَ، قَالَتْ لَمَّا بَعَثَ أَهْلُ مَكَّةَ فِي فِدَاءِ أَسْرَاهُمْ بَعَثَتْ زَيْنَبُ فِي فِدَاءِ أَبِي الْعَاصِ بِمَالٍ وَبَعَثَتْ فِيهِ بِقِلاَدَةٍ لَهَا كَانَتْ عِنْدَ خَدِيجَةَ أَدْخَلَتْهَا بِهَا عَلَى أَبِي الْعَاصِ ‏.‏ قَالَتْ فَلَمَّا رَآهَا رَسُولُ اللَّهِ صلى الله عليه وسلم رَقَّ لَهَا رِقَّةً شَدِيدَةً وَقَالَ ‏"‏ إِنْ رَأَيْتُمْ أَنْ تُطْلِقُوا لَهَا أَسِيرَهَا وَتَرُدُّوا عَلَيْهَا الَّذِي لَهَا ‏"‏ ‏.‏ فَقَالُوا نَعَمْ ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَخَذَ عَلَيْهِ أَوْ وَعَدَهُ أَنْ يُخَلِّيَ سَبِيلَ زَيْنَبَ إِلَيْهِ وَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدَ بْنَ حَارِثَةَ وَرَجُلاً مِنَ الأَنْصَارِ فَقَالَ ‏"‏ كُونَا بِبَطْنِ يَأْجِجَ حَتَّى تَمُرَّ بِكُمَا زَيْنَبُ فَتَصْحَبَاهَا حَتَّى تَأْتِيَا بِهَا ‏"‏ ‏.‏\hadithno{2692}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When the people of Mecca sent about ransoming their prisoners Zaynab sent some property to ransom Abul'As, sending among it a necklace of hers which Khadijah had had, and (which she) had given to her when she married Abul'As. When the Messenger of Allah (ﷺ) saw it, he felt great tenderness about it and said: If you consider that you should free her prisoner for her and return to her what belongs to her, (it will be well). They said: Yes. The Messenger of Allah (ﷺ) made an agreement with him that he should let Zaynab come to him, and the Messenger of Allah (ﷺ) sent Zayd ibn Harithah and a man of the Ansar (the Helpers) and said: Wait in the valley of Yajij till Zaynab passes you, then you should accompany her and bring her back}}
\hadithdefcmd{abudawud}{2693}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا عَمِّي، - يَعْنِي سَعِيدَ بْنَ الْحَكَمِ - قَالَ أَخْبَرَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ وَذَكَرَ عُرْوَةُ بْنُ الزُّبَيْرِ أَنَّ مَرْوَانَ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ مُسْلِمِينَ فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَعِي مَنْ تَرَوْنَ وَأَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ فَاخْتَارُوا إِمَّا السَّبْىَ وَإِمَّا الْمَالَ ‏"‏ ‏.‏ فَقَالُوا نَخْتَارُ سَبْيَنَا فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَثْنَى عَلَى اللَّهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ إِخْوَانَكُمْ هَؤُلاَءِ جَاءُوا تَائِبِينَ وَإِنِّي قَدْ رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ وَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏ ‏.‏ فَقَالَ النَّاسُ قَدْ طَيَّبْنَا ذَلِكَ لَهُمْ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ مِمَّنْ لَمْ يَأْذَنْ فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏ ‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ فَأَخْبَرُوهُمْ أَنَّهُمْ قَدْ طَيَّبُوا وَأَذِنُوا ‏.‏\hadithno{2693}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2307، 2308)}\hadithtrans{Marwan and Al Miswar bin Makhramah told that when the deputation of the Hawazin came to the Muslims and asked the Apostle of Allaah(ﷺ) to return to them their property, the Apostle of Allaah(ﷺ) said to them “with me are those whom you see”. The speech dearest to me is the one which is true, so choose (one of the two) either the captives or the property. They said “We choose our captives. The Apostle of Allaah(ﷺ) stood up, extolled Allaah and then said “To proceed, your brethren have come repentant I have considered that I should return their captives to them, so let those of you who are willing to release the captives act accordingly, but those who wish to hold on to what they have till we give them some of the first booty Allaah gives us may do so. The people said “We are willing for that (to release their captives), Apostle of Allaah. The Apostle of Allaah(ﷺ) said “We cannot distinguish between those of you who have granted that and those who have not , so return till your headmen may tell us about your affair. The people then returned and their headmen spoke to them, then they informed that they were agreeable and had given their permission}}
\hadithdefcmd{abudawud}{2694}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، فِي هَذِهِ الْقِصَّةِ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ رُدُّوا عَلَيْهِمْ نِسَاءَهُمْ وَأَبْنَاءَهُمْ فَمَنْ مَسَكَ بِشَىْءٍ مِنْ هَذَا الْفَىْءِ فَإِنَّ لَهُ بِهِ عَلَيْنَا سِتَّ فَرَائِضَ مِنْ أَوَّلِ شَىْءٍ يُفِيئُهُ اللَّهُ عَلَيْنَا ‏"‏ ‏.‏ ثُمَّ دَنَا - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - مِنْ بَعِيرٍ فَأَخَذَ وَبَرَةً مِنْ سَنَامِهِ ثُمَّ قَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّهُ لَيْسَ لِي مِنَ الْفَىْءِ شَىْءٌ وَلاَ هَذَا ‏"‏ ‏.‏ وَرَفَعَ أُصْبُعَيْهِ ‏"‏ إِلاَّ الْخُمُسَ وَالْخُمُسُ مَرْدُودٌ عَلَيْكُمْ فَأَدُّوا الْخِيَاطَ وَالْمِخْيَطَ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فِي يَدِهِ كُبَّةٌ مِنْ شَعْرٍ فَقَالَ أَخَذْتُ هَذِهِ لأُصْلِحَ بِهَا بَرْذَعَةً لِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا مَا كَانَ لِي وَلِبَنِي عَبْدِ الْمُطَّلِبِ فَهُوَ لَكَ ‏"‏ ‏.‏ فَقَالَ أَمَّا إِذْ بَلَغَتْ مَا أَرَى فَلاَ أَرَبَ لِي فِيهَا ‏.‏ وَنَبَذَهَا ‏.‏\hadithno{2694}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) then said: Return to them (Hawazin) their women and their sons. If any of you withholds anything from this booty, we have six camels for him from the first booty which Allah gives us. The Prophet (ﷺ) then approached a camel, and taking a hair from its hump said: O people, I get nothing of this booty, not even this (meanwhile raising his two fingers) but the fifth, and the fifth is returned to you, so hand over threads and needles. A man got up with a ball of hair in his hand and said: I took this to repair the cloth under a pack-saddle. The Messenger of Allah (ﷺ) said: You can have what belongs to me and to the Banu al-Muttalib. He said: If it produces the result that I now realise, I have no desire for it}}
\hadithdefcmd{abudawud}{2695}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، ح وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا رَوْحٌ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ أَبِي طَلْحَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا غَلَبَ عَلَى قَوْمٍ أَقَامَ بِالْعَرْصَةِ ثَلاَثًا ‏.‏ قَالَ ابْنُ الْمُثَنَّى إِذَا غَلَبَ قَوْمًا أَحَبَّ أَنْ يُقِيمَ بِعَرْصَتِهِمْ ثَلاَثًا ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ يَحْيَى بْنُ سَعِيدٍ يَطْعَنُ فِي هَذَا الْحَدِيثِ لأَنَّهُ لَيْسَ مِنْ قَدِيمِ حَدِيثِ سَعِيدٍ لأَنَّهُ تَغَيَّرَ سَنَةَ خَمْسٍ وَأَرْبَعِينَ وَلَمْ يُخْرِجْ هَذَا الْحَدِيثَ إِلاَّ بِأَخَرَةٍ ‏.‏ قَالَ أَبُو دَاوُدَ يُقَالُ إِنَّ وَكِيعًا حَمَلَ عَنْهُ فِي تَغَيُّرِهِ ‏.‏\hadithno{2695}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3065)}\hadithtrans{Abu Talhah said “When the Apostle of Allaah(ﷺ) prevailed on any people, he stayed three nights in the field. Ibn Al Muthanna said “When he prevailed over people, he liked to stay three nights in the field.” Abu Dawud said “Yahya bin Sa’id used to object to this tradition for this is not from his early traditions because his memory was spoiled at the age of forty five. He narrated this tradition in the last days of his age.” Abu Dawud said “ It is said that Waki ‘ recived this tradition from him when his memory was spoiled.”}}
\hadithdefcmd{abudawud}{2696}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ الْحَكَمِ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ عَلِيٍّ، أَنَّهُ فَرَّقَ بَيْنَ جَارِيَةٍ وَوَلَدِهَا فَنَهَاهُ النَّبِيُّ صلى الله عليه وسلم عَنْ ذَلِكَ وَرَدَّ الْبَيْعَ ‏.‏ قَالَ أَبُو دَاوُدَ وَمَيْمُونٌ لَمْ يُدْرِكْ عَلِيًّا قُتِلَ بِالْجَمَاجِمِ وَالْجَمَاجِمُ سَنَةُ ثَلاَثٍ وَثَمَانِينَ ‏.‏ قَالَ أَبُو دَاوُدَ وَالْحَرَّةُ سَنَةُ ثَلاَثٍ وَسِتِّينَ وَقُتِلَ ابْنُ الزُّبَيْرِ سَنَةَ ثَلاَثٍ وَسَبْعِينَ ‏.‏\hadithno{2696}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: Ali separated between a slave-girl and her child. The Prophet (ﷺ) prohibited it and made the sale transactions withdrawn. Abu Dawud said: The narrator Maimun (b. Abi Shaib) did not meet 'Ali. He (Maimun) was killed in the battle of Jamajim in 83 A.H. Abu Dawud said: The battle of Harrah took place in 63 A.H., and Ibn al-Zubair was killed in 73 A.H}}
\hadithdefcmd{abudawud}{2697}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنَا عِكْرِمَةُ، قَالَ حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبِي قَالَ، خَرَجْنَا مَعَ أَبِي بَكْرٍ وَأَمَّرَهُ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَغَزَوْنَا فَزَارَةَ فَشَنَنَّا الْغَارَةَ ثُمَّ نَظَرْتُ إِلَى عُنُقٍ مِنَ النَّاسِ فِيهِ الذُّرِّيَّةُ وَالنِّسَاءُ فَرَمَيْتُ بِسَهْمٍ فَوَقَعَ بَيْنَهُمْ وَبَيْنَ الْجَبَلِ فَقَامُوا فَجِئْتُ بِهِمْ إِلَى أَبِي بَكْرٍ فِيهِمُ امْرَأَةٌ مِنْ فَزَارَةَ وَعَلَيْهَا قِشْعٌ مِنْ أَدَمٍ مَعَهَا بِنْتٌ لَهَا مِنْ أَحْسَنِ الْعَرَبِ فَنَفَّلَنِي أَبُو بَكْرٍ ابْنَتَهَا فَقَدِمْتُ الْمَدِينَةَ فَلَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي ‏"‏ يَا سَلَمَةُ هَبْ لِيَ الْمَرْأَةَ ‏"‏ ‏.‏ فَقُلْتُ وَاللَّهِ لَقَدْ أَعْجَبَتْنِي وَمَا كَشَفْتُ لَهَا ثَوْبًا ‏.‏ فَسَكَتَ حَتَّى إِذَا كَانَ مِنَ الْغَدِ لَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي السُّوقِ فَقَالَ ‏"‏ يَا سَلَمَةُ هَبْ لِيَ الْمَرْأَةَ لِلَّهِ أَبُوكَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا كَشَفْتُ لَهَا ثَوْبًا وَهِيَ لَكَ ‏.‏ فَبَعَثَ بِهَا إِلَى أَهْلِ مَكَّةَ وَفِي أَيْدِيهِمْ أَسْرَى فَفَادَاهُمْ بِتِلْكَ الْمَرْأَةِ ‏.‏\hadithno{2697}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1755)}\hadithtrans{Salamah said “We went out (on an expedition) with Abu Bakr. The Apostle of Allaah(ﷺ) appointed him commander over us. We attacked Fazarah and took them from all sides. I then saw a group of people which contained children and women. I shot an arrow towards them, but it fell between them and the mountain. They stood; I brought them to Abu Bakr. There was among them a woman of Fazarah. She wore a skin over her and her daughter who was the most beautiful of the Arabs was with her. Abu Bakr gave her daughter to me as a reward. I came back to Madeenah. The Apostle of Allaah(ﷺ) met me and said to me “Give me the woman, Salamah. I said to him, I swear by Allaah, she is to my liking and I have not yet untied he garment. He kept silence, and when the next day came the Apostle of Allaah(ﷺ) met me in the market and said to me “Give me the woman, Salamah, by Allaah, your father. I said the Apostle of Allaah, I have not yet untied her garment. I swear by Allaah, she is now yours. He sent her to the people of Makkah who had (some Muslims) prisoners in their hands. They released them for this woman}}
\hadithdefcmd{abudawud}{2698}{حَدَّثَنَا صَالِحُ بْنُ سُهَيْلٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ أَبِي زَائِدَةَ - عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ غُلاَمًا، لاِبْنِ عُمَرَ أَبَقَ إِلَى الْعَدُوِّ فَظَهَرَ عَلَيْهِ الْمُسْلِمُونَ فَرَدَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى ابْنِ عُمَرَ وَلَمْ يُقْسَمْ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ غَيْرُهُ رَدَّهُ عَلَيْهِ خَالِدُ بْنُ الْوَلِيدِ ‏.‏\hadithno{2698}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Nafi' said that a slave of Ibn Umar ran away to the enemy, and then the Muslims overpowered them. The Messenger of Allah (ﷺ) returned him to Ibn Umar and that was not distributed (as a part of booty). Abu Dawud said: The other narrators said: Khalid b. al-Walid returned him to him (Ibd 'Umar)}}
\hadithdefcmd{abudawud}{2699}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، وَالْحَسَنُ بْنُ عَلِيٍّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ ذَهَبَ فَرَسٌ لَهُ فَأَخَذَهَا الْعَدُوُّ فَظَهَرَ عَلَيْهِمُ الْمُسْلِمُونَ فَرُدَّ عَلَيْهِ فِي زَمَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَأَبَقَ عَبْدٌ لَهُ فَلَحِقَ بِأَرْضِ الرُّومِ فَظَهَرَ عَلَيْهِمُ الْمُسْلِمُونَ فَرَدَّهُ عَلَيْهِ خَالِدُ بْنُ الْوَلِيدِ بَعْدَ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2699}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi said that a horse of Ibn ‘Umar went away and the enemy seized it. The Muslims overpowered them. Khalid bin Walid returned it to him after the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{2700}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ مَنْصُورِ بْنِ الْمُعْتَمِرِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ خَرَجَ عِبْدَانٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم - يَعْنِي يَوْمَ الْحُدَيْبِيَةِ - قَبْلَ الصُّلْحِ فَكَتَبَ إِلَيْهِ مَوَالِيهِمْ فَقَالُوا يَا مُحَمَّدُ وَاللَّهِ مَا خَرَجُوا إِلَيْكَ رَغْبَةً فِي دِينِكَ وَإِنَّمَا خَرَجُوا هَرَبًا مِنَ الرِّقِّ فَقَالَ نَاسٌ صَدَقُوا يَا رَسُولَ اللَّهِ رُدَّهُمْ إِلَيْهِمْ ‏.‏ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ مَا أُرَاكُمْ تَنْتَهُونَ يَا مَعْشَرَ قُرَيْشٍ حَتَّى يَبْعَثَ اللَّهُ عَلَيْكُمْ مَنْ يَضْرِبُ رِقَابَكُمْ عَلَى هَذَا ‏"‏ ‏.‏ وَأَبَى أَنْ يَرُدَّهُمْ وَقَالَ ‏"‏ هُمْ عُتَقَاءُ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2700}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: Some slaves (of the unbelievers) went out to the Messenger of Allah (ﷺ) on the day of al-Hudaybiyyah before treaty. Their masters wrote to him saying: O Muhammad, they have not gone out to you with an interest in your religion, but they have gone out to escape from slavery. Some people said: They have spoken the truth, Messenger of Allah, send them back to them. The Messenger of Allah (ﷺ) became angry and said: I do not see your restraining yourself from this action), group of Quraysh, but that Allah send someone to you who strike your necks. He then refused to return them, and said: They are emancipated (slaves) of Allah, the Exalted}}
\hadithdefcmd{abudawud}{2701}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ الزُّبَيْرِيُّ، قَالَ حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ جَيْشًا، غَنِمُوا فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم طَعَامًا وَعَسَلاً فَلَمْ يُؤْخَذْ مِنْهُمُ الْخُمُسُ ‏.‏\hadithno{2701}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: In the time of the Messenger of Allah (ﷺ) an army got food and honey and a fifth was not taken from them}}
\hadithdefcmd{abudawud}{2702}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَالْقَعْنَبِيُّ، قَالاَ حَدَّثَنَا سُلَيْمَانُ، عَنْ حُمَيْدٍ، - يَعْنِي ابْنَ هِلاَلٍ - عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ دُلِّيَ جِرَابٌ مِنْ شَحْمٍ يَوْمَ خَيْبَرَ - قَالَ - فَأَتَيْتُهُ فَالْتَزَمْتُهُ - قَالَ - ثُمَّ قُلْتُ لاَ أُعْطِي مِنْ هَذَا أَحَدًا الْيَوْمَ شَيْئًا - قَالَ - فَالْتَفَتُّ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَبَسَّمُ إِلَىَّ ‏.‏\hadithno{2702}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3153) Sahih Muslim (1772)}\hadithtrans{‘Abd Allaah bin Mughaffal said “On the day of Khaibar a skin of fat was hanging. I came to it and clung to it. I then said (i.e., thought) I shall not give any one any of it today. I then turned round and saw the Apostle of Allaah(ﷺ) smiling at me}}
\hadithdefcmd{abudawud}{2703}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - عَنْ يَعْلَى بْنِ حَكِيمٍ، عَنْ أَبِي لُبَيْدٍ، قَالَ كُنَّا مَعَ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ بِكَابُلَ فَأَصَابَ النَّاسُ غَنِيمَةً فَانْتَهَبُوهَا فَقَامَ خَطِيبًا فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ النُّهْبَى ‏.‏ فَرَدُّوا مَا أَخَذُوا فَقَسَمَهُ بَيْنَهُمْ ‏.‏\hadithno{2703}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbdurRahman ibn Samurah ibn Kabul: AbuLabid said: We were with AbdurRahman ibn Samurah ibn Kabul. The people got booty and plundered it. He stood and addressed (the people): I heard the Messenger of Allah (ﷺ) prohibiting getting property from the booty before its distribution. Therefore, they returned what they had taken, He then distributed it among them}}
\hadithdefcmd{abudawud}{2704}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، عَنْ مُحَمَّدِ بْنِ أَبِي مُجَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ قُلْتُ هَلْ كُنْتُمْ تُخَمِّسُونَ - يَعْنِي الطَّعَامَ - فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَصَبْنَا طَعَامًا يَوْمَ خَيْبَرَ فَكَانَ الرَّجُلُ يَجِيءُ فَيَأْخُذُ مِنْهُ مِقْدَارَ مَا يَكْفِيهِ ثُمَّ يَنْصَرِفُ ‏.‏\hadithno{2704}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn AbuAwfa: Muhammad ibn AbulMujahid reported Abdullah ibn AbuAwfa as saying: I asked: Did you set aside the fifth of the food in the time of the Messenger of Allah (ﷺ)? He replied: On the day of Khaybar we captured food and a man would come and take as much food of it as needed and then go away}}
\hadithdefcmd{abudawud}{2705}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَاصِمٍ، - يَعْنِي ابْنَ كُلَيْبٍ - عَنْ أَبِيهِ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَأَصَابَ النَّاسَ حَاجَةٌ شَدِيدَةٌ وَجَهْدٌ وَأَصَابُوا غَنَمًا فَانْتَهَبُوهَا فَإِنَّ قُدُورَنَا لَتَغْلِي إِذْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي عَلَى قَوْسِهِ فَأَكْفَأَ قُدُورَنَا بِقَوْسِهِ ثُمَّ جَعَلَ يُرَمِّلُ اللَّحْمَ بِالتُّرَابِ ثُمَّ قَالَ ‏"‏ إِنَّ النُّهْبَةَ لَيْسَتْ بِأَحَلَّ مِنَ الْمَيْتَةِ ‏"‏ ‏.‏ أَوْ ‏"‏ إِنَّ الْمَيْتَةَ لَيْسَتْ بِأَحَلَّ مِنَ النُّهْبَةِ ‏"‏ ‏.‏ الشَّكُّ مِنْ هَنَّادٍ ‏.‏\hadithno{2705}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A man of the Ansar: Kulayb reported from a man of the Ansar. He said: We went out with the Messenger of Allah (ﷺ) on a journey. The people suffered from intense need and strain. They gained booty and then plundered it. While our pots were boiling the Messenger of Allah (ﷺ) came walking with his bow touching the ground. He turned over our pots with his bow and smeared the meat with the soil, and said: "Plunder is more unlawful than carrion," or he said: "Carrion is more unlawful than plunder." The narrator Hannad was doubtful}}
\hadithdefcmd{abudawud}{2706}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ ابْنَ حَرْشَفٍ الأَزْدِيَّ، حَدَّثَهُ عَنِ الْقَاسِمِ، مَوْلَى عَبْدِ الرَّحْمَنِ عَنْ بَعْضِ، أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ كُنَّا نَأْكُلُ الْجَزْرَ فِي الْغَزْوِ وَلاَ نَقْسِمُهُ حَتَّى إِنْ كُنَّا لَنَرْجِعُ إِلَى رِحَالِنَا وَأَخْرِجَتُنَا مِنْ��ُ مُمْلاَةٌ ‏.‏\hadithno{2706}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated One of the Companion: Al-Qasim, the client of AbdurRahman, quoted one of the Companion of the Prophet (ﷺ) as saying: We would eat a camel on an expedition without dividing it, and when we returned to our dwellings our saddle-bags would be full with its flesh}}
\hadithdefcmd{abudawud}{2707}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ حَمْزَةَ، قَالَ حَدَّثَنَا أَبُو عَبْدِ الْعَزِيزِ، - شَيْخٌ مِنْ أَهْلِ الأُرْدُنِّ - عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، قَالَ رَابَطْنَا مَدِينَةَ قِنَّسْرِينَ مَعَ شُرَحْبِيلَ بْنِ السِّمْطِ فَلَمَّا فَتَحَهَا أَصَابَ فِيهَا غَنَمًا وَبَقَرًا فَقَسَمَ فِينَا طَائِفَةً مِنْهَا وَجَعَلَ بَقِيَّتَهَا فِي الْمَغْنَمِ فَلَقِيتُ مُعَاذَ بْنَ جَبَلٍ فَحَدَّثْتُهُ فَقَالَ مُعَاذٌ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم خَيْبَرَ فَأَصَبْنَا فِيهَا غَنَمًا فَقَسَمَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم طَائِفَةً وَجَعَلَ بَقِيَّتَهَا فِي الْمَغْنَمِ ‏.‏\hadithno{2707}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'adh ibn Jabal: AbdurRahman ibn Ghanam said: We were stationed at the frontiers of the city of Qinnisrin with Shurahbil ibn as-Simt. When he conquered it, he got sheep and cows there. He distributed some of them amongst us, and deposited the rest of them in the spoils of war. I met Mu'adh ibn Jabal and mentioned it to him. Mu'adh said: we went on an expedition of Khaybar along with the Messenger of Allah (ﷺ) and we got spoils there. The Messenger of Allah (ﷺ) divided them among us and placed the rest of them in the booty}}
\hadithdefcmd{abudawud}{2708}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى - قَالَ أَبُو دَاوُدَ وَأَنَا لِحَدِيثِهِ، أَتْقَنُ - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي مَرْزُوقٍ، مَوْلَى تُجَيْبٍ عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنْ رُوَيْفِعِ بْنِ ثَابِتٍ الأَنْصَارِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَبِالْيَوْمِ الآخِرِ فَلاَ يَرْكَبْ دَابَّةً مِنْ فَىْءِ الْمُسْلِمِينَ حَتَّى إِذَا أَعْجَفَهَا رَدَّهَا فِيهِ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَبِالْيَوْمِ الآخِرِ فَلاَ يَلْبَسْ ثَوْبًا مِنْ فَىْءِ الْمُسْلِمِينَ حَتَّى إِذَا أَخْلَقَهُ رَدَّهُ فِيهِ ‏"‏ ‏.‏\hadithno{2708}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ruwayfi' ibn Thabit al-Ansari: The Prophet (ﷺ) said: He who believes in Allah and the Last Day must not ride on packhorse belonging to the booty of the Muslims and put it back when he has emaciated it; and he who believes in Allah and the Last Day must not wear a garment belonging to the booty of the Muslims and put it back when he made it threadbare}}
\hadithdefcmd{abudawud}{2709}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَخْبَرَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ يُوسُفَ بْنِ إِسْحَاقَ بْنِ أَبِي إِسْحَاقَ السَّبِيعِيَّ - عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ السَّبِيعِيِّ، حَدَّثَنِي أَبُو عُبَيْدَةَ، عَنْ أَبِيهِ، قَالَ مَرَرْتُ فَإِذَا أَبُو جَهْلٍ صَرِيعٌ قَدْ ضُرِبَتْ رِجْلُهُ فَقُلْتُ يَا عَدُوَّ اللَّهِ يَا أَبَا جَهْلٍ قَدْ أَخْزَى اللَّهُ الأَخِرَ ‏.‏ قَالَ وَلاَ أَهَابُهُ عِنْدَ ذَلِكَ ‏.‏ فَقَالَ أَبْعَدُ مِنْ رَجُلٍ قَتَلَهُ قَوْمُهُ فَضَرَبْتُهُ بِسَيْفٍ غَيْرِ طَائِلٍ فَلَمْ يُغْنِ شَيْئًا حَتَّى سَقَطَ سَيْفُهُ مِنْ يَدِهِ فَضَرَبْتُهُ بِهِ حَتَّى بَرَدَ ‏.‏\hadithno{2709}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: I passed when AbuJahl had fallen as his foot was struck (with the swords). I said: O enemy of Allah, AbuJahl, Allah has disgraced a man who was far away from His mercy. I did not fear him at that moment. He replied: It is most strange that a man has been killed by his people. I struck him with a blunt sword. But it did not work, and then his sword fell down from his hand, I struck him with it until he became dead}}
\hadithdefcmd{abudawud}{2710}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ يَحْيَى بْنَ سَعِيدٍ، وَبِشْرَ بْنَ الْمُفَضَّلِ، حَدَّثَاهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَبِي عَمْرَةَ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم تُوُفِّيَ يَوْمَ خَيْبَرَ فَذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَتَغَيَّرَتْ وُجُوهُ النَّاسِ لِذَلِكَ فَقَالَ ‏"‏ إِنَّ صَاحِبَكُمْ غَلَّ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ فَفَتَّشْنَا مَتَاعَهُ فَوَجَدْنَا خَرَزًا مِنْ خَرَزِ يَهُودَ لاَ يُسَاوِي دِرْهَمَيْنِ ‏.‏\hadithno{2710}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zayd ibn Khalid al-Juhani: A man from the Companions of the Prophet (ﷺ) died on the day of Khaybar. They mentioned the matter to the Messenger of Allah. He said: Offer prayer over your companion. When the faces of the people looked perplexed, he said: Your companion misappropriated booty in the path of Allah. We searched his belongings and found some Jewish beads not worth two dirhams}}
\hadithdefcmd{abudawud}{2711}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ أَبِي الْغَيْثِ، مَوْلَى ابْنِ مُطِيعٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ خَيْبَرَ فَلَمْ يَغْنَمْ ذَهَبًا وَلاَ وَرِقًا إِلاَّ الثِّيَابَ وَالْمَتَاعَ وَالأَمْوَالَ - قَالَ - فَوَجَّهَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَحْوَ وَادِي الْقُرَى وَقَدْ أُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم عَبْدٌ أَسْوَدُ يُقَالُ لَهُ مِدْعَمٌ حَتَّى إِذَا كَانُوا بِوَادِي الْقُرَى فَبَيْنَا مِدْعَمٌ يَحُطُّ رَحْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَهُ سَهْمٌ فَقَتَلَهُ فَقَالَ النَّاسُ هَنِيئًا لَهُ الْجَنَّةُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ كَلاَّ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ الشَّمْلَةَ الَّتِي أَخَذَهَا يَوْمَ خَيْبَرَ مِنَ الْمَغَانِمِ لَمْ تُصِبْهَا الْمَقَاسِمُ لَتَشْتَعِلُ عَلَيْهِ نَارًا ‏"‏ ‏.‏ فَلَمَّا سَمِعُوا ذَلِكَ جَاءَ رَجُلٌ بِشِرَاكٍ أَوْ شِرَاكَيْنِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شِرَاكٌ مِنْ نَارٍ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ شِرَاكَانِ مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{2711}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6707) Sahih Muslim (115)}\hadithtrans{Abu Hurairah said “We went out along with the Apostle of Allaah(ﷺ) in the year of Khaibar. We did not get gold or silver in the booty of war except clothes, equipment and property. The Apostle of Allaah(ﷺ) sent (a detachment) towards Wadi Al Qura. The Apostle of Allaah(ﷺ) was presented a black slave called Mid’am. And while they were in Wadi Al Qura and Mid’am was unsaddling a Camel belonging to the Apostle of Allaah(ﷺ) he was struck by a random arrow which killed him. The people said “Congratulations to him, he will go to paradise. But the Apostle of Allaah(ﷺ) said “Not at all. By Him in Whose hand my soul is the cloak he took on the day of Khaibar from the spoils which was not among the shares divided will blaze with fire upon him. When they (the people) heard that, a man brought a sandal strap or two sandal straps to the Apostle of Allaah(ﷺ). The Apostle of Allaah(ﷺ) said “A sandal strap of fire or two sandal straps of fire.”}}
\hadithdefcmd{abudawud}{2712}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى قَالَ أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَوْذَبٍ، قَالَ حَدَّثَنِي عَامِرٌ، - يَعْنِي ابْنَ عَبْدِ الْوَاحِدِ - عَنِ ابْنِ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَصَابَ غَنِيمَةً أَمَرَ بِلاَلاً فَنَادَى فِي النَّاسِ فَيَجِيئُونَ بِغَنَائِمِهِمْ فَيُخَمِّسُهُ وَيُقَسِّمُهُ فَجَاءَ رَجُلٌ بَعْدَ ذَلِكَ بِزِمَامٍ مِنْ شَعَرٍ فَقَالَ يَا رَسُولَ اللَّهِ هَذَا فِيمَا كُنَّا أَصَبْنَاهُ مِنَ الْغَنِيمَةِ ‏.‏ فَقَالَ ‏"‏ أَسَمِعْتَ بِلاَلاً يُنَادِي ‏"‏ ‏.‏ ثَلاَثًا ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا مَنَعَكَ أَنْ تَجِيءَ بِهِ ‏"‏ ‏.‏ فَاعْتَذَرَ إِلَيْهِ فَقَالَ ‏"‏ كُنْ أَنْتَ تَجِيءُ بِهِ يَوْمَ الْقِيَامَةِ فَلَنْ أَقْبَلَهُ عَنْكَ ‏"‏ ‏.‏\hadithno{2712}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: When the Messenger of Allah (ﷺ) gained booty he ordered Bilal to make a public announcement. He made a public announcement, and when the people brought their booty, he would take a fifth and divide it. Thereafter a man brought a halter of hair and said: Messenger of Allah, this is a part of the booty we got. He asked: Have you heard Bilal making announcement three times? He replied: Yes. He asked: What did prevent you from bringing it? He made some excuse, to which he said: Be (as you are), you may bring it on the Day of Judgment, for I shall not accept it from you}}
\hadithdefcmd{abudawud}{2713}{حَدَّثَنَا النُّفَيْلِيُّ، وَسَعِيدُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، - قَالَ النُّفَيْلِيُّ الأَنْدَرَاوَرْدِيُّ - عَنْ صَالِحِ بْنِ مُحَمَّدِ بْنِ زَائِدَةَ، - قَالَ أَبُو دَاوُدَ وَصَالِحٌ هَذَا أَبُو وَاقِدٍ - قَالَ دَخَلْتُ مَعَ مَسْلَمَةَ أَرْضَ الرُّومِ فَأُتِيَ بِرَجُلٍ قَدْ غَلَّ فَسَأَلَ سَالِمًا عَنْهُ فَقَالَ سَمِعْتُ أَبِي يُحَدِّثُ عَنْ عُمَرَ بْنِ الْخَطَّابِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَجَدْتُمُ الرَّجُلَ قَدْ غَلَّ فَأَحْرِقُوا مَتَاعَهُ وَاضْرِبُوهُ ‏"‏ ‏.‏ قَالَ فَوَجَدْنَا فِي مَتَاعِهِ مُصْحَفًا فَسَأَلَ سَالِمًا عَنْهُ فَقَالَ بِعْهُ وَتَصَدَّقْ بِثَمَنِهِ ‏.‏\hadithno{2713}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: Salih ibn Muhammad ibn Za'idah (AbuDawud said: This Salih is AbuWaqid) said: We entered the Byzantine territory with Maslamah. A man who had been dishonest about booty was brought. He (Maslamah) asked Salim about him. He said: I heard my father narrating from Umar ibn al-Khattab from the Prophet (ﷺ). He said: When you find a man who has been dishonest about booty, burn his property, and beat him. He beat him. He said: We found in his property a copy of the Qur'an. He again asked Salim about it. He said: Sell it and give its price in charity}}
\hadithdefcmd{abudawud}{2714}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى الأَنْطَاكِيُّ قَالَ أَخْبَرَنَا أَبُو إِسْحَاقَ، عَنْ صَالِحِ بْنِ مُحَمَّدٍ، قَالَ غَزَوْنَا مَعَ الْوَلِيدِ بْنِ هِشَامٍ وَمَعَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ وَعُمَرُ بْنُ عَبْدِ الْعَزِيزِ فَغَلَّ رَجُلٌ مَتَاعًا فَأَمَرَ الْوَلِيدُ بِمَتَاعِهِ فَأُحْرِقَ وَطِيفَ بِهِ وَلَمْ يُعْطِهِ سَهْمَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا أَصَحُّ الْحَدِيثَيْنِ رَوَاهُ غَيْرُ وَاحِدٍ أَنَّ الْوَلِيدَ بْنَ هِشَامٍ حَرَّقَ رَحْلَ زِيَادِ بْنِ سَعْدٍ - وَكَانَ قَدْ غَلَّ - وَضَرَبَهُ ‏.‏\hadithno{2714}\hadithgrade{Al-Albani: Daif Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Maqtu; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Salih bin Muhammad said “We went out on an expedition with Al Walid bin Hisham and Salim bin ‘Abd Allaah bin ‘Umat and ‘Umar bin ‘Abd Al Aziz were with us. A man had been dishonest about booty. Al Walid ordered to burn his property and it was circulated (among the people). He did not give him his share. Abu Dawud said “This is sounder of the two traditions. Others narrated that Al Walid bin Hashim burnt the Camel saddle of Ziyad bin Sa’d “He had been dishonest about booty and he beat him.”}}
\hadithdefcmd{abudawud}{2715}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ حَرَّقُوا مَتَاعَ الْغَالِّ وَضَرَبُوهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَزَادَ فِيهِ عَلِيُّ بْنُ بَحْرٍ عَنِ الْوَلِيدِ - وَلَمْ أَسْمَعْهُ مِنْهُ - وَمَنَعُوهُ سَهْمَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدَّثَنَا بِهِ الْوَلِيدُ بْنُ عُتْبَةَ وَعَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ قَالاَ حَدَّثَنَا الْوَلِيدُ عَنْ زُهَيْرِ بْنِ مُحَمَّدٍ عَنْ عَمْرِو بْنِ شُعَيْبٍ قَوْلَهُ وَلَمْ يَذْكُرْ عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ الْحَوْطِيُّ مَنَعَ سَهْمَهُ ‏.‏\hadithno{2715}\hadithgrade{Al-Albani: Daif Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ), AbuBakr and Umar burned the belongings of anyone who had been dishonest about booty and beat him. Abu Dawud said: 'Ali b. Bahr added on the authority of al-Walid, and I did not hear (a tradition) from him: And they denied him his share." Abu Dawud said: This tradition has also been transmitted by al-Walid b. 'Utbah from 'Abd al-Wahhab b. Najdah; They said: This has been transmitted by al-Walid, from Zuhair b. Muhammad, from 'Amr b. Shu'aib. 'Abd al-Wahhab b. Najdah al-Huti did not mention the words "He denied him his share" (as narrated by 'Ali b. Bahr from al-Walid)}}
\hadithdefcmd{abudawud}{2716}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ مُوسَى أَبُو دَاوُدَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سَعْدِ بْنِ سَمُرَةَ بْنِ جُنْدُبٍ، حَدَّثَنِي خُبَيْبُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، سُلَيْمَانَ بْنِ سَمُرَةَ عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ أَمَّا بَعْدُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ كَتَمَ غَالاًّ فَإِنَّهُ مِثْلُهُ ‏"‏ ‏.‏\hadithno{2716}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: To begin with, anyone who conceals one who has been dishonest about booty is like him}}
\hadithdefcmd{abudawud}{2717}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُمَرَ بْنِ كَثِيرِ بْنِ أَفْلَحَ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي عَامِ حُنَيْنٍ فَلَمَّا الْتَقَيْنَا كَانَتْ لِلْمُسْلِمِينَ جَوْلَةٌ - قَالَ - فَرَأَيْتُ رَجُلاً مِنَ الْمُشْرِكِينَ قَدْ عَلاَ رَجُلاً مِنَ الْمُسْلِمِينَ - قَالَ - فَاسْتَدَرْتُ لَهُ حَتَّى أَتَيْتُهُ مِنْ وَرَائِهِ فَضَرَبْتُهُ بِالسَّيْفِ عَلَى حَبْلِ عَاتِقِهِ فَأَقْبَلَ عَلَىَّ فَضَمَّنِي ضَمَّةً وَجَدْتُ مِنْهَا رِيحَ الْمَوْتِ ثُمَّ أَدْرَكَهُ الْمَوْتُ فَأَرْسَلَنِي فَلَحِقْتُ عُمَرَ بْنَ الْخَطَّابِ فَقُلْتُ مَا بَالُ النَّاسِ قَالَ أَمْرُ اللَّهِ ‏.‏ ثُمَّ إِنَّ النَّاسَ رَجَعُوا وَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ مَنْ قَتَلَ قَتِيلاً لَهُ عَلَيْهِ بَيِّنَةٌ فَلَهُ سَلَبُهُ ‏"‏ ‏.‏ قَالَ فَقُمْتُ ثُمَّ قُلْتُ مَنْ يَشْهَدُ لِي ثُمَّ جَلَسْتُ ثُمَّ قَالَ ذَلِكَ الثَّانِيَةَ ‏"‏ مَنْ قَتَلَ قَتِيلاً لَهُ عَلَيْهِ بَيِّنَةٌ فَلَهُ سَلَبُهُ ‏"‏ قَالَ فَقُمْتُ ثُمَّ قُلْتُ مَنْ يَشْهَدُ لِي ثُمَّ جَلَسْتُ ثُمَّ قَالَ ذَلِكَ الثَّالِثَةَ فَقُمْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكَ يَا أَبَا قَتَادَةَ ‏"‏ ‏.‏ قَالَ فَاقْتَصَصْتُ عَلَيْهِ الْقِصَّةَ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ صَدَقَ يَا رَسُولَ اللَّهِ وَسَلَبُ ذَلِكَ الْقَتِيلِ عِنْدِي فَأَرْضِهِ مِنْهُ فَقَالَ أَبُو بَكْرٍ الصِّدِّيقُ لاَهَا اللَّهِ إِذًا يَعْمِدُ إِلَى أَسَدٍ مِنْ أُسْدِ اللَّهِ يُقَاتِلُ عَنِ اللَّهِ وَعَنْ رَسُولِهِ فَيُعْطِيكَ سَلَبَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقَ فَأَعْطِهِ إِيَّاهُ ‏"‏ ‏.‏ فَقَالَ أَبُو قَتَادَةَ فَأَعْطَانِيهِ فَبِعْتُ الدِّرْعَ فَابْتَعْتُ بِهِ مَخْرَفًا فِي بَنِي سَلِمَةَ فَإِنَّهُ لأَوَّلُ مَالٍ تَأَثَّلْتُهُ فِي الإِسْلاَمِ ‏.‏\hadithno{2717}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2100) Sahih Muslim (1751)}\hadithtrans{Abu Qatadah said “We went out with the Apostle of Allaah(ﷺ) in the year of Hunain. And when the armies met, the Muslims suffered a reverse. I saw one of the polytheists prevailing over a Muslim, so I went round him till I came to him from behind and struck him with my sword at the vein between his neck and shoulder. He came towards me and closed with me, so that I felt death was near, but he was overtaken by death and let me go. I then caught upon on “Umar bin Al Khattab and said to him “What is the matter with the people?” He said “It is what Allaah has commanded. Then the people returned and the Apostle of Allaah(ﷺ)sat down and said “If anyone kills a man and can prove it, he will get his spoil. I stood up and said “Who will testify for me? I then sat down.” He said again “If anyone kills a man and can prove it, he will get his spoil. I stood up and said “Who will testify for me? I then sat down.” He then said the same for the third time. I then stood up. The Apostle of Allaah(ﷺ) said “What is the matter with you, Abu Qatadah? I told him the story. A man from the people said “He has spoken the truth, and I have this spoil with me, so make him agreeable (to take something in exchange). Abu Bakr said “In that case I swear by Allaah that he must not do so. One of the Allaah’s heroes does not fight for Allaah and his Apostle and then give you his spoil. The Apostle of Allaah(ﷺ) said “He has spoken the truth, hand it over to him. Abu Qatadah said “he handed it over to me, I sold the coat of mail and brought a garden among Banu Salamh. This was the first property I acquired in the Islamic period}}
\hadithdefcmd{abudawud}{2718}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ - يَعْنِي يَوْمَ حُنَيْنٍ - ‏ "‏ مَنْ قَتَلَ كَافِرًا فَلَهُ سَلَبُهُ ‏"‏ ‏.‏ فَقَتَلَ أَبُو طَلْحَةَ يَوْمَئِذٍ عِشْرِينَ رَجُلاً وَأَخَذَ أَسْلاَبَهُمْ وَلَقِيَ أَبُو طَلْحَةَ أُمَّ سُلَيْمٍ وَمَعَهَا خِنْجَرٌ فَقَالَ يَا أُمَّ سُلَيْمٍ مَا هَذَا مَعَكِ قَالَتْ أَرَدْتُ وَاللَّهِ إِنْ دَنَا مِنِّي بَعْضُهُمْ أَبْعَجُ بِهِ بَطْنَهُ ‏.‏ فَأَخْبَرَ بِذَلِكَ أَبُو طَلْحَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ قَالَ أَبُو دَاوُدَ أَرَدْنَا بِهَذَا الْخِنْجَرَ وَكَانَ سِلاَحَ الْعَجَمِ يَوْمَئِذٍ الْخِنْجَرُ ‏.‏\hadithno{2718}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1809)}\hadithtrans{Anas reported the Apostle of Allaah(ﷺ) as saying “He who kills and infidel gets his spoil.” Abu Talhah killed twenty men that day meaning the day of Hunain and got their spoils. Abu Talhah met Umm Sulaim who had a dagger with her. He asked “What is with you, Umm Sulaim”? She replied “I swear by Allaah, I intended that if anyone came near me I would pierce his belly with it. Abu Talhah informed the Apostle of Allaah(ﷺ)about it. Abu Dawud said “This is good (hasan) tradition." Abu Dawud said “By this was meant dagger. The weapon used by the Non – Arabs in those days was dagger.”}}
\hadithdefcmd{abudawud}{2719}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنِي صَفْوَانُ بْنُ عَمْرٍو، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ خَرَجْتُ مَعَ زَيْدِ بْنِ حَارِثَةَ فِي غَزْوَةِ مُؤْتَةَ فَرَافَقَنِي مَدَدِيٌّ مِنْ أَهْلِ الْيَمَنِ لَيْسَ مَعَهُ غَيْرُ سَيْفِهِ فَنَحَرَ رَجُلٌ مِنَ الْمُسْلِمِينَ جَزُورًا فَسَأَلَهُ الْمَدَدِيُّ طَائِفَةً مِنْ جِلْدِهِ فَأَعْطَاهُ إِيَّاهُ فَاتَّخَذَهُ كَهَيْئَةِ الدَّرَقِ وَمَضَيْنَا فَلَقِينَا جُمُوعَ الرُّومِ وَفِيهِمْ رَجُلٌ عَلَى فَرَسٍ لَهُ أَشْقَرَ عَلَيْهِ سَرْجٌ مُذْهَبٌ وَسِلاَحٌ مُذْهَبٌ فَجَعَلَ الرُّومِيُّ يُغْرِي بِالْمُسْلِمِينَ فَقَعَدَ لَهُ الْمَدَدِيُّ خَلْفَ صَخْرَةٍ فَمَرَّ بِهِ الرُّومِيُّ فَعَرْقَبَ فَرَسَهُ فَخَرَّ وَعَلاَهُ فَقَتَلَهُ وَحَازَ فَرَسَهُ وَسِلاَحَهُ فَلَمَّا فَتَحَ اللَّهُ عَزَّ وَجَلَّ لِلْمُسْلِمِينَ بَعَثَ إِلَيْهِ خَالِدُ بْنُ الْوَلِيدِ فَأَخَذَ مِنَ السَّلَبِ قَالَ عَوْفٌ فَأَتَيْتُهُ فَقُلْتُ يَا خَالِدُ أَمَا عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالسَّلَبِ لِلْقَاتِلِ قَالَ بَلَى وَلَكِنِّي اسْتَكْثَرْتُهُ ‏.‏ قُلْتُ لَتَرُدَّنَّهُ عَلَيْهِ أَوْ لأُعَرِّفَنَّكَهَا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَبَى أَنْ يَرُدَّ عَلَيْهِ قَالَ عَوْفٌ فَاجْتَمَعْنَا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَصَصْتُ عَلَيْهِ قِصَّةَ الْمَدَدِيِّ وَمَا فَعَلَ خَالِدٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا خَالِدُ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ ‏"‏ قَالَ يَا رَسُولَ اللَّهِ اسْتَكْثَرْتُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا خَالِدُ رُدَّ عَلَيْهِ مَا أَخَذْتَ مِنْهُ ‏"‏ ‏.‏ قَالَ عَوْفٌ فَقُلْتُ لَهُ دُونَكَ يَا خَالِدُ أَلَمْ أَفِ لَكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا ذَلِكَ ‏"‏ فَأَخْبَرْتُهُ قَالَ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا خَالِدُ لاَ تَرُدَّ عَلَيْهِ هَلْ أَنْتُمْ تَارِكُونَ لِي أُمَرَائِي لَكُمْ صِفْوَةُ أَمْرِهِمْ وَعَلَيْهِمْ كَدَرُهُ ‏"‏ ‏.‏\hadithno{2719}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1753)}\hadithtrans{‘Awf bin malik Al Ashja’I said “I went out with Zaid bin Harith in the battle of Mutah. For the reinforcement of the Muslim army a man from the people of Yemen accompanied me. He had only his sword with him. A man from the Muslims slaughtered a Camel. The man for the reinforcement asked him for a part of its skin which he gave him. He made it like the shape of a shield. We went on and met the Byzantine armies. There was a man among them on a reddish horse with a golden saddle and golden weapons. This Byzantinian soldiers began to attack the Muslims desperately. The man for reinforcement sat behind a rock for (attacking) him. He hamstrung his horse and overpowered him and then killed him. He took his horse and weapons. When Allah, Most High, bestowed victory on the Muslims. Khalid bin Al Walid sent for him and took his spoils. ‘Awf said “I came to him and said “Khalid, do you know that the Apostle of Allaah(ﷺ) had decided to give spoils to the killer? He said “Yes, I thought it abundant. I said “You should return it to him, or I shall tell you about it before the Apostle of Allaah(ﷺ). But he refused to return it. ‘Awf said “We then assembled with the Apostle of Allaah(ﷺ). I told him the story of the man of reinforcement and what Khalid had done. The Apostle of Allaah(ﷺ) said “Khalid, what made you do the work you have done?” He said “Apostle of Allaah(ﷺ), I considered it to be abundant. The Apostle of Allaah(ﷺ) said “Khalid, return it to him what you have taken from him.” ‘Awf said “I said to him “here you are, Khalid. Did I not keep my word? The Apostle of Allaah(ﷺ) said “What is that? I then informed him.” He said “The Apostle of Allaah(ﷺ) became angry and said “Khalid, do not return it to him. Are you going to leave my commanders? You may take from them what is best for you and eave to them what is worst}}
\hadithdefcmd{abudawud}{2720}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ سَأَلْتُ ثَوْرًا عَنْ هَذَا الْحَدِيثِ، فَحَدَّثَنِي عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، نَحْوَهُ ‏.‏\hadithno{2720}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by ‘Awf bin Malik Al Ashja’I through a different chain of narrators}}
\hadithdefcmd{abudawud}{2721}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ صَفْوَانَ بْنِ عَمْرٍو، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، وَخَالِدِ بْنِ الْوَلِيدِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالسَّلَبِ لِلْقَاتِلِ وَلَمْ يُخَمِّسِ السَّلَبَ ‏.‏\hadithno{2721}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Awf ibn Malik al-Ashja'i ; Khalid ibn al-Walid: The Messenger of Allah (ﷺ) gave judgement that the killer should have what was taken from the man he killed, and did not make this subject to division into fifths}}
\hadithdefcmd{abudawud}{2722}{حَدَّثَنَا هَارُونُ بْنُ عَبَّادٍ الأَزْدِيُّ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ نَفَّلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ بَدْرٍ سَيْفَ أَبِي جَهْلٍ كَانَ قَتَلَهُ ‏.‏\hadithno{2722}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: At the battle of Badr the Messenger of Allah gave me AbuJahl's sword, as I had killed him}}
\hadithdefcmd{abudawud}{2723}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ الْوَلِيدِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، أَنَّ عَنْبَسَةَ بْنَ سَعِيدٍ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ سَعِيدَ بْنَ الْعَاصِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَبَانَ بْنَ سَعِيدِ بْنِ الْعَاصِ عَلَى سَرِيَّةٍ مِنَ الْمَدِينَةِ قِبَلَ نَجْدٍ فَقَدِمَ أَبَانُ بْنُ سَعِيدٍ وَأَصْحَابُهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِخَيْبَرَ بَعْدَ أَنْ فَتَحَهَا وَإِنَّ حُزُمَ خَيْلِهِمْ لِيفٌ فَقَالَ أَبَانُ اقْسِمْ لَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَقُلْتُ لاَ تَقْسِمْ لَهُمْ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ أَبَانُ أَنْتَ بِهَا يَا وَبْرُ تَحَدَّرُ عَلَيْنَا مِنْ رَأْسِ ضَالٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اجْلِسْ يَا أَبَانُ ‏"‏ ‏.‏ وَلَمْ يَقْسِمْ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2723}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'id ibn al-'As: The Messenger of Allah (ﷺ) sent AbuSa'id ibn al-'As with an expedition from Medina towards Najd. Aban ibn Sa'id and his companions came to the Messenger of Allah (ﷺ) at Khaybar after it had been captured. The girths of their horses were made of palm fibres. Aban said: Give us a share (from the booty), Messenger of Allah. AbuHurayrah said: I said: Do not give them a share, Messenger of Allah. Aban said: Why are you talking so, Wabr. You have come to us from the peak of Dal. The Prophet (ﷺ) said: Sit down, Aban. The Messenger of Allah (ﷺ) did not give any share to them (from the booty)}}
\hadithdefcmd{abudawud}{2724}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى الْبَلْخِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، وَسَأَلَهُ، إِسْمَاعِيلُ بْنُ أُمَيَّةَ فَحَدَّثَنَاهُ الزُّهْرِيُّ، أَنَّهُ سَمِعَ عَنْبَسَةَ بْنَ سَعِيدٍ الْقُرَشِيَّ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَدِمْتُ الْمَدِينَةَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بِخَيْبَرَ حِينَ افْتَتَحَهَا فَسَأَلْتُهُ أَنْ يُسْهِمَ لِي فَتَكَلَّمَ بَعْضُ وُلْدِ سَعِيدِ بْنِ الْعَاصِ فَقَالَ لاَ تُسْهِمْ لَهُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ فَقُلْتُ هَذَا قَاتِلُ ابْنِ قَوْقَلٍ فَقَالَ سَعِيدُ بْنُ الْعَاصِ يَا عَجَبًا لِوَبْرٍ قَدْ تَدَلَّى عَلَيْنَا مِنْ قَدُومِ ضَالٍ يُعَيِّرُنِي بِقَتْلِ امْرِئٍ مُسْلِمٍ أَكْرَمَهُ اللَّهُ عَلَى يَدَىَّ وَلَمْ يُهِنِّي عَلَى يَدَيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ هَؤُلاَءِ كَانُوا نَحْوَ عَشَرَةٍ فَقُتِلَ مِنْهُمْ سِتَّةٌ وَرَجَعَ مَنْ بَقِيَ ‏.‏\hadithno{2724}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4237)}\hadithtrans{Abu Hurairah said “I came to Madeenah when the Abu Apostle of Allaah(ﷺ) was in Khaibar, after it was captured. I asked him to give me a share from the booty. A son of Sa’id bin Al ‘As spoke and said “Do not give him any share, Apostle of Allaah(ﷺ). I said “This is the killer of Ibn Qauqal.” (The son of) Sa’id bin Al ‘As said “Oh, how wonderful! A Wabr who came down to us from the peak of Dal blames me of having killed a Muslim whom Allaah honored at my hands and did not disgrace me at his hands. Abu Dawud said “They were about ten persons. Six of them were killed and the remaining returned}}
\hadithdefcmd{abudawud}{2725}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدٌ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَدِمْنَا فَوَافَقْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ افْتَتَحَ خَيْبَرَ فَأَسْهَمَ لَنَا أَوْ قَالَ فَأَعْطَانَا مِنْهَا وَمَا قَسَمَ لأَحَدٍ غَابَ عَنْ فَتْحِ خَيْبَرَ مِنْهَا شَيْئًا إِلاَّ لِمَنْ شَهِدَ مَعَهُ إِلاَّ أَصْحَابَ سَفِينَتِنَا جَعْفَرٌ وَأَصْحَابُهُ فَأَسْهَمَ لَهُمْ مَعَهُمْ ‏.‏\hadithno{2725}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4233) Sahih Muslim (2502)}\hadithtrans{Abu Nusa said “We arrived just at the moment when the Apostle of Allaah(ﷺ) conquered Khaibar and he allotted us a portion (or he said he gave us some of it). He allotted nothing to anyone who was not present at the conquest of Khaybar, giving shares only to those who were present with him except for those who were in our ship, Ja’far and his companions to whom he gave (a portion) something along with them}}
\hadithdefcmd{abudawud}{2726}{حَدَّثَنَا مَحْبُوبُ بْنُ مُوسَى أَبُو صَالِحٍ، أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ كُلَيْبِ بْنِ وَائِلٍ، عَنْ هَانِئِ بْنِ قَيْسٍ، عَنْ حَبِيبِ بْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عُمَرَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ - يَعْنِي يَوْمَ بَدْرٍ - فَقَالَ ‏ "‏ إِنَّ عُثْمَانَ انْطَلَقَ فِي حَاجَةِ اللَّهِ وَحَاجَةِ رَسُولِ اللَّهِ وَإِنِّي أُبَايِعُ لَهُ ‏"‏ ‏.‏ فَضَرَبَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَهْمٍ وَلَمْ يَضْرِبْ لأَحَدٍ غَابَ غَيْرُهُ ‏.‏\hadithno{2726}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) stood up, i.e. on the day of Badr, and said: Uthman has gone off on the business of Allah and His Apostle, and I shall take the oath of allegiance on his behalf. The Messenger of Allah (ﷺ) then allotted him a share, but did not do so for anyone else who was absent}}
\hadithdefcmd{abudawud}{2727}{حَدَّثَنَا مَحْبُوبُ بْنُ مُوسَى أَبُو صَالِحٍ، حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ زَائِدَةَ، عَنِ الأَعْمَشِ، عَنِ الْمُخْتَارِ بْنِ صَيْفِيٍّ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، قَالَ كَتَبَ نَجْدَةُ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنْ كَذَا، وَكَذَا، وَذَكَرَ، أَشْيَاءَ وَعَنِ الْمَمْلُوكِ، أَلَهُ فِي الْفَىْءِ شَىْءٌ وَعَنِ النِّسَاءِ، هَلْ كُنَّ يَخْرُجْنَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَهَلْ لَهُنَّ نَصِيبٌ فَقَالَ ابْنُ عَبَّاسٍ لَوْلاَ أَنْ يَأْتِيَ أُحْمُوقَةً مَا كَتَبْتُ إِلَيْهِ أَمَّا الْمَمْلُوكُ فَكَانَ يُحْذَى وَأَمَّا النِّسَاءُ فَقَدْ كُنَّ يُدَاوِينَ الْجَرْحَى وَيَسْقِينَ الْمَاءَ ‏.‏\hadithno{2727}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1812)}\hadithtrans{Narrated Abdullah ibn Abbas: Yazid ibn Hurmuz said: Najdah wrote to Ibn Abbas asking him about such-and-such, and such-and-such, and he mentioned some things; he (asked) about a slave whether he would get something from the spoils; and he (asked) about women whether they used to go out (on expeditions) along with the Messenger of Allah (ﷺ), and whether they would be allotted a share, Ibn Abbas said: Had I not apprehended a folly, I would not have written (a reply) to him. As for the slave, he was given a little of the spoils (as a reward from the booty); as to the women, they would treat the wounded and supply water}}
\hadithdefcmd{abudawud}{2728}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، - يَعْنِي الْوَهْبِيَّ - حَدَّثَنَا ابْنُ إِسْحَاقَ، عَنْ أَبِي جَعْفَرٍ، وَالزُّهْرِيُّ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، قَالَ كَتَبَ نَجْدَةُ الْحَرُورِيُّ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنِ النِّسَاءِ، هَلْ كُنَّ يَشْهَدْنَ الْحَرْبَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهَلْ كَانَ يُضْرَبُ لَهُنَّ بِسَهْمٍ قَالَ فَأَنَا كَتَبْتُ كِتَابَ ابْنِ عَبَّاسٍ إِلَى نَجْدَةَ قَدْ كُنَّ يَحْضُرْنَ الْحَرْبَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَّا أَنْ يُضْرَبَ لَهُنَّ بِسَهْمٍ فَلاَ وَقَدْ كَانَ يُرْضَخُ لَهُنَّ ‏.‏\hadithno{2728}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Yazid bin Humruz said “Najdah Al Hururi wrote to Ibn ‘Abbas asking him whether the women participated in battle along with the Apostle of Allaah(ﷺ) and whether they were allotted a share from the spoils. I (Yazid bin Hurmuz) wrote a letter on behalf of Ibn ‘Abbas to Najdah. They participated in the battle along with the Apostle of Allaah(ﷺ), but no portion (from the spoils) was allotted to them, they were given only a little of it}}
\hadithdefcmd{abudawud}{2729}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ، وَغَيْرُهُ، أَخْبَرَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا رَافِعُ بْنُ سَلَمَةَ بْنِ زِيَادٍ، حَدَّثَنِي حَشْرَجُ بْنُ زِيَادٍ، عَنْ جَدَّتِهِ أُمِّ أَبِيهِ، أَنَّهَا خَرَجَتْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ خَيْبَرَ سَادِسَ سِتِّ نِسْوَةٍ فَبَلَغَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَبَعَثَ إِلَيْنَا فَجِئْنَا فَرَأَيْنَا فِيهِ الْغَضَبَ فَقَالَ ‏"‏ مَعَ مَنْ خَرَجْتُنَّ وَبِإِذْنِ مَنْ خَرَجْتُنَّ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ خَرَجْنَا نَغْزِلُ الشَّعَرَ وَنُعِينُ بِهِ فِي سَبِيلِ اللَّهِ وَمَعَنَا دَوَاءُ الْجَرْحَى وَنُنَاوِلُ السِّهَامَ وَنَسْقِي السَّوِيقَ فَقَالَ ‏"‏ قُمْنَ ‏"‏ حَتَّى إِذَا فَتَحَ اللَّهُ عَلَيْهِ خَيْبَرَ أَسْهَمَ لَنَا كَمَا أَسْهَمَ لِلرِّجَالِ ‏.‏ قَالَ فَقُلْتُ لَهَا يَا جَدَّةُ وَمَا كَانَ ذَلِكَ قَالَتْ تَمْرًا ‏.‏\hadithno{2729}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Ziyad: Hashraj ibn Ziyad reported on the authority of his grandmother that she went out with the Messenger of Allah (ﷺ) for the battle of Khaybar. They were six in number including herself. (She said): When the Messenger of Allah (ﷺ) was informed about it, he sent for us. We came to him, and found him angry. He said: With whom did you come out, and by whose permission did you come out? We said: Messenger of Allah, we have come out to spin the hair, by which we provide aid in the cause of Allah. We have medicine for the wounded, we hand arrows (to the fighters), and supply drink made of wheat or barley. He said: Stand up. When Allah bestowed victory of Khaybar on him, he allotted shares to us from spoils that he allotted to the men. He (Hashraj ibn Ziyad) said: I said to her: Grandmother, what was that? She replied: Dates}}
\hadithdefcmd{abudawud}{2730}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - عَنْ مُحَمَّدِ بْنِ زَيْدٍ، قَالَ حَدَّثَنِي عُمَيْرٌ، مَوْلَى آبِي اللَّحْمِ قَالَ شَهِدْتُ خَيْبَرَ مَعَ سَادَتِي فَكَلَّمُوا فِيَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِي فَقُلِّدْتُ سَيْفًا فَإِذَا أَنَا أَجُرُّهُ فَأُخْبِرَ أَنِّي مَمْلُوكٌ فَأَمَرَ لِي بِشَىْءٍ مِنْ خُرْثِيِّ الْمَتَاعِ ‏.‏ قَالَ أَبُو دَاوُدَ مَعْنَاهُ أَنَّهُ لَمْ يُسْهِمْ لَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ أَبُو عُبَيْدٍ كَانَ حَرَّمَ اللَّحْمَ عَلَى نَفْسِهِ فَسُمِّيَ آبِي اللَّحْمِ ‏.‏\hadithno{2730}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umayr, client of AbulLahm: I was present at Khaybar along with my masters who spoke about me to the Messenger of Allah (ﷺ). He ordered about me, and a sword was girded on me and I was trailing it. He was then informed that I was a slave. He, therefore, ordered that I should be given some inferior goods. Abu Dawud said: This means that he (the Prophet) did not allot a portion of the spoils. Abu Dawud said: Abu 'Ubaid said: As he (the narrator Abi al-Lahm) made eating meat unlawful on himself, he was called Abi al-Lahm (one who hates meat)}}
\hadithdefcmd{abudawud}{2731}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ كُنْتُ أَمِيحُ أَصْحَابِي الْمَاءَ يَوْمَ بَدْرٍ ‏.‏\hadithno{2731}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: I supplied water to my companions on the day of Badr}}
\hadithdefcmd{abudawud}{2732}{حَدَّثَنَا مُسَدَّدٌ، وَيَحْيَى بْنُ مَعِينٍ، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنِ الْفُضَيْلِ، عَنْ عَبْدِ اللَّهِ بْنِ نِيَارٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَ يَحْيَى أَنَّ رَجُلاً، مِنَ الْمُشْرِكِينَ لَحِقَ بِالنَّبِيِّ صلى الله عليه وسلم لِيُقَاتِلَ مَعَهُ فَقَالَ ‏"‏ ارْجِعْ ‏"‏ ‏.‏ ثُمَّ اتَّفَقَا فَقَالَ ‏"‏ إِنَّا لاَ نَسْتَعِينُ بِمُشْرِكٍ ‏"‏ ‏.‏\hadithno{2732}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1817)}\hadithtrans{A’ishah said (this is the version of narrator Yahya). A man from the polytheists accompanied the Prophet (ﷺ) to fight along with him. He said “Go back. Both the narrators (Musaddad and Yahya) then agreed. The Prophet said “We do not want any help from a polytheist.”}}
\hadithdefcmd{abudawud}{2733}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَسْهَمَ لِرَجُلٍ وَلِفَرَسِهِ ثَلاَثَةَ أَسْهُمٍ سَهْمًا لَهُ وَسَهْمَيْنِ لِفَرَسِهِ ‏.‏\hadithno{2733}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (2863) Sahih Muslim (1762)}\hadithtrans{Ibn ‘Umar said “The Apostle of Allaah(ﷺ) allotted three portions for a man and his horse, one for him and two for his horse}}
\hadithdefcmd{abudawud}{2734}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنِي الْمَسْعُودِيُّ، حَدَّثَنِي أَبُو عَمْرَةَ، عَنْ أَبِيهِ، قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْبَعَةَ نَفَرٍ وَمَعَنَا فَرَسٌ فَأَعْطَى كُلَّ إِنْسَانٍ مِنَّا سَهْمًا وَأَعْطَى لِلْفَرَسِ سَهْمَيْنِ ‏.‏\hadithno{2734}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUmrah (al-Ansari?): We four persons, came to the Messenger of Allah (ﷺ), and we (i.e. each one of us) had horses. He therefore, allotted one portion for each of us, and two portions for his horse}}
\hadithdefcmd{abudawud}{2735}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ رَجُلٍ، مِنْ آلِ أَبِي عَمْرَةَ عَنْ أَبِي عَمْرَةَ، بِمَعْنَاهُ إِلاَّ أَنَّهُ قَالَ ثَلاَثَةَ نَفَرٍ ‏.‏ زَادَ فَكَانَ لِلْفَارِسِ ثَلاَثَةُ أَسْهُمٍ ‏.‏\hadithno{2735}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Abu ‘Umrah through a different chain of narrators to the same effect. But this version has “Three Persons” and added “To the horseman three portions.”}}
\hadithdefcmd{abudawud}{2736}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا مُجَمِّعُ بْنُ يَعْقُوبَ بْنِ مُجَمِّعِ بْنِ يَزِيدَ الأَنْصَارِيُّ، قَالَ سَمِعْتُ أَبِي يَعْقُوبَ بْنَ مُجَمِّعٍ، يَذْكُرُ عَنْ عَمِّهِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ الأَنْصَارِيِّ، عَنْ عَمِّهِ، مُجَمِّعِ بْنِ جَارِيَةَ الأَنْصَارِيِّ وَكَانَ أَحَدَ الْقُرَّاءِ الَّذِينَ قَرَءُوا الْقُرْآنَ قَالَ شَهِدْنَا الْحُدَيْبِيَةَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا انْصَرَفْنَا عَنْهَا إِذَا النَّاسُ يَهُزُّونَ الأَبَاعِرَ فَقَالَ بَعْضُ النَّاسِ لِبَعْضٍ مَا لِلنَّاسِ قَالُوا أُوحِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَخَرَجْنَا مَعَ النَّاسِ نُوجِفُ فَوَجَدْنَا النَّبِيَّ صلى الله عليه وسلم وَاقِفًا عَلَى رَاحِلَتِهِ عِنْدَ كُرَاعِ الْغَمِيمِ فَلَمَّا اجْتَمَعَ عَلَيْهِ النَّاسُ قَرَأَ عَلَيْهِمْ ‏\{‏ إِنَّا فَتَحْنَا لَكَ فَتْحًا مُبِينًا ‏\}‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَفَتْحٌ هُوَ قَالَ ‏"‏ نَعَمْ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ إِنَّهُ لَفَتْحٌ ‏"‏ ‏.‏ فَقُسِّمَتْ خَيْبَرُ عَلَى أَهْلِ الْحُدَيْبِيَةِ فَقَسَّمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ثَمَانِيَةَ عَشَرَ سَهْمًا وَكَانَ الْجَيْشُ أَلْفًا وَخَمْسَمِائَةٍ فِيهِمْ ثَلاَثُمِائَةِ فَارِسٍ فَأَعْطَى الْفَارِسَ سَهْمَيْنِ وَأَعْطَى الرَّاجِلَ سَهْمًا ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ أَبِي مُعَاوِيَةَ أَصَحُّ وَالْعَمَلُ عَلَيْهِ وَأَرَى الْوَهَمَ فِي حَدِيثِ مُجَمِّعٍ أَنَّهُ قَالَ ثَلاَثُمِائَةِ فَارِسٍ وَكَانُوا مِائَتَىْ فَارِسٍ ‏.‏\hadithno{2736}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mujammi' ibn Jariyah al-Ansari: Mujammi' was one of the Qur'an-reciters (qaris), and he said: We were present with the Messenger of Allah (ﷺ) at al-Hudaybiyyah. When we returned, the people were driving their camels quickly. The people said to one another: What is the matter with them? They said: Revelation has come down to the Prophet (ﷺ). We also proceeded with the people, galloping (our camels). We found the Prophet (ﷺ) standing on his riding-animal at Kura' al-Ghamim. When the people gathered near him, he recited: "Verily We have granted thee a manifest victory. A man asked: Is this a victory, Messenger of Allah? He replied: Yes. By Him in Whose hands the soul of Muhammad is, this is a victory. Khaybar was divided among those who had been at al-Hudaybiyyah, and the Messenger of Allah (ﷺ) divided it into eighteen portions. The army consisted of one thousand five hundred men, of which three hundred were cavalry, and he gave two shares to a horseman and one to a foot-soldier. Abu Dawud said: Abu Mu'awiyah's tradition is sounder, and it is one which is followed. I think the error is in the tradition of Mujammi', because he said: "three hundred horsemen." when there were only two hundred}}
\hadithdefcmd{abudawud}{2737}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، قَالَ أَخْبَرَنَا خَالِدٌ، عَنْ دَاوُدَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ بَدْرٍ ‏"‏ مَنْ فَعَلَ كَذَا وَكَذَا فَلَهُ مِنَ النَّفْلِ كَذَا وَكَذَا ‏"‏ قَالَ فَتَقَدَّمَ الْفِتْيَانُ وَلَزِمَ الْمَشْيَخَةُ الرَّايَاتِ فَلَمْ يَبْرَحُوهَا فَلَمَّا فَتَحَ اللَّهُ عَلَيْهِمْ قَالَتِ الْمَشْيَخَةُ كُنَّا رِدْءًا لَكُمْ لَوِ انْهَزَمْتُمْ لَفِئْتُمْ إِلَيْنَا فَلاَ تَذْهَبُوا بِالْمَغْنَمِ وَنَبْقَى فَأَبَى الْفِتْيَانُ وَقَالُوا جَعَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لَنَا فَأَنْزَلَ اللَّهُ ‏\{‏ يَسْأَلُونَكَ عَنِ الأَنْفَالِ قُلِ الأَنْفَالُ لِلَّهِ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ كَمَا أَخْرَجَكَ رَبُّكَ مِنْ بَيْتِكَ بِالْحَقِّ وَإِنَّ فَرِيقًا مِنَ الْمُؤْمِنِينَ لَكَارِهُونَ ‏\}‏ يَقُولُ فَكَانَ ذَلِكَ خَيْرًا لَهُمْ فَكَذَلِكَ أَيْضًا فَأَطِيعُونِي فَإِنِّي أَعْلَمُ بِعَاقِبَةِ هَذَا مِنْكُمْ ‏.‏\hadithno{2737}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) said on the day of Badr: He who does such-and-such, will have such-and such. The young men came forward and the old men remained standing near the banners, and they did not move from there. When Allah bestowed victory on them, the old men said: We were support for you. If you had been defeated, you would have returned to us. Do not take this booty alone and we remain (deprived of it). The young men refused (to give), and said: The Messenger of Allah (ﷺ) has given it to us. Then Allah sent down: "They ask thee concerning (things taken as) spoils of war, Say: (Such) spoils are at the disposal of Allah and the Apostle......Just as they Lord ordered thee out of thy house in truth, even though a party among the believers disliked it." This proved good for them. Similarly obey me. I know the consequence of this better than you}}
\hadithdefcmd{abudawud}{2738}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَوْمَ بَدْرٍ ‏ "‏ مَنْ قَتَلَ قَتِيلاً فَلَهُ كَذَا وَكَذَا وَمَنْ أَسَرَ أَسِيرًا فَلَهُ كَذَا وَكَذَا ‏"‏ ثُمَّ سَاقَ نَحْوَهُ وَحَدِيثُ خَالِدٍ أَتَمُّ ‏.‏\hadithno{2738}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) said on the day of Badr: He who kills a man will get such-and-such, and he who captivates a man will get such-and-such. The narrator then transmitted the rest of the tradition in a similar manner. The tradition of Khalid is more perfect}}
\hadithdefcmd{abudawud}{2739}{حَدَّثَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، قَالَ أَخْبَرَنِي دَاوُدُ، بِهَذَا الْحَدِيثِ بِإِسْنَادِهِ قَالَ فَقَسَّمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالسَّوَاءِ ‏.‏ وَحَدِيثُ خَالِدٍ أَتَمُّ ‏.‏\hadithno{2739}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has been transmitted by Dawud with a different chain of narrators. He said “The Apostle of Allaah(ﷺ) apportioned it (spoils of war) equally. The tradition of Khalid is more perfect}}
\hadithdefcmd{abudawud}{2740}{حَدَّثَنِي هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي بَكْرٍ، عَنْ عَاصِمٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ جِئْتُ إِلَى النَّبِي صلى الله عليه وسلم يَوْمَ بَدْرٍ بِسَيْفٍ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ قَدْ شَفَى صَدْرِي الْيَوْمَ مِنَ الْعَدُوِّ فَهَبْ لِي هَذَا السَّيْفَ ‏.‏ قَالَ ‏"‏ إِنَّ هَذَا السَّيْفَ لَيْسَ لِي وَلاَ لَكَ ‏"‏ فَذَهَبْتُ وَأَنَا أَقُولُ يُعْطَاهُ الْيَوْمَ مَنْ لَمْ يُبْلِ بَلاَئِي ‏.‏ فَبَيْنَا أَنَا إِذْ جَاءَنِي الرَّسُولُ فَقَالَ أَجِبْ ‏.‏ فَظَنَنْتُ أَنَّهُ نَزَلَ فِيَّ شَىْءٌ بِكَلاَمِي فَجِئْتُ فَقَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّكَ سَأَلْتَنِي هَذَا السَّيْفَ وَلَيْسَ هُوَ لِي وَلاَ لَكَ وَإِنَّ اللَّهَ قَدْ جَعَلَهُ لِي فَهُوَ لَكَ ثُمَّ قَرَأَ ‏\{‏ يَسْأَلُونَكَ عَنِ الأَنْفَالِ قُلِ الأَنْفَالُ لِلَّهِ وَالرَّسُولِ ‏\}‏ إِلَى آخِرِ الآيَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قِرَاءَةُ ابْنِ مَسْعُودٍ يَسْأَلُونَكَ النَّفْلَ ‏.‏\hadithno{2740}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1748)}\hadithtrans{Mus’ab bin Sa’d reported on the authority of his father (Sa’ad bin Abi Waqqas) “I brought a sword to the Prophet(ﷺ) on the day of the Badr and I said (to him) Apostle of Allaah(ﷺ) , Allaah has healed up my breast from the enemy today, so give me this sword. He said “This sword is neither mine nor yours. I then went away saying “today this will be given to a man who has not been put to trial like me. Meanwhile a messenger and came to me and said “Respond, I thought something was revealed about me owing to my speech. I came and the Prophet (ﷺ) said to me “You asked me for this sword, but this was neither mine nor yours. Now Allaah has given it to me, hence it is yours. He then recited “they ask thee concerning (things taken as) spoils of war. Say “(Such) spoils are at the disposal of Allaah and the Apostle. Abu Dawud said “According to the reading of the Qur’an of Ibn Mas’ud the verse goes. They ask thee concerning (things taken as ) spoils of war}}
\hadithdefcmd{abudawud}{2741}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، ح وَحَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الأَنْطَاكِيُّ، قَالَ حَدَّثَنَا مُبَشِّرٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، أَنَّ الْحَكَمَ بْنَ نَافِعٍ، حَدَّثَهُمْ - الْمَعْنَى، - كُلُّهُمْ عَنْ شُعَيْبِ بْنِ أَبِي حَمْزَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي جَيْشٍ قِبَلَ نَجْدٍ وَانْبَعَثَتْ سَرِيَّةٌ مِنَ الْجَيْشِ فَكَانَ سُهْمَانُ الْجَيْشِ اثْنَىْ عَشَرَ بَعِيرًا اثْنَىْ عَشَرَ بَعِيرًا وَنَفَّلَ أَهْلَ السَّرِيَّةِ بَعِيرًا بَعِيرًا فَكَانَتْ سُهْمَانُهُمْ ثَلاَثَةَ عَشَرَ ثَلاَثَةَ عَشَرَ ‏.‏\hadithno{2741}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) sent us along with an army towards Najd, and he sent a detachment of that army (to face the enemy). The whole army got twelve camels per head as their portion, but he gave the detachment one additional camel (apart from the division made to the army). Thus they got thirteen camels each (as a reward)}}
\hadithdefcmd{abudawud}{2742}{حَدَّثَنَا الْوَلِيدُ بْنُ عُتْبَةَ الدِّمَشْقِيُّ، قَالَ قَالَ الْوَلِيدُ - يَعْنِي ابْنَ مُسْلِمٍ - حَدَّثْتُ ابْنَ الْمُبَارَكِ، بِهَذَا الْحَدِيثِ قُلْتُ وَكَذَا حَدَّثَنَا ابْنُ أَبِي فَرْوَةَ، عَنْ نَافِعٍ، قَالَ لاَ تَعْدِلْ مَنْ سَمَّيْتَ بِمَالِكٍ هَكَذَا أَوْ نَحْوَهُ يَعْنِي مَالِكَ بْنَ أَنَسٍ ‏.‏\hadithno{2742}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al Walid bin Muslim said “I narrated this tradition (mentioned above) to Ibn Al Mubarak and said “And similarly it has been narrated by Ibn Abi Farwah to us on the authority of Nafi’(as narrated by Shu’aib). He (Ibn Al Mubarak) said “Those whom you have named cannot be equal to Malik i.e, Malik bin Anas}}
\hadithdefcmd{abudawud}{2743}{حَدَّثَنَا هَنَّادٌ، قَالَ حَدَّثَنَا عَبْدَةُ، - يَعْنِي ابْنَ سُلَيْمَانَ الْكِلاَبِيَّ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً إِلَى نَجْدٍ فَخَرَجْتُ مَعَهَا فَأَصَبْنَا نَعَمًا كَثِيرًا فَنَفَّلَنَا أَمِيرُنَا بَعِيرًا بَعِيرًا لِكُلِّ إِنْسَانٍ ثُمَّ قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَسَّمَ بَيْنَنَا غَنِيمَتَنَا فَأَصَابَ كُلُّ رَجُلٍ مِنَّا اثْنَىْ عَشَرَ بَعِيرًا بَعْدَ الْخُمُسِ وَمَا حَاسَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالَّذِي أَعْطَانَا صَاحِبُنَا وَلاَ عَابَ عَلَيْهِ بَعْدَ مَا صَنَعَ فَكَانَ لِكُلِّ رَجُلٍ مِنَّا ثَلاَثَةَ عَشَرَ بَعِيرًا بِنَفْلِهِ ‏.‏\hadithno{2743}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) sent a detachment to Najd. I went out along with them, and got abundant riches. Our commander gave each of us a camel as a reward. We then came upon the Messenger of Allah (ﷺ) and he divided the spoils of war among us. Each of us received twelve camels after taking a fifth of it. The Messenger of Allah (ﷺ) did not take account of our companion (i.e. the commander of the army), nor did he blame him for what he had done. Thus each man of us had received thirteen camels with the reward he gave}}
\hadithdefcmd{abudawud}{2744}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، وَيَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ، قَالاَ حَدَّثَنَا اللَّيْثُ، - الْمَعْنَى - عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ سَرِيَّةً فِيهَا عَبْدُ اللَّهِ بْنُ عُمَرَ قِبَلَ نَجْدٍ فَغَنِمُوا إِبِلاً كَثِيرَةً فَكَانَتْ سُهْمَانُهُمُ اثْنَىْ عَشَرَ بَعِيرًا وَنُفِّلُوا بَعِيرًا بَعِيرًا ‏.‏ زَادَ ابْنُ مَوْهَبٍ فَلَمْ يُغَيِّرْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2744}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3134) Sahih Muslim (1749)}\hadithtrans{Nafi’ reported on the authority of ‘Abd Allaah bin ‘Umar “The Apostle of Allaah(ﷺ) sent a detachment towards Najd. ‘Abd Allaah bin ‘Umar also accompanied it. They gained a large number of Camels as a booty. Their portion was twelve Camels each and they were rewarded (in addition) one Camel each. The version of Ibn Mawhab added “The Apostle of Allaah(ﷺ) did not change it”}}
\hadithdefcmd{abudawud}{2745}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَرِيَّةٍ فَبَلَغَتْ سُهْمَانُنَا اثْنَىْ عَشَرَ بَعِيرًا وَنَفَّلَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَعِيرًا بَعِيرًا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ بُرْدُ بْنُ سِنَانٍ عَنْ نَافِعٍ مِثْلَ حَدِيثِ عُبَيْدِ اللَّهِ وَرَوَاهُ أَيُّوبُ عَنْ نَافِعٍ مِثْلَهُ إِلاَّ أَنَّهُ قَالَ وَنُفِّلْنَا بَعِيرًا بَعِيرًا ‏.‏ لَمْ يَذْكُرِ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{2745}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1749)}\hadithtrans{‘Abd Allaah (bin ‘Umar) said “The Apostle of Allaah(ﷺ) sent us along with a detachment. The share of each was twelve Camels. The Apostle of Allaah(ﷺ) gave each one of us a Camel as a reward. Abu Dawud said “Burd bin Sinan narrated a similar tradition from Nafi’ as narrated by ‘Ubaid Allaah. Ayyub also narrated from Nafi’ a similar tradition, but his version goes “We were rewarded one Camel each. He did not mention the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{2746}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، ح وَحَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، قَالَ حَدَّثَنِي حُجَيْنٌ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ كَانَ يُنَفِّلُ بَعْضَ مَنْ يَبْعَثُ مِنَ السَّرَايَا لأَنْفُسِهِمْ خَاصَّةً النَّفْلَ سِوَى قَسْمِ عَامَّةِ الْجَيْشِ وَالْخُمُسُ فِي ذَلِكَ وَاجِبٌ كُلُّهُ ‏.‏\hadithno{2746}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3135) Sahih Muslim (1750)}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) used to give to some of the detachments he sent out (something extra) for themselves in particular apart from the division made to the whole army. The fifth is necessary in all that}}
\hadithdefcmd{abudawud}{2747}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا حُيَىٌّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمَ بَدْرٍ فِي ثَلاَثِمِائَةٍ وَخَمْسَةَ عَشَرَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنَّهُمْ حُفَاةٌ فَاحْمِلْهُمُ اللَّهُمَّ إِنَّهُمْ عُرَاةٌ فَاكْسُهُمُ اللَّهُمَّ إِنَّهُمْ جِيَاعٌ فَأَشْبِعْهُمْ ‏"‏ ‏.‏ فَفَتَحَ اللَّهُ لَهُ يَوْمَ بَدْرٍ فَانْقَلَبُوا حِينَ انْقَلَبُوا وَمَا مِنْهُمْ رَجُلٌ إِلاَّ وَقَدْ رَجَعَ بِجَمَلٍ أَوْ جَمَلَيْنِ وَاكْتَسَوْا وَشَبِعُوا ‏.‏\hadithno{2747}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) went out on the day of Badr along with three hundred and fifteen (men). The Messenger of Allah (ﷺ) said: O Allah, they are on foot, provide mount for them; O Allah , they are naked, clothe them; O Allah, they are hungry, provide food for them. Allah then bestowed victory on them. They returned when they were clothed. There was no man of them but he returned with one or two camels; they were clothed and ate to their fill}}
\hadithdefcmd{abudawud}{2748}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ يَزِيدَ بْنِ جَابِرٍ الشَّامِيِّ، عَنْ مَكْحُولٍ، عَنْ زِيَادِ بْنِ جَارِيَةَ التَّمِيمِيِّ، عَنْ حَبِيبِ بْنِ مَسْلَمَةَ الْفِهْرِيِّ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنَفِّلُ الثُّلُثَ بَعْدَ الْخُمُسِ ‏.‏\hadithno{2748}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Habib ibn Maslamah al-Fihri: The Messenger of Allah (ﷺ) would give a third of the spoils after he would keep off the fifth}}
\hadithdefcmd{abudawud}{2749}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ الْجُشَمِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ مَكْحُولٍ، عَنِ ابْنِ جَارِيَةَ، عَنْ حَبِيبِ بْنِ مَسْلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُنَفِّلُ الرُّبُعَ بَعْدَ الْخُمُسِ وَالثُّلُثَ بَعْدَ الْخُمُسِ إِذَا قَفَلَ ‏.‏\hadithno{2749}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Habib ibn Maslamah: The Messenger of Allah (ﷺ) used to give a quarter of the booty as reward after the fifty had been kept off, and a third after the fifth had been kept off when he returned}}
\hadithdefcmd{abudawud}{2750}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ بَشِيرِ بْنِ ذَكْوَانَ، وَمَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيَّانِ، - الْمَعْنَى - قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، قَالَ سَمِعْتُ أَبَا وَهْبٍ، يَقُولُ سَمِعْتُ مَكْحُولاً، يَقُولُ كُنْتُ عَبْدًا بِمِصْرَ لاِمْرَأَةٍ مِنْ بَنِي هُذَيْلٍ فَأَعْتَقَتْنِي فَمَا خَرَجْتُ مِنْ مِصْرَ وَبِهَا عِلْمٌ إِلاَّ حَوَيْتُ عَلَيْهِ فِيمَا أُرَى ثُمَّ أَتَيْتُ الْحِجَازَ فَمَا خَرَجْتُ مِنْهَا وَبِهَا عِلْمٌ إِلاَّ حَوَيْتُ عَلَيْهِ فِيمَا أُرَى ثُمَّ أَتَيْتُ الْعِرَاقَ فَمَا خَرَجْتُ مِنْهَا وَبِهَا عِلْمٌ إِلاَّ حَوَيْتُ عَلَيْهِ فِيمَا أُرَى ثُمَّ أَتَيْتُ الشَّامَ فَغَرْبَلْتُهَا كُلُّ ذَلِكَ أَسْأَلُ عَنِ النَّفْلِ فَلَمْ أَجِدْ أَحَدًا يُخْبِرُنِي فِيهِ بِشَىْءٍ حَتَّى أَتَيْتُ شَيْخًا يُقَالُ لَهُ زِيَادُ بْنُ جَارِيَةَ التَّمِيمِيُّ فَقُلْتُ لَهُ هَلْ سَمِعْتَ فِي النَّفْلِ شَيْئًا قَالَ نَعَمْ سَمِعْتُ حَبِيبَ بْنَ مَسْلَمَةَ الْفِهْرِيَّ يَقُولُ شَهِدْتُ النَّبِيَّ صلى الله عليه وسلم نَفَّلَ الرُّبُعَ فِي الْبَدْأَةِ وَالثُّلُثَ فِي الرَّجْعَةِ ‏.‏\hadithno{2750}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Habib ibn Maslamah al-Fihri: Makhul said: I was the slave of a woman of Banu Hudhayl; afterwards she emancipated me. I did not leave Egypt until I had acquired all the knowledge that seemed to me to exist there. I then came to al-Hijaz and I did not leave it until I had acquired all the knowledge that seemed to be available. Then I came to al-Iraq, and I did not leave it until I had acquired all the knowledge that seemed to be available. I then came to Syria, and besieged it. I asked everyone about giving rewards from the booty. I did not find anyone who could tell me anything about it. I then met an old man called Ziyad ibn Jariyah at-Tamimi. I asked him: Have you heard anything about giving rewards from the booty? He replied: Yes. I heard Maslamah al-Fihri say: I was present with the Prophet (ﷺ). He gave a quarter of the spoils on the outward journey and a third on the return journey}}
\hadithdefcmd{abudawud}{2751}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ إِسْحَاقَ، - هُوَ مُحَمَّدٌ - بِبَعْضِ هَذَا ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنِي هُشَيْمٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، جَمِيعًا عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْلِمُونَ تَتَكَافَأُ دِمَاؤُهُمْ يَسْعَى بِذِمَّتِهِمْ أَدْنَاهُمْ وَيُجِيرُ عَلَيْهِمْ أَقْصَاهُمْ وَهُمْ يَدٌ عَلَى مَنْ سِوَاهُمْ يَرُدُّ مُشِدُّهُمْ عَلَى مُضْعِفِهِمْ وَمُتَسَرِّعُهُمْ عَلَى قَاعِدِهِمْ لاَ يُقْتَلُ مُؤْمِنٌ بِكَافِرٍ وَلاَ ذُو عَهْدٍ فِي عَهْدِهِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ابْنُ إِسْحَاقَ الْقَوَدَ وَالتَّكَافُؤَ ‏.‏\hadithno{2751}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: Muslims are equal in respect of blood. The lowest of them is entitled to give protection on behalf of them, and the one residing far away may give protection on behalf of them. They are like one hand over against all those who are outside the community. Those who have quick mounts should return to those who have slow mounts, and those who got out along with a detachment (should return) to those who are stationed. A believer shall not be killed for an unbeliever, nor a confederate within the term of confederation with him. Ibn Ishaq did not mention retaliation and equality in respect of blood}}
\hadithdefcmd{abudawud}{2752}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا عِكْرِمَةُ، حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ، عَنْ أَبِيهِ، قَالَ أَغَارَ عَبْدُ الرَّحْمَنِ بْنُ عُيَيْنَةَ عَلَى إِبِلِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَتَلَ رَاعِيَهَا وَخَرَجَ يَطْرُدُهَا هُوَ وَأُنَاسٌ مَعَهُ فِي خَيْلٍ فَجَعَلْتُ وَجْهِي قِبَلَ الْمَدِينَةِ ثُمَّ نَادَيْتُ ثَلاَثَ مَرَّاتٍ يَا صَبَاحَاهُ ‏.‏ ثُمَّ اتَّبَعْتُ الْقَوْمَ فَجَعَلْتُ أَرْمِي وَأَعْقِرُهُمْ فَإِذَا رَجَعَ إِلَىَّ فَارِسٌ جَلَسْتُ فِي أَصْلِ شَجَرَةٍ حَتَّى مَا خَلَقَ اللَّهُ شَيْئًا مِنْ ظَهْرِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ جَعَلْتُهُ وَرَاءَ ظَهْرِي وَحَتَّى أَلْقَوْا أَكْثَرَ مِنْ ثَلاَثِينَ رُمْحًا وَثَلاَثِينَ بُرْدَةً يَسْتَخِفُّونَ مِنْهَا ثُمَّ أَتَاهُمْ عُيَيْنَةُ مَدَدًا فَقَالَ لِيَقُمْ إِلَيْهِ نَفَرٌ مِنْكُمْ ‏.‏ فَقَامَ إِلَىَّ أَرْبَعَةٌ مِنْهُمْ فَصَعِدُوا الْجَبَلَ فَلَمَّا أَسْمَعْتُهُمْ قُلْتُ أَتَعْرِفُونِي قَالُوا وَمَنْ أَنْتَ قُلْتُ أَنَا ابْنُ الأَكْوَعِ وَالَّذِي كَرَّمَ وَجْهَ مُحَمَّدٍ صلى الله عليه وسلم لاَ يَطْلُبُنِي رَجُلٌ مِنْكُمْ فَيُدْرِكُنِي وَلاَ أَطْلُبُهُ فَيَفُوتُنِي ‏.‏ فَمَا بَرِحْتُ حَتَّى نَظَرْتُ إِلَى فَوَارِسِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَتَخَلَّلُونَ الشَّجَرَ أَوَّلُهُمُ الأَخْرَمُ الأَسَدِيُّ فَيَلْحَقُ بِعَبْدِ الرَّحْمَنِ بْنِ عُيَيْنَةَ وَيَعْطِفُ عَلَيْهِ عَبْدُ الرَّحْمَنِ فَاخْتَلَفَا طَعْنَتَيْنِ فَعَقَرَ الأَخْرَمُ عَبْدَ الرَّحْمَنِ وَطَعَنَهُ عَبْدُ الرَّحْمَنِ فَقَتَلَهُ فَتَحَوَّلَ عَبْدُ الرَّحْمَنِ عَلَى فَرَسِ الأَخْرَمِ فَيَلْحَقُ أَبُو قَتَادَةَ بِعَبْدِ الرَّحْمَنِ فَاخْتَلَفَا طَعْنَتَيْنِ فَعَقَرَ بِأَبِي قَتَادَةَ وَقَتَلَهُ أَبُو قَتَادَةَ فَتَحَوَّلَ أَبُو قَتَادَةَ عَلَى فَرَسِ الأَخْرَمِ ثُمَّ جِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمَاءِ الَّذِي جَلَّيْتُهُمْ عَنْهُ ذُو قَرَدٍ فَإِذَا نَبِيُّ اللَّهِ صلى الله عليه وسلم فِي خَمْسِمِائَةٍ فَأَعْطَانِي سَهْمَ الْفَارِسِ وَالرَّاجِلِ ‏.‏\hadithno{2752}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (1807)}\hadithtrans{Salamah (bin Al ‘Akwa) said “Abd Al rahman bin ‘Uyainah raided the Camels of the Apostle of Allaah(ﷺ) and killed their herdsman. He and some people who were with him on horses proceeded on driving them away. I turned my face towards Madeenah and shouted three times. A morning raid, I then went after the people shooting arrows at them and hamstringing them (their beasts). When a horseman returned to me, I sat in the foot of a tree till there was no riding beast of the Prophet (ﷺ) created by Allaah which I had not kept behind my back. They threw away more than thirty lance and thirty cloaks to lighten themselves. Then ‘Uyainah came to them with reinforcement and said “A few of you should go to him. Four of them stood and came to me. They ascended a mountain. Then they came near me till they could hear my voice. I told them “Do you know me?” They said “Who are you? I replied “I am Ibn Al ‘Akwa. By Him Who honored the face of Muhammad (ﷺ) if any man of you pursues he cannot catch me and if I pursue him, I will not miss him. This went on with me till I saw the horsemen of the Apostle of Allaah(ﷺ) coming through the trees. Al Akhram Al Asadi was at their head. He then joined ‘Abd Al Rahman bin ‘Uyainah and ‘Abd Al Rahman turned over him. They attacked each other with lances. Al Akhram hamstrung ‘Abd Al Rahman’s horse and ‘Abd Al Rahman pierced a lance in his body and killed him. ‘Abd al Rahman then returned on the horse of Al Akhram. I then came to the Apostle of Allaah(ﷺ) who was present at the same water from where I drove them away and which is known as Dhu Qarad. The Prophet (ﷺ) was among five hundred people. He then gave me two portions a horseman’s and a footman’s}}
\hadithdefcmd{abudawud}{2753}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي الْجُوَيْرِيَةِ الْجَرْمِيِّ، قَالَ أَصَبْتُ بِأَرْضِ الرُّومِ جَرَّةً حَمْرَاءَ فِيهَا دَنَانِيرُ فِي إِمْرَةِ مُعَاوِيَةَ وَعَلَيْنَا رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْ بَنِي سُلَيْمٍ يُقَالُ لَهُ مَعْنُ بْنُ يَزِيدَ فَأَتَيْتُهُ بِهَا فَقَسَمَهَا بَيْنَ الْمُسْلِمِينَ وَأَعْطَانِي مِنْهَا مِثْلَ مَا أَعْطَى رَجُلاً مِنْهُمْ ثُمَّ قَالَ لَوْلاَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ نَفْلَ إِلاَّ بَعْدَ الْخُمُسِ ‏"‏ ‏.‏ لأَعْطَيْتُكَ ‏.‏ ثُمَّ أَخَذَ يَعْرِضُ عَلَىَّ مِنْ نَصِيبِهِ فَأَبَيْتُ ‏.‏\hadithno{2753}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ma'an ibn Yazid: AbulJuwayriyyah al-Jarmi said: I found a red pitcher containing dinars in Byzantine territory during the reign of Mu'awiyah. A man from the Companions of the Prophet (ﷺ) belonging to Banu Sulaym was our ruler. He was called Ma'an ibn Yazid. I brought it to him. He apportioned it among the Muslims. He gave me the same portion which he gave to one of them. He then said: Had I not heard the Messenger of Allah (ﷺ) say: There is no reward except after taking the fifth (from the booty), I would have given you (the reward). He then presented his own share to me, but I refused}}
\hadithdefcmd{abudawud}{2754}{حَدَّثَنَا هَنَّادٌ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ أَبِي عَوَانَةَ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏\hadithno{2754}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by ‘Asim bin Kulaib through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{2755}{حَدَّثَنَا الْوَلِيدُ بْنُ عُتْبَةَ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ الأَسْوَدَ، قَالَ سَمِعْتُ عَمْرَو بْنَ عَبَسَةَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى بَعِيرٍ مِنَ الْمَغْنَمِ فَلَمَّا سَلَّمَ أَخَذَ وَبَرَةً مِنْ جَنْبِ الْبَعِيرِ ثُمَّ قَالَ ‏ "‏ وَلاَ يَحِلُّ لِي مِنْ غَنَائِمِكُمْ مِثْلُ هَذَا إِلاَّ الْخُمُسَ وَالْخُمُسُ مَرْدُودٌ فِيكُمْ ‏"‏ ‏.‏\hadithno{2755}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Amr ibn Abasah: The Messenger of Allah (ﷺ) led us in prayer facing a camel which had been taken in booty, and when he had given the salutation, he took a hair from the camel's side and said: I have no right as much as this of your booty, but only to the fifth. and the fifth is returned to you}}
\hadithdefcmd{abudawud}{2756}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْغَادِرَ يُنْصَبُ لَهُ لِوَاءٌ يَوْمَ الْقِيَامَةِ فَيُقَالُ هَذِهِ غَدْرَةُ فُلاَنِ بْنِ فُلاَنٍ ‏"‏ ‏.‏\hadithno{2756}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6178) Sahih Muslim (Through Last 1735)}\hadithtrans{Ibn ‘Umar reported the Apostle of Allaah(ﷺ) as saying “A banner will be hoisted for a treacherous man on the Day of Judgment, it will then be announced. This is a treachery of so and so, son of so and so}}
\hadithdefcmd{abudawud}{2757}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الإِمَامُ جُنَّةٌ يُقَاتَلُ بِهِ ‏"‏ ‏.‏\hadithno{2757}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurarirah reported the Apostle of Allaah(ﷺ) as saying “A Muslim ruler is shield by which a battle is fought.”}}
\hadithdefcmd{abudawud}{2758}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنِ الْحَسَنِ بْنِ عَلِيِّ بْنِ أَبِي رَافِعٍ، أَنَّ أَبَا رَافِعٍ، أَخْبَرَهُ قَالَ بَعَثَتْنِي قُرَيْشٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أُلْقِيَ فِي قَلْبِيَ الإِسْلاَمُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي وَاللَّهِ لاَ أَرْجِعُ إِلَيْهِمْ أَبَدًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لاَ أَخِيسُ بِالْعَهْدِ وَلاَ أَحْبِسُ الْبُرُدَ وَلَكِنِ ارْجِعْ فَإِنْ كَانَ فِي نَفْسِكَ الَّذِي فِي نَفْسِكَ الآنَ فَارْجِعْ ‏"‏ ‏.‏ قَالَ فَذَهَبْتُ ثُمَّ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَأَسْلَمْتُ ‏.‏ قَالَ بُكَيْرٌ وَأَخْبَرَنِي أَنَّ أَبَا رَافِعٍ كَانَ قِبْطِيًّا ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا كَانَ فِي ذَلِكَ الزَّمَانِ فَأَمَّا الْيَوْمَ فَلاَ يَصْلُحُ ‏.‏\hadithno{2758}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuRafi': The Quraysh sent me to the Messenger of Allah (ﷺ), and when I saw the Messenger of Allah (ﷺ), Islam was cast into my heart, so I said: Messenger of Allah, I swear by Allah, I shall never return to them. The Messenger of Allah (ﷺ) replied: I do not break a covenant or imprison messengers, but return, and if you feel the same as you do just now, come back. So I went away, and then came to the Prophet (ﷺ) and accepted Islam. The narrator Bukair said: He informed me that Abu Rafi' was a Copt. Abu Dawud said: This was valid in those days, but today it is not valid}}
\hadithdefcmd{abudawud}{2759}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي الْفَيْضِ، عَنْ سُلَيْمِ بْنِ عَامِرٍ، - رَجُلٍ مِنْ حِمْيَرَ - قَالَ كَانَ بَيْنَ مُعَاوِيَةَ وَبَيْنَ الرُّومِ عَهْدٌ وَكَانَ يَسِيرُ نَحْوَ بِلاَدِهِمْ حَتَّى إِذَا انْقَضَى الْعَهْدُ غَزَاهُمْ فَجَاءَ رَجُلٌ عَلَى فَرَسٍ أَوْ بِرْذَوْنٍ وَهُوَ يَقُولُ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ وَفَاءٌ لاَ غَدْرٌ فَنَظَرُوا فَإِذَا عَمْرُو بْنُ عَبَسَةَ فَأَرْسَلَ إِلَيْهِ مُعَاوِيَةُ فَسَأَلَهُ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ كَانَ بَيْنَهُ وَبَيْنَ قَوْمٍ عَهْدٌ فَلاَ يَشُدُّ عُقْدَةً وَلاَ يَحُلُّهَا حَتَّى يَنْقَضِيَ أَمَدُهَا أَوْ يَنْبِذَ إِلَيْهِمْ عَلَى سَوَاءٍ ‏"‏ ‏.‏ فَرَجَعَ مُعَاوِيَةُ ‏.‏\hadithno{2759}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Amr ibn Abasah: Sulaym ibn Amir, a man of Himyar, said: There was a covenant between Mu'awiyah and the Byzantines, and he was going towards their country, and when the covenant came to an end, he attacked them. A man came on a horse, or a packhorse saying, Allah is Most Great, Allah is Most Great; let there be faithfulness and not treachery. And when they looked they found that he was Amr ibn Abasah. Mu'awiyah sent for him and questioned him (about that). He said: I heard the Messenger of Allah (ﷺ) say: When one has covenant with people he must not strengthen or loosen it till its term comes to an end or he brings it to an end in agreement with them (to make both the parties equal). So Mu'awiyah returned}}
\hadithdefcmd{abudawud}{2760}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ مُعَاهِدًا فِي غَيْرِ كُنْهِهِ حَرَّمَ اللَّهُ عَلَيْهِ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{2760}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuBakrah: The Prophet (ﷺ) said: If anyone kills a man whom he grants protection prematurely, Allah will forbid him to enter Paradise}}
\hadithdefcmd{abudawud}{2761}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الْفَضْلِ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ كَانَ مُسَيْلِمَةُ كَتَبَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ وَقَدْ حَدَّثَنِي مُحَمَّدُ بْنُ إِسْحَاقَ عَنْ شَيْخٍ مِنْ أَشْجَعَ يُقَالُ لَهُ سَعْدُ بْنُ طَارِقٍ عَنْ سَلَمَةَ بْنِ نُعَيْمِ بْنِ مَسْعُودٍ الأَشْجَعِيِّ عَنْ أَبِيهِ نُعَيْمٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لَهُمَا حِينَ قَرَآ كِتَابَ مُسَيْلِمَةَ ‏"‏ مَا تَقُولاَنِ أَنْتُمَا ‏"‏ قَالاَ نَقُولُ كَمَا قَالَ ‏.‏ قَالَ ‏"‏ أَمَا وَاللَّهِ لَوْلاَ أَنَّ الرُّسُلَ لاَ تُقْتَلُ لَضَرَبْتُ أَعْنَاقَكُمَا ‏"‏ ‏.‏\hadithno{2761}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Nu'aym ibn Mas'ud: I heard the Messenger of Allah (ﷺ) say when they (messengers sent by Musaylimah) read the letter of Musaylimah: What do you believe yourselves? They said: We believe as he believes. He said: I swear by Allah that were it not that messengers are not killed, I would cut off your heads}}
\hadithdefcmd{abudawud}{2762}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ مُضَرِّبٍ، أَنَّهُ أَتَى عَبْدَ اللَّهِ فَقَالَ مَا بَيْنِي وَبَيْنَ أَحَدٍ مِنَ الْعَرَبِ حِنَةٌ وَإِنِّي مَرَرْتُ بِمَسْجِدٍ لِبَنِي حَنِيفَةَ فَإِذَا هُمْ يُؤْمِنُونَ بِمُسَيْلِمَةَ ‏.‏ فَأَرْسَلَ إِلَيْهِمْ عَبْدُ اللَّهِ فَجِيءَ بِهِمْ فَاسْتَتَابَهُمْ غَيْرَ ابْنِ النَّوَّاحَةِ قَالَ لَهُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْلاَ أَنَّكَ رَسُولٌ لَضَرَبْتُ عُنُقَكَ ‏"‏ ‏.‏ فَأَنْتَ الْيَوْمَ لَسْتَ بِرَسُولٍ فَأَمَرَ قَرَظَةَ بْنَ كَعْبٍ فَضَرَبَ عُنُقَهُ فِي السُّوقِ ثُمَّ قَالَ مَنْ أَرَادَ أَنْ يَنْظُرَ إِلَى ابْنِ النَّوَّاحَةِ قَتِيلاً بِالسُّوقِ ‏.‏\hadithno{2762}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: Harithah ibn Mudarrib said that he came to Abdullah ibn Mas'ud and said (to him): There is no enmity between me and any of the Arabs. I passed a mosque of Banu Hanifah. They (the people) believed in Musaylimah. Abdullah (ibn Mas'ud) sent for them. They were brought, and he asked them to repent, except Ibn an-Nawwahah. He said to him: I heard the Messenger of Allah (ﷺ) say: Were it not that you were not a messenger, I would behead you. But today you are not a messenger. He then ordered Qarazah ibn Ka'b (to kill him). He beheaded him in the market. Anyone who wants to see Ibn an-Nawwahah slain in the market (he may see him)}}
\hadithdefcmd{abudawud}{2763}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عِيَاضُ بْنُ عَبْدِ اللَّهِ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَتْنِي أُمُّ هَانِئٍ بِنْتُ أَبِي طَالِبٍ، أَنَّهَا أَجَارَتْ رَجُلاً مِنَ الْمُشْرِكِينَ يَوْمَ الْفَتْحِ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَتْ لَهُ ذَلِكَ فَقَالَ ‏ "‏ قَدْ أَجَرْنَا مَنْ أَجَرْتِ وَأَمَّنَّا مَنْ أَمَّنْتِ ‏"‏ ‏.‏\hadithno{2763}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn ‘Abbas said “Umm Hani daughter of Abu Talib told me that in the year of the conquest she gave protection to a man from the polytheists. She came to the Prophet (ﷺ) and mentioned it to him. He said “We have given security to those to whom you have given it.”}}
\hadithdefcmd{abudawud}{2764}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَتِ الْمَرْأَةُ لَتُجِيرُ عَلَى الْمُؤْمِنِينَ فَيَجُوزُ ‏.‏\hadithno{2764}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A woman would give security from the believers and it would be allowed}}
\hadithdefcmd{abudawud}{2765}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، أَنَّ مُحَمَّدَ بْنَ ثَوْرٍ، حَدَّثَهُمْ عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم زَمَنَ الْحُدَيْبِيَةِ فِي بِضْعَ عَشَرَةَ مِائَةٍ مِنْ أَصْحَابِهِ حَتَّى إِذَا كَانُوا بِذِي الْحُلَيْفَةِ قَلَّدَ الْهَدْىَ وَأَشْعَرَهُ وَأَحْرَمَ بِالْعُمْرَةِ ‏.‏ وَسَاقَ الْحَدِيثَ قَالَ وَسَارَ النَّبِيُّ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِالثَّنِيَّةِ الَّتِي يُهْبَطُ عَلَيْهِمْ مِنْهَا بَرَكَتْ بِهِ رَاحِلَتُهُ فَقَالَ النَّاسُ حَلْ حَلْ خَلأَتِ الْقَصْوَاءُ ‏.‏ مَرَّتَيْنِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا خَلأَتْ وَمَا ذَلِكَ لَهَا بِخُلُقٍ وَلَكِنْ حَبَسَهَا حَابِسُ الْفِيلِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَسْأَلُونِي الْيَوْمَ خُطَّةً يُعَظِّمُونَ بِهَا حُرُمَاتِ اللَّهِ إِلاَّ أَعْطَيْتُهُمْ إِيَّاهَا ‏"‏ ‏.‏ ثُمَّ زَجَرَهَا فَوَثَبَتْ فَعَدَلَ عَنْهُمْ حَتَّى نَزَلَ بِأَقْصَى الْحُدَيْبِيَةِ عَلَى ثَمَدٍ قَلِيلِ الْمَاءِ فَجَاءَهُ بُدَيْلُ بْنُ وَرْقَاءَ الْخُزَاعِيُّ ثُمَّ أَتَاهُ - يَعْنِي عُرْوَةَ بْنَ مَسْعُودٍ - فَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم فَكُلَّمَا كَلَّمَهُ أَخَذَ بِلِحْيَتِهِ وَالْمُغِيرَةُ بْنُ شُعْبَةَ قَائِمٌ عَلَى النَّبِيِّ صلى الله عليه وسلم وَمَعَهُ السَّيْفُ وَعَلَيْهِ الْمِغْفَرُ فَضَرَبَ يَدَهُ بِنَعْلِ السَّيْفِ وَقَالَ أَخِّرْ يَدَكَ عَنْ لِحْيَتِهِ ‏.‏ فَرَفَعَ عُرْوَةُ رَأْسَهُ فَقَالَ مَنْ هَذَا قَالُوا الْمُغِيرَةُ بْنُ شُعْبَةَ ‏.‏ فَقَالَ أَىْ غُدَرُ أَوَلَسْتُ أَسْعَى فِي غَدْرَتِكَ وَكَانَ الْمُغِيرَةُ صَحِبَ قَوْمًا فِي الْجَاهِلِيَّةِ فَقَتَلَهُمْ وَأَخَذَ أَمْوَالَهُمْ ثُمَّ جَاءَ فَأَسْلَمَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا الإِسْلاَمُ فَقَدْ قَبِلْنَا وَأَمَّا الْمَالُ فَإِنَّهُ مَالُ غَدْرٍ لاَ حَاجَةَ لَنَا فِيهِ ‏"‏ ‏.‏ فَذَكَرَ الْحَدِيثَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اكْتُبْ هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ‏.‏ وَقَصَّ الْخَبَرَ فَقَالَ سُهَيْلٌ وَعَلَى أَنَّهُ لاَ يَأْتِيكَ مِنَّا رَجُلٌ وَإِنْ كَانَ عَلَى دِينِكَ إِلاَّ رَدَدْتَهُ إِلَيْنَا ‏.‏ فَلَمَّا فَرَغَ مِنْ قَضِيَّةِ الْكِتَابِ قَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ قُومُوا فَانْحَرُوا ثُمَّ احْلِقُوا ‏"‏ ‏.‏ ثُمَّ جَاءَ نِسْوَةٌ مُؤْمِنَاتٌ مُهَاجِرَاتٌ الآيَةَ فَنَهَاهُمُ اللَّهُ أَنْ يَرُدُّوهُنَّ وَأَمَرَهُمْ أَنْ يَرُدُّوا الصَّدَاقَ ثُمَّ رَجَعَ إِلَى الْمَدِينَةِ فَجَاءَهُ أَبُو بَصِيرٍ رَجُلٌ مِنْ قُرَيْشٍ - يَعْنِي فَأَرْسَلُوا فِي طَلَبِهِ - فَدَفَعَهُ إِلَى الرَّجُلَيْنِ فَخَرَجَا بِهِ حَتَّى إِذَا بَلَغَا ذَا الْحُلَيْفَةِ نَزَلُوا يَأْكُلُونَ مِنْ تَمْرٍ لَهُمْ فَقَالَ أَبُو بَصِيرٍ لأَحَدِ الرَّجُلَيْنِ وَاللَّهِ إِنِّي لأَرَى سَيْفَكَ هَذَا يَا فُلاَنُ جَيِّدًا ‏.‏ فَاسْتَلَّهُ الآخَرُ فَقَالَ أَجَلْ قَدْ جَرَّبْتُ بِهِ فَقَالَ أَبُو بَصِيرٍ أَرِنِي أَنْظُرْ إِلَيْهِ فَأَمْكَنَهُ مِنْهُ فَضَرَبَهُ حَتَّى بَرَدَ وَفَرَّ الآخَرُ حَتَّى أَتَى الْمَدِينَةَ فَدَخَلَ الْمَسْجِدَ يَعْدُو فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ رَأَى هَذَا ذُعْرًا ‏"‏ ‏.‏ فَقَالَ قَدْ قُتِلَ وَاللَّهِ صَاحِبِي وَإِنِّي لَمَقْتُولٌ فَجَاءَ أَبُو بَصِيرٍ فَقَالَ قَدْ أَوْفَى اللَّهُ ذِمَّتَكَ فَقَدْ رَدَدْتَنِي إِلَيْهِمْ ثُمَّ نَجَّانِي اللَّهُ مِنْهُمْ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَيْلَ أُمِّهِ مِسْعَرَ حَرْبٍ لَوْ كَانَ لَهُ أَحَدٌ ‏"‏ ‏.‏ فَلَمَّا سَمِعَ ذَلِكَ عَرَفَ أَنَّهُ سَيَرُدُّهُ إِلَيْهِمْ فَخَرَجَ حَتَّى أَتَى سِيفَ الْبَحْرِ وَيَنْفَلِتُ أَبُو جَنْدَلٍ فَلَحِقَ بِأَبِي بَصِيرٍ حَتَّى اجْتَمَعَتْ مِنْهُمْ عِصَابَةٌ ‏.‏\hadithno{2765}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2731، 2732)}\hadithtrans{Al Miswar bin Makhramah said :The Messenger of Allah (ﷺ) came out in the year of al-Hudaibbiyyah with over ten hundreds of Companions and when he came to Dhu al Hulaifah. He garlanded and marked the sacrificial animals, and entered the sacred state of Umrah. He then went on with the tradition. The Prophet moved on and when he came to the mountain, pass by which one descends (to Mecca) to them, his riding-beast knelt down, and the people said twice: Go on, go on, al-Qaswa has become jaded. The Prophet (May peace be upon him) said: She has not become jaded and that is not a characteristic of hers, but He Who restrained the elephant has restrained her. He then said: By Him in Whose hand my soul is, they will not ask any me good thing by which they honor which God has made sacred without my giving them it. He then urged her and she leaped up and he turned aside from them, and stopped at the farthest side of al-Hudaibiyyah at a pool with little water. Meanwhile Budail bin Warqa al-Khuza’I came, and ‘Urwah bin Mas’ud joined him. He began to speak to the Prophet (ﷺ). Whenever he spoke to the Prophet (ﷺ), he caught his beard. Al Mughriah bin Shu’bah was standing beside the Prophet (ﷺ).He had a sword with him, wearing a helmet. He (Al Mughriah) struck his (‘Urwah’s) hand with the lower end of his sheath, and said: Keep away your hand from his beard. ‘Urwah then raised his hand and asked: Who is this? They replied: Al-Mughirah bin Shu’bah. He said: O treacherous one! Did I not use my offices in your treachery? In pre-Islamic days Al-Mughirah bin Shu’bah accompanied some people and murdered them, and took their property. He then came (to the Prophet) and embraced Islam. The Prophet (ﷺ) said: As for Islam we accepted it, but as to the property, as it has been taken by treachery, we have no need of it. He went on with the tradition the Prophet (ﷺ) said: Write down: This is what Muhammad, the Messenger of Allah, has decided. He then narrated the tradition. Suhail then said: And that a man will not come to you from us, even if he follows your religion, without you sending him back to us. When he finished drawing up the document, the Prophet (ﷺ) said to his Companions: Get up and sacrifice and then shave. Thereafter some believing women who were immigrants came. (Allah sent down: O yea who believe, when believing women come to you as emigrants). Allah most high forbade them to send them back, but ordered them to restore the dower. He then returned to Medina. Abu Basir a man from the Quraish (who was a Muslim), came to him. And they sent (two men) to look for him; so he handed him over to the two men. They took him away, and when they reached Dhu Al Hulaifah and alighted to eat some dates which they had, Abu Basir said to one of the men : I swear by Allah so-and-so, that I think this sword of yours is a fine one; the other drew the sword and said : Yes I have tried it. Abu Basir said: Let me look at it. He let him have it and he struck him till he died, whereupon the other fled and came to Medina, and running entered the mosque. The Prophet ( may peace be upon him) said: This man has seen something frightful. He said: I swear by Allah that my Companion has been killed, and im as good as dead. Abu Basir then arrived and said: Allah has fulfilled your covenant. You returned me to them, but Allah saved me from them. The Prophet (ﷺ) said: Woe to his mother, stirrer up of war! Would that he had someone (i.e. some kinsfolk). When he heard that he knew that he would send him back to them, so he went out and came to the seashore. Abu Jandal escaped and joined Abu Basir till a band of them collected}}
\hadithdefcmd{abudawud}{2766}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ ابْنَ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَمَرْوَانَ بْنِ الْحَكَمِ، أَنَّهُمُ اصْطَلَحُوا عَلَى وَضْعِ الْحَرْبِ عَشْرَ سِنِينَ يَأْمَنُ فِيهِنَّ النَّاسُ وَعَلَى أَنَّ بَيْنَنَا عَيْبَةً مَكْفُوفَةً وَأَنَّهُ لاَ إِسْلاَلَ وَلاَ إِغْلاَلَ ‏.‏\hadithno{2766}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Al Miswar bin Makhramah and Marwan bin Al Hakam said “They agreed to abandon war for ten years during which the people which have security on the basis that there should be sincerity between them and that there should be not theft or treachery}}
\hadithdefcmd{abudawud}{2767}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، قَالَ مَالَ مَكْحُولٌ وَابْنُ أَبِي زَكَرِيَّاءَ إِلَى خَالِدِ بْنِ مَعْدَانَ وَمِلْتُ مَعَهُمَا فَحَدَّثَنَا عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، قَالَ قَالَ جُبَيْرٌ انْطَلِقْ بِنَا إِلَى ذِي مِخْبَرٍ - رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم - فَأَتَيْنَاهُ فَسَأَلَهُ جُبَيْرٌ عَنِ الْهُدْنَةِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَتُصَالِحُونَ الرُّومَ صُلْحًا آمِنًا وَتَغْزُونَ أَنْتُمْ وَهُمْ عَدُوًّا مِنْ وَرَائِكُمْ ‏"‏ ‏.‏\hadithno{2767}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Dhu Mikhbar: Hassan ibn Atiyyah said: Makhul and Ibn Zakariyya went to Khalid ibn Ma'dan, and I also went along with them. He reported a tradition on the authority of Jubayr ibn Nufayr. He said: Go with us to Dhu Mikhbar, a man from the Companions of the Prophet (ﷺ). We came to him and Jubayr asked him about peace. He said: I heard the Messenger of Allah (ﷺ) say: You will make a secure peace with the Byzantines, then you and they will fight an enemy behind you}}
\hadithdefcmd{abudawud}{2768}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ لِكَعْبِ بْنِ الأَشْرَفِ فَإِنَّهُ قَدْ آذَى اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏ فَقَامَ مُحَمَّدُ بْنُ مَسْلَمَةَ فَقَالَ أَنَا يَا رَسُولَ اللَّهِ أَتُحِبُّ أَنْ أَقْتُلَهُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَأْذَنْ لِي أَنْ أَقُولَ شَيْئًا ‏.‏ قَالَ ‏"‏ نَعَمْ قُلْ ‏"‏ ‏.‏ فَأَتَاهُ فَقَالَ إِنَّ هَذَا الرَّجُلَ قَدْ سَأَلَنَا الصَّدَقَةَ وَقَدْ عَنَّانَا قَالَ وَأَيْضًا لَتَمَلُّنَّهُ ‏.‏ قَالَ اتَّبَعْنَاهُ فَنَحْنُ نَكْرَهُ أَنْ نَدَعَهُ حَتَّى نَنْظُرَ إِلَى أَىِّ شَىْءٍ يَصِيرُ أَمْرُهُ وَقَدْ أَرَدْنَا أَنْ تُسْلِفَنَا وَسْقًا أَوْ وَسْقَيْنِ ‏.‏ قَالَ كَعْبٌ أَىَّ شَىْءٍ تَرْهَنُونِي قَالَ وَمَا تُرِيدُ مِنَّا قَالَ نِسَاءَكُمْ قَالُوا سُبْحَانَ اللَّهِ أَنْتَ أَجْمَلُ الْعَرَبِ نَرْهَنُكَ نِسَاءَنَا فَيَكُونُ ذَلِكَ عَارًا عَلَيْنَا ‏.‏ قَالَ فَتَرْهَنُونِي أَوْلاَدَكُمْ ‏.‏ قَالُوا سُبْحَانَ اللَّهِ يُسَبُّ ابْنُ أَحَدِنَا فَيُقَالُ رُهِنْتَ بِوَسْقٍ أَوْ وَسْقَيْنِ ‏.‏ قَالُوا نَرْهَنُكَ اللأْمَةَ يُرِيدُ السِّلاَحَ قَالَ نَعَمْ ‏.‏ فَلَمَّا أَتَاهُ نَادَاهُ فَخَرَجَ إِلَيْهِ وَهُوَ مُتَطَيِّبٌ يَنْضَخُ رَأْسُهُ فَلَمَّا أَنْ جَلَسَ إِلَيْهِ وَقَدْ كَانَ جَاءَ مَعَهُ بِنَفَرٍ ثَلاَثَةٍ أَوْ أَرْبَعَةٍ فَذَكَرُوا لَهُ قَالَ عِنْدِي فُلاَنَةُ وَهِيَ أَعْطَرُ نِسَاءِ النَّاسِ ‏.‏ قَالَ تَأْذَنُ لِي فَأَشُمُّ قَالَ نَعَمْ ‏.‏ فَأَدْخَلَ يَدَهُ فِي رَأْسِهِ فَشَمَّهُ قَالَ أَعُودُ قَالَ نَعَمْ فَأَدْخَلَ يَدَهُ فِي رَأْسِهِ فَلَمَّا اسْتَمْكَنَ مِنْهُ قَالَ دُونَكُمْ ‏.‏ فَضَرَبُوهُ حَتَّى قَتَلُوهُ ‏.‏\hadithno{2768}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3031) Sahih Muslim (1801)}\hadithtrans{Jabir reported:The Messenger of Allah ( may peace be upon him) said : Who will pursue Ka’b bin Al-Ashraf, for he has caused trouble to Allah and His Apostle? Muhammad bin Maslamah stood up and said: I (shall do), Messenger of Allah. Do you want that I should kill him? He said: Yes. He said: So permit me to say something (against you). He said: Yes say. He then came to him (Ka’b b. al-Ashraf) and said to him: This man has asked us for sadaqah (alms) and has put us into trouble. He (Ka’b) said: You will be more grieved. He (Muhammad bin Maslamah) said: We have followed him and we do not like to forsake him until we see what will be the consequences of his matter. We wished if you could lend us one or two wasqs. Ka’b said: What will you mortgage with me? He asked: what do you want from us? He replied : your Women. They said: Glory be to Allah: You are the most beautiful of the Arabs. If we mortgage our women with you, that will be a disgrace for us. He said “The mortgage your children.” They said “Glory be to Allaah, a son of us may abuse saying “You were mortgaged for one or two wasqs.” They said “We shall mortgage or coat of mail with you. By this he meant arms”. He said “Yes, when he came to him, he called him and he came out while he used perfume and his head was spreading fragrance. When he at with him and he came there accompanied by three or four persons who mentioned his perfume. He said “I have such and such woman with me. She is most fragrant of the women among the people. He (Muhammad bin Maslamah) asked “Do you permit me so that I may smell? He said “Yes. He then entered his hand through his hair and smell it.” He said “May I repeat?” He said “Yes. He again entered his hand through his hair. When he got his complete control, he said “Take him. So he struck him until they killed him.”}}
\hadithdefcmd{abudawud}{2769}{حَدَّثَنَا مُحَمَّدُ بْنُ حُزَابَةَ، حَدَّثَنَا إِسْحَاقُ، - يَعْنِي ابْنَ مَنْصُورٍ - حَدَّثَنَا أَسْبَاطُ الْهَمْدَانِيُّ، عَنِ السُّدِّيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الإِيمَانُ قَيَّدَ الْفَتْكَ لاَ يَفْتِكُ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{2769}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Faith prevented assassination. A believer should not assassinate}}
\hadithdefcmd{abudawud}{2770}{حَدَّثَنِي الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَفَلَ مِنْ غَزْوٍ أَوْ حَجٍّ أَوْ عُمْرَةٍ يُكَبِّرُ عَلَى كُلِّ شَرَفٍ مِنَ الأَرْضِ ثَلاَثَ تَكْبِيرَاتٍ وَيَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ آيِبُونَ تَائِبُونَ عَابِدُونَ سَاجِدُونَ لِرَبِّنَا حَامِدُونَ صَدَقَ اللَّهُ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏\hadithno{2770}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1797) Sahih Muslim (1344)}\hadithtrans{‘Abd Allah bin ‘Umar said “When the Apostle of Allaah(ﷺ) returned from an expedition, Hajj or ‘Umrah on every rising piece of ground he would say three times “Allaah is Most Great” and he would say “There is no god bt Allaah alone who has no partner, to Whom the dominion belongs, to Whom praise is due, and Who is Omnipotent, serving, prostrating ourselves before our Lord and expressing praise. Allaah alone has kept his word, helped His servant and routed the confederate}}
\hadithdefcmd{abudawud}{2771}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ لاَ يَسْتَأْذِنُكَ الَّذِينَ يُؤْمِنُونَ بِاللَّهِ وَالْيَوْمِ الآخِرِ ‏\}‏ الآيَةَ نَسَخَتْهَا الَّتِي فِي النُّورِ ‏\{‏ إِنَّمَا الْمُؤْمِنُونَ الَّذِينَ آمَنُوا بِاللَّهِ وَرَسُولِهِ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ غَفُورٌ رَحِيمٌ ‏\}‏ ‏.‏\hadithno{2771}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Abbas said “The verse “Those who believe in Allaah and the Last Day ask thee for no exemption from fighting with their goods and persons” was abrogated by the verse “Only those are believers who believe in Allaah and His Apostle....For Allaah is Oft-Forgiving, Most Merciful.”}}
\hadithdefcmd{abudawud}{2772}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا عِيسَى، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ تُرِيحُنِي مِنْ ذِي الْخَلَصَةِ ‏"‏ ‏.‏ فَأَتَاهَا فَحَرَّقَهَا ثُمَّ بَعَثَ رَجُلاً مِنْ أَحْمَسَ إِلَى النَّبِيِّ صلى الله عليه وسلم يُبَشِّرُهُ يُكْنَى أَبَا أَرْطَاةَ ‏.‏\hadithno{2772}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3076) Sahih Muslim (2476)}\hadithtrans{Jarir (bin ‘Abd Allaah) said “The Apostle of Allaah(ﷺ) said to me “Why do you not give me rest from Dhu Al Khulasah? He went there and burned it. He then sent a man from Ahmas to the Prophet (ﷺ) to give him good tidings. His surname was Artah}}
\hadithdefcmd{abudawud}{2773}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَدِمَ مِنْ سَفَرٍ بَدَأَ بِالْمَسْجِدِ فَرَكَعَ فِيهِ رَكْعَتَيْنِ ثُمَّ جَلَسَ لِلنَّاسِ ‏.‏ وَقَصَّ ابْنُ السَّرْحِ الْحَدِيثَ قَالَ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُسْلِمِينَ عَنْ كَلاَمِنَا أَيُّهَا الثَّلاَثَةُ حَتَّى إِذَا طَالَ عَلَىَّ تَسَوَّرْتُ جِدَارَ حَائِطِ أَبِي قَتَادَةَ وَهُوَ ابْنُ عَمِّي فَسَلَّمْتُ عَلَيْهِ فَوَاللَّهِ مَا رَدَّ عَلَىَّ السَّلاَمَ ثُمَّ صَلَّيْتُ الصُّبْحَ صَبَاحَ خَمْسِينَ لَيْلَةً عَلَى ظَهْرِ بَيْتٍ مِنْ بُيُوتِنَا فَسَمِعْتُ صَارِخًا يَا كَعْبُ بْنَ مَالِكٍ أَبْشِرْ ‏.‏ فَلَمَّا جَاءَنِي الَّذِي سَمِعْتُ صَوْتَهُ يُبَشِّرُنِي نَزَعْتُ لَهُ ثَوْبَىَّ فَكَسَوْتُهُمَا إِيَّاهُ فَانْطَلَقْتُ حَتَّى إِذَا دَخَلْتُ الْمَسْجِدَ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ فَقَامَ إِلَىَّ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ يُهَرْوِلُ حَتَّى صَافَحَنِي وَهَنَّأَنِي ‏.‏\hadithno{2773}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4676) Sahih Muslim (2769)}\hadithtrans{Ka’ab bin Malik said “When the Prophet(ﷺ) arrived from a journey, he first went to a mosque where he prayed two rak’ahs after which he sat in it and gave audience to the people. The narrator Ibn Al Sarh then narrated the rest of the tradition. He said “The Apostle of Allaah(ﷺ) forbade the Muslims to speak to any three of us. When considerable time had passed on me, I ascended the wall of Abu Qatadah who was my cousin. I saluted him, but, I swear by Allaah he did not return my salutation. I then offered the dawn prayer on the fiftieth day on the roof of one of our houses. I then hear d a crier say “Ka’ab bin Mailk, have good news”. When the man whose voice I heard came to me giving me good news, I took off my garments and clothed him. I went on till I entered the mosque. The Apostle of Allaah(ﷺ) was sitting there. Talhah bin ‘Ubaid Allaah stood up and hastened to me till he shook hands with me and greeted me}}
\hadithdefcmd{abudawud}{2774}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ أَبِي بَكْرَةَ، بَكَّارِ بْنِ عَبْدِ الْعَزِيزِ أَخْبَرَنِي أَبِي عَبْدُ الْعَزِيزِ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ إِذَا جَاءَهُ أَمْرُ سُرُورٍ أَوْ بُشِّرَ بِهِ خَرَّ سَاجِدًا شَاكِرًا لِلَّهِ ‏.‏\hadithno{2774}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuBakrah: When anything came to the Prophet (ﷺ) which caused pleasure (or, by which he was made glad), he prostrated himself in gratitude to Allah}}
\hadithdefcmd{abudawud}{2775}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي مُوسَى بْنُ يَعْقُوبَ، عَنِ ابْنِ عُثْمَانَقَالَ أَبُو دَاوُدَ وَهُوَ يَحْيَى بْنُ الْحَسَنِ بْنِ عُثْمَانَ عَنِ الأَشْعَثِ بْنِ إِسْحَاقَ بْنِ سَعْدٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ مَكَّةَ نُرِيدُ الْمَدِينَةَ فَلَمَّا كُنَّا قَرِيبًا مِنْ عَزْوَرَا نَزَلَ ثُمَّ رَفَعَ يَدَيْهِ فَدَعَا اللَّهَ سَاعَةً ثُمَّ خَرَّ سَاجِدًا فَمَكَثَ طَوِيلاً ثُمَّ قَامَ فَرَفَعَ يَدَيْهِ فَدَعَا اللَّهَ سَاعَةً ثُمَّ خَرَّ سَاجِدًا فَمَكَثَ طَوِيلاً ثُمَّ قَامَ فَرَفَعَ يَدَيْهِ سَاعَةً ثُمَّ خَرَّ سَاجِدًا ذَكَرَهُ أَحْمَدُ ثَلاَثًا قَالَ ‏ "‏ إِنِّي سَأَلْتُ رَبِّي وَشَفَعْتُ لأُمَّتِي فَأَعْطَانِي ثُلُثَ أُمَّتِي فَخَرَرْتُ سَاجِدًا شُكْرًا لِرَبِّي ثُمَّ رَفَعْتُ رَأْسِي فَسَأَلْتُ رَبِّي لأُمَّتِي فَأَعْطَانِي ثُلُثَ أُمَّتِي فَخَرَرْتُ سَاجِدًا لِرَبِّي شُكْرًا ثُمَّ رَفَعْتُ رَأْسِي فَسَأَلْتُ رَبِّي لأُمَّتِي فَأَعْطَانِي الثُّلُثَ الآخَرَ فَخَرَرْتُ سَاجِدًا لِرَبِّي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَشْعَثُ بْنُ إِسْحَاقَ أَسْقَطَهُ أَحْمَدُ بْنُ صَالِحٍ حِينَ حَدَّثَنَا بِهِ فَحَدَّثَنِي بِهِ عَنْهُ مُوسَى بْنُ سَهْلٍ الرَّمْلِيُّ ‏.‏\hadithno{2775}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: We went out with the Messenger of Allah (ﷺ) from Mecca making for Medina. When we were near Azwara', he alighted, then raised his hands, and made supplication to Allah for a time, after which he prostrated himself, remaining a long time in prostration. Then he stood up and raised his hands for a time, after which he prostrated himself, remaining a long time in prostration. He then stood up and raised his hands for a time, after which he prostrated himself. Ahmad mentioned it three times. He then said: I begged my Lord and made intercession for my people, and He gave me a third of my people, so I prostrated myself in gratitude to my Lord. Then I raised my head and begged my Lord for my people, and He gave me a third of my people, so I prostrated myself in gratitude to my Lord. Then I raised my head and begged my Lord for my people and He gave me the remaining third, so I prostrated myself in gratitude to my Lord. Abu Dawud said: When Ahmad b. Salih narrated this tradition to us, he omitted the name of Ash'ath b. Ishaq, but Musa b. Sahl al-Ramli narrated it to us through him}}
\hadithdefcmd{abudawud}{2776}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَكْرَهُ أَنْ يَأْتِيَ الرَّجُلُ أَهْلَهُ طُرُوقًا ‏.‏\hadithno{2776}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5243) Sahih Muslim (715 After 1928)}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) disapproved that a man should come to his family during the night (after returning from a journey)}}
\hadithdefcmd{abudawud}{2777}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحْسَنَ مَا دَخَلَ الرَّجُلُ عَلَى أَهْلِهِ إِذَا قَدِمَ مِنْ سَفَرٍ أَوَّلَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{2777}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5244) Sahih Muslim (715 After 1928)}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: The best time for a man to go in to his family on return from a journey is at the beginning of the night}}
\hadithdefcmd{abudawud}{2778}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَلَمَّا ذَهَبْنَا لِنَدْخُلَ قَالَ ‏ "‏ أَمْهِلُوا حَتَّى نَدْخُلَ لَيْلاً لِكَىْ تَمْتَشِطَ الشَّعِثَةُ وَتَسْتَحِدَّ الْمُغِيبَةُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ الزُّهْرِيُّ الطُّرُوقُ بَعْدَ الْعِشَاءِ ‏.‏ قَالَ أَبُو دَاوُدَ وَبَعْدَ الْمَغْرِبِ لاَ بَأْسَ بِهِ ‏.‏\hadithno{2778}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5247) Sahih Muslim (715 After 1928)}\hadithtrans{Jabir bin ‘Abd Allaah said “We were on a journey with the Apostle of Allaah(ﷺ). When we were going to come to our family, he said “Stay till we enter during the night, so that the disheveled woman combs herself and the woman whose husband has been away cleans herself. Abu Dawud aid “Al Zuhri said “(this prohibition applies) when one arrives after the night prayer. Abu dawud said “There is no harm in coming (to one’s family) after the sunset prayer}}
\hadithdefcmd{abudawud}{2779}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ مِنْ غَزْوَةِ تَبُوكَ تَلَقَّاهُ النَّاسُ فَلَقِيتُهُ مَعَ الصِّبْيَانِ عَلَى ثَنِيَّةِ الْوَدَاعِ ‏.‏\hadithno{2779}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4427)}\hadithtrans{Al Sai’ib bin Yazid said “When the Prophet(ﷺ) turned from the battle of Tabuk to Madeenah, the people received him, I met him along with the children at Thaniyyat Al Wada’}}
\hadithdefcmd{abudawud}{2780}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ فَتًى، مِنْ أَسْلَمَ قَالَ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ الْجِهَادَ وَلَيْسَ لِي مَالٌ أَتَجَهَّزُ بِهِ ‏.‏ قَالَ ‏ "‏ اذْهَبْ إِلَى فُلاَنٍ الأَنْصَارِيِّ فَإِنَّهُ كَانَ قَدْ تَجَهَّزَ فَمَرِضَ فَقُلْ لَهُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقْرِئُكَ السَّلاَمَ وَقُلْ لَهُ ادْفَعْ إِلَىَّ مَا تَجَهَّزْتَ بِهِ ‏"‏ ‏.‏ فَأَتَاهُ فَقَالَ لَهُ ذَلِكَ فَقَالَ لاِمْرَأَتِهِ يَا فُلاَنَةُ ادْفَعِي لَهُ مَا جَهَّزْتِنِي بِهِ وَلاَ تَحْبِسِي مِنْهُ شَيْئًا فَوَاللَّهِ لاَ تَحْبِسِينَ مِنْهُ شَيْئًا فَيُبَارِكَ اللَّهُ فِيهِ ‏.‏\hadithno{2780}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1894)}\hadithtrans{Anas bin Malik said “A youth of Aslam said “Apostle of Allaah(ﷺ), I wish to go on an expedition, but I have no property to make myself equipped. He said “go to so and so Ansari who prepared equipment(for the battle), but he fell ill and tell him that the Apostle of Allaah(ﷺ) has conveyed his regards to you, and then tell him “Give him all the equipment you have made. He came to him and told him that. He said to his wife “O so and so, give him all the equipment I have made and do not detain anything from him. I swear by Allaah, if you detain anything from him, Allaah will not bless it}}
\hadithdefcmd{abudawud}{2781}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، وَالْحَسَنُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ عَبْدِ اللَّهِ بْنِ كَعْبٍ، وَعَمِّهِ، عُبَيْدِ اللَّهِ بْنِ كَعْبٍ عَنْ أَبِيهِمَا، كَعْبِ بْنِ مَالِكٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَقْدِمُ مِنْ سَفَرٍ إِلاَّ نَهَارًا ‏.‏ قَالَ الْحَسَنُ فِي الضُّحَى فَإِذَا قَدِمَ مِنْ سَفَرٍ أَتَى الْمَسْجِدَ فَرَكَعَ فِيهِ رَكْعَتَيْنِ ثُمَّ جَلَسَ فِيهِ ‏.‏\hadithno{2781}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (3088) Sahih Muslim (3769)}\hadithtrans{Ka’ab bin Malik said “The Prophet (ﷺ) used to arrive from a journey in the daytime. Al Hasan said “During the forenoon.” When he arrived from a journey he went first to the mosque where he prayed two rak’ahs after which he sat in it and gave audience to the people}}
\hadithdefcmd{abudawud}{2782}{حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الطُّوسِيُّ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ أَقْبَلَ مِنْ حَجَّتِهِ دَخَلَ الْمَدِينَةَ فَأَنَاخَ عَلَى بَابِ مَسْجِدِهِ ثُمَّ دَخَلَهُ فَرَكَعَ فِيهِ رَكْعَتَيْنِ ثُمَّ انْصَرَفَ إِلَى بَيْتِهِ ‏.‏ قَالَ نَافِعٌ فَكَانَ ابْنُ عُمَرَ كَذَلِكَ يَصْنَعُ ‏.‏\hadithno{2782}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: When the Messenger of Allah (ﷺ) arrived from his hajj, he entered Medina, and made (his camel) kneel down at the gate of his mosque; and he entered it and offered two rak'ahs of prayer; he then returned to his home. Nafi' said: Ibn Umar also used to do so}}
\hadithdefcmd{abudawud}{2783}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ التِّنِّيسِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا الزَّمْعِيُّ، عَنِ الزُّبَيْرِ بْنِ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ سُرَاقَةَ، أَنَّ مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، أَخْبَرَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْقُسَامَةَ ‏"‏ ‏.‏ قَالَ فَقُلْنَا وَمَا الْقُسَامَةُ قَالَ ‏"‏ الشَّىْءُ يَكُونُ بَيْنَ النَّاسِ فَيَجِيءُ فَيَنْتَقِصُ مِنْهُ ‏"‏ ‏.‏\hadithno{2783}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Messenger of Allah (ﷺ) said: Beware of the wages of a distributor of booty (qusamah). We asked: What is qusamah (wages of a distributor)? He said: It means a thing which is shared by the people, and then it is reduced}}
\hadithdefcmd{abudawud}{2784}{حَدَّثَنَا عَبْدُ اللَّهِ الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ شَرِيكٍ، - يَعْنِي ابْنَ أَبِي نَمِرٍ - عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ ‏ "‏ الرَّجُلُ يَكُونُ عَلَى الْفِئَامِ مِنَ النَّاسِ فَيَأْخُذُ مِنْ حَظِّ هَذَا وَحَظِّ هَذَا ‏"‏ ‏.‏\hadithno{2784}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ata' ibn Yasar: Ata' reported a similar tradition (to No 2777) from the Prophet (ﷺ). This version adds: a man is appointed on groups of people, and takes (wages) from the share of this, and from the share of this}}
\hadithdefcmd{abudawud}{2785}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ زَيْدٍ، - يَعْنِي ابْنَ سَلاَّمٍ - أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، يَقُولُ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ سَلْمَانَ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم حَدَّثَهُ قَالَ لَمَّا فَتَحْنَا خَيْبَرَ أَخْرَجُوا غَنَائِمَهُمْ مِنَ الْمَتَاعِ وَالسَّبْىِ فَجَعَلَ النَّاسُ يَتَبَايَعُونَ غَنَائِمَهُمْ فَجَاءَ رَجُلٌ حِينَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ لَقَدْ رَبِحْتُ رِبْحًا مَا رَبِحَ الْيَوْمَ مِثْلَهُ أَحَدٌ مِنْ أَهْلِ هَذَا الْوَادِي قَالَ ‏"‏ وَيْحَكَ وَمَا رَبِحْتَ ‏"‏ ‏.‏ قَالَ مَا زِلْتُ أَبِيعُ وَأَبْتَاعُ حَتَّى رَبِحْتُ ثَلاَثَمِائَةِ أُوقِيَّةٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنَا أُنَبِّئُكَ بِخَيْرِ رَجُلٍ رَبِحَ ‏"‏ ‏.‏ قَالَ مَا هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ رَكْعَتَيْنِ بَعْدَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{2785}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated A man from the Companions of the Prophet: Ubaydullah ibn Salman reported on the authority of a man from the Companions of the Prophet (ﷺ): When we conquered Khaybar, they (the people) took out their spoils which contained equipment and captives. The people began to buy and sell their spoils. When the Messenger of Allah (ﷺ) prayed, a man came to him and said: Messenger of Allah, I have gained today so much so that no one gained from this valley. He asked: Woe unto you, how much did you gain? He replied: I kept on selling and buying until I gained three hundred uqiyahs. The Messenger of Allah (ﷺ) said: I tell you a man who gained better than you. He asked: What is that, Messenger of Allah? He replied! Two rak'ahs (of supererogatory prayer) after the (obligatory) prayer}}
\hadithdefcmd{abudawud}{2786}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، أَخْبَرَنِي أَبِي، عَنْ أَبِي إِسْحَاقَ، عَنْ ذِي الْجَوْشَنِ، - رَجُلٍ مِنَ الضِّبَابِ - قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بَعْدَ أَنْ فَرَغَ مِنْ أَهْلِ بَدْرٍ بِابْنِ فَرَسٍ لِي يُقَالُ لَهَا الْقَرْحَاءُ فَقُلْتُ يَا مُحَمَّدُ إِنِّي قَدْ جِئْتُكَ بِابْنِ الْقَرْحَاءِ لِتَتَّخِذَهُ قَالَ ‏"‏ لاَ حَاجَةَ لِي فِيهِ وَإِنْ شِئْتَ أَنْ أُقِيضَكَ بِهِ الْمُخْتَارَةَ مِنْ دُرُوعِ بَدْرٍ فَعَلْتُ ‏"‏ ‏.‏ قُلْتُ مَا كُنْتُ أُقِيضُهُ الْيَوْمَ بِغُرَّةٍ ‏.‏ قَالَ ‏"‏ فَلاَ حَاجَةَ لِي فِيهِ ‏"‏ ‏.‏\hadithno{2786}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Dhul-Jawshan: A man of ad-Dabab, said: When the Prophet (ﷺ) became free from the people of Badr I brought to him a colt of my mare called al-Qarha' I said: Muhammad, I have brought a colt of a al-Qarha' , so that you may take it. He said: I have no need of it. If you wish that I give you a select coat of mail from (the spoils of) Badr, I shall do it. I said: I cannot give you today a colt in exchange. He said: Then I have no need of it}}
\hadithdefcmd{abudawud}{2787}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ سُفْيَانَ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، أَخْبَرَنَا سُلَيْمَانُ بْنُ مُوسَى أَبُو دَاوُدَ، حَدَّثَنَا جَعْفَرُ بْنُ سَعْدِ بْنِ سَمُرَةَ بْنِ جُنْدُبٍ، حَدَّثَنِي خُبَيْبُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، سُلَيْمَانَ بْنِ سَمُرَةَ عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَمَّا بَعْدُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَامَعَ الْمُشْرِكَ وَسَكَنَ مَعَهُ فَإِنَّهُ مِثْلُهُ ‏"‏ ‏.‏\hadithno{2787}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: To proceed, the Messenger of Allah (ﷺ) said: Anyone who associates with a polytheist and lives with him is like him}}
